@@ -81,7 +81,7 @@
 
 #include "ompi_config.h"
 
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
 
