@@ -10,7 +10,7 @@
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2007-2011 University of Houston. All rights reserved.
- * Copyright (c) 2007-2008 Cisco, Inc. All rights reserved.
+ * Copyright (c) 2007-2008 Cisco Systems, Inc. All rights reserved.
  * Copyright (c) 2009      Sun Microsystems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
@@ -27,12 +27,12 @@
 
 #include "opal/dss/dss.h"
 #include "orte/util/name_fns.h"
+#include "orte/mca/rml/rml_types.h"
 
 #include "ompi/proc/proc.h"
 #include "opal/threads/mutex.h"
 #include "opal/util/bit_ops.h"
-#include "orte/util/show_help.h"
-#include "opal/util/convert.h"
+#include "opal/util/output.h"
 #include "ompi/mca/topo/topo.h"
 #include "ompi/mca/topo/base/base.h"
 #include "ompi/mca/dpm/dpm.h"
@@ -582,12 +582,13 @@ int ompi_comm_split ( ompi_communicator_t* comm, int color, int key,
              newcomp->c_contextid, comm->c_contextid );
 
     /* set the rank to MPI_UNDEFINED. This prevents in comm_activate
-     * the collective module selection for a communicator that will 
+     * the collective module selection for a communicator that will
      * be freed anyway.
      */
-     if ( MPI_UNDEFINED == color ) {
-         newcomp->c_local_group->grp_my_rank = MPI_UNDEFINED;
-     }
+    if ( MPI_UNDEFINED == color ) {
+	newcomp->c_local_group->grp_my_rank = MPI_UNDEFINED;
+    }
+
 
     /* Activate the communicator and init coll-component */
     rc = ompi_comm_activate( &newcomp, /* new communicator */ 
@@ -1000,27 +1001,28 @@ int ompi_comm_free ( ompi_communicator_t **comm )
         ompi_comm_num_dyncomm --;
     }
     OBJ_RELEASE ( (*comm) );
+
     if ( is_extra_retain) {
-	/* This communicator has been marked as an extra_retain
-	 * communicator. This can happen if a communicator creates
-	 * 'dependent' subcommunicators (e.g. for inter
-	 * communicators or when using hierarch collective
-	 * module *and* the cid of the dependent communicator
-	 * turned out to be lower than of the parent one.
-	 * In that case, the reference counter has been increased
-	 * by one more, in order to handle the scenario,
-	 * that the user did not free the communicator. 
-	 * Note, that if we enter this routine, we can 
-	 * decrease the counter by one more therefore. However,
-	 * in ompi_comm_finalize, we only used OBJ_RELEASE instead
-	 * of ompi_comm_free(), and the increased reference counter
-	 * makes sure that the pointer to the dependent communicator
-	 * still contains a valid object.
-	 */ 
-	ompi_communicator_t *tmpcomm = (ompi_communicator_t *) opal_pointer_array_get_item(&ompi_mpi_communicators, cid);
-	if ( NULL != tmpcomm ){
-	    OBJ_RELEASE (tmpcomm);
-	}
+        /* This communicator has been marked as an "extra retain"
+         * communicator. This can happen if a communicator creates
+         * 'dependent' subcommunicators (e.g. for inter
+         * communicators or when using hierarch collective
+         * module *and* the cid of the dependent communicator
+         * turned out to be lower than of the parent one.
+         * In that case, the reference counter has been increased
+         * by one more, in order to handle the scenario,
+         * that the user did not free the communicator.
+         * Note, that if we enter this routine, we can
+         * decrease the counter by one more therefore. However,
+         * in ompi_comm_finalize, we only used OBJ_RELEASE instead
+         * of ompi_comm_free(), and the increased reference counter
+         * makes sure that the pointer to the dependent communicator
+         * still contains a valid object.
+         */
+        ompi_communicator_t *tmpcomm = (ompi_communicator_t *) opal_pointer_array_get_item(&ompi_mpi_communicators, cid);
+        if ( NULL != tmpcomm ){
+            OBJ_RELEASE (tmpcomm);
+        }
     }
 
 
