@@ -6,11 +6,11 @@
  * Copyright (c) 2004-2008 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2008 High Performance Computing Center Stuttgart, 
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2007      Cisco, Inc.  All rights reserved.
+ * Copyright (c) 2007      Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2007      Voltaire All rights reserved.
  * Copyright (c) 2006-2010 University of Houston.  All rights reserved.
  * Copyright (c) 2009      Sun Microsystems, Inc.  All rights reserved.
@@ -24,17 +24,17 @@
 #include "ompi_config.h"
 
 #include "opal/dss/dss.h"
-#include "opal/util/convert.h"
 #include "orte/types.h"
+#include "ompi/proc/proc.h" 
 #include "ompi/communicator/communicator.h"
 #include "ompi/op/op.h"
-#include "ompi/proc/proc.h"
 #include "ompi/constants.h"
 #include "opal/class/opal_pointer_array.h"
 #include "opal/class/opal_list.h"
 #include "ompi/mca/pml/pml.h"
 #include "ompi/mca/coll/base/base.h"
 #include "ompi/request/request.h"
+#include "ompi/runtime/ompi_module_exchange.h" 
 #include "ompi/runtime/mpiruntime.h"
 #include "ompi/mca/dpm/dpm.h"
 
@@ -49,11 +49,6 @@ BEGIN_C_DECLS
  * and a bridge-comm (intercomm-create scenario).
  */
 
-static int cid_block_start = 28;
-
-static int ompi_comm_cid_checkforreuse ( int c_id_start_index, int block );
-static int ompi_comm_get_blocksize ( ompi_communicator_t* comm  );
-
 
 typedef int ompi_comm_cid_allredfct (int *inbuf, int* outbuf, 
                                      int count, struct ompi_op_t *op, 
@@ -117,6 +112,51 @@ static opal_mutex_t ompi_cid_lock;
 static opal_list_t ompi_registered_comms;
 
 
+/* This variable is zero (false) if all processes in MPI_COMM_WORLD
+ * did not require MPI_THREAD_MULTIPLE support, and is 1 (true) as
+ * soon as at least one process requested support for THREAD_MULTIPLE */
+static int ompi_comm_world_thread_level_mult=0;
+
+
+int ompi_comm_cid_init (void)
+{
+    ompi_proc_t **procs, *thisproc;
+    uint8_t thread_level;
+    void *tlpointer;
+    int ret;
+    size_t i, size, numprocs;
+    
+    /** Note that the following call only returns processes
+     * with the same jobid. This is on purpose, since 
+     * we switch for the dynamic communicators anyway 
+     * to the original (slower) cid allocation algorithm.
+     */ 
+    procs = ompi_proc_world ( &numprocs );
+
+    for ( i=0; i<numprocs; i++ ) {
+        thisproc = procs[i];
+       
+        ret = ompi_modex_recv_string("MPI_THREAD_LEVEL", thisproc, &tlpointer, &size);
+        if (OMPI_SUCCESS == ret) {
+            thread_level = *((uint8_t *) tlpointer);
+            if ( OMPI_THREADLEVEL_IS_MULTIPLE (thread_level) ) {
+                ompi_comm_world_thread_level_mult = 1;
+                break;
+            }
+        } else if (OMPI_ERR_NOT_IMPLEMENTED == ret) {
+            if (ompi_mpi_thread_multiple) {
+                ompi_comm_world_thread_level_mult = 1;
+            }
+            break;
+        } else {
+            return ret;
+        }
+    }
+
+    return OMPI_SUCCESS;
+}
+
+
 int ompi_comm_nextcid ( ompi_communicator_t* newcomm, 
                         ompi_communicator_t* comm, 
                         ompi_communicator_t* bridgecomm, 
@@ -124,9 +164,13 @@ int ompi_comm_nextcid ( ompi_communicator_t* newcomm,
                         void* remote_leader,
                         int mode, int send_first )
 {
-    int nextcid, block;
-    int global_block_start;
+    int nextcid;
     bool flag;
+    int nextlocal_cid;
+    int done=0;
+    int response, glresponse=0;
+    int start;
+    unsigned int i;
     
     ompi_comm_cid_allredfct* allredfnct;
 
@@ -153,178 +197,85 @@ int ompi_comm_nextcid ( ompi_communicator_t* newcomm,
             return MPI_UNDEFINED;
             break;
     }
-
-    /*
-     * BWB: Always make the multi-threaded algorithm the selected
-     * algorithm.  The others don't reuse CIDs which leads to CID
-     * space exhaustion in real-world applications. Leave the other
-     * code, as Edgar plans on adding CID reuse in the not-to-distant
-     * future. */
-    /**
-     * In case multi-threading is enabled, we revert to the old algorithm
-     * starting from cid_block_start
-     */
-    if (1 || MPI_THREAD_MULTIPLE == ompi_mpi_thread_provided) {
-        int nextlocal_cid;
-        int done=0;
-        int response, glresponse=0;
-        int start;
-        int i;
-        
-        do {
-            /* Only one communicator function allowed in same time on the
-             * same communicator.
-             */
-            OPAL_THREAD_LOCK(&ompi_cid_lock);
-            response = ompi_comm_register_cid (comm->c_contextid);
-            OPAL_THREAD_UNLOCK(&ompi_cid_lock);
-        } while (OMPI_SUCCESS != response );
-        start = ompi_mpi_communicators.lowest_free;
-
-        while (!done) {
-            /**
-             * This is the real algorithm described in the doc 
-             */
-            
-            OPAL_THREAD_LOCK(&ompi_cid_lock);
-            if (comm->c_contextid != ompi_comm_lowest_cid() ) {
-                /* if not lowest cid, we do not continue, but sleep and try again */
-                OPAL_THREAD_UNLOCK(&ompi_cid_lock);
-                continue;
-            }
-            OPAL_THREAD_UNLOCK(&ompi_cid_lock);
-            
-            
-            for (i=start; i < mca_pml.pml_max_contextid ; i++) {
-                flag=opal_pointer_array_test_and_set_item(&ompi_mpi_communicators, 
-                                                          i, comm);
-                if (true == flag) {
-                    nextlocal_cid = i;
-                    break;
-                }
-            }
-            
-            (allredfnct)(&nextlocal_cid, &nextcid, 1, MPI_MAX, comm, bridgecomm,
-                         local_leader, remote_leader, send_first );
-            if (nextcid == nextlocal_cid) {
-                response = 1; /* fine with me */
-            }
-            else {
-                opal_pointer_array_set_item(&ompi_mpi_communicators, 
-                                            nextlocal_cid, NULL);
-                
-                flag = opal_pointer_array_test_and_set_item(&ompi_mpi_communicators, 
-                                                            nextcid, comm );
-                if (true == flag) {
-                    response = 1; /* works as well */
-                }
-                else {
-                    response = 0; /* nope, not acceptable */
-                }
-            }
-            
-            (allredfnct)(&response, &glresponse, 1, MPI_MIN, comm, bridgecomm,
-                         local_leader, remote_leader, send_first );
-            if (1 == glresponse) {
-                done = 1;             /* we are done */
-                break;
-            }
-            else if ( 0 == glresponse ) {
-                if ( 1 == response ) {
-                    /* we could use that, but other don't agree */
-                    opal_pointer_array_set_item(&ompi_mpi_communicators, 
-                                                nextcid, NULL);
-                }
-                start = nextcid+1; /* that's where we can start the next round */
-            }
-        }
-        
-        /* set the according values to the newcomm */
-        newcomm->c_contextid = nextcid;
-        newcomm->c_f_to_c_index = newcomm->c_contextid;
-        opal_pointer_array_set_item (&ompi_mpi_communicators, nextcid, newcomm);
-        
-        OPAL_THREAD_LOCK(&ompi_cid_lock);
-        ompi_comm_unregister_cid (comm->c_contextid);
-        OPAL_THREAD_UNLOCK(&ompi_cid_lock);
-        
-        return (MPI_SUCCESS);
-    }
-
-     /**
-      * In case the communication mode is INTRA_OOB or INTAR_BRIDGE, we use the 
-      * highest-free algorithm
-      */
-    if ( OMPI_COMM_CID_INTRA_OOB == mode || OMPI_COMM_CID_INTRA_BRIDGE == mode) {       
-        (allredfnct)(&cid_block_start, &global_block_start, 1, 
-                     MPI_MAX, comm, bridgecomm,
-                     local_leader, remote_leader, send_first );
-        cid_block_start = global_block_start;
-        nextcid = cid_block_start;
-        cid_block_start = cid_block_start + 1;
-    }
-    else {
     
-        block = ompi_comm_get_blocksize ( comm  ); 
-
-	/**
-	 * If the communicator has IDs available then allocate one for the child
+    do {
+	/* Only one communicator function allowed in same time on the
+	 * same communicator.
 	 */
-	if ( MPI_UNDEFINED != comm->c_id_available && 
-	     MPI_UNDEFINED != comm->c_id_start_index &&  
-	     block > comm->c_id_available - comm->c_id_start_index) {
-	    nextcid = comm->c_id_available;
-	    flag=opal_pointer_array_test_and_set_item (&ompi_mpi_communicators,
-						       nextcid, comm);
+	OPAL_THREAD_LOCK(&ompi_cid_lock);
+	response = ompi_comm_register_cid (comm->c_contextid);
+	OPAL_THREAD_UNLOCK(&ompi_cid_lock);
+    } while (OMPI_SUCCESS != response );
+    start = ompi_mpi_communicators.lowest_free;
+    
+    while (!done) {
+	/**
+	 * This is the real algorithm described in the doc 
+	 */
+	
+	OPAL_THREAD_LOCK(&ompi_cid_lock);
+	if (comm->c_contextid != ompi_comm_lowest_cid() ) {
+	    /* if not lowest cid, we do not continue, but sleep and try again */
+	    OPAL_THREAD_UNLOCK(&ompi_cid_lock);
+	    continue;
 	}
-	/**
-	 * Otherwise the communicator needs to negotiate a new block of IDs
-	 */
-	else {
-	    int start[3], gstart[3];
-	    /* the next function either returns exactly the same start_id as 
-	       the communicator had, or the cid_block_start*/
-	    start[0] = ompi_comm_cid_checkforreuse ( comm->c_id_start_index, block );
-	    
-	    /* this is now a little tricky. By multiplying the start[0] values with -1
-	       and executing the MAX operation on those as well, we will be able to
-	       determine the minimum value across the provided input */ 
-	    start[1] = (-1) * start[0]; 
-	    start[2] = cid_block_start;
-	    
-	    (allredfnct)(start, gstart, 3, MPI_MAX, comm, bridgecomm,
-			 local_leader, remote_leader, send_first );
-	    
-	    /* revert the minimum value back to a positive number */
-	    gstart[1] = (-1) * gstart[1];
-	    
-	    if  ( gstart[0] == start[0] && 
-		  gstart[1] == start[0] && 
-		  gstart[0] != cid_block_start ) {
-		comm->c_id_available   = gstart[0];
-		comm->c_id_start_index = gstart[0];
-		nextcid                = comm->c_id_available;
-		/* note: cid_block_start not modified in this section */
-	    }
-	    else {
-		/* no, one process did not agree on the reuse of the block
-		   so we have to go with the higher number */
-		comm->c_id_available   = gstart[2];
-		comm->c_id_start_index = gstart[2];
-		cid_block_start        = gstart[2] + block;
-		nextcid                = comm->c_id_available;
+	OPAL_THREAD_UNLOCK(&ompi_cid_lock);
+        
+        
+	for (i=start; i < mca_pml.pml_max_contextid ; i++) {
+	    flag=opal_pointer_array_test_and_set_item(&ompi_mpi_communicators, 
+						      i, comm);
+	    if (true == flag) {
+		nextlocal_cid = i;
+		break;
 	    }
 	}
 	
-	comm->c_id_available++;
+	(allredfnct)(&nextlocal_cid, &nextcid, 1, MPI_MAX, comm, bridgecomm,
+		     local_leader, remote_leader, send_first );
+	if (nextcid == nextlocal_cid) {
+	    response = 1; /* fine with me */
+	}
+	else {
+	    opal_pointer_array_set_item(&ompi_mpi_communicators, 
+					nextlocal_cid, NULL);
+	    
+	    flag = opal_pointer_array_test_and_set_item(&ompi_mpi_communicators, 
+							nextcid, comm );
+	    if (true == flag) {
+		response = 1; /* works as well */
+	    }
+	    else {
+		response = 0; /* nope, not acceptable */
+	    }
+	}
+        
+	(allredfnct)(&response, &glresponse, 1, MPI_MIN, comm, bridgecomm,
+		     local_leader, remote_leader, send_first );
+	if (1 == glresponse) {
+	    done = 1;             /* we are done */
+	    break;
+	}
+	else if ( 0 == glresponse ) {
+	    if ( 1 == response ) {
+		/* we could use that, but other don't agree */
+		opal_pointer_array_set_item(&ompi_mpi_communicators, 
+					    nextcid, NULL);
+	    }
+	    start = nextcid+1; /* that's where we can start the next round */
+	}
     }
+    
     /* set the according values to the newcomm */
     newcomm->c_contextid = nextcid;
     newcomm->c_f_to_c_index = newcomm->c_contextid;
     opal_pointer_array_set_item (&ompi_mpi_communicators, nextcid, newcomm);
-
+    
+    OPAL_THREAD_LOCK(&ompi_cid_lock);
+    ompi_comm_unregister_cid (comm->c_contextid);
+    OPAL_THREAD_UNLOCK(&ompi_cid_lock);
+    
     return (MPI_SUCCESS);
-
 }
 
 /**************************************************************************/
@@ -367,7 +318,7 @@ static int ompi_comm_register_cid (uint32_t cid )
             if ( regcom->cid > cid ) {
                 break;
             }
-#if OMPI_ENABLE_MPI_THREADS
+#if OMPI_ENABLE_THREAD_MULTIPLE
             if( regcom->cid == cid ) {
                 /**
                  * The MPI standard state that is the user responsability to
@@ -380,7 +331,7 @@ static int ompi_comm_register_cid (uint32_t cid )
                 OBJ_RELEASE(newentry);
                 return OMPI_ERROR;
             }
-#endif  /* OMPI_ENABLE_MPI_THREADS */
+#endif  /* OMPI_ENABLE_THREAD_MULTIPLE */
         }
         opal_list_insert_pos (&ompi_registered_comms, item, 
                               (opal_list_item_t *)newentry);
@@ -519,31 +470,31 @@ int ompi_comm_activate ( ompi_communicator_t** newcomm,
 	goto bail_on_error;
     }
 
-
-    /* For an inter communicator, we have to deal with the potential 
+    /* For an inter communicator, we have to deal with the potential
      * problem of what is happening if the local_comm that we created
-     * has a lower CID than the parent comm. This is not a problem 
+     * has a lower CID than the parent comm. This is not a problem
      * as long as the user calls MPI_Comm_free on the inter communicator.
      * However, if the communicators are not freed by the user but released
      * by Open MPI in MPI_Finalize, we walk through the list of still available
-     * communicators and free them one by one. Thus, local_comm is freed before 
-     * the actual inter-communicator. However, the local_comm pointer in the 
-     * inter communicator will still contain the 'previous' address of the local_comm 
+     * communicators and free them one by one. Thus, local_comm is freed before
+     * the actual inter-communicator. However, the local_comm pointer in the
+     * inter communicator will still contain the 'previous' address of the local_comm
      * and thus this will lead to a segmentation violation. In order to prevent
      * that from happening, we increase the reference counter local_comm
      * by one if its CID is lower than the parent. We cannot increase however
-     *  its reference counter if the CID of local_comm is larger than 
+     *  its reference counter if the CID of local_comm is larger than
      * the CID of the inter communicators, since a regular MPI_Comm_free would
      * leave in that the case the local_comm hanging around and thus we would not
      * recycle CID's properly, which was the reason and the cause for this trouble.
      */
     if ( OMPI_COMM_IS_INTER(*newcomm)) {
-	if ( OMPI_COMM_CID_IS_LOWER(*newcomm, comm)) {
-	    OMPI_COMM_SET_EXTRA_RETAIN (*newcomm);
-	    OBJ_RETAIN (*newcomm);
-	}
+        if ( OMPI_COMM_CID_IS_LOWER(*newcomm, comm)) {
+            OMPI_COMM_SET_EXTRA_RETAIN (*newcomm);
+            OBJ_RETAIN (*newcomm);
+        }
     }
 
+
     return OMPI_SUCCESS;
 
  bail_on_error:
@@ -552,80 +503,6 @@ int ompi_comm_activate ( ompi_communicator_t** newcomm,
     return ret;
 }                         
 
-/**************************************************************************/
-/**************************************************************************/
-/**************************************************************************/
-/* check whether all communicators registered from c_id_start_index to 
-** c_id_start_index + block have been freed. For this, we rely on 
-** the communicators having been properly removed from the fortran array, 
-** i.e. the according request should return a NULL pointer. 
-*/
-static int ompi_comm_cid_checkforreuse ( int c_id_start_index, int block )
-{
-    int ret=cid_block_start;
-    int i, count=0;
-    ompi_communicator_t * tempcomm;
-
-    if ( MPI_UNDEFINED != c_id_start_index ) {
-	for ( i= c_id_start_index; i < c_id_start_index + block; i++ ) {
-	    tempcomm = (ompi_communicator_t *) opal_pointer_array_get_item ( &ompi_mpi_communicators, i );
-	    if ( NULL == tempcomm ) {
-		count++;
-	    }
-	}
-	
-	if ( count == block ) {
-	    ret = c_id_start_index;
-	}
-    }
-
-    return ret;
-}
-
-/* this function is called from the communicator destructor. It is a
-   generic interface which verifies whether the cid block assigned to 
-   that communicator can be reused. 
-   In the current implementation it checks whether all communicators 
-   have been freed. If that's the case *and* the current leading fron
-   of cid's (i.e. cid_block-start) is right after the block following
-   the block assigned to that communicator, we reset the leading block.
-*/
-void  ompi_comm_checkfor_blockreset ( ompi_communicator_t *comm )
-{
-    int block=ompi_comm_get_blocksize ( comm );
-    int next=0;
-
-    if (MPI_THREAD_MULTIPLE == ompi_mpi_thread_provided) {
-	return;
-    }
-
-    if ( MPI_UNDEFINED == comm->c_id_start_index ) {
-	return;
-    }
-
-    next = ompi_comm_cid_checkforreuse ( comm->c_id_start_index, block );
-    if ( next            == comm->c_id_start_index && 
-	 cid_block_start == (comm->c_id_start_index + block ) ) {
- 	cid_block_start = comm->c_id_start_index;
-    }
-
-    return;
-}
-
-static int ompi_comm_get_blocksize ( ompi_communicator_t* comm  ) 
-{
-    int block=0;
-
-    if( 0 == comm->c_contextid ) {
-	block = OMPI_COMM_BLOCK_WORLD;
-    }
-    else {
-	block = OMPI_COMM_BLOCK_OTHERS;
-    }
-
-    return block;
-}
-
 /**************************************************************************/
 /**************************************************************************/
 /**************************************************************************/
@@ -685,8 +562,9 @@ static int ompi_comm_allreduce_inter ( int *inbuf, int *outbuf,
     tmpbuf  = (int *) malloc ( count * sizeof(int));
     rdisps  = (int *) calloc ( rsize, sizeof(int));
     rcounts = (int *) calloc ( rsize, sizeof(int) );
-    if ( NULL == tmpbuf || NULL == rdisps || NULL == rcounts ) {
-        return OMPI_ERR_OUT_OF_RESOURCE;
+    if ( OPAL_UNLIKELY (NULL == tmpbuf || NULL == rdisps || NULL == rcounts)) {
+        rc = OMPI_ERR_OUT_OF_RESOURCE;
+        goto exit;
     }
     
     /* Execute the inter-allreduce: the result of our group will
@@ -707,18 +585,19 @@ static int ompi_comm_allreduce_inter ( int *inbuf, int *outbuf,
         /* local leader exchange their data and determine the overall result
            for both groups */
         rc = MCA_PML_CALL(irecv (outbuf, count, MPI_INT, 0, 
-                                OMPI_COMM_ALLREDUCE_TAG
-                                , intercomm, &req));
+                                 OMPI_COMM_ALLREDUCE_TAG,
+                                 intercomm, &req));
         if ( OMPI_SUCCESS != rc ) {
             goto exit;
         }
         rc = MCA_PML_CALL(send (tmpbuf, count, MPI_INT, 0,
-                               OMPI_COMM_ALLREDUCE_TAG, 
-                               MCA_PML_BASE_SEND_STANDARD, intercomm));
+                                OMPI_COMM_ALLREDUCE_TAG,
+                                MCA_PML_BASE_SEND_STANDARD,
+                                intercomm));
         if ( OMPI_SUCCESS != rc ) {
             goto exit;
         }
-        rc = ompi_request_wait_all ( 1, &req, MPI_STATUS_IGNORE );
+        rc = ompi_request_wait ( &req, MPI_STATUS_IGNORE );
         if ( OMPI_SUCCESS != rc ) {
             goto exit;
         }
@@ -799,7 +678,8 @@ static int ompi_comm_allreduce_intra_bridge (int *inbuf, int *outbuf,
     local_rank = ompi_comm_rank ( comm );
     tmpbuf     = (int *) malloc ( count * sizeof(int));
     if ( NULL == tmpbuf ) {
-        return MPI_ERR_INTERN;
+        rc = OMPI_ERR_OUT_OF_RESOURCE;
+        goto exit;
     }
 
     /* Intercomm_create */
@@ -897,7 +777,8 @@ static int ompi_comm_allreduce_intra_oob (int *inbuf, int *outbuf,
     local_rank = ompi_comm_rank ( comm );
     tmpbuf     = (int *) malloc ( count * sizeof(int));
     if ( NULL == tmpbuf ) {
-        return MPI_ERR_INTERN;
+        rc = OMPI_ERR_OUT_OF_RESOURCE;
+        goto exit;
     }
 
     /* comm is an intra-communicator */
