@@ -1,5 +1,5 @@
 /*
- This is part of the OTF library. Copyright by ZIH, TU Dresden 2005-2012.
+ This is part of the OTF library. Copyright by ZIH, TU Dresden 2005-2013.
  Authors: Michael Heyde
 */
 
@@ -252,7 +252,7 @@ int main(int argc, char **argv)
     checkVal = OTF_Reader_readDefinitions( reader, handles );
     otfinfo_assert( checkVal != OTF_READ_ERROR );
 
-    if( info.counterDefinitionMarker != 0 )
+    if( info.counterMarkerDefinition != 0 )
     {
       /*read markers*/
       checkVal = OTF_Reader_readMarkers( reader, handles );
@@ -279,7 +279,8 @@ int main(int argc, char **argv)
         OTF_Reader_eventBytesProgress( reader, &minRead, &currRead, &size );
         current = ( PROGRESSBARLEN * currRead ) / size;
         for( ; i < current; i++ )
-          printf( "#" ); fflush( stdout );
+          printf( "#" );
+        fflush( stdout );
       }
       otfinfo_assert( checkVal != OTF_READ_ERROR )
       for( ; i < PROGRESSBARLEN; i++ )
@@ -449,6 +450,13 @@ static void set_handles_level_2( OTF_HandlerArray *handles, definitionInfoT *inf
                                OTF_DEFFUNCTION_RECORD );
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFFUNCTION_RECORD );
 
+  /*handler and inits for getting the count of collop. definitions*/
+  info->counterCollectiveOperationDefinition = 0;
+  OTF_HandlerArray_setHandler( handles,
+                               (OTF_FunctionPointer*)handleDefCollectiveOperation,
+                               OTF_DEFCOLLOP_RECORD );
+  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFCOLLOP_RECORD );
+
   /*handler and inits for getting the count of counter definitions*/
   info->counterCounterDefinition = 0;
   OTF_HandlerArray_setHandler( handles,
@@ -456,13 +464,6 @@ static void set_handles_level_2( OTF_HandlerArray *handles, definitionInfoT *inf
                                OTF_DEFCOUNTER_RECORD);
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFCOUNTER_RECORD );
 
-  /*handler and inits for getting the count of marker definitions*/
-  info->counterDefinitionMarker = 0;
-  OTF_HandlerArray_setHandler( handles,
-                               (OTF_FunctionPointer*)handleDefMarker,
-                               OTF_DEFMARKER_RECORD );
-  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFMARKER_RECORD  );
-
   /*handler and inits for getting the count of process group definitions*/
   info->counterProcessGroupDefinition = 0;
   OTF_HandlerArray_setHandler( handles,
@@ -491,6 +492,13 @@ static void set_handles_level_2( OTF_HandlerArray *handles, definitionInfoT *inf
                                (OTF_FunctionPointer*)handleDefSclFile,
                                OTF_DEFSCLFILE_RECORD );
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFSCLFILE_RECORD );
+
+  /*handler and inits for getting the count of marker definitions*/
+  info->counterMarkerDefinition = 0;
+  OTF_HandlerArray_setHandler( handles,
+                               (OTF_FunctionPointer*)handleDefMarker,
+                               OTF_DEFMARKER_RECORD );
+  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFMARKER_RECORD  );
 }
 
 static void show_info_level_2( definitionInfoT *info )
@@ -507,8 +515,8 @@ static void show_info_level_2( definitionInfoT *info )
           (unsigned long long)info->counterFunctionDefinition );
   printf( "| counter definitions        | %llu\n",
           (unsigned long long)info->counterCounterDefinition );
-  printf( "| marker definitions         | %llu\n",
-          (unsigned long long)info->counterDefinitionMarker );
+  printf( "| collective op. definitions | %llu\n",
+          (unsigned long long)info->counterCollectiveOperationDefinition );
   printf( "|                            |\n" );
   printf( "| process group definitions  | %llu\n",
           (unsigned long long)info->counterProcessGroupDefinition );
@@ -516,6 +524,9 @@ static void show_info_level_2( definitionInfoT *info )
           (unsigned long long)info->counterFunctionGroupDefinition );
   printf( "| counter group definitions  | %llu\n",
           (unsigned long long)info->counterCounterGroupDefinition );
+  printf( "|                            |\n" );
+  printf( "| marker definitions         | %llu\n",
+          (unsigned long long)info->counterMarkerDefinition );
   printf( "+----------------------------+--------------------------------------------------\n" );
 
   index = info->counterSourceFileName;
@@ -609,9 +620,14 @@ static void set_handles_level_3( OTF_HandlerArray *handles,
   /*handler and inits for getting the count of collective operations*/
   info->counterCollectiveOperation = 0;
   OTF_HandlerArray_setHandler( handles,
-                               (OTF_FunctionPointer*)handleDefCollectiveOperation,
-                               OTF_DEFCOLLOP_RECORD );
-  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFCOLLOP_RECORD  );
+                               (OTF_FunctionPointer*)handleCollectiveOperation,
+                               OTF_COLLOP_RECORD );
+  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_COLLOP_RECORD  );
+
+  OTF_HandlerArray_setHandler( handles,
+                               (OTF_FunctionPointer*)handleEndCollectiveOperation,
+                               OTF_ENDCOLLOP_RECORD );
+  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_ENDCOLLOP_RECORD  );
 
   /*handler and inits for getting the count of file operations*/
   info->counterFileOperation = 0;
@@ -625,6 +641,13 @@ static void set_handles_level_3( OTF_HandlerArray *handles,
                                OTF_ENDFILEOP_RECORD );
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_ENDFILEOP_RECORD  );
 
+  /*handler and inits for getting the count of markers*/
+  info->counterMarker = 0;
+  OTF_HandlerArray_setHandler( handles,
+                               (OTF_FunctionPointer*)handleMarker,
+                               OTF_MARKER_RECORD );
+  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_MARKER_RECORD  );
+
   /*handler and inits for getting the count of snapshots*/
   info->counterSnapshot = 0;
   OTF_HandlerArray_setHandler( handles,
@@ -634,6 +657,7 @@ static void set_handles_level_3( OTF_HandlerArray *handles,
 
   (info->counters) = (counterT*)malloc( info->counterCounterDefinition *
                                         sizeof(counterT) );
+
   for( i = 0; i < info->counterCounterDefinition; i++ )
   {
     (info->counters)[i].name = NULL;
@@ -681,6 +705,8 @@ static void show_info_level_3( definitionInfoT *info )
           (unsigned long long)info->counterCollectiveOperation );
   printf( "| file operations       | %llu\n",
           (unsigned long long)info->counterFileOperation );
+  printf( "| markers               | %llu\n",
+          (unsigned long long)info->counterMarker );
   printf( "| snapshots             | %llu\n",
           (unsigned long long)info->counterSnapshot );
   printf( "+-----------------------+-------------------------------------------------------\n" );
@@ -748,14 +774,14 @@ static void set_handles_level_4( OTF_HandlerArray *handles,
                                OTF_DEFFUNCTION_RECORD);
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFFUNCTION_RECORD );
 
-  /*handler and inits for getting the names of markers*/
-  info->markerNames = NULL;
-  info->markerNames = (char**)calloc( info->counterDefinitionMarker,
-                                      sizeof(char*) );
+  /*handler and inits for getting the names of collective operations*/
+  info->collectiveOperationNames = NULL;
+  info->collectiveOperationNames = (char**)calloc( info->counterCollectiveOperationDefinition,
+                                                   sizeof(char*) );
   OTF_HandlerArray_setHandler( handles,
-                               (OTF_FunctionPointer*)handleDefMarker,
-                               OTF_DEFMARKER_RECORD );
-  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFMARKER_RECORD  );
+                               (OTF_FunctionPointer*)handleDefCollectiveOperation,
+                               OTF_DEFCOLLOP_RECORD );
+  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFCOLLOP_RECORD );
 
   /*handler and inits for getting the names of processe groups*/
   info->processGroupNames = NULL;
@@ -766,8 +792,6 @@ static void set_handles_level_4( OTF_HandlerArray *handles,
                                OTF_DEFPROCESSGROUP_RECORD);
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFPROCESSGROUP_RECORD );
 
-  info->collectiveOperationNames = NULL;
-
   /*handler and inits for getting the names of function groups*/
   info->functionGroupNames = NULL;
   info->functionGroupNames = (char**)calloc( info->counterFunctionGroupDefinition,
@@ -777,7 +801,7 @@ static void set_handles_level_4( OTF_HandlerArray *handles,
                                OTF_DEFFUNCTIONGROUP_RECORD);
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFFUNCTIONGROUP_RECORD );
 
-  /*handler and inits for getting the names of counter groupss*/
+  /*handler and inits for getting the names of counter groups*/
   info->counterGroupNames = NULL;
   info->counterGroupNames = (char**)calloc( info->counterCounterGroupDefinition,
                                             sizeof(char*) );
@@ -785,6 +809,15 @@ static void set_handles_level_4( OTF_HandlerArray *handles,
                                (OTF_FunctionPointer*)handleDefCounterGroup,
                                OTF_DEFCOUNTERGROUP_RECORD);
   OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFCOUNTERGROUP_RECORD );
+
+  /*handler and inits for getting the names of markers*/
+  info->markerNames = NULL;
+  info->markerNames = (char**)calloc( info->counterMarkerDefinition,
+                                      sizeof(char*) );
+  OTF_HandlerArray_setHandler( handles,
+                               (OTF_FunctionPointer*)handleDefMarker,
+                               OTF_DEFMARKER_RECORD );
+  OTF_HandlerArray_setFirstHandlerArg( handles, info, OTF_DEFMARKER_RECORD  );
 }
 
 static void show_info_level_4( definitionInfoT *info )
@@ -816,9 +849,9 @@ static void show_info_level_4( definitionInfoT *info )
   printf( "\n" );
   printf( "+-------------------------------------------------------------------------------\n" );
   printf( "| marker definitions[%llu]\n",
-          (unsigned long long)info->counterDefinitionMarker );
+          (unsigned long long)info->counterMarkerDefinition );
   printf( "+-------------------------------------------------------------------------------\n" );
-  for( i = 0; i < info->counterDefinitionMarker; i++ )
+  for( i = 0; i < info->counterMarkerDefinition; i++ )
   {
      printf( "| %s\n", info->markerNames[i] );
   }
@@ -826,9 +859,9 @@ static void show_info_level_4( definitionInfoT *info )
   printf( "\n" );
   printf( "+-------------------------------------------------------------------------------\n" );
   printf( "| collective operation definitions[%llu]\n",
-          (unsigned long long)info->counterCollectiveOperation );
+          (unsigned long long)info->counterCollectiveOperationDefinition );
   printf( "+-------------------------------------------------------------------------------\n" );
-  for( i = 0; i < info->counterCollectiveOperation; i++ )
+  for( i = 0; i < info->counterCollectiveOperationDefinition; i++ )
   {
     printf( "| %s\n", info->collectiveOperationNames[i] );
   }
@@ -905,7 +938,7 @@ static void free_data_level_4( definitionInfoT *info )
     free( info->functionGroupNames );
   }
 
-  for(i = 0; i < info->counterCollectiveOperation; i++ )
+  for(i = 0; i < info->counterCollectiveOperationDefinition; i++ )
   {
     free( (info->collectiveOperationNames)[i] );
   }
@@ -917,7 +950,7 @@ static void free_data_level_4( definitionInfoT *info )
   }
   free( info->counterGroupNames );
 
-  for( i = 0; i < info->counterDefinitionMarker; i++ )
+  for( i = 0; i < info->counterMarkerDefinition; i++ )
   {
     free( (info->markerNames)[i] );
   }
