@@ -11,6 +11,8 @@
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2007-2008 Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c)      2012 Los Alamos National Security, LLC.  All rights
+ *                         reserved. 
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -74,7 +76,6 @@
 
 #include "orte/mca/errmgr/errmgr.h"
 #include "orte/mca/rml/rml.h"
-#include "orte/mca/debugger/base/base.h"
 #include "orte/runtime/orte_globals.h"
 
 #if defined(OMPI_MSGQ_DLL)
@@ -126,8 +127,8 @@ OMPI_DECLSPEC opal_datatype_t* opal_datatype_t_type_force_inclusion = NULL;
 OMPI_DECLSPEC ompi_datatype_t* ompi_datatype_t_type_force_inclusion = NULL;
 
 OMPI_DECLSPEC volatile int MPIR_debug_gate = 0;
-ORTE_DECLSPEC extern volatile int MPIR_being_debugged;
-ORTE_DECLSPEC extern volatile int MPIR_debug_state;
+ORTE_DECLSPEC volatile int MPIR_being_debugged;
+ORTE_DECLSPEC volatile int MPIR_debug_state;
 OMPI_DECLSPEC char *MPIR_debug_abort_string = "";
 
 /* Check for a file in few direct ways for portability */
@@ -173,7 +174,7 @@ void ompi_wait_for_debugger(void)
     char *a, *b, **dirs, **tmp1 = NULL, **tmp2 = NULL;
     opal_buffer_t buf;
 
-    /* See lengthy comment in orte/tools/orterun/debuggers.c about
+    /* See lengthy comment in orte/tools/orterun/orterun.c about
        orte_in_parallel_debugger */
 #if ORTE_DISABLE_FULL_SUPPORT
     debugger = 0;
@@ -276,3 +277,13 @@ void ompi_debugger_notify_abort(char *reason)
     /* Now tell the debugger */
     MPIR_Breakpoint();
 }
+
+/* 
+ * Breakpoint function for parallel debuggers.  This function is also 
+ * defined in orterun for the starter.  It should never conflict with 
+ * this 
+ */
+void* MPIR_Breakpoint(void)
+{
+    return NULL;
+}
