@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2006 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2009      Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -22,22 +23,27 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif  /* HAVE_UNISTD_H */
-#include "ompi/mca/bml/bml.h" 
 #include "ompi/mca/bml/base/base.h"
 #include "ompi/mca/btl/base/base.h"
 #include "ompi/mca/bml/base/static-components.h"
 #include "opal/mca/base/base.h"
 
-opal_list_t mca_bml_base_components_available;
+int mca_bml_base_already_opened = 0;
+opal_list_t mca_bml_base_components_available = {{0}};
 
-#if OMPI_ENABLE_DEBUG_RELIABILITY
+#if OPAL_ENABLE_DEBUG_RELIABILITY
 double mca_bml_base_error_rate_floor;
 double mca_bml_base_error_rate_ceiling;
 int    mca_bml_base_error_count;
 #endif
 
-int mca_bml_base_open( void ) { 
-    
+int mca_bml_base_open(void) 
+{
+    /* See if we've already been here */
+    if (++mca_bml_base_already_opened > 1) {
+        return OMPI_SUCCESS;
+    }
+
     if(OMPI_SUCCESS !=
        mca_base_components_open("bml", 0, mca_bml_base_static_components, 
                                 &mca_bml_base_components_available, 
@@ -45,7 +51,7 @@ int mca_bml_base_open( void ) {
         return OMPI_ERROR; 
     }
 
-#if OMPI_ENABLE_DEBUG_RELIABILITY
+#if OPAL_ENABLE_DEBUG_RELIABILITY
     do {
         int param, value;
         
