@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2011 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -127,16 +128,6 @@ struct mca_btl_mx_module_t {
 typedef struct mca_btl_mx_module_t mca_btl_mx_module_t;
 extern mca_btl_mx_module_t mca_btl_mx_module;
 
-/**
- * Register MX component parameters with the MCA framework
- */
-extern int mca_btl_mx_component_open(void);
-
-/**
- * Any final cleanup before being unloaded.
- */
-extern int mca_btl_mx_component_close(void);
-
 /**
  * MX component initialization.
  * 
