@@ -37,6 +37,8 @@
 #include "ompi/mca/btl/base/btl_base_error.h"
 #include "connect/base.h"
 
+#define QP_TX_BATCH_COUNT 64
+
 BEGIN_C_DECLS
 
 struct mca_btl_openib_frag_t;
@@ -133,6 +135,8 @@ typedef struct mca_btl_openib_qp_t {
     struct ibv_qp *lcl_qp;
     uint32_t lcl_psn;
     int32_t  sd_wqe;      /**< number of available send wqe entries */
+    int32_t  sd_wqe_inflight;
+    int wqe_count;
     int users;
     opal_mutex_t lock;
 } mca_btl_openib_qp_t;
@@ -270,6 +274,55 @@ static inline int32_t qp_put_wqe(mca_btl_openib_endpoint_t *ep, const int qp)
     return OPAL_THREAD_ADD32(&ep->qps[qp].qp->sd_wqe, 1);
 }
 
+
+static inline int32_t qp_inc_inflight_wqe(mca_btl_openib_endpoint_t *ep, const int qp, mca_btl_openib_com_frag_t *frag)
+{
+    frag->n_wqes_inflight = 0;
+    return OPAL_THREAD_ADD32(&ep->qps[qp].qp->sd_wqe_inflight, 1);
+}
+
+static inline void qp_inflight_wqe_to_frag(mca_btl_openib_endpoint_t *ep, const int qp, mca_btl_openib_com_frag_t *frag)
+{
+
+    frag->n_wqes_inflight = ep->qps[qp].qp->sd_wqe_inflight;
+    ep->qps[qp].qp->sd_wqe_inflight = 0;
+}
+
+static inline int qp_frag_to_wqe(mca_btl_openib_endpoint_t *ep, const int qp, mca_btl_openib_com_frag_t *frag)
+{
+    int n;
+    n = frag->n_wqes_inflight;
+    OPAL_THREAD_ADD32(&ep->qps[qp].qp->sd_wqe, n);
+    frag->n_wqes_inflight = 0;
+
+    return n;
+}
+
+static inline int qp_need_signal(mca_btl_openib_endpoint_t *ep, const int qp, size_t size, int rdma)
+{
+
+    /* note that size here is payload only */
+    if (ep->qps[qp].qp->sd_wqe <= 0  || 
+            size + sizeof(mca_btl_openib_header_t) + (rdma ? sizeof(mca_btl_openib_footer_t) : 0) > ep->qps[qp].ib_inline_max ||
+             (!BTL_OPENIB_QP_TYPE_PP(qp) && ep->endpoint_btl->qps[qp].u.srq_qp.sd_credits <= 0)) {
+        ep->qps[qp].qp->wqe_count = QP_TX_BATCH_COUNT;
+        return 1;
+    }
+
+    if (0 < --ep->qps[qp].qp->wqe_count) {
+        return 0;
+    }
+
+    ep->qps[qp].qp->wqe_count = QP_TX_BATCH_COUNT;
+    return 1;
+}
+
+static inline void qp_reset_signal_count(mca_btl_openib_endpoint_t *ep, const int qp)
+{
+    ep->qps[qp].qp->wqe_count = QP_TX_BATCH_COUNT;
+}
+
+
 int mca_btl_openib_endpoint_send(mca_btl_base_endpoint_t*,
         mca_btl_openib_send_frag_t*);
 int mca_btl_openib_endpoint_post_send(mca_btl_openib_endpoint_t*,
@@ -457,10 +510,14 @@ static inline int check_endpoint_state(mca_btl_openib_endpoint_t *ep,
 }
 
 static inline __opal_attribute_always_inline__ int
-ib_send_flags(uint32_t size, mca_btl_openib_endpoint_qp_t *qp)
+ib_send_flags(uint32_t size, mca_btl_openib_endpoint_qp_t *qp, int do_signal)
 {
-    return IBV_SEND_SIGNALED |
-        ((size <= qp->ib_inline_max) ? IBV_SEND_INLINE : 0);
+    if (do_signal) {
+        return IBV_SEND_SIGNALED |
+            ((size <= qp->ib_inline_max) ? IBV_SEND_INLINE : 0);
+    } else {
+        return   ((size <= qp->ib_inline_max) ? IBV_SEND_INLINE : 0);
+    }
 }
 
 static inline int
@@ -475,7 +532,7 @@ acquire_eager_rdma_send_credit(mca_btl_openib_endpoint_t *endpoint)
 }
 
 static inline int post_send(mca_btl_openib_endpoint_t *ep,
-        mca_btl_openib_send_frag_t *frag, const bool rdma)
+        mca_btl_openib_send_frag_t *frag, const bool rdma, int do_signal)
 {
     mca_btl_openib_module_t *openib_btl = ep->endpoint_btl;
     mca_btl_base_segment_t *seg = &to_base_frag(frag)->segment;
@@ -487,7 +544,7 @@ static inline int post_send(mca_btl_openib_endpoint_t *ep,
     sg->length = seg->seg_len + sizeof(mca_btl_openib_header_t) +
         (rdma ? sizeof(mca_btl_openib_footer_t) : 0) + frag->coalesced_length;
 
-    sr_desc->send_flags = ib_send_flags(sg->length, &(ep->qps[qp]));
+    sr_desc->send_flags = ib_send_flags(sg->length, &(ep->qps[qp]), do_signal);
 
     if(ep->nbo)
         BTL_OPENIB_HEADER_HTON(*frag->hdr);
@@ -538,6 +595,12 @@ static inline int post_send(mca_btl_openib_endpoint_t *ep,
 #endif
     assert(sg->addr == (uint64_t)(uintptr_t)frag->hdr);
 
+    if (sr_desc->send_flags & IBV_SEND_SIGNALED) {
+        qp_inflight_wqe_to_frag(ep, qp, to_com_frag(frag));
+    } else {
+        qp_inc_inflight_wqe(ep, qp, to_com_frag(frag));
+    }
+
     return ibv_post_send(ep->qps[qp].qp->lcl_qp, sr_desc, &bad_wr);
 }
 
