@@ -35,9 +35,7 @@
 
 #include <stdio.h>
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
 int btl_openib_ini_yylex(void);
 int btl_openib_ini_init_buffer(FILE *file);
@@ -70,8 +68,6 @@ enum {
     BTL_OPENIB_INI_PARSE_MAX
 };
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 
 #endif
