@@ -10,16 +10,12 @@
 #ifndef MCA_BTL_IB_MCA_H
 #define MCA_BTL_IB_MCA_H
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
     /**
      * Function to register MCA params and check for sane values
      */
     int btl_openib_register_mca_params(void);
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 #endif
