@@ -270,15 +270,14 @@ static int reply_start_connect(mca_btl_openib_endpoint_t *endpoint,
 static int set_remote_info(mca_btl_base_endpoint_t* endpoint,
                            mca_btl_openib_rem_info_t* rem_info)
 {
+    /* Free up the memory pointed to by rem_qps before overwriting the pointer
+       in the following memcpy */
+    free(endpoint->rem_info.rem_qps);
+
     /* copy the rem_info stuff */
     memcpy(&((mca_btl_openib_endpoint_t*) endpoint)->rem_info, 
            rem_info, sizeof(mca_btl_openib_rem_info_t)); 
     
-    /* copy over the rem qp info */
-    memcpy(endpoint->rem_info.rem_qps,
-           rem_info->rem_qps, sizeof(mca_btl_openib_rem_qp_info_t) * 
-           mca_btl_openib_component.num_qps);
-    
     BTL_VERBOSE(("Setting QP info,  LID = %d", endpoint->rem_info.rem_lid));
     return ORTE_SUCCESS;
 
@@ -484,11 +483,15 @@ static int qp_create_one(mca_btl_base_endpoint_t* endpoint, int qp,
     }
     init_attr.cap.max_send_wr  = max_send_wr;
 
-    my_qp = ibv_create_qp(openib_btl->device->ib_pd, &init_attr); 
-    
-    if (NULL == my_qp) { 
-        BTL_ERROR(("error creating qp errno says %s", strerror(errno))); 
-        return OMPI_ERROR; 
+    my_qp = ibv_create_qp(openib_btl->device->ib_pd, &init_attr);
+
+    if (NULL == my_qp) {
+	orte_show_help("help-mpi-btl-openib-cpc-base.txt",
+		       "ibv_create_qp failed", true,
+		       orte_process_info.nodename,
+		       ibv_get_device_name(openib_btl->device->ib_dev),
+		       "Reliable connected (RC)");
+        return OMPI_ERROR;
     }
     endpoint->qps[qp].qp->lcl_qp = my_qp;
 
@@ -661,7 +664,12 @@ static void rml_recv_cb(int status, orte_process_name_t* process_name,
     mca_btl_openib_rem_info_t rem_info;
     uint8_t message_type;
     bool master;
-    
+
+    /* We later memcpy this whole structure. Make sure
+       that all the parameters are initialized, especially
+       the pointers */
+    memset(&rem_info,0, sizeof(rem_info));
+
     /* start by unpacking data first so we know who is knocking at 
        our door */ 
     BTL_VERBOSE(("unpacking %d of %d\n", cnt, OPAL_UINT8));
@@ -825,7 +833,7 @@ static void rml_recv_cb(int status, orte_process_name_t* process_name,
                just ignore this connection request */
             if (found && !master &&
                 MCA_BTL_IB_CLOSED != ib_endpoint->endpoint_state) {
-		OPAL_THREAD_UNLOCK(&mca_btl_openib_component.ib_lock);
+                OPAL_THREAD_UNLOCK(&mca_btl_openib_component.ib_lock);
                 return;
             }
         }
@@ -833,7 +841,7 @@ static void rml_recv_cb(int status, orte_process_name_t* process_name,
         if (!found) {
             BTL_ERROR(("can't find suitable endpoint for this peer\n")); 
             mca_btl_openib_endpoint_invoke_error(NULL);
-	    OPAL_THREAD_UNLOCK(&mca_btl_openib_component.ib_lock);
+            OPAL_THREAD_UNLOCK(&mca_btl_openib_component.ib_lock);
             return; 
         }
         
@@ -848,6 +856,7 @@ static void rml_recv_cb(int status, orte_process_name_t* process_name,
                to CONNECTING, and then reply with our QP
                information */
             if (master) {
+                assert(rem_info.rem_qps != NULL);
                 rc = reply_start_connect(ib_endpoint, &rem_info);
             } else {
                 rc = oob_module_start_connect(ib_endpoint->endpoint_local_cpc, 
@@ -870,6 +879,7 @@ static void rml_recv_cb(int status, orte_process_name_t* process_name,
             break;
              
         case MCA_BTL_IB_CONNECTING :
+            assert(rem_info.rem_qps != NULL);
             set_remote_info(ib_endpoint, &rem_info);
             if (OMPI_SUCCESS != (rc = qp_connect_all(ib_endpoint))) {
                 BTL_ERROR(("endpoint connect error: %d", rc)); 
