@@ -1,14 +1,15 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
  * Copyright (c) 2004-2005 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2008 High Performance Computing Center Stuttgart, 
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2008      UT-Battelle, LLC. All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -24,9 +25,8 @@
 
 #include "ompi/constants.h"
 
-#include "opal/util/output.h"
-#include "opal/threads/threads.h"
 #include "opal/mca/base/mca_base_param.h"
+
 #include "ompi/mca/common/portals/common_portals.h"
 
 #include "btl_portals.h"
@@ -40,10 +40,7 @@ mca_btl_portals_component_t mca_btl_portals_component = {
       /* First, the mca_base_module_t struct containing meta
          information about the module itself */
       {
-        /* Indicate that we are a pml v1.0.0 module (which also
-           implies a specific MCA version) */
-
-        MCA_BTL_BASE_VERSION_1_0_1,
+        MCA_BTL_BASE_VERSION_2_0_0,
 
         "portals", /* MCA module name */
         OMPI_MAJOR_VERSION,  /* MCA module major version */
@@ -52,13 +49,9 @@ mca_btl_portals_component_t mca_btl_portals_component = {
         mca_btl_portals_component_open,  /* module open */
         mca_btl_portals_component_close  /* module close */
       },
-      
-      /* Next the MCA v1.0.0 module meta data */
-      
       {
-        /* Whether the module is checkpointable or not */
-        
-        false
+          /* The component is not checkpoint ready */
+          MCA_BASE_METADATA_PARAM_NONE
       },
       
       mca_btl_portals_component_init,  
@@ -73,7 +66,6 @@ int
 mca_btl_portals_component_open(void)
 {
     int i;
-    int dummy;
 
     ompi_common_portals_register_mca();
 
@@ -126,85 +118,46 @@ mca_btl_portals_component_open(void)
                            false,
                            32,
                            &(mca_btl_portals_component.portals_free_list_eager_max_num));
+    
+    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
+                           "support_self",
+                           "Use portals for send to self",
+                           false,
+                           false,
+                           1, /* default to true.. */ 
+                           &(mca_btl_portals_component.portals_support_self));
+
+    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
+                           "needs_ack",
+                           "Require a portals level ACK",
+                           false,
+                           false,
+                           1, /* default to true.. */ 
+                           &(mca_btl_portals_component.portals_need_ack));
 
     /* 
      * fill default module state 
      */
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "eager_limit",
-                           "Maximum size for eager frag",
-                           false,
-                           false,
-                           32 * 1024,
-                           &dummy);
-    mca_btl_portals_module.super.btl_eager_limit = dummy;
-
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "min_send_size",
-                           "Minimum size for a send frag",
-                           false,
-                           false,
-                           32 * 1024,
-                           &dummy);
-    mca_btl_portals_module.super.btl_min_send_size = dummy;
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "max_send_size",
-                           "Maximum size for a send frag",
-                           false,
-                           false,
-                           64 * 1024,
-                           &dummy);
-    mca_btl_portals_module.super.btl_max_send_size = dummy;
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "min_rdma_size",
-                           "Minimum size for a rdma frag",
-                           false,
-                           false,
-                           64 * 1024,
-                           &dummy);
-    mca_btl_portals_module.super.btl_min_rdma_size = dummy;
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "max_rdma_size",
-                           "Maximum size for a rdma frag",
-                           false,
-                           false,
-                           INT_MAX,
-                           &dummy);
-    mca_btl_portals_module.super.btl_max_rdma_size = dummy;
-
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "exclusivity",
-                           "Exclusivity level for selection process",
-                           false,
-                           false,
-                           60,
-                           &dummy);
-    mca_btl_portals_module.super.btl_exclusivity = dummy;
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "latency",
-                           "Latency level for short message scheduling",
-                           false,
-                           false,
-                           0,
-                           &dummy);
-    mca_btl_portals_module.super.btl_latency = dummy;
-    mca_base_param_reg_int(&mca_btl_portals_component.super.btl_version,
-                           "bandwidth",
-                           "Bandwidth level for frag scheduling",
-                           false,
-                           false,
-                           1000,
-                           &dummy);
-    mca_btl_portals_module.super.btl_bandwidth = dummy;
+    mca_btl_portals_module.super.btl_exclusivity = 60;
+    mca_btl_portals_module.super.btl_eager_limit = 32 * 1024;
+    mca_btl_portals_module.super.btl_rndv_eager_limit = 32 * 1024;
+    mca_btl_portals_module.super.btl_max_send_size = 64 * 1024;
+    mca_btl_portals_module.super.btl_rdma_pipeline_send_length = 64 * 1024;
+    mca_btl_portals_module.super.btl_rdma_pipeline_frag_size = INT_MAX;
+    mca_btl_portals_module.super.btl_min_rdma_pipeline_size = 0;
+    mca_btl_portals_module.super.btl_flags = 
+        MCA_BTL_FLAGS_RDMA |
+        MCA_BTL_FLAGS_RDMA_MATCHED;
+    mca_btl_portals_module.super.btl_bandwidth = 1000;
+    mca_btl_portals_module.super.btl_latency = 0;
 
+    mca_btl_base_param_register(&mca_btl_portals_component.super.btl_version,
+            &mca_btl_portals_module.super);
     /* send in place actually increases our latency because we have to
        hold on to the buffer until we're done with it, rather than
        copy and send.  So don't use it for now. */
-    mca_btl_portals_module.super.btl_flags = MCA_BTL_FLAGS_RDMA;
 
     mca_btl_portals_module.portals_num_procs = 0;
-    bzero(&(mca_btl_portals_module.portals_reg),
-          sizeof(mca_btl_portals_module.portals_reg));
 
     for (i = 0 ; i < OMPI_BTL_PORTALS_EQ_SIZE ; ++i) {
         mca_btl_portals_module.portals_eq_sizes[i] = 0;
@@ -279,6 +232,7 @@ mca_btl_portals_component_init(int *num_btls,
                                bool enable_mpi_threads)
 {
     mca_btl_base_module_t ** btls = malloc(sizeof(mca_btl_base_module_t*));
+    bool accel;
     btls[0] = (mca_btl_base_module_t*) &mca_btl_portals_module;
 
     if (enable_progress_threads || enable_mpi_threads) {
@@ -289,7 +243,7 @@ mca_btl_portals_component_init(int *num_btls,
 
     /* initialize portals btl.  note that this is in the compat code because
        it's fairly non-portable between implementations */
-    if (OMPI_SUCCESS != ompi_common_portals_initialize()) {
+    if (OMPI_SUCCESS != ompi_common_portals_initialize(&mca_btl_portals_module.portals_ni_h, &accel)) {
         opal_output_verbose(20, mca_btl_portals_component.portals_output,
                             "disabled because compatibility init failed");
         return NULL;
@@ -300,29 +254,35 @@ mca_btl_portals_component_init(int *num_btls,
     OBJ_CONSTRUCT(&(mca_btl_portals_module.portals_frag_user), ompi_free_list_t);
 
     /* eager frags */
-    ompi_free_list_init(&(mca_btl_portals_module.portals_frag_eager),
+    ompi_free_list_init_new(&(mca_btl_portals_module.portals_frag_eager),
                         sizeof(mca_btl_portals_frag_eager_t) + 
                         mca_btl_portals_module.super.btl_eager_limit,
+                        opal_cache_line_size,
                         OBJ_CLASS(mca_btl_portals_frag_eager_t),
+                        0,opal_cache_line_size,
                         mca_btl_portals_component.portals_free_list_init_num,
                         mca_btl_portals_component.portals_free_list_eager_max_num,
                         mca_btl_portals_component.portals_free_list_inc_num,
                         NULL);
 
     /* send frags */
-    ompi_free_list_init(&(mca_btl_portals_module.portals_frag_max),
+    ompi_free_list_init_new(&(mca_btl_portals_module.portals_frag_max),
                         sizeof(mca_btl_portals_frag_max_t) + 
                         mca_btl_portals_module.super.btl_max_send_size,
+                        opal_cache_line_size,
                         OBJ_CLASS(mca_btl_portals_frag_max_t),
+                        0,opal_cache_line_size,
                         mca_btl_portals_component.portals_free_list_init_num,
                         mca_btl_portals_component.portals_free_list_max_num,
                         mca_btl_portals_component.portals_free_list_inc_num,
                         NULL);
 
     /* user frags */
-    ompi_free_list_init(&(mca_btl_portals_module.portals_frag_user),
+    ompi_free_list_init_new(&(mca_btl_portals_module.portals_frag_user),
                         sizeof(mca_btl_portals_frag_user_t),
+                        opal_cache_line_size,
                         OBJ_CLASS(mca_btl_portals_frag_user_t),
+                        0,opal_cache_line_size,
                         mca_btl_portals_component.portals_free_list_init_num,
                         mca_btl_portals_component.portals_free_list_max_num,
                         mca_btl_portals_component.portals_free_list_inc_num,
@@ -352,7 +312,7 @@ int
 mca_btl_portals_component_progress(void)
 {
     int num_progressed = 0;
-    int ret, which;
+    int ret, which, btl_ownership;
     static ptl_event_t ev;
     mca_btl_portals_frag_t *frag = NULL;
     mca_btl_portals_recv_block_t *block = NULL;
@@ -371,32 +331,40 @@ mca_btl_portals_component_progress(void)
         switch (ret) {
         case PTL_OK:
             frag = ev.md.user_ptr;
+            btl_ownership = (frag->base.des_flags & MCA_BTL_DES_FLAGS_BTL_OWNERSHIP);
             num_progressed++;
-
+            
             switch (ev.type) {
             case PTL_EVENT_GET_START:
                 /* generated on source (target) when a get from memory starts */
-                OPAL_OUTPUT_VERBOSE((900, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_GET_START for 0x%x, %d",
-                                     frag, (int) ev.hdr_data));
-
+                OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                     "PTL_EVENT_GET_START for 0x%lx, %d",
+                                     (unsigned long) frag, (int) ev.hdr_data));
+                
                 break;
-
+                
             case PTL_EVENT_GET_END:
                 /* generated on source (target) when a get from memory ends */
-                OPAL_OUTPUT_VERBOSE((900, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_GET_END for 0x%x, %d",
-                                     frag, (int) ev.hdr_data));
-
+                OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                     "PTL_EVENT_GET_END for 0x%lx, %d, flags %d",
+                                     (unsigned long) frag, (int) ev.hdr_data, 
+                                     frag->base.des_flags));
+                
+                if( btl_ownership ) {
+                    OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                         "in PTL_EVENT_GET_END received a frag with btl_ownership!"));
+                    mca_btl_portals_free(&mca_btl_portals_module.super,
+                                         &frag->base);
+                }
                 break;
-
             case PTL_EVENT_PUT_START:
+                tag = ((unsigned char*) (&ev.hdr_data))[7];
                 /* generated on destination (target) when a put into memory starts */
-                OPAL_OUTPUT_VERBOSE((900, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_PUT_START for 0x%x, %d",
-                                     frag, (int) ev.hdr_data));
+                OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                     "PTL_EVENT_PUT_START for 0x%lx, %d",
+                                     (unsigned long) frag, (int) tag));
 
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
                 if (ev.ni_fail_type != PTL_NI_OK) {
                     opal_output(mca_btl_portals_component.portals_output,
                                 "Failure to start event\n");
@@ -404,7 +372,7 @@ mca_btl_portals_component_progress(void)
                 }
 #endif
                 /* if it's a pending unexpected receive, do book keeping. */
-                if (ev.hdr_data < MCA_BTL_TAG_MAX) {
+                if (tag < MCA_BTL_TAG_MAX) {
                     block = ev.md.user_ptr;
                     OPAL_THREAD_ADD32(&(block->pending), 1);
                 }
@@ -412,12 +380,13 @@ mca_btl_portals_component_progress(void)
                 break;
 
             case PTL_EVENT_PUT_END: 
+                tag = ((unsigned char*) (&ev.hdr_data))[7];
                 /* generated on destination (target) when a put into memory ends */
-                OPAL_OUTPUT_VERBOSE((900, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_PUT_END for 0x%x, %d",
-                                     frag, (int) ev.hdr_data));
+                OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                     "PTL_EVENT_PUT_END for 0x%lx, %d",
+                                     (unsigned long) frag, (int) tag));
 
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
                 if (ev.ni_fail_type != PTL_NI_OK) {
                     opal_output(mca_btl_portals_component.portals_output,
                                 "Failure to end event\n");
@@ -427,74 +396,112 @@ mca_btl_portals_component_progress(void)
                 }
 #endif
                 /* if it's an unexpected receive, do book keeping and send to PML */
-                if (ev.hdr_data < MCA_BTL_TAG_MAX) {
+                if (tag < MCA_BTL_TAG_MAX) {
                     block = ev.md.user_ptr;
-                    tag = ev.hdr_data;
-
-                    /* if we ever make this thread hot, need to do
-                       something with the receive fragments */
                     frag = &mca_btl_portals_module.portals_recv_frag;
-                    frag->segments[0].seg_addr.pval = (((char*) ev.md.start) + ev.offset);
-                    frag->segments[0].seg_len = ev.mlength;
-
-                    OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
-                                         "received send fragment %x (thresh: %d, length %d)", 
-                                         frag, ev.md.threshold, (int) ev.mlength));
-
-                    if (ev.md.length - (ev.offset + ev.mlength) < ev.md.max_size ||
+                    if(ev.match_bits) { 
+                        uint8_t header_size = ((uint8_t*) (&ev.hdr_data))[6];
+                        memcpy(frag->data, &ev.match_bits, header_size > 8 ? 8 : header_size);
+                        if(header_size > 8) { 
+                            memcpy(frag->data+8, &ev.hdr_data, header_size - 8);
+                        }
+                        OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,"received  %x %x %x %x %x %x %x %x %x %x : header_size %x : tag %x \n",  
+                                             frag->data[0], 
+                                             frag->data[1], 
+                                             frag->data[2], 
+                                             frag->data[3], 
+                                             frag->data[4], 
+                                             frag->data[5], 
+                                             frag->data[6], 
+                                             frag->data[7], 
+                                             frag->data[8], 
+                                             frag->data[9],
+                                             header_size,
+                                             tag
+                                             ));
+                        
+                        OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,"received %d bytes \n", (int) ev.mlength));
+                        frag->segments[0].seg_addr.pval = &frag->data;
+                        frag->segments[0].seg_len = header_size;
+                        if(ev.mlength) {
+                            frag->segments[1].seg_addr.pval = ((((char*) ev.md.start) + ev.offset));
+                            frag->segments[1].seg_len = ev.mlength;
+                            frag->base.des_dst_cnt = 2;
+                        } else { 
+                            frag->base.des_dst_cnt = 1;
+                        }
+                    } else { 
+                        /* if we ever make this thread hot, need to do
+                           something with the receive fragments */
+                        frag->segments[0].seg_addr.pval = (((char*) ev.md.start) + ev.offset);
+                        frag->segments[0].seg_len = ev.mlength;
+                        
+                        OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                             "received send fragment 0x%lx (thresh: %d, length %d)", 
+                                             (unsigned long) frag,
+                                             ev.md.threshold, (int) ev.mlength));
+                        frag->base.des_dst_cnt = 1;
+                    }
+                    if (ev.md.length - (ev.offset + ev.mlength) < (ptl_size_t) ev.md.max_size ||
                         ev.md.threshold == 1) {
                         /* the block is full.  It's deactivated automagically, but we
                            can't start it up again until everyone is done with it.
                            The actual reactivation and all that will happen after the
                            free completes the last operation... */
                         OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
-                                             "marking block 0x%x as full", block->start));
+                                             "marking block 0x%lx as full",
+                                             (unsigned long) block->start));
                         block->full = true;
                     }
 
-                    assert(NULL != mca_btl_portals_module.portals_reg[tag].cbfunc);
-
-                    mca_btl_portals_module.portals_reg[tag].cbfunc(
+                    mca_btl_base_active_message_trigger[tag].cbfunc(
                                              &mca_btl_portals_module.super,
                                              tag,
                                              &frag->base,
-                                             mca_btl_portals_module.portals_reg[tag].cbdata);
+                                             mca_btl_base_active_message_trigger[tag].cbdata);
                     mca_btl_portals_return_block_part(&mca_btl_portals_module, block);
                 }
                 break;
-
+                
             case PTL_EVENT_REPLY_START:
                 /* generated on destination (origin) when a get starts
                    returning data */
-
-                OPAL_OUTPUT_VERBOSE((900, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_REPLY_START for 0x%x, %d",
-                                     frag, (int) ev.hdr_data));
-
+                
+                OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                     "PTL_EVENT_REPLY_START for 0x%lx, %d",
+                                     (unsigned long) frag, (int) ev.hdr_data));
+                
                 break;
-
+                
             case PTL_EVENT_REPLY_END:
                 /* generated on destination (origin) when a get is
                    done returning data */
-
+                
                 OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_REPLY_END for 0x%x", frag));
-
-                /* let the PML know we're done */
+                                     "PTL_EVENT_REPLY_END for 0x%lx",
+                                     (unsigned long) frag));
+                
                 frag->base.des_cbfunc(&mca_btl_portals_module.super,
                                       frag->endpoint,
                                       &frag->base,
                                       OMPI_SUCCESS);
+                
+                if( btl_ownership ) {
+                    OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                        "in PTL_EVENT_REPLY_END received a frag with btl_ownership!"));
+                    mca_btl_portals_free(&mca_btl_portals_module.super,
+                                         &frag->base);
+                }
 
                 break;
 
             case PTL_EVENT_SEND_START:
                 /* generated on source (origin) when put starts sending */
 
-#if OMPI_ENABLE_DEBUG
-                OPAL_OUTPUT_VERBOSE((900, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_SEND_START for 0x%x, %d",
-                                     frag, (int) ev.hdr_data));
+#if OPAL_ENABLE_DEBUG
+                OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
+                                     "PTL_EVENT_SEND_START for 0x%lx, %d",
+                                     (unsigned long) frag, (int) ev.hdr_data));
 
                 if (ev.ni_fail_type != PTL_NI_OK) {
                     opal_output(mca_btl_portals_component.portals_output,
@@ -503,26 +510,54 @@ mca_btl_portals_component_progress(void)
                                           frag->endpoint,
                                           &frag->base,
                                           OMPI_ERROR);
+                    if( btl_ownership ) {
+                        mca_btl_portals_free(&mca_btl_portals_module.super,
+                                             &frag->base);
+                    }
                 }
 #endif
                 break;
 
             case PTL_EVENT_SEND_END:
                 /* generated on source (origin) when put stops sending */
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
                 OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_SEND_END for 0x%x, %d",
-                                     frag, (int) ev.hdr_data));
-
+                                     "PTL_EVENT_SEND_END for 0x%lx, %d",
+                                     (unsigned long) frag, (int) ev.hdr_data));
+                
                 if (ev.ni_fail_type != PTL_NI_OK) {
                     opal_output(mca_btl_portals_component.portals_output,
                                 "Failure to end send event\n");
-                    frag->base.des_cbfunc(&mca_btl_portals_module.super,
-                                          frag->endpoint,
-                                          &frag->base,
-                                          OMPI_ERROR);
+                    if( MCA_BTL_DES_SEND_ALWAYS_CALLBACK & frag->base.des_flags ){ 
+                        frag->base.des_cbfunc(&mca_btl_portals_module.super,
+                                              frag->endpoint,
+                                              &frag->base,
+                                              OMPI_ERROR);
+                    }
+                    if( btl_ownership ) {
+                        mca_btl_portals_free(&mca_btl_portals_module.super,
+                                             &frag->base);
+                    }
                 }
 #endif
+                if(!mca_btl_portals_component.portals_need_ack) { 
+                    /* my part's done, in portals we trust! */
+                    if( MCA_BTL_DES_SEND_ALWAYS_CALLBACK & frag->base.des_flags ){ 
+                        frag->base.des_cbfunc(&mca_btl_portals_module.super,
+                                              frag->endpoint,
+                                              &frag->base,
+                                              OMPI_SUCCESS);
+                    }
+                    if( btl_ownership ) {
+                        mca_btl_portals_free(&mca_btl_portals_module.super,
+                                             &frag->base);
+                    }
+                    if (0 != frag->size) {
+                        OPAL_THREAD_ADD32(&mca_btl_portals_module.portals_outstanding_ops,
+                                          -1);
+                        MCA_BTL_PORTALS_PROGRESS_QUEUED_SENDS();
+                    }
+                }
                 break;
 
             case PTL_EVENT_ACK:
@@ -533,27 +568,44 @@ mca_btl_portals_component_progress(void)
                    Requeue the put on badness */
 
                 OPAL_OUTPUT_VERBOSE((90, mca_btl_portals_component.portals_output,
-                                     "PTL_EVENT_ACK for 0x%x", frag));
-
-#if OMPI_ENABLE_DEBUG
+                                     "PTL_EVENT_ACK for 0x%lx",
+                                     (unsigned long) frag));
+                
+#if OPAL_ENABLE_DEBUG
+                if(!mca_btl_portals_component.portals_need_ack) { 
+                    opal_output(mca_btl_portals_component.portals_output, 
+                                "Received PTL_EVENT_ACK but ACK's are disabled!\n");
+                    abort();
+                }
                 if (ev.ni_fail_type != PTL_NI_OK) {
                     opal_output(mca_btl_portals_component.portals_output,
                                 "Failure to ack event\n");
-                    frag->base.des_cbfunc(&mca_btl_portals_module.super,
-                                          frag->endpoint,
-                                          &frag->base,
-                                          OMPI_ERROR);
+                    if( MCA_BTL_DES_SEND_ALWAYS_CALLBACK & frag->base.des_flags ){ 
+                        frag->base.des_cbfunc(&mca_btl_portals_module.super,
+                                              frag->endpoint,
+                                              &frag->base,
+                                              OMPI_ERROR);
+                    }
+                    if( btl_ownership ) {
+                        mca_btl_portals_free(&mca_btl_portals_module.super,
+                                             &frag->base);
+                    }
                 } else
 #endif
 
-                if (0 == ev.mlength) {
+                if ((ev.rlength != ev.mlength) || (ev.rlength == 0)) {
                     /* other side received message but truncated to 0.
                        This should only happen for unexpected
                        messages, and only when the other side has no
                        buffer space available for receiving */
-                    opal_output_verbose(50,
-                                        mca_btl_portals_component.portals_output,
-                                        "message was dropped.  Trying again");
+
+                    if (ev.rlength == 0)
+                        opal_output_verbose(10, mca_btl_portals_component.portals_output,
+                                            "PTL_EVENT_ACK: ev.rlength=%lu ev.mlength=%lu: requeueing request",
+                                            (unsigned long)ev.rlength, (unsigned long)ev.mlength);
+                    else
+                        opal_output_verbose(50, mca_btl_portals_component.portals_output,
+                                            "message was dropped.  Trying again");
                     
                     mca_btl_portals_send(&mca_btl_portals_module.super,
                                          frag->endpoint,
@@ -563,14 +615,18 @@ mca_btl_portals_component_progress(void)
                     /* other side received the message.  should have
                        received entire thing */
                     /* let the PML know we're done */
-                    frag->base.des_cbfunc(&mca_btl_portals_module.super,
-                                          frag->endpoint,
-                                          &frag->base,
-                                          OMPI_SUCCESS);
+                    if( MCA_BTL_DES_SEND_ALWAYS_CALLBACK & frag->base.des_flags ) {
+                        frag->base.des_cbfunc(&mca_btl_portals_module.super,
+                                              frag->endpoint,
+                                              &frag->base,
+                                              OMPI_SUCCESS);
+                    }
+                    if( btl_ownership ) {
+                        mca_btl_portals_free(&mca_btl_portals_module.super,
+                                             &frag->base);
+                    }
                 }
 
-                opal_output_verbose(50, mca_btl_portals_component.portals_output, "fuck");
-
                 if (0 != frag->size) {
                     OPAL_THREAD_ADD32(&mca_btl_portals_module.portals_outstanding_ops,
                                       -1);
