@@ -19,9 +19,7 @@
 #ifndef OMPI_BTL_PORTALS_FRAG_H
 #define OMPI_BTL_PORTALS_FRAG_H
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
 /**
  * Portals send fragment derived type
@@ -42,6 +40,7 @@ struct mca_btl_portals_frag_t {
     enum { BTL_PORTALS_FRAG_TYPE_EAGER, 
            BTL_PORTALS_FRAG_TYPE_MAX,
            BTL_PORTALS_FRAG_TYPE_USER } type;
+    unsigned char  data[16];
 };
 typedef struct mca_btl_portals_frag_t mca_btl_portals_frag_t; 
 OBJ_CLASS_DECLARATION(mca_btl_portals_frag_t);
@@ -67,10 +66,10 @@ OBJ_CLASS_DECLARATION(mca_btl_portals_frag_recv_t);
                                                                    \
     ompi_free_list_item_t *item;                                        \
     OMPI_FREE_LIST_GET(&((mca_btl_portals_module_t*)btl_macro)->portals_frag_eager, item, rc); \
+    frag = (mca_btl_portals_frag_t*) item;                         \
     if (rc == OMPI_ERR_TEMP_OUT_OF_RESOURCE) {                     \
         OMPI_BTL_PORTALS_FRAG_ALLOC_MAX(btl_macro, frag, rc);      \
     }                                                              \
-    frag = (mca_btl_portals_frag_t*) item;                         \
 }
 
 
@@ -85,9 +84,9 @@ OBJ_CLASS_DECLARATION(mca_btl_portals_frag_recv_t);
 #define OMPI_BTL_PORTALS_FRAG_ALLOC_MAX(btl_macro, frag, rc)       \
 {                                                                  \
                                                                    \
-    ompi_free_list_item_t *item;                                        \
-    OMPI_FREE_LIST_WAIT(&((mca_btl_portals_module_t*)btl_macro)->portals_frag_max, item, rc); \
-    frag = (mca_btl_portals_frag_t*) item;                         \
+    ompi_free_list_item_t *item_macro;                                        \
+    OMPI_FREE_LIST_GET(&((mca_btl_portals_module_t*)btl_macro)->portals_frag_max, item_macro, rc); \
+    frag = (mca_btl_portals_frag_t*) item_macro;                         \
 }
 
 
@@ -115,7 +114,5 @@ OBJ_CLASS_DECLARATION(mca_btl_portals_frag_recv_t);
 }
 
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 #endif
