@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -24,6 +25,7 @@
 #include "opal/mca/mca.h"
 #include "opal/mca/base/base.h"
 #include "ompi/mca/coll/base/base.h"
+#include "opal/util/output.h"
 
 
 int mca_coll_base_close(void)
@@ -34,16 +36,18 @@ int mca_coll_base_close(void)
 
     if (mca_coll_base_components_opened_valid) {
         mca_base_components_close(mca_coll_base_output,
-                                  &mca_coll_base_components_opened, NULL);
+                                  &mca_coll_base_components_opened, 
+                                  NULL, false);
         OBJ_DESTRUCT(&mca_coll_base_components_opened);
         mca_coll_base_components_opened_valid = false;
     } else if (mca_coll_base_components_available_valid) {
         mca_base_components_close(mca_coll_base_output,
                                   &mca_coll_base_components_available,
-                                  NULL);
+                                  NULL, false);
         OBJ_DESTRUCT(&mca_coll_base_components_available);
         mca_coll_base_components_available_valid = false;
     }
+    opal_output_close(mca_coll_base_output);
 
     /* All done */
 
