@@ -22,7 +22,7 @@
 #include "mpi.h"
 #include "ompi/constants.h"
 #include "coll_basic.h"
-#include "ompi/datatype/datatype.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "ompi/mca/coll/coll.h"
 #include "ompi/mca/coll/base/coll_tags.h"
 #include "ompi/mca/pml/pml.h"
@@ -64,12 +64,12 @@ mca_coll_basic_gather_intra(void *sbuf, int scount,
 
     /* I am the root, loop receiving the data. */
 
-    ompi_ddt_get_extent(rdtype, &lb, &extent);
+    ompi_datatype_get_extent(rdtype, &lb, &extent);
     incr = extent * rcount;
     for (i = 0, ptmp = (char *) rbuf; i < size; ++i, ptmp += incr) {
         if (i == rank) {
             if (MPI_IN_PLACE != sbuf) {
-                err = ompi_ddt_sndrcv(sbuf, scount, sdtype,
+                err = ompi_datatype_sndrcv(sbuf, scount, sdtype,
                                       ptmp, rcount, rdtype);
             } else {
                 err = MPI_SUCCESS;
@@ -125,7 +125,7 @@ mca_coll_basic_gather_inter(void *sbuf, int scount,
                                 MCA_PML_BASE_SEND_STANDARD, comm));
     } else {
         /* I am the root, loop receiving the data. */
-        err = ompi_ddt_get_extent(rdtype, &lb, &extent);
+        err = ompi_datatype_get_extent(rdtype, &lb, &extent);
         if (OMPI_SUCCESS != err) {
             return OMPI_ERROR;
         }
