@@ -25,6 +25,7 @@
 #include "ompi/constants.h"
 #include "ompi/mca/coll/coll.h"
 #include "ompi/mca/coll/base/coll_tags.h"
+#include "ompi/mca/pml/pml.h"
 #include "ompi/op/op.h"
 
 /*
@@ -187,8 +188,8 @@ mca_coll_basic_reduce_lin_intra(void *sbuf, void *rbuf, int count,
      * 
      */
 
-    ompi_ddt_get_extent(dtype, &lb, &extent);
-    ompi_ddt_get_true_extent(dtype, &true_lb, &true_extent);
+    ompi_datatype_get_extent(dtype, &lb, &extent);
+    ompi_datatype_get_true_extent(dtype, &true_lb, &true_extent);
 
     if (MPI_IN_PLACE == sbuf) {
         sbuf = rbuf;
@@ -210,7 +211,7 @@ mca_coll_basic_reduce_lin_intra(void *sbuf, void *rbuf, int count,
     /* Initialize the receive buffer. */
 
     if (rank == (size - 1)) {
-        err = ompi_ddt_copy_content_same_ddt(dtype, count, (char*)rbuf, (char*)sbuf);
+        err = ompi_datatype_copy_content_same_ddt(dtype, count, (char*)rbuf, (char*)sbuf);
     } else {
         err = MCA_PML_CALL(recv(rbuf, count, dtype, size - 1,
                                 MCA_COLL_BASE_TAG_REDUCE, comm,
@@ -248,7 +249,7 @@ mca_coll_basic_reduce_lin_intra(void *sbuf, void *rbuf, int count,
     }
 
     if (NULL != inplace_temp) {
-        err = ompi_ddt_copy_content_same_ddt(dtype, count, (char*)sbuf, inplace_temp);
+        err = ompi_datatype_copy_content_same_ddt(dtype, count, (char*)sbuf, inplace_temp);
         free(inplace_temp);
     }
     if (NULL != free_buffer) {
@@ -346,13 +347,11 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
     vrank = ompi_op_is_commute(op) ? (rank - root + size) % size : rank;
     dim = comm->c_cube_dim;
 
-	
-
     /* Allocate the incoming and resulting message buffers.  See lengthy
      * rationale above. */
 
-    ompi_ddt_get_extent(dtype, &lb, &extent);
-    ompi_ddt_get_true_extent(dtype, &true_lb, &true_extent);
+    ompi_datatype_get_extent(dtype, &lb, &extent);
+    ompi_datatype_get_true_extent(dtype, &true_lb, &true_extent);
     
     free_buffer = (char*)malloc(true_extent + (count - 1) * extent);
     if (NULL == free_buffer) {
@@ -372,10 +371,11 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
     if (MPI_IN_PLACE == sbuf) {
         inplace_temp = (char*)malloc(true_extent + (count - 1) * extent);
         if (NULL == inplace_temp) {
-            return OMPI_ERR_OUT_OF_RESOURCE;
+            err = OMPI_ERR_OUT_OF_RESOURCE;
+            goto cleanup_and_return;
         }
         sbuf = inplace_temp - lb;
-        err = ompi_ddt_copy_content_same_ddt(dtype, count, (char*)sbuf, (char*)rbuf);
+        err = ompi_datatype_copy_content_same_ddt(dtype, count, (char*)sbuf, (char*)rbuf);
     }
     snd_buffer = (char*)sbuf;
 
@@ -385,8 +385,8 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
          * here to be valid on all non-leaf ranks */
         free_rbuf = (char*)malloc(true_extent + (count - 1) * extent);
         if (NULL == free_rbuf) {
-            free(free_buffer);
-            return OMPI_ERR_OUT_OF_RESOURCE;
+            err = OMPI_ERR_OUT_OF_RESOURCE;
+            goto cleanup_and_return;
         }
         rbuf = free_rbuf - lb;
     }
@@ -407,13 +407,7 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
                                     dtype, peer, MCA_COLL_BASE_TAG_REDUCE,
                                     MCA_PML_BASE_SEND_STANDARD, comm));
             if (MPI_SUCCESS != err) {
-                if (NULL != free_buffer) {
-                    free(free_buffer);
-                }
-                if (NULL != free_rbuf) {
-                    free(free_rbuf);
-                }
-                return err;
+                goto cleanup_and_return;
             }
             snd_buffer = (char*)rbuf;
             break;
@@ -444,13 +438,7 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
                                     MCA_COLL_BASE_TAG_REDUCE, comm,
                                     MPI_STATUS_IGNORE));
             if (MPI_SUCCESS != err) {
-                if (NULL != free_buffer) {
-                    free(free_buffer);
-                }
-                if (NULL != free_rbuf) {
-                    free(free_rbuf);
-                }
-                return err;
+                goto cleanup_and_return;
             }
             /* Perform the operation. The target is always the user
              * provided buffer We do the operation only if we receive it
@@ -465,7 +453,7 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
                  * buffer into a temp buffer (pml_buffer) and then reduce
                  * what we just received against it. */
                 if (!ompi_op_is_commute(op)) {
-                    ompi_ddt_copy_content_same_ddt(dtype, count, pml_buffer,
+                    ompi_datatype_copy_content_same_ddt(dtype, count, pml_buffer,
                                                    (char*)sbuf);
                     ompi_op_reduce(op, rbuf, pml_buffer, count, dtype);
                 } else {
@@ -484,7 +472,7 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
     err = MPI_SUCCESS;
     if (0 == vrank) {
         if (root == rank) {
-            ompi_ddt_copy_content_same_ddt(dtype, count, (char*)rbuf, snd_buffer);
+            ompi_datatype_copy_content_same_ddt(dtype, count, (char*)rbuf, snd_buffer);
         } else {
             err = MCA_PML_CALL(send(snd_buffer, count,
                                     dtype, root, MCA_COLL_BASE_TAG_REDUCE,
@@ -499,6 +487,7 @@ mca_coll_basic_reduce_log_intra(void *sbuf, void *rbuf, int count,
         }
     }
 
+  cleanup_and_return:
     if (NULL != inplace_temp) {
         free(inplace_temp);
     }
@@ -547,8 +536,8 @@ mca_coll_basic_reduce_lin_inter(void *sbuf, void *rbuf, int count,
                                 MCA_PML_BASE_SEND_STANDARD, comm));
     } else {
         /* Root receives and reduces messages  */
-        ompi_ddt_get_extent(dtype, &lb, &extent);
-        ompi_ddt_get_true_extent(dtype, &true_lb, &true_extent);
+        ompi_datatype_get_extent(dtype, &lb, &extent);
+        ompi_datatype_get_true_extent(dtype, &true_lb, &true_extent);
 
         free_buffer = (char*)malloc(true_extent + (count - 1) * extent);
         if (NULL == free_buffer) {
