@@ -21,7 +21,7 @@
 
 #include "mpi.h"
 #include "ompi/constants.h"
-#include "ompi/datatype/datatype.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "ompi/mca/coll/coll.h"
 #include "ompi/mca/coll/base/coll_tags.h"
 #include "ompi/mca/pml/pml.h"
@@ -40,7 +40,8 @@ mca_coll_basic_scatter_intra(void *sbuf, int scount,
                              struct ompi_datatype_t *sdtype,
                              void *rbuf, int rcount,
                              struct ompi_datatype_t *rdtype,
-                             int root, struct ompi_communicator_t *comm)
+                             int root, struct ompi_communicator_t *comm,
+                             mca_coll_base_module_t *module)
 {
     int i, rank, size, err;
     char *ptmp;
@@ -62,7 +63,7 @@ mca_coll_basic_scatter_intra(void *sbuf, int scount,
 
     /* I am the root, loop sending data. */
 
-    err = ompi_ddt_get_extent(sdtype, &lb, &incr);
+    err = ompi_datatype_get_extent(sdtype, &lb, &incr);
     if (OMPI_SUCCESS != err) {
         return OMPI_ERROR;
     }
@@ -75,7 +76,7 @@ mca_coll_basic_scatter_intra(void *sbuf, int scount,
         if (i == rank) {
             if (MPI_IN_PLACE != rbuf) {
                 err =
-                    ompi_ddt_sndrcv(ptmp, scount, sdtype, rbuf, rcount,
+                    ompi_datatype_sndrcv(ptmp, scount, sdtype, rbuf, rcount,
                                     rdtype);
             }
         } else {
@@ -106,16 +107,16 @@ mca_coll_basic_scatter_inter(void *sbuf, int scount,
                              struct ompi_datatype_t *sdtype,
                              void *rbuf, int rcount,
                              struct ompi_datatype_t *rdtype,
-                             int root, struct ompi_communicator_t *comm)
+                             int root, struct ompi_communicator_t *comm,
+                             mca_coll_base_module_t *module)
 {
-    int i, rank, size, err;
+    int i, size, err;
     char *ptmp;
     ptrdiff_t lb, incr;
-    ompi_request_t **reqs = comm->c_coll_basic_data->mccb_reqs;
+    mca_coll_basic_module_t *basic_module = (mca_coll_basic_module_t*) module;
+    ompi_request_t **reqs = basic_module->mccb_reqs;
 
     /* Initialize */
-
-    rank = ompi_comm_rank(comm);
     size = ompi_comm_remote_size(comm);
 
     if (MPI_PROC_NULL == root) {
@@ -128,7 +129,7 @@ mca_coll_basic_scatter_inter(void *sbuf, int scount,
                                 comm, MPI_STATUS_IGNORE));
     } else {
         /* I am the root, loop sending data. */
-        err = ompi_ddt_get_extent(sdtype, &lb, &incr);
+        err = ompi_datatype_get_extent(sdtype, &lb, &incr);
         if (OMPI_SUCCESS != err) {
             return OMPI_ERROR;
         }
@@ -145,7 +146,7 @@ mca_coll_basic_scatter_inter(void *sbuf, int scount,
         }
 
         err =
-            ompi_request_wait_all(size, comm->c_coll_basic_data->mccb_reqs,
+            ompi_request_wait_all(size, basic_module->mccb_reqs,
                                   MPI_STATUSES_IGNORE);
     }
 
