@@ -35,7 +35,7 @@ static mca_coll_fca_dtype_info_t* mca_coll_fca_get_dtype(ompi_datatype_t *dtype)
     /* assert we don't overwrite another datatype */
     assert(dtype_info->mpi_dtype == MPI_DATATYPE_NULL);
 
-    fca_dtype = mca_coll_fca_component.fca_ops.translate_mpi_dtype(dtype->name);
+    fca_dtype = fca_translate_mpi_dtype(dtype->name);
     if (fca_dtype < 0) {
         return NULL;
     }
@@ -44,7 +44,7 @@ static mca_coll_fca_dtype_info_t* mca_coll_fca_get_dtype(ompi_datatype_t *dtype)
     dtype_info->mpi_dtype = dtype;
     dtype_info->mpi_dtype_extent = extent;
     dtype_info->fca_dtype = fca_dtype;
-    dtype_info->fca_dtype_extent = mca_coll_fca_component.fca_ops.get_dtype_size(fca_dtype);
+    dtype_info->fca_dtype_extent = fca_get_dtype_size(fca_dtype);
     FCA_VERBOSE(2, "Added new dtype[%d]: %s fca id: %d, mpi size: %lu, fca size: %lu",
                 id, dtype->name, dtype_info->fca_dtype, dtype_info->mpi_dtype_extent,
                 dtype_info->fca_dtype_extent);
@@ -66,7 +66,7 @@ static mca_coll_fca_op_info_t *mca_coll_fca_get_op(ompi_op_t *op)
         if (op_info->mpi_op == op) {
             return op_info;
         } else if (op_info->mpi_op == MPI_OP_NULL) {
-            fca_op = mca_coll_fca_component.fca_ops.translate_mpi_op(op->o_name);
+            fca_op = fca_translate_mpi_op(op->o_name);
             if (fca_op < 0)
                 return NULL;
             op_info->mpi_op = op;
@@ -153,12 +153,12 @@ int mca_coll_fca_barrier(struct ompi_communicator_t *comm,
     int ret;
 
     FCA_VERBOSE(5,"Using FCA Barrier");
-    ret = mca_coll_fca_component.fca_ops.do_barrier(fca_module->fca_comm);
+    ret = fca_do_barrier(fca_module->fca_comm);
     if (ret < 0) {
         if (ret == -EUSEMPI) {
             goto orig_barrier;
         }
-        FCA_ERROR("Barrier failed: %s", mca_coll_fca_component.fca_ops.strerror(ret));
+        FCA_ERROR("Barrier failed: %s", fca_strerror(ret));
         return OMPI_ERROR;
     }
     return OMPI_SUCCESS;
@@ -216,7 +216,7 @@ int mca_coll_fca_bcast(void *buff, int count, struct ompi_datatype_t *datatype,
 
     /* Call FCA Bcast */
     FCA_VERBOSE(5, "Using FCA Bcast");
-    ret = mca_coll_fca_component.fca_ops.do_bcast(fca_module->fca_comm, &spec);
+    ret = fca_do_bcast(fca_module->fca_comm, &spec);
 
     /* Destroy convertor if operation failed */
     if (ret < 0) {
@@ -224,7 +224,7 @@ int mca_coll_fca_bcast(void *buff, int count, struct ompi_datatype_t *datatype,
         if (ret == -EUSEMPI) {
             goto orig_bcast;
         }
-        FCA_ERROR("Bcast failed: %s", mca_coll_fca_component.fca_ops.strerror(ret));
+        FCA_ERROR("Bcast failed: %s", fca_strerror(ret));
         return OMPI_ERROR;
     }
 
@@ -269,12 +269,12 @@ int mca_coll_fca_reduce(void *sbuf, void *rbuf, int count,
     }
 
     FCA_VERBOSE(5,"Using FCA Reduce");
-    ret = mca_coll_fca_component.fca_ops.do_reduce(fca_module->fca_comm, &spec);
+    ret = fca_do_reduce(fca_module->fca_comm, &spec);
     if (ret < 0) {
         if (ret == -EUSEMPI) {
             goto orig_reduce;
         }
-        FCA_ERROR("Reduce failed: %s", mca_coll_fca_component.fca_ops.strerror(ret));
+        FCA_ERROR("Reduce failed: %s", fca_strerror(ret));
         return OMPI_ERROR;
     }
     return OMPI_SUCCESS;
@@ -310,12 +310,12 @@ int mca_coll_fca_allreduce(void *sbuf, void *rbuf, int count,
     }
 
     FCA_VERBOSE(5,"Using FCA Allreduce");
-    ret = mca_coll_fca_component.fca_ops.do_all_reduce(fca_module->fca_comm, &spec);
+    ret = fca_do_all_reduce(fca_module->fca_comm, &spec);
     if (ret < 0) {
         if (ret == -EUSEMPI) {
             goto orig_allreduce;
         }
-        FCA_ERROR("Allreduce failed: %s", mca_coll_fca_component.fca_ops.strerror(ret));
+        FCA_ERROR("Allreduce failed: %s", fca_strerror(ret));
         return OMPI_ERROR;
     }
     return OMPI_SUCCESS;
@@ -328,7 +328,7 @@ orig_allreduce:
 /*
  * Prepare a send buffer for allgather/allgatherv, handle packing and MPI_IN_PLACE.
  */
-static size_t __setup_gather_sendbuf(void *sbuf, void *inplace_sbuf, int scount,
+static size_t __setup_gather_sendbuf(void *sbuf, int scount,
                                      struct ompi_datatype_t *sdtype,
                                      struct mca_coll_fca_convertor *sconv,
                                      void **real_sendbuf)
@@ -336,18 +336,31 @@ static size_t __setup_gather_sendbuf(void *sbuf, void *inplace_sbuf, int scount,
     size_t gap, ssize;
 
     if (mca_coll_fca_array_size(sdtype, scount, &gap, &ssize)) {
-        *real_sendbuf = (char*)((MPI_IN_PLACE == sbuf) ? inplace_sbuf : sbuf) + gap;
+        *real_sendbuf = (char*) sbuf + gap;
     } else {
         FCA_VERBOSE(5, "Packing send buffer");
-        if (MPI_IN_PLACE == sbuf) {
-            mca_coll_fca_convertor_create(sconv, sdtype, scount, inplace_sbuf,
-                                          MCA_COLL_FCA_CONV_SEND, real_sendbuf,
-                                          &ssize);
-        } else {
-            mca_coll_fca_convertor_create(sconv, sdtype, scount, sbuf,
-                                          MCA_COLL_FCA_CONV_SEND, real_sendbuf,
-                                          &ssize);
-        }
+        mca_coll_fca_convertor_create(sconv, sdtype, scount, sbuf,
+                                      MCA_COLL_FCA_CONV_SEND, real_sendbuf,
+                                      &ssize);
+        mca_coll_fca_convertor_process(sconv, 0);
+    }
+    return ssize;
+}
+
+static size_t __setup_gather_sendbuf_inplace(void *inplace_sbuf, int rcount,
+                                             struct ompi_datatype_t *rdtype,
+                                             struct mca_coll_fca_convertor *sconv,
+                                             void **real_sendbuf)
+{
+    size_t gap, ssize;
+
+    if (mca_coll_fca_array_size(rdtype, rcount, &gap, &ssize)) {
+        *real_sendbuf = (char*) inplace_sbuf + gap;
+    } else {
+        FCA_VERBOSE(5, "Packing send buffer");
+        mca_coll_fca_convertor_create(sconv, rdtype, rcount, inplace_sbuf,
+                                      MCA_COLL_FCA_CONV_SEND, real_sendbuf,
+                                      &ssize);
         mca_coll_fca_convertor_process(sconv, 0);
     }
     return ssize;
@@ -375,12 +388,15 @@ int mca_coll_fca_allgather(void *sbuf, int scount, struct ompi_datatype_t *sdtyp
     ssize_t total_rcount;
     int ret;
 
-    FCA_DT_EXTENT(rdtype, &rdtype_extent);
-
     /* Setup send buffer */
-    spec.size =
-            __setup_gather_sendbuf(sbuf, (char *)rbuf + rcount * fca_module->rank * rdtype_extent,
-                                   scount, sdtype, &sconv, &spec.sbuf);
+    if(sbuf == MPI_IN_PLACE ) {
+        FCA_DT_EXTENT(rdtype, &rdtype_extent);
+        spec.size = __setup_gather_sendbuf_inplace(
+                        (char *)rbuf + rcount * fca_module->rank * rdtype_extent,
+                        rcount, rdtype, &sconv, &spec.sbuf);
+    } else {
+        spec.size = __setup_gather_sendbuf(sbuf, scount, sdtype, &sconv, &spec.sbuf);
+    }
 
     /* Setup recv buffer */
     total_rcount = ompi_comm_size(comm) * rcount;
@@ -394,7 +410,7 @@ int mca_coll_fca_allgather(void *sbuf, int scount, struct ompi_datatype_t *sdtyp
 
     /* Call FCA Allgather */
     FCA_VERBOSE(5,"Using FCA Allgather size");
-    ret = mca_coll_fca_component.fca_ops.do_allgather(fca_module->fca_comm, &spec);
+    ret = fca_do_allgather(fca_module->fca_comm, &spec);
 
     /* Destroy convertors if operation failed */
     if (ret < 0) {
@@ -403,7 +419,7 @@ int mca_coll_fca_allgather(void *sbuf, int scount, struct ompi_datatype_t *sdtyp
         if (ret == -EUSEMPI) {
             goto orig_allgather;
         }
-        FCA_ERROR("Allgather failed: %s", mca_coll_fca_component.fca_ops.strerror(ret));
+        FCA_ERROR("Allgather failed: %s", fca_strerror(ret));
         return OMPI_ERROR;
     }
 
@@ -446,9 +462,13 @@ int mca_coll_fca_allgatherv(void *sbuf, int scount,
     FCA_DT_EXTENT(rdtype, &rdtype_extent);
 
     /* Setup send buffer */
-    spec.sendsize =
-            __setup_gather_sendbuf(sbuf, (char *)rbuf + disps[fca_module->rank] * rdtype_extent,
-                                   scount, sdtype, &sconv, &spec.sbuf);
+    if(sbuf == MPI_IN_PLACE ) {
+        spec.sendsize = __setup_gather_sendbuf_inplace(
+                                (char *)rbuf + disps[fca_module->rank] * rdtype_extent,
+                                rcounts[fca_module->rank], rdtype, &sconv, &spec.sbuf);
+    } else {
+        spec.sendsize = __setup_gather_sendbuf(sbuf, scount, sdtype, &sconv, &spec.sbuf);
+    }
 
     /* Allocate alternative recvsizes/displs on the stack, which will be in bytes */
     spec.recvsizes = alloca(sizeof *spec.recvsizes * comm_size);
@@ -489,7 +509,7 @@ int mca_coll_fca_allgatherv(void *sbuf, int scount,
 
     /* Call FCA AllgatherV */
     FCA_VERBOSE(5,"Using FCA Allgatherv");
-    ret = mca_coll_fca_component.fca_ops.do_allgatherv(fca_module->fca_comm, &spec);
+    ret = fca_do_allgatherv(fca_module->fca_comm, &spec);
 
     /* Destroy convertors if operation failed */
     if (ret < 0) {
@@ -498,7 +518,7 @@ int mca_coll_fca_allgatherv(void *sbuf, int scount,
         if (ret == -EUSEMPI) {
             goto orig_allgatherv;
         }
-        FCA_ERROR("Allgatherv failed: %s", mca_coll_fca_component.fca_ops.strerror(ret));
+        FCA_ERROR("Allgatherv failed: %s", fca_strerror(ret));
         return OMPI_ERROR;
     }
 
