@@ -10,7 +10,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2007-2010 University of Houston. All rights reserved.
+ * Copyright (c) 2007-2008 University of Houston. All rights reserved.
  * Copyright (c) 2008      Sun Microsystems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
@@ -28,13 +28,12 @@
 #include "ompi/communicator/communicator.h"
 #include "ompi/group/group.h"
 #include "ompi/proc/proc.h"
-#include "ompi/op/op.h"
 
 #include "ompi/mca/coll/coll.h"
 #include "ompi/mca/coll/base/base.h"
 #include "ompi/mca/coll/base/coll_tags.h"
 
-#include "ompi/class/ompi_bitmap.h"
+#include "opal/class/opal_bitmap.h"
 #include "ompi/mca/bml/bml.h"
 #include "ompi/mca/bml/base/base.h"
 #include "ompi/mca/pml/pml.h"
@@ -269,13 +268,13 @@ int mca_coll_hierarch_module_enable (mca_coll_base_module_t *module,
     if ( OMPI_SUCCESS != ret ) {
         goto exit;
     }
-    if ( OMPI_COMM_CID_IS_LOWER ( lcomm, comm ) ) {	
-	/* Mark the communicator as 'interna' and increase the 
-	   reference count by one more. See ompi_comm_activate
-	   for detailed comments 
+    if ( OMPI_COMM_CID_IS_LOWER ( lcomm, comm ) ) {
+        /* Mark the communicator as 'extra retain' and increase the
+           reference count by one more. See ompi_comm_activate
+           for detailed comments
 	*/
         OMPI_COMM_SET_EXTRA_RETAIN (lcomm);
-	OBJ_RETAIN(lcomm);
+        OBJ_RETAIN(lcomm);
     }
     
     hierarch_module->hier_comm     = comm;
@@ -290,7 +289,7 @@ int mca_coll_hierarch_module_enable (mca_coll_base_module_t *module,
        information about local leader and the according subcommunicators 
     */
     llead = (struct mca_coll_hierarch_llead_t * ) malloc ( 
-	                          sizeof(struct mca_coll_hierarch_llead_t));
+                                                          sizeof(struct mca_coll_hierarch_llead_t));
     if ( NULL == llead ) {
         goto exit;
     }
@@ -303,7 +302,7 @@ int mca_coll_hierarch_module_enable (mca_coll_base_module_t *module,
      */
     mca_coll_hierarch_get_llr ( hierarch_module );
     mca_coll_hierarch_get_all_lleaders ( rank, hierarch_module, llead, 1 );        
-
+    
     /* Generate the lleader communicator assuming that all lleaders are the first
        process in the list of processes with the same color. A function generating 
        other lleader-comms will follow soon. */
@@ -315,15 +314,16 @@ int mca_coll_hierarch_module_enable (mca_coll_base_module_t *module,
     if ( OMPI_SUCCESS != ret ) {
         goto exit;
     }
-    if ( OMPI_COMM_CID_IS_LOWER ( llcomm, comm ) ) {	
-	/* Mark the communicator as 'extra_retain' and increase the 
-	   reference count by one more. See ompi_comm_activate
-	   for detailed explanations. */
-	OMPI_COMM_SET_EXTRA_RETAIN (llcomm);
-	OBJ_RETAIN(llcomm);
+    if ( OMPI_COMM_CID_IS_LOWER ( llcomm, comm ) ) {
+        /* Mark the communicator as 'extra retain' and increase the
+           reference count by one more. See ompi_comm_activate
+	   for detailed explanation. 
+	*/
+        OMPI_COMM_SET_EXTRA_RETAIN (llcomm);
+        OBJ_RETAIN(llcomm);
     }
 
-
+    
     llead->llcomm = llcomm;
     
     /* Store it now on the data structure */
@@ -507,23 +507,24 @@ struct ompi_communicator_t*  mca_coll_hierarch_get_llcomm (int root,
 	
 	/* generate the list of lleaders with this offset */
 	mca_coll_hierarch_get_all_lleaders ( rank, hierarch_module, llead, offset );   
-	
-	/* create new lleader subcommunicator */
 	color = MPI_UNDEFINED;
 	if ( llead->am_lleader ) {
 	    color = 1;
 	}
+
+	/* create new lleader subcommunicator */
 	rc = ompi_comm_split ( hierarch_module->hier_comm, color, root, &llcomm, 0);
 	if ( OMPI_SUCCESS != rc ) {
 	    return NULL;
 	}
-	if ( OMPI_COMM_CID_IS_LOWER ( llcomm, hierarch_module->hier_comm ) ) {	
-	    /* Mark the communicator as 'extra_retain' and increase the 
-	       reference count by one more. See ompi_comm_activate
-	       for detailed explanations. */
-	    OMPI_COMM_SET_EXTRA_RETAIN (llcomm);
-	    OBJ_RETAIN(llcomm);
-	}
+	if ( OMPI_COMM_CID_IS_LOWER ( llcomm, hierarch_module->hier_comm ) ) {
+            /* Mark the communicator as 'extra retain' and increase the
+               reference count by one more. See ompi_comm_activate 
+	       for detailed explanation. */
+            OMPI_COMM_SET_EXTRA_RETAIN (llcomm);
+            OBJ_RETAIN(llcomm);
+        }
+
 
 	llead->llcomm = llcomm;
 
@@ -536,13 +537,13 @@ struct ompi_communicator_t*  mca_coll_hierarch_get_llcomm (int root,
     *llroot = MPI_UNDEFINED;
 
     if ( MPI_COMM_NULL != llcomm ) {
-	group = hierarch_module->hier_comm->c_local_group;
+	group   = hierarch_module->hier_comm->c_local_group;
 	llgroup = llcomm->c_local_group;
-	
-	rc = ompi_group_translate_ranks ( group, 1, &root, llgroup, llroot);
-	if ( OMPI_SUCCESS != rc ) {
-	    return NULL;
-	}
+
+        rc = ompi_group_translate_ranks ( group, 1, &root, llgroup, llroot);
+        if ( OMPI_SUCCESS != rc ) {
+            return NULL;
+        }
     }
      
     return llcomm;
@@ -567,7 +568,7 @@ mca_coll_hierarch_checkfor_sm ( struct ompi_communicator_t *comm, int *color,  i
     procs = comm->c_local_group->grp_proc_pointers;
     for ( i = 0 ; i < size ; i++) {
 	if ( procs[i]->proc_name.jobid == my_proc->proc_name.jobid &&
-	     ( (procs[i]->proc_flags & OMPI_PROC_FLAG_LOCAL)) ) {
+	     ( OPAL_PROC_ON_LOCAL_NODE(procs[i]->proc_flags)) ) {
 	    lncount++;
 	    if ( *color == -1){
 		 *color = i;
@@ -602,7 +603,7 @@ mca_coll_hierarch_checkfor_component ( struct ompi_communicator_t *comm,
 				       int *key,
 				       int *ncount )
 {
-    ompi_bitmap_t reachable;
+    opal_bitmap_t reachable;
     ompi_proc_t **procs=NULL;
     struct mca_bml_base_btl_array_t *bml_btl_array=NULL;
     mca_bml_base_btl_t *bml_btl=NULL;
@@ -625,8 +626,8 @@ mca_coll_hierarch_checkfor_component ( struct ompi_communicator_t *comm,
     size = ompi_comm_size ( comm );
     rank = ompi_comm_rank ( comm );
 
-    OBJ_CONSTRUCT(&reachable, ompi_bitmap_t);
-    rc = ompi_bitmap_init(&reachable, size);
+    OBJ_CONSTRUCT(&reachable, opal_bitmap_t);
+    rc = opal_bitmap_init(&reachable, size);
     if(OMPI_SUCCESS != rc) {
         return;
     }
