@@ -10,7 +10,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2007-2010 University of Houston. All rights reserved.
+ * Copyright (c) 2007-2009 University of Houston. All rights reserved.
  * Copyright (c) 2008      Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
@@ -46,6 +46,8 @@ int mca_coll_hierarch_verbose_param=0;
 int mca_coll_hierarch_use_rdma_param=0;   
 int mca_coll_hierarch_ignore_sm_param=0;   
 int mca_coll_hierarch_detection_alg_param=2;
+int mca_coll_hierarch_bcast_alg_param=COLL_HIERARCH_BASIC_BCAST_ALG;
+int mca_coll_hierarch_segsize_param=32768;
 
 /*
  * Local function
@@ -122,10 +124,23 @@ static int hierarch_open(void)
     mca_base_param_reg_int(&mca_coll_hierarch_component.collm_version,
                            "detection_alg",
                            "Used to specify the algorithm for detecting Hierarchy."
-			   "To specify all levels or two levels of hierarchy",
+			   "Choose between all or two levels of hierarchy",
                            false, false, mca_coll_hierarch_detection_alg_param,
                            &mca_coll_hierarch_detection_alg_param);
 
+
+    mca_base_param_reg_int(&mca_coll_hierarch_component.collm_version,
+                           "bcast_alg",
+                           "Used to specify the algorithm used for bcast operations.",
+                           false, false, mca_coll_hierarch_bcast_alg_param,
+                           &mca_coll_hierarch_bcast_alg_param);
+
+    mca_base_param_reg_int(&mca_coll_hierarch_component.collm_version,
+                           "segment_size",
+                           "Used to specify the segment size for segmented algorithms.",
+                           false, false, mca_coll_hierarch_segsize_param,
+                           &mca_coll_hierarch_segsize_param);
+
     return OMPI_SUCCESS;
 }
 
@@ -165,10 +180,9 @@ mca_coll_hierarch_module_destruct(mca_coll_hierarch_module_t *hierarch_module)
         if ( NULL != current->lleaders ) {
             free ( current->lleaders );
         }
-	if ( MPI_COMM_NULL != current->llcomm ) {
-            ompi_comm_free ( &(current->llcomm));
+	if ( MPI_COMM_NULL != current->llcomm ){
+	    ompi_comm_free ( &(current->llcomm));
 	}
-
         free ( current );
     }
     opal_pointer_array_remove_all ( &(hierarch_module->hier_llead));
