@@ -19,7 +19,7 @@
 #include "ompi_config.h"
 
 #include "ompi/constants.h"
-#include "ompi/datatype/datatype.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "coll_self.h"
 
 
@@ -40,15 +40,15 @@ mca_coll_self_alltoallv_intra(void *sbuf, int *scounts, int *sdisps,
 {
     int err;        
     ptrdiff_t lb, rextent, sextent;
-    err = ompi_ddt_get_extent(sdtype, &lb, &sextent);
+    err = ompi_datatype_get_extent(sdtype, &lb, &sextent);
     if (OMPI_SUCCESS != err) {
         return OMPI_ERROR;
     }
-    err = ompi_ddt_get_extent(rdtype, &lb, &rextent);
+    err = ompi_datatype_get_extent(rdtype, &lb, &rextent);
     if (OMPI_SUCCESS != err) {
         return OMPI_ERROR;
     }
-    return ompi_ddt_sndrcv(((char *) sbuf) + sdisps[0] * sextent, 
+    return ompi_datatype_sndrcv(((char *) sbuf) + sdisps[0] * sextent, 
                            scounts[0], sdtype,
                            ((char *) rbuf) + rdisps[0] * rextent, 
                            rcounts[0], rdtype);
