@@ -172,7 +172,7 @@ int ompi_coll_tuned_allgather_intra_bruck(void *sbuf, int scount,
       err = ompi_datatype_get_true_extent(rdtype, &true_lb, &true_extent);
       if (MPI_SUCCESS != err) { line = __LINE__; goto err_hndl; }
 
-      free_buf = (char*) calloc(((true_extent + 
+      free_buf = (char*) calloc(((true_extent + true_lb +
                                   ((size - rank) * rcount - 1) * rext)),
                                 sizeof(char));
       if (NULL == free_buf) { 
