@@ -19,6 +19,7 @@
 #ifndef OMPI_MCA_COMMON_MX_H
 #define OMPI_MCA_COMMON_MX_H
 
+#include "ompi_config.h"
 #include "myriexpress.h"
 
 
@@ -28,14 +29,14 @@
  * @retval OMPI_SUCCESS MX successfully initialized
  * @retval OMPI_ERR_NOT_AVAILABLE MX could not be initialized
  */
-int ompi_common_mx_initialize(void);
+OMPI_DECLSPEC int ompi_common_mx_initialize(void);
 
 
 /**
  * Shut down mx library 
  *
  */
-int ompi_common_mx_finalize(void);
+OMPI_DECLSPEC int ompi_common_mx_finalize(void);
 
 
 
