@@ -32,12 +32,6 @@ struct mca_io_base_file_t;
 struct mca_io_base_delete_t;
 
 
-/*
- * Forward declaration so that we don't create an include file loop.
- */
-struct mca_io_base_request_t;
-
-
 /*
  * Forward declarations of things declared in this file
  */
@@ -100,8 +94,6 @@ typedef int (*mca_io_base_component_file_delete_unselect_fn_t)
     (char *filename, struct ompi_info_t *info,
      struct mca_io_base_delete_t *private_data);
 
-typedef int (*mca_io_base_component_progress_fn_t)(void);
-
 typedef int (*mca_io_base_component_register_datarep_fn_t)(
                                               char *,
                                               MPI_Datarep_conversion_function*,
@@ -115,11 +107,6 @@ struct mca_io_base_component_2_0_0_t {
     mca_base_component_t io_version;
     mca_base_component_data_t io_data;
 
-    /** Additional bytes that this module needs to be allocated when
-        an MPI_Request (ompi_request_t) is allocated. */
-
-    size_t io_request_bytes;
-
     mca_io_base_component_init_query_fn_t io_init_query;
     mca_io_base_component_file_query_2_0_0_fn_t io_file_query;
     mca_io_base_component_file_unquery_fn_t io_file_unquery;
@@ -128,8 +115,6 @@ struct mca_io_base_component_2_0_0_t {
     mca_io_base_component_file_delete_unselect_fn_t io_delete_unquery;
     mca_io_base_component_file_delete_select_fn_t io_delete_select;
 
-    mca_io_base_component_progress_fn_t io_progress;
-
     mca_io_base_component_register_datarep_fn_t io_register_datarep;
 };
 typedef struct mca_io_base_component_2_0_0_t mca_io_base_component_2_0_0_t;
@@ -148,55 +133,6 @@ typedef union mca_io_base_components_t mca_io_base_components_t;
  * Module v2.0.0
  */
 
-/**
- * Initialize a request for use by the io module.
- *
- * @param module (IN)    IO module
- * @param request (IN)   Pointer to allocated request.
- *
- * To reduce latency (number of required allocations), the io base
- * allocates additional space along with each request that may be used
- * by the io module for additional control information. If the io
- * module intends to use this space, the io_request_bytes attribute
- * should be set to reflect the number of bytes above
- * sizeof(mca_io_base_request_t) are needed by the io component. This
- * space is allocated contiguously along with the
- * mca_io_base_request_t with the space immediately following the base
- * request available to the io module.
- * 
- * This init function is called the first time the request is created
- * by the io base. On completion of the request, the io base will
- * cache the request for later use by the same io module.  When the
- * request is re-used from the cache, this init function is NOT called
- * again.
- */
-typedef int (*mca_io_base_module_request_once_init_fn_t)(
-    union mca_io_base_modules_t* module_union,
-    struct mca_io_base_request_t* request);
-
-
-/**
- * Cleanup any resources that may have been associated with the
- * request by the io module.
- *
- * @param module (IN)    io module
- * @param request (IN)   Pointer to allocated request.
- *
- * This function is called when the io base removes a request from the
- * io module's cache (due to resource constraints) or the cache limit
- * has been reached, prior to re-using the request for another io
- * module. This provides the io module the chance to cleanup/release
- * any resources cached on the request by the io module.
- */
-typedef int (*mca_io_base_module_request_once_finalize_fn_t)(
-    union mca_io_base_modules_t* module_union,
-    struct mca_io_base_request_t* request);
-
-typedef int (*mca_io_base_module_request_fini_fn_t)(
-    struct ompi_file_t *file,
-    union mca_io_base_modules_t* module_union,
-    struct mca_io_base_request_t* request);
-
 typedef int (*mca_io_base_module_file_open_fn_t)
     (struct ompi_communicator_t *comm, char *filename, int amode,
      struct ompi_info_t *info, struct ompi_file_t *fh);
@@ -244,11 +180,11 @@ typedef int (*mca_io_base_module_file_write_at_all_fn_t)
 typedef int (*mca_io_base_module_file_iread_at_fn_t)
     (struct ompi_file_t *fh, MPI_Offset offset, void *buf,
      int count, struct ompi_datatype_t *datatype, 
-     struct mca_io_base_request_t *request);
+     struct ompi_request_t **request);
 typedef int (*mca_io_base_module_file_iwrite_at_fn_t)
     (struct ompi_file_t *fh, MPI_Offset offset, void *buf,
      int count, struct ompi_datatype_t *datatype, 
-     struct mca_io_base_request_t *request);
+     struct ompi_request_t **request);
 
 typedef int (*mca_io_base_module_file_read_fn_t)
     (struct ompi_file_t *fh, void *buf, int count, struct ompi_datatype_t *
@@ -264,11 +200,11 @@ typedef int (*mca_io_base_module_file_write_all_fn_t)
      datatype, struct ompi_status_public_t *status);
 
 typedef int (*mca_io_base_module_file_iread_fn_t)
-    (struct ompi_file_t *fh, void *buf, int count, struct ompi_datatype_t *
-     datatype, struct mca_io_base_request_t *request); 
+    (struct ompi_file_t *fh, void *buf, int count, 
+     struct ompi_datatype_t *datatype, struct ompi_request_t **request); 
 typedef int (*mca_io_base_module_file_iwrite_fn_t)
     (struct ompi_file_t *fh, void *buf, int count, 
-     struct ompi_datatype_t *datatype, struct mca_io_base_request_t *request);
+     struct ompi_datatype_t *datatype, struct ompi_request_t **request);
 
 typedef int (*mca_io_base_module_file_seek_fn_t)
     (struct ompi_file_t *fh, MPI_Offset offset, int whence);
@@ -285,10 +221,10 @@ typedef int (*mca_io_base_module_file_write_shared_fn_t)
      struct ompi_datatype_t *datatype, struct ompi_status_public_t *status);
 typedef int (*mca_io_base_module_file_iread_shared_fn_t)
     (struct ompi_file_t *fh, void *buf, int count, 
-     struct ompi_datatype_t *datatype, struct mca_io_base_request_t *request);
+     struct ompi_datatype_t *datatype, struct ompi_request_t **request);
 typedef int (*mca_io_base_module_file_iwrite_shared_fn_t)
     (struct ompi_file_t *fh, void *buf, int count, 
-     struct ompi_datatype_t *datatype, struct mca_io_base_request_t *request);
+     struct ompi_datatype_t *datatype, struct ompi_request_t **request);
 typedef int (*mca_io_base_module_file_read_ordered_fn_t)
     (struct ompi_file_t *fh, void *buf, int count, 
      struct ompi_datatype_t *datatype, struct ompi_status_public_t *status);
@@ -343,22 +279,6 @@ typedef int (*mca_io_base_module_file_sync_fn_t)(struct ompi_file_t *fh);
 
 struct mca_io_base_module_2_0_0_t {
 
-    /** Once-per-process request initializtion function */
-
-    mca_io_base_module_request_once_init_fn_t io_module_request_once_init;
-
-    /** Once-per-process request finalization function */
-
-    mca_io_base_module_request_once_finalize_fn_t io_module_request_once_finalize;
-
-    /** Free a request (per usage) */
-
-    ompi_request_free_fn_t io_module_request_free;
-
-    /** Cancel a request (per usage) */
-
-    ompi_request_cancel_fn_t io_module_request_cancel;
-
     /* Back-ends to MPI API calls (pretty much a 1-to-1 mapping) */
 
     mca_io_base_module_file_open_fn_t        io_module_file_open;
