@@ -1,5 +1,6 @@
 /* ---------------------------------------------------------------- */
 /* (C)Copyright IBM Corp.  2007, 2008                               */
+/* ---------------------------------------------------------------- */
 /**
  * \file ad_bgl_aggrs.c
  * \brief The externally used function from this file is is declared in ad_bgl_aggrs.h
@@ -7,7 +8,7 @@
 
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   Copyright (C) 1997 University of Chicago. 
+ *   Copyright (C) 1997-2001 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
@@ -16,10 +17,49 @@
 #include "ad_bgl.h"
 #include "ad_bgl_pset.h"
 #include "ad_bgl_aggrs.h"
+#ifdef AGGREGATION_PROFILE
+#include "mpe.h"
+#endif
+
+#ifdef USE_DBG_LOGGING
+  #define AGG_DEBUG 1
+#endif
 
 
-int aggrsInPsetSize=0;
-int *aggrsInPset=NULL;
+
+static int aggrsInPsetSize=0;
+static int *aggrsInPset=NULL;
+
+/* Comments copied from common:
+ * This file contains four functions:
+ *
+ * ADIOI_Calc_aggregator()
+ * ADIOI_Calc_file_domains()
+ * ADIOI_Calc_my_req()
+ * ADIOI_Calc_others_req()
+ *
+ * The last three of these were originally in ad_read_coll.c, but they are
+ * also shared with ad_write_coll.c.  I felt that they were better kept with
+ * the rest of the shared aggregation code.  
+ */
+
+/* Discussion of values available from above:
+ *
+ * ADIO_Offset st_offsets[0..nprocs-1]
+ * ADIO_Offset end_offsets[0..nprocs-1]
+ *    These contain a list of start and end offsets for each process in 
+ *    the communicator.  For example, an access at loc 10, size 10 would
+ *    have a start offset of 10 and end offset of 19.
+ * int nprocs
+ *    number of processors in the collective I/O communicator
+ * ADIO_Offset min_st_offset
+ * ADIO_Offset fd_start[0..nprocs_for_coll-1]
+ *    starting location of "file domain"; region that a given process will
+ *    perform aggregation for (i.e. actually do I/O)
+ * ADIO_Offset fd_end[0..nprocs_for_coll-1]
+ *    start + size - 1 roughly, but it can be less, or 0, in the case of 
+ *    uneven distributions
+ */
 
 /* forward declaration */
 static void 
@@ -219,8 +259,7 @@ ADIOI_BGL_compute_agg_ranklist_serial ( ADIO_File fd,
 					ADIOI_BGL_ProcInfo_t *all_procInfo,
 					int *aggrsInPset )
 {
-#   define DEBUG 0
-#   if DEBUG
+#   if AGG_DEBUG
     int i; 
 #   endif
     int naggs; 
@@ -229,9 +268,10 @@ ADIOI_BGL_compute_agg_ranklist_serial ( ADIO_File fd,
   /* compute the ranklist of IO aggregators and put into tmp_ranklist */
     tmp_ranklist = (int *) ADIOI_Malloc (confInfo->nProcs * sizeof(int));
 
-#   if DEBUG
-    for (i=0; i<confInfo->nProcs; i++) 
-    printf( "\tcpuid %1d, rank = %6d\n", all_procInfo[i].cpuid, all_procInfo[i].rank );
+#   if AGG_DEBUG
+    for (i=0; i<confInfo->nProcs; i++) {
+      DBG_FPRINTF(stderr, "\tcpuid %1d, rank = %6d\n", all_procInfo[i].cpuid, all_procInfo[i].rank );
+    }
 #   endif
 
     naggs = 
@@ -239,7 +279,7 @@ ADIOI_BGL_compute_agg_ranklist_serial ( ADIO_File fd,
 
 #   define VERIFY 0
 #   if VERIFY
-    printf( "\tconfInfo = %3d,%3d,%3d,%3d,%3d,%3d,%.4f; naggs = %d\n", 
+    DBG_FPRINTF(stderr, "\tconfInfo = %3d,%3d,%3d,%3d,%3d,%3d,%.4f; naggs = %d\n", 
 	    confInfo->PsetSize        ,
 	    confInfo->numPsets        ,
 	    confInfo->isVNM           ,
@@ -250,9 +290,10 @@ ADIOI_BGL_compute_agg_ranklist_serial ( ADIO_File fd,
 	    naggs );
 #   endif
 
-#   if DEBUG
-    for (i=0; i<naggs; i++) 
-    printf( "\taggr %-4d = %6d\n", i, tmp_ranklist[i] );
+#   if AGG_DEBUG
+    for (i=0; i<naggs; i++) {
+      DBG_FPRINTF(stderr, "\taggr %-4d = %6d\n", i, tmp_ranklist[i] );
+    }
 #   endif
 
   /* copy the ranklist of IO aggregators to fd->hints */
@@ -267,293 +308,34 @@ ADIOI_BGL_compute_agg_ranklist_serial ( ADIO_File fd,
     return;
 }
 
-
-
-/* 
- * Compute a dynamic access range based file domain partition among I/O aggregators,
- * which align to the GPFS block size
- * Divide the I/O workload among "nprocs_for_coll" processes. This is
- * done by (logically) dividing the file into file domains (FDs); each
- * process may directly access only its own file domain. 
- * Additional effort is to make sure that each I/O aggregator get
- * a file domain that aligns to the GPFS block size.  So, there will 
- * not be any false sharing of GPFS file blocks among multiple I/O nodes. 
- */
-void ADIOI_BGL_GPFS_Calc_file_domains(ADIO_Offset *st_offsets,
-                                      ADIO_Offset *end_offsets,
-                                      int          nprocs,
-                                      int          nprocs_for_coll,
-                                      ADIO_Offset *min_st_offset_ptr,
-                                      ADIO_Offset **fd_start_ptr,
-                                      ADIO_Offset **fd_end_ptr,
-                                      ADIO_Offset *fd_size_ptr,
-                                      void        *fs_ptr)
-{
-    ADIO_Offset min_st_offset, max_end_offset, *fd_start, *fd_end, *fd_size;
-    int i, aggr;
-    static char myname[] = "ADIOI_BGL_GPFS_Calc_file_domains";
-    __blksize_t blksize = 1048576; /* default to 1M */
-    if(fs_ptr && ((ADIOI_BGL_fs*)fs_ptr)->blksize) /* ignore null ptr or 0 blksize */
-      blksize = ((ADIOI_BGL_fs*)fs_ptr)->blksize;
-/*    FPRINTF(stderr,"%s(%d): Blocksize=%ld\n",myname,__LINE__,blksize);*/
-
-    /* find the range of all the requests */
-    min_st_offset  = st_offsets [0];
-    max_end_offset = end_offsets[0];
-    for (i=1; i<nprocs; i++) {
-        min_st_offset = ADIOI_MIN(min_st_offset, st_offsets[i]);
-        max_end_offset = ADIOI_MAX(max_end_offset, end_offsets[i]);
-    }
-
-    // printf( "_calc_file_domains, min_st_offset, max_ = %qd, %qd\n", min_st_offset, max_end_offset );
-
-    /* determine the "file domain (FD)" of each process, i.e., the portion of
-       the file that will be "owned" by each process */
-
-    ADIO_Offset gpfs_ub       = (max_end_offset +blksize-1) / blksize * blksize - 1;
-    ADIO_Offset gpfs_lb       = min_st_offset / blksize * blksize;
-    ADIO_Offset gpfs_ub_rdoff = (max_end_offset +blksize-1) / blksize * blksize - 1 - max_end_offset;
-    ADIO_Offset gpfs_lb_rdoff = min_st_offset - min_st_offset / blksize * blksize;
-    ADIO_Offset fd_gpfs_range = gpfs_ub - gpfs_lb + 1;
-
-    int         naggs    = nprocs_for_coll;
-    fd_size              = (ADIO_Offset *) ADIOI_Malloc(nprocs_for_coll * sizeof(ADIO_Offset));
-    *fd_start_ptr        = (ADIO_Offset *) ADIOI_Malloc(nprocs_for_coll * sizeof(ADIO_Offset));
-    *fd_end_ptr          = (ADIO_Offset *) ADIOI_Malloc(nprocs_for_coll * sizeof(ADIO_Offset));
-    fd_start             = *fd_start_ptr;
-    fd_end               = *fd_end_ptr;
-
-    ADIO_Offset n_gpfs_blk    = fd_gpfs_range / blksize;
-    ADIO_Offset nb_cn_small   = n_gpfs_blk/naggs;
-    ADIO_Offset naggs_large   = n_gpfs_blk - naggs * (n_gpfs_blk/naggs);
-    ADIO_Offset naggs_small   = naggs - naggs_large;
-
-    for (i=0; i<naggs; i++)
-        if (i < naggs_small) fd_size[i] = nb_cn_small     * blksize;
-                        else fd_size[i] = (nb_cn_small+1) * blksize;
-
-/*     FPRINTF(stderr,"%s(%d): "
-                   "gpfs_ub       %llu, "
-                   "gpfs_lb       %llu, "
-                   "gpfs_ub_rdoff %llu, "
-                   "gpfs_lb_rdoff %llu, "
-                   "fd_gpfs_range %llu, "
-                   "n_gpfs_blk    %llu, "
-                   "nb_cn_small   %llu, "
-                   "naggs_large   %llu, "
-                   "naggs_small   %llu, "
-                   "\n",
-                   myname,__LINE__,
-                   gpfs_ub      ,
-                   gpfs_lb      ,
-                   gpfs_ub_rdoff,
-                   gpfs_lb_rdoff,
-                   fd_gpfs_range,
-                   n_gpfs_blk   ,
-                   nb_cn_small  ,
-                   naggs_large  ,
-                   naggs_small
-                   );
-*/
-    fd_size[0]       -= gpfs_lb_rdoff;
-    fd_size[naggs-1] -= gpfs_ub_rdoff;
-
-    /* compute the file domain for each aggr */
-    ADIO_Offset offset = min_st_offset;
-    for (aggr=0; aggr<naggs; aggr++) {
-        fd_start[aggr] = offset;
-        fd_end  [aggr] = offset + fd_size[aggr] - 1;
-        offset += fd_size[aggr];
-    }
-
-    *fd_size_ptr = fd_size[0];
-    *min_st_offset_ptr = min_st_offset;
-
-    ADIOI_Free (fd_size);
-}
-
-
-/* 
- * deprecated
+/* Description from common/ad_aggregate.c.  (Does it completely apply to bgl?)
+ * ADIOI_Calc_aggregator()
  *
-void ADIOI_BGL_GPFS_Calc_file_domain0(ADIO_Offset *st_offsets, 
-				      ADIO_Offset *end_offsets, 
-				      int          nprocs, 
-				      int          nprocs_for_coll,
-				      ADIO_Offset *min_st_offset_ptr,
-				      ADIO_Offset **fd_start_ptr, 
-				      ADIO_Offset **fd_end_ptr, 
-				      ADIO_Offset *fd_size_ptr)
-{
-    ADIO_Offset min_st_offset, max_end_offset, *fd_start, *fd_end, *fd_size;
-    int i;
-static int GPFS_BSIZE=1048576;
-     * find the range of all the requests *
-    min_st_offset  = st_offsets [0];
-    max_end_offset = end_offsets[0];
-    for (i=1; i<nprocs; i++) {
-        min_st_offset = ADIOI_MIN(min_st_offset, st_offsets[i]);
-        max_end_offset = ADIOI_MAX(max_end_offset, end_offsets[i]);
-    }
-
-     * determine the "file domain (FD)" of each process, i.e., the portion of
-       the file that will be "owned" by each process *
-          
-     * GPFS specific, pseudo starting/end point has to round to GPFS_BSIZE *
-    ADIO_Offset gpfs_ub       = (max_end_offset +GPFS_BSIZE-1) / GPFS_BSIZE * GPFS_BSIZE - 1;
-    ADIO_Offset gpfs_lb       = min_st_offset / GPFS_BSIZE * GPFS_BSIZE;
-    ADIO_Offset gpfs_ub_rdoff = (max_end_offset +GPFS_BSIZE-1) / GPFS_BSIZE * GPFS_BSIZE - 1 - max_end_offset;
-    ADIO_Offset gpfs_lb_rdoff = min_st_offset - min_st_offset / GPFS_BSIZE * GPFS_BSIZE;
-    ADIO_Offset fd_gpfs_range = gpfs_ub - gpfs_lb + 1;
-
-     * all computation of partition is based on the rounded pseudo-range *
-    ADIO_Offset fds_ub   = (fd_gpfs_range  +nprocs_for_coll-1) / nprocs_for_coll;
-    ADIO_Offset fds_lb   =  fd_gpfs_range                      / nprocs_for_coll;
-    int         naggs    = nprocs_for_coll;
-    int         npsets   = aggrsInPset[0];         * special meaning for element 0 *
-    fd_size              = (ADIO_Offset *) ADIOI_Malloc(naggs * sizeof(ADIO_Offset));
-    *fd_start_ptr        = (ADIO_Offset *) ADIOI_Malloc(naggs * sizeof(ADIO_Offset));
-    *fd_end_ptr          = (ADIO_Offset *) ADIOI_Malloc(naggs * sizeof(ADIO_Offset));
-    fd_start             = *fd_start_ptr;
-    fd_end               = *fd_end_ptr;
-
-     * some pre-computation to determine rough ratio of when to up-fit, when to low-fit *
-     * 1. get the estimated data per pset *
-     * 2. determine a factor between up and down *
-        int           avg_aggrsInPset = (naggs +npsets-1)/npsets;
-        ADIO_Offset avg_bytes_perPset = fd_gpfs_range / npsets;
-        ADIO_Offset             resid = avg_bytes_perPset % GPFS_BSIZE;
-        ADIO_Offset             downr = GPFS_BSIZE - resid;
-        int                     small = (resid < downr);
-        int                     ratio = downr == 0 ? npsets + 2 : (resid +downr-1)/downr;
-        if (small)              ratio = resid == 0 ? npsets + 2 : (downr +resid-1)/resid;
-
-
-     * go through aggrsInfo of all PSETs *
-    ADIO_Offset fd_range = fd_gpfs_range;
-    int aggr = 0, pset; 
-    for (pset=0; pset<npsets; pset++) {
-
-        ADIO_Offset fds_try  = fds_lb;
-	int         my_naggs = aggrsInPset[pset+1];
-	ADIO_Offset fds_pset;
-
-	 * Last pset will deal with the residuals *
-	if (pset == npsets-1) 
-	    fds_pset = fd_range;
-	else 
-	{
-	    int cond1 = ((pset+1) % ratio == 0);
-	    int cond2 = ((pset+1) % ratio != 0);
-
-	    if (small) {
-		int temp = cond1; cond1 = cond2; cond2 = temp;
-	    }
-
-	    if (cond1) {
-		fds_pset = fds_try * my_naggs;
-		if (fds_pset % GPFS_BSIZE)   			// align to GPFS_BSIZE
-		    fds_pset = ((fds_pset +GPFS_BSIZE-1)/GPFS_BSIZE) * GPFS_BSIZE;	
-	    }
-	    if (cond2) 
-	    {
-		fds_try = fds_ub;
-		fds_pset = fds_try * my_naggs;
-		if (fds_pset % GPFS_BSIZE)   			// align to GPFS_BSIZE
-		    fds_pset = (fds_pset / GPFS_BSIZE) * GPFS_BSIZE;	
-	    }
-	}
-
-	 * for aggrs in each PSET, divide evenly the data range *
-#define CN_ALIGN 1
-#if !CN_ALIGN
-	fd_range -= fds_pset;
-	if ( pset == 0        ) fds_pset -= gpfs_lb_rdoff;
-	if ( pset == npsets-1 ) fds_pset -= gpfs_ub_rdoff;
-        int p;
-        for (p=0; p<my_naggs; p++) {
-            fd_size[aggr]  = (fds_pset   +my_naggs-1) / my_naggs;
-            if (p== my_naggs-1)
-                fd_size[aggr] -= (fd_size[aggr]*my_naggs - fds_pset);
-
-            aggr++;
-        }
-#else
-        ADIO_Offset avg_bytes_perP = fds_pset / my_naggs;
-        ADIO_Offset resid2 = avg_bytes_perP % GPFS_BSIZE;
-        ADIO_Offset downr2 = GPFS_BSIZE - resid2;
-        int small2 = (resid2 < downr2);
-        int         ratio2 = downr2 == 0 ? my_naggs + 2 : (resid2 +downr2-1)/downr2;
-        if (small2) ratio2 = resid2 == 0 ? my_naggs + 2 : (downr2 +resid2-1)/resid2;
-        ADIO_Offset accu = 0;
-        int p;
-        for (p=0; p<my_naggs; p++) {
-            int cond1 = ((p+1) % ratio2 == 0);
-            int cond2 = ((p+1) % ratio2 != 0);
-            if (small2) {
-                int temp = cond1; cond1 = cond2; cond2 = temp;
-            }
-            fd_size[aggr]  = avg_bytes_perP;
-            if (cond2) fd_size[aggr] = ((fd_size[aggr] +GPFS_BSIZE-1)/GPFS_BSIZE) * GPFS_BSIZE;
-            if (cond1) fd_size[aggr] = ((fd_size[aggr]              )/GPFS_BSIZE) * GPFS_BSIZE;
-            if (p== my_naggs-1)
-                fd_size[aggr] = (fds_pset - accu);
-
-            accu     += fd_size[aggr];
-            fd_range -= fd_size[aggr];
-            aggr++;
-        }
-#endif
-    }
-
-     * after scheduling, the first and the last region has to remove the round-off effect *
-
-#if CN_ALIGN
-    fd_size[0]       -= gpfs_lb_rdoff;
-    fd_size[naggs-1] -= gpfs_ub_rdoff;
-#endif
-    
-     * compute the file domain for each aggr *
-    ADIO_Offset offset = min_st_offset;
-    for (aggr=0; aggr<naggs; aggr++) {
-        fd_start[aggr] = offset;
-	fd_end  [aggr] = offset + fd_size[aggr] - 1;
-	offset += fd_size[aggr];
-    }
-
-     *
-    printf( "\t%6d : %12qd:%12qd, %12qd:%12qd:%12qd, %12qd:%12qd:%12qd\n", 
-	    naggs,
-	    min_st_offset,
-	    max_end_offset,
-	    fd_start[0],	
-	    fd_end  [0],	
-	    fd_size [0],	
-	    fd_start[naggs-1],	
-	    fd_end  [naggs-1],	
-	    fd_size [naggs-1] );	
-    *
-
-
-    *fd_size_ptr = fd_size[0];
-    *min_st_offset_ptr = min_st_offset;
-
-    ADIOI_Free (fd_size);
-}
-*/
-
-/* 
- * When a process is an IO aggregator, this will return its index in the aggrs list.
- * Otherwise, this will return -1 
+ * The intention here is to implement a function which provides basically 
+ * the same functionality as in Rajeev's original version of 
+ * ADIOI_Calc_my_req().  He used a ceiling division approach to assign the 
+ * file domains, and we use the same approach here when calculating the
+ * location of an offset/len in a specific file domain.  Further we assume
+ * this same distribution when calculating the rank_index, which is later
+ *  used to map to a specific process rank in charge of the file domain.
+ *
+ * A better (i.e. more general) approach would be to use the list of file
+ * domains only.  This would be slower in the case where the
+ * original ceiling division was used, but it would allow for arbitrary
+ * distributions of regions to aggregators.  We'd need to know the 
+ * nprocs_for_coll in that case though, which we don't have now.
+ *
+ * Note a significant difference between this function and Rajeev's old code:
+ * this code doesn't necessarily return a rank in the range
+ * 0..nprocs_for_coll; instead you get something in 0..nprocs.  This is a
+ * result of the rank mapping; any set of ranks in the communicator could be
+ * used now.
+ *
+ * Returns an integer representing a rank in the collective I/O communicator.
+ *
+ * The "len" parameter is also modified to indicate the amount of data
+ * actually available in this file domain.
  */
-int ADIOI_BGL_Aggrs_index( ADIO_File fd, int myrank )
-{
-    int i;
-    for (i=0; i<fd->hints->cb_nodes; i++) 
-	if (fd->hints->ranklist[i] == myrank) return i;
-    return -1;
-}
-
 /* 
  * This is more general aggregator search function which does not base on the assumption
  * that each aggregator hosts the file domain with the same size 
@@ -574,6 +356,21 @@ int ADIOI_BGL_Calc_aggregator(ADIO_File fd,
     /* binary search --> rank_index is returned */
     int ub = fd->hints->cb_nodes;
     int lb = 0;
+    /* get an index into our array of aggregators */
+    /* Common code for striping - bgl doesn't use it but it's
+       here to make diff'ing easier.
+    rank_index = (int) ((off - min_off + fd_size)/ fd_size - 1);
+
+    if (fd->hints->striping_unit > 0) {
+        * wkliao: implementation for file domain alignment
+           fd_start[] and fd_end[] have been aligned with file lock
+	   boundaries when returned from ADIOI_Calc_file_domains() so cannot
+	   just use simple arithmatic as above *
+        rank_index = 0;
+        while (off > fd_end[rank_index]) rank_index++;
+    } 
+    bgl does it's own striping below 
+    */
     rank_index = fd->hints->cb_nodes / 2;
     while ( off < fd_start[rank_index] || off > fd_end[rank_index] ) {
 	if ( off > fd_end  [rank_index] ) {
@@ -586,8 +383,15 @@ int ADIOI_BGL_Calc_aggregator(ADIO_File fd,
 	    rank_index = (rank_index + lb) / 2;
 	}
     }
-
-    // printf ("ADIOI_BGL_Calc_aggregator: rank_index = %d\n", rank_index );
+    /* we index into fd_end with rank_index, and fd_end was allocated to be no
+     * bigger than fd->hins->cb_nodes.   If we ever violate that, we're
+     * overrunning arrays.  Obviously, we should never ever hit this abort */
+    if (rank_index >= fd->hints->cb_nodes || rank_index < 0) {
+        FPRINTF(stderr, "Error in ADIOI_Calc_aggregator(): rank_index(%d) >= fd->hints->cb_nodes (%d) fd_size=%lld off=%lld\n",
+			rank_index,fd->hints->cb_nodes,fd_size,off);
+        MPI_Abort(MPI_COMM_WORLD, 1);
+    }
+    // DBG_FPRINTF ("ADIOI_BGL_Calc_aggregator: rank_index = %d\n", rank_index );
 
     /* 
      * remember here that even in Rajeev's original code it was the case that
@@ -611,16 +415,161 @@ int ADIOI_BGL_Calc_aggregator(ADIO_File fd,
     return rank;
 }
 
+/* 
+ * Compute a dynamic access range based file domain partition among I/O aggregators,
+ * which align to the GPFS block size
+ * Divide the I/O workload among "nprocs_for_coll" processes. This is
+ * done by (logically) dividing the file into file domains (FDs); each
+ * process may directly access only its own file domain. 
+ * Additional effort is to make sure that each I/O aggregator get
+ * a file domain that aligns to the GPFS block size.  So, there will 
+ * not be any false sharing of GPFS file blocks among multiple I/O nodes. 
+ *  
+ * The common version of this now accepts a min_fd_size and striping_unit. 
+ * It doesn't seem necessary here (using GPFS block sizes) but keep it in mind
+ * (e.g. we could pass striping unit instead of using fs_ptr->blksize). 
+ */
+void ADIOI_BGL_GPFS_Calc_file_domains(ADIO_Offset *st_offsets,
+                                      ADIO_Offset *end_offsets,
+                                      int          nprocs,
+                                      int          nprocs_for_coll,
+                                      ADIO_Offset *min_st_offset_ptr,
+                                      ADIO_Offset **fd_start_ptr,
+                                      ADIO_Offset **fd_end_ptr,
+                                      ADIO_Offset *fd_size_ptr,
+                                      void        *fs_ptr)
+{
+    ADIO_Offset min_st_offset, max_end_offset, *fd_start, *fd_end, *fd_size;
+    int i, aggr;
+
+#ifdef AGGREGATION_PROFILE
+    MPE_Log_event (5004, 0, NULL);
+#endif
+
+#   if AGG_DEBUG
+    static char myname[] = "ADIOI_BGL_GPFS_Calc_file_domains";
+    DBG_FPRINTF(stderr, "%s(%d): %d aggregator(s)\n", 
+	    myname,__LINE__,nprocs_for_coll);
+#   endif
+    __blksize_t blksize = 1048576; /* default to 1M */
+    if(fs_ptr && ((ADIOI_BGL_fs*)fs_ptr)->blksize) /* ignore null ptr or 0 blksize */
+      blksize = ((ADIOI_BGL_fs*)fs_ptr)->blksize;
+#   if AGG_DEBUG
+    DBG_FPRINTF(stderr,"%s(%d): Blocksize=%ld\n",myname,__LINE__,blksize);
+#   endif
+/* find min of start offsets and max of end offsets of all processes */
+    min_st_offset  = st_offsets [0];
+    max_end_offset = end_offsets[0];
+    for (i=1; i<nprocs; i++) {
+        min_st_offset = ADIOI_MIN(min_st_offset, st_offsets[i]);
+        max_end_offset = ADIOI_MAX(max_end_offset, end_offsets[i]);
+    }
+
+    // DBG_FPRINTF(stderr, "_calc_file_domains, min_st_offset, max_ = %qd, %qd\n", min_st_offset, max_end_offset );
+
+    /* determine the "file domain (FD)" of each process, i.e., the portion of
+       the file that will be "owned" by each process */
+
+    ADIO_Offset gpfs_ub       = (max_end_offset +blksize-1) / blksize * blksize - 1;
+    ADIO_Offset gpfs_lb       = min_st_offset / blksize * blksize;
+    ADIO_Offset gpfs_ub_rdoff = (max_end_offset +blksize-1) / blksize * blksize - 1 - max_end_offset;
+    ADIO_Offset gpfs_lb_rdoff = min_st_offset - min_st_offset / blksize * blksize;
+    ADIO_Offset fd_gpfs_range = gpfs_ub - gpfs_lb + 1;
+
+    int         naggs    = nprocs_for_coll;
+
+    /* Tweak the file domains so that no fd is smaller than a threshold.  We
+     * have to strike a balance between efficency and parallelism: somewhere
+     * between 10k processes sending 32-byte requests and one process sending a
+     * 320k request is a (system-dependent) sweet spot 
+     
+    This is from the common code - the new min_fd_size parm that we didn't implement. 
+    (And common code uses a different declaration of fd_size so beware) 
+     
+    if (fd_size < min_fd_size)
+        fd_size = min_fd_size;
+    */
+    fd_size              = (ADIO_Offset *) ADIOI_Malloc(nprocs_for_coll * sizeof(ADIO_Offset));
+    *fd_start_ptr        = (ADIO_Offset *) ADIOI_Malloc(nprocs_for_coll * sizeof(ADIO_Offset));
+    *fd_end_ptr          = (ADIO_Offset *) ADIOI_Malloc(nprocs_for_coll * sizeof(ADIO_Offset));
+    fd_start             = *fd_start_ptr;
+    fd_end               = *fd_end_ptr;
+
+    ADIO_Offset n_gpfs_blk    = fd_gpfs_range / blksize;
+    ADIO_Offset nb_cn_small   = n_gpfs_blk/naggs;
+    ADIO_Offset naggs_large   = n_gpfs_blk - naggs * (n_gpfs_blk/naggs);
+    ADIO_Offset naggs_small   = naggs - naggs_large;
+
+    for (i=0; i<naggs; i++)
+        if (i < naggs_small) fd_size[i] = nb_cn_small     * blksize;
+                        else fd_size[i] = (nb_cn_small+1) * blksize;
+
+#   if AGG_DEBUG
+     DBG_FPRINTF(stderr,"%s(%d): "
+                   "gpfs_ub       %llu, "
+                   "gpfs_lb       %llu, "
+                   "gpfs_ub_rdoff %llu, "
+                   "gpfs_lb_rdoff %llu, "
+                   "fd_gpfs_range %llu, "
+                   "n_gpfs_blk    %llu, "
+                   "nb_cn_small   %llu, "
+                   "naggs_large   %llu, "
+                   "naggs_small   %llu, "
+                   "\n",
+                   myname,__LINE__,
+                   gpfs_ub      ,
+                   gpfs_lb      ,
+                   gpfs_ub_rdoff,
+                   gpfs_lb_rdoff,
+                   fd_gpfs_range,
+                   n_gpfs_blk   ,
+                   nb_cn_small  ,
+                   naggs_large  ,
+                   naggs_small
+                   );
+#   endif
+
+    fd_size[0]       -= gpfs_lb_rdoff;
+    fd_size[naggs-1] -= gpfs_ub_rdoff;
+
+    /* compute the file domain for each aggr */
+    ADIO_Offset offset = min_st_offset;
+    for (aggr=0; aggr<naggs; aggr++) {
+        fd_start[aggr] = offset;
+        fd_end  [aggr] = offset + fd_size[aggr] - 1;
+        offset += fd_size[aggr];
+    }
+
+    *fd_size_ptr = fd_size[0];
+    *min_st_offset_ptr = min_st_offset;
+
+#ifdef AGGREGATION_PROFILE
+    MPE_Log_event (5005, 0, NULL);
+#endif
+    ADIOI_Free (fd_size);
+}
+
+/* 
+ * When a process is an IO aggregator, this will return its index in the aggrs list.
+ * Otherwise, this will return -1 
+ */
+int ADIOI_BGL_Aggrs_index( ADIO_File fd, int myrank )
+{
+    int i;
+    for (i=0; i<fd->hints->cb_nodes; i++) 
+	if (fd->hints->ranklist[i] == myrank) return i;
+    return -1;
+}
 
 /* 
  * ADIOI_BGL_Calc_my_req() overrides ADIOI_Calc_my_req for the default implementation 
  * is specific for static file domain partitioning.
  *
- * ADIOI_Calc_my_req() calculate what portions of the access requests
+ * ADIOI_Calc_my_req() - calculate what portions of the access requests
  * of this process are located in the file domains of various processes
  * (including this one)
  */
-void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, int *len_list, 
+void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, ADIO_Offset *len_list, 
 			   int contig_access_count, ADIO_Offset 
 			   min_st_offset, ADIO_Offset *fd_start,
 			   ADIO_Offset *fd_end, ADIO_Offset fd_size,
@@ -629,12 +578,17 @@ void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, int *len_list
 			   int **count_my_req_per_proc_ptr,
 			   ADIOI_Access **my_req_ptr,
 			   int **buf_idx_ptr)
+/* Possibly reconsider if buf_idx's are ok as int's, or should they be aints/offsets? 
+   They are used as memory buffer indices so it seems like the 2G limit is in effect */
 {
     int *count_my_req_per_proc, count_my_req_procs, *buf_idx;
     int i, l, proc;
     ADIO_Offset fd_len, rem_len, curr_idx, off;
     ADIOI_Access *my_req;
 
+#ifdef AGGREGATION_PROFILE
+    MPE_Log_event (5024, 0, NULL);
+#endif
 
     *count_my_req_per_proc_ptr = (int *) ADIOI_Calloc(nprocs,sizeof(int)); 
     count_my_req_per_proc = *count_my_req_per_proc_ptr;
@@ -656,10 +610,10 @@ void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, int *len_list
      * contig_access_count was calculated way back in ADIOI_Calc_my_off_len()
      */
     for (i=0; i < contig_access_count; i++) {
-
-	/* When there is no data being processed, bypass this loop */
-	if (len_list[i] == 0) continue;
-
+	/* short circuit offset/len processing if len == 0 
+	 * 	(zero-byte  read/write */
+	if (len_list[i] == 0) 
+		continue;
 	off = offset_list[i];
 	fd_len = len_list[i];
 	/* note: we set fd_len to be the total size of the access.  then
@@ -710,20 +664,24 @@ void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, int *len_list
 /* now fill in my_req */
     curr_idx = 0;
     for (i=0; i<contig_access_count; i++) { 
-
-        /* When there is no data being processed, bypass this loop */
-        if (len_list[i] == 0) continue;
-
+	/* short circuit offset/len processing if len == 0 
+	 * 	(zero-byte  read/write */
+	if (len_list[i] == 0)
+		continue;
 	off = offset_list[i];
 	fd_len = len_list[i];
 	proc = ADIOI_BGL_Calc_aggregator(fd, off, min_st_offset, &fd_len, fd_size, 
 				     fd_start, fd_end);
 
 	/* for each separate contiguous access from this process */
-	if (buf_idx[proc] == -1) buf_idx[proc] = (int) curr_idx;
+	if (buf_idx[proc] == -1)
+  {
+    ADIOI_Assert(curr_idx == (int) curr_idx);
+    buf_idx[proc] = (int) curr_idx;
+  }
 
 	l = my_req[proc].count;
-	curr_idx += (int) fd_len; /* NOTE: Why is curr_idx an int?  Fix? */
+	curr_idx += fd_len;
 
 	rem_len = len_list[i] - fd_len;
 
@@ -733,6 +691,7 @@ void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, int *len_list
 	 * and the associated count. 
 	 */
 	my_req[proc].offsets[l] = off;
+  ADIOI_Assert(fd_len == (int) fd_len);
 	my_req[proc].lens[l] = (int) fd_len;
 	my_req[proc].count++;
 
@@ -742,13 +701,18 @@ void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, int *len_list
 	    proc = ADIOI_BGL_Calc_aggregator(fd, off, min_st_offset, &fd_len, 
 					 fd_size, fd_start, fd_end);
 
-	    if (buf_idx[proc] == -1) buf_idx[proc] = (int) curr_idx;
+	    if (buf_idx[proc] == -1) 
+      {
+        ADIOI_Assert(curr_idx == (int) curr_idx);
+        buf_idx[proc] = (int) curr_idx;
+      }
 
 	    l = my_req[proc].count;
 	    curr_idx += fd_len;
 	    rem_len -= fd_len;
 
 	    my_req[proc].offsets[l] = off;
+      ADIOI_Assert(fd_len == (int) fd_len);
 	    my_req[proc].lens[l] = (int) fd_len;
 	    my_req[proc].count++;
 	}
@@ -757,27 +721,26 @@ void ADIOI_BGL_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, int *len_list
 #ifdef AGG_DEBUG
     for (i=0; i<nprocs; i++) {
 	if (count_my_req_per_proc[i] > 0) {
-	    FPRINTF(stdout, "data needed from %d (count = %d):\n", i, 
+	    DBG_FPRINTF(stderr, "data needed from %d (count = %d):\n", i, 
 		    my_req[i].count);
 	    for (l=0; l < my_req[i].count; l++) {
-		FPRINTF(stdout, "   off[%d] = %Ld, len[%d] = %d\n", l,
+		DBG_FPRINTF(stderr, "   off[%d] = %lld, len[%d] = %d\n", l,
 			my_req[i].offsets[l], l, my_req[i].lens[l]);
 	    }
 	}
+	DBG_FPRINTF(stderr, "buf_idx[%d] = 0x%x\n", i, buf_idx[i]);
     }
-#if 0
-    for (i=0; i<nprocs; i++) {
-	FPRINTF(stdout, "buf_idx[%d] = 0x%x\n", i, buf_idx[i]);
-    }
-#endif
 #endif
 
     *count_my_req_procs_ptr = count_my_req_procs;
     *buf_idx_ptr = buf_idx;
+#ifdef AGGREGATION_PROFILE
+    MPE_Log_event (5025, 0, NULL);
+#endif
 }
 
 /*
- * ADIOI_Calc_others_req
+ * ADIOI_Calc_others_req (copied to bgl and switched to all to all for performance)
  *
  * param[in]  count_my_req_procs        Number of processes whose file domain my
  *                                        request touches.
@@ -826,7 +789,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	 *recvBufForLens   =(void*)0xFFFFFFFF; 
 
 /* first find out how much to send/recv and from/to whom */
-
+#ifdef AGGREGATION_PROFILE
+    MPE_Log_event (5026, 0, NULL);
+#endif
     /* Send 1 int to each process.  count_my_req_per_proc[i] is the number of 
      * requests that my process will do to the file domain owned by process[i].
      * Receive 1 int from each process.  count_others_req_per_proc[i] is the number of
@@ -866,9 +831,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	    others_req[i].lens = (int *)
 		ADIOI_Malloc(count_others_req_per_proc[i]*sizeof(int)); 
 
-	    if ( (unsigned)others_req[i].offsets < (unsigned)recvBufForOffsets )
+	    if ( (MPIR_Upint)others_req[i].offsets < (MPIR_Upint)recvBufForOffsets )
 		recvBufForOffsets = others_req[i].offsets;
-	    if ( (unsigned)others_req[i].lens < (unsigned)recvBufForLens )
+	    if ( (MPIR_Upint)others_req[i].lens < (MPIR_Upint)recvBufForLens )
 		recvBufForLens = others_req[i].lens;
 
 	    others_req[i].mem_ptrs = (MPI_Aint *)
@@ -883,6 +848,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	    others_req[i].lens    = NULL;
 	}
     }
+    /* If no recv buffer was allocated in the loop above, make it NULL */
+    if ( recvBufForOffsets == (void*)0xFFFFFFFF) recvBufForOffsets = NULL;
+    if ( recvBufForLens    == (void*)0xFFFFFFFF) recvBufForLens    = NULL;
     
     /* Now send the calculated offsets and lengths to respective processes */
 
@@ -894,14 +862,18 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
     for (i=0; i<nprocs; i++)
     {
 	if ( (my_req[i].count) &&
-	     ((unsigned)my_req[i].offsets <= (unsigned)sendBufForOffsets) )
-	    sendBufForOffsets = my_req[i].offsets;
+	     ((MPIR_Upint)my_req[i].offsets <= (MPIR_Upint)sendBufForOffsets) )
+	  sendBufForOffsets = my_req[i].offsets;
 	   
 	if ( (my_req[i].count) &&
-	     ((unsigned)my_req[i].lens <= (unsigned)sendBufForLens) )
+	     ((MPIR_Upint)my_req[i].lens <= (MPIR_Upint)sendBufForLens) )
 	    sendBufForLens = my_req[i].lens;
     }
 
+    /* If no send buffer was found in the loop above, make it NULL */
+    if ( sendBufForOffsets == (void*)0xFFFFFFFF) sendBufForOffsets = NULL;
+    if ( sendBufForLens    == (void*)0xFFFFFFFF) sendBufForLens    = NULL;
+
     /* Calculate the displacements from the sendBufForOffsets/Lens */
     for (i=0; i<nprocs; i++)
     {
@@ -910,16 +882,20 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	if ( scounts[i] == 0 )
 	    sdispls[i] = 0;
 	else
-	    sdispls[i] = ( (unsigned)my_req[i].offsets - 
-			   (unsigned)sendBufForOffsets ) / sizeof(ADIO_Offset);
+  	  sdispls[i] =  (int)
+	                ( ( (MPIR_Upint)my_req[i].offsets - 
+			   (MPIR_Upint)sendBufForOffsets ) / 
+			  (MPIR_Upint)sizeof(ADIO_Offset) );
 
 	// Receive these offsets from process i.
 	rcounts[i] = count_others_req_per_proc[i];
 	if ( rcounts[i] == 0 )
 	    rdispls[i] = 0;
 	else
-	    rdispls[i] = ( (unsigned)others_req[i].offsets - 
-			   (unsigned)recvBufForOffsets ) / sizeof(ADIO_Offset);
+	    rdispls[i] = (int)
+	                 ( ( (MPIR_Upint)others_req[i].offsets - 
+			     (MPIR_Upint)recvBufForOffsets ) / 
+			   (MPIR_Upint)sizeof(ADIO_Offset) );
     }
 
     /* Exchange the offsets */
@@ -940,16 +916,20 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	if ( scounts[i] == 0 )
 	    sdispls[i] = 0;
 	else
-	    sdispls[i] = ( (unsigned)my_req[i].lens - 
-			   (unsigned)sendBufForLens ) / sizeof(int);
+	  sdispls[i] = (int)
+	               ( ( (MPIR_Upint)my_req[i].lens - 
+			   (MPIR_Upint)sendBufForLens ) / 
+			 (MPIR_Upint) sizeof(int) );
 	
 	// Receive these offsets from process i.
 	rcounts[i] = count_others_req_per_proc[i];
 	if ( rcounts[i] == 0 )
 	    rdispls[i] = 0;
 	else
-	    rdispls[i] = ( (unsigned)others_req[i].lens - 
-			   (unsigned)recvBufForLens ) / sizeof(int);
+	    rdispls[i] = (int)
+	                 ( ( (MPIR_Upint)others_req[i].lens - 
+			     (MPIR_Upint)recvBufForLens ) / 
+			   (MPIR_Upint) sizeof(int) );
     }
 
     /* Exchange the lengths */
@@ -967,4 +947,7 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
     ADIOI_Free (rdispls);
 
     *count_others_req_procs_ptr = count_others_req_procs;
+#ifdef AGGREGATION_PROFILE
+    MPE_Log_event (5027, 0, NULL);
+#endif
 }
