@@ -177,7 +177,7 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
     ADIO_Offset userbuf_off;
     ADIO_Offset off, req_off, disp, end_offset=0, readbuf_off, start_off;
     char *readbuf, *tmp_buf, *value;
-    int flag, st_frd_size, st_n_filetypes, readbuf_len;
+    int st_frd_size, st_n_filetypes, readbuf_len;
     int new_brd_size, new_frd_size, err_flag=0, info_flag, max_bufsize;
 
     static char myname[] = "ADIOI_NFS_READSTRIDED";
@@ -201,7 +201,7 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
 /* get max_bufsize from the info object. */
 
     value = (char *) ADIOI_Malloc((MPI_MAX_INFO_VAL+1)*sizeof(char));
-    MPI_Info_get(fd->info, "ind_rd_buffer_size", MPI_MAX_INFO_VAL, value, 
+    ADIOI_Info_get(fd->info, "ind_rd_buffer_size", MPI_MAX_INFO_VAL, value, 
                  &info_flag);
     max_bufsize = atoi(value);
     ADIOI_Free(value);
@@ -278,25 +278,32 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
 	disp = fd->disp;
 
 	if (file_ptr_type == ADIO_INDIVIDUAL) {
-	    offset = fd->fp_ind; /* in bytes */
-	    n_filetypes = -1;
-	    flag = 0;
-	    while (!flag) {
-                n_filetypes++;
-		for (i=0; i<flat_file->count; i++) {
-		    if (disp + flat_file->indices[i] + 
-                        (ADIO_Offset) n_filetypes*filetype_extent + flat_file->blocklens[i] 
-                            >= offset) {
-			st_index = i;
-			frd_size = (int) (disp + flat_file->indices[i] + 
-			        (ADIO_Offset) n_filetypes*filetype_extent
-			         + flat_file->blocklens[i] - offset);
-			flag = 1;
-			break;
-		    }
-		}
-	    }
-	}
+          /* Wei-keng reworked type processing to be a bit more efficient */
+           offset       = fd->fp_ind - disp;
+           n_filetypes  = (offset - flat_file->indices[0]) / filetype_extent;
+          offset -= (ADIO_Offset)n_filetypes * filetype_extent;
+          /* now offset is local to this extent */
+ 
+           /* find the block where offset is located, skip blocklens[i]==0 */
+           for (i=0; i<flat_file->count; i++) {
+               ADIO_Offset dist;
+               if (flat_file->blocklens[i] == 0) continue;
+               dist = flat_file->indices[i] + flat_file->blocklens[i] - offset;
+               /* frd_size is from offset to the end of block i */
+              if (dist == 0) {
+                  i++;
+                  offset   = flat_file->indices[i];
+                  frd_size = flat_file->blocklens[i];
+                  break;
+              }
+              if (dist > 0 ) { 
+                   frd_size = dist;
+		   break;
+              }
+          }
+           st_index = i;  /* starting index in flat_file->indices[] */
+           offset += disp + (ADIO_Offset)n_filetypes*filetype_extent;
+       }
 	else {
 	    n_etypes_in_filetype = filetype_size/etype_size;
 	    n_filetypes = (int) (offset / n_etypes_in_filetype);
@@ -316,11 +323,42 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
 	    }
 
 	    /* abs. offset in bytes in the file */
-	    offset = disp + (ADIO_Offset) n_filetypes*filetype_extent + abs_off_in_filetype;
+	    offset = disp + (ADIO_Offset) n_filetypes*filetype_extent + 
+		    abs_off_in_filetype;
 	}
 
         start_off = offset;
 
+       /* Wei-keng Liao: read request is within a single flat_file contig
+        * block e.g. with subarray types that actually describe the whole
+        * array */
+       if (buftype_is_contig && bufsize <= frd_size) {
+            ADIO_ReadContig(fd, buf, bufsize, MPI_BYTE, ADIO_EXPLICIT_OFFSET,
+                             offset, status, error_code);
+
+           if (file_ptr_type == ADIO_INDIVIDUAL) {
+                /* update MPI-IO file pointer to point to the first byte that 
+                * can be accessed in the fileview. */
+               fd->fp_ind = offset + bufsize;
+               if (bufsize == frd_size) {
+                   do {
+                       st_index++;
+                       if (st_index == flat_file->count) {
+                           st_index = 0;
+                           n_filetypes++;
+                       }
+                    } while (flat_file->blocklens[st_index] == 0);
+                   fd->fp_ind = disp + flat_file->indices[st_index]
+                               + n_filetypes*filetype_extent;
+               }
+           }
+           fd->fp_sys_posn = -1;   /* set it to null. */ 
+#ifdef HAVE_STATUS_SET_BYTES
+           MPIR_Status_set_bytes(status, datatype, bufsize);
+#endif 
+            return;
+       }
+
        /* Calculate end_offset, the last byte-offset that will be accessed.
          e.g., if start_offset=0 and 100 bytes to be read, end_offset=99*/
 
@@ -333,11 +371,11 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
 	while (i < bufsize) {
 	    i += frd_size;
 	    end_offset = off + frd_size - 1;
-
-	    if (j < (flat_file->count - 1)) j++;
-	    else {
-		j = 0;
-		n_filetypes++;
+            j = (j+1) % flat_file->count;
+            n_filetypes += (j == 0) ? 1 : 0;
+            while (flat_file->blocklens[j]==0) {
+               j = (j+1) % flat_file->count;
+               n_filetypes += (j == 0) ? 1 : 0;
 	    }
 
 	    off = disp + flat_file->indices[j] + (ADIO_Offset) n_filetypes*filetype_extent;
@@ -402,11 +440,12 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
                 /* did not reach end of contiguous block in filetype.
                    no more I/O needed. off is incremented by frd_size. */
                 else {
-		    if (j < (flat_file->count - 1)) j++;
-		    else {
-			j = 0;
-			n_filetypes++;
-		    }
+                    j = (j+1) % flat_file->count;
+                    n_filetypes += (j == 0) ? 1 : 0;
+                    while (flat_file->blocklens[j]==0) {
+                        j = (j+1) % flat_file->count;
+                        n_filetypes += (j == 0) ? 1 : 0;
+                    }
 		    off = disp + flat_file->indices[j] + 
                                         (ADIO_Offset) n_filetypes*filetype_extent;
 		    frd_size = ADIOI_MIN(flat_file->blocklens[j], bufsize-i);
@@ -445,12 +484,12 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
 
 		if (size == frd_size) {
 /* reached end of contiguous block in file */
-		    if (j < (flat_file->count - 1)) j++;
-		    else {
-			j = 0;
-			n_filetypes++;
-		    }
-
+                    j = (j+1) % flat_file->count;
+                    n_filetypes += (j == 0) ? 1 : 0;
+                    while (flat_file->blocklens[j]==0) {
+                        j = (j+1) % flat_file->count;
+                        n_filetypes += (j == 0) ? 1 : 0;
+                    }
 		    off = disp + flat_file->indices[j] + 
                                               (ADIO_Offset) n_filetypes*filetype_extent;
 
