@@ -35,7 +35,7 @@
 #undef CB_CONFIG_LIST_DEBUG
 
 /* a couple of globals keep things simple */
-static int cb_config_list_keyval = MPI_KEYVAL_INVALID;
+int ADIOI_cb_config_list_keyval = MPI_KEYVAL_INVALID;
 static char *yylval;
 static char *token_ptr;
 
@@ -83,7 +83,7 @@ int ADIOI_cb_bcast_rank_map(ADIO_File fd)
      * FS-INDEP. */
     value = (char *) ADIOI_Malloc((MPI_MAX_INFO_VAL+1)*sizeof(char));
     ADIOI_Snprintf(value, MPI_MAX_INFO_VAL+1, "%d", fd->hints->cb_nodes);
-    MPI_Info_set(fd->info, "cb_nodes", value);
+    ADIOI_Info_set(fd->info, "cb_nodes", value);
     ADIOI_Free(value);
 
     return 0;
@@ -111,14 +111,16 @@ int ADIOI_cb_gather_name_array(MPI_Comm comm,
     ADIO_cb_name_array array = NULL;
     int alloc_size;
 
-    if (cb_config_list_keyval == MPI_KEYVAL_INVALID) {
+    if (ADIOI_cb_config_list_keyval == MPI_KEYVAL_INVALID) {
+        /* cleaned up by ADIOI_End_call */
 	MPI_Keyval_create((MPI_Copy_function *) ADIOI_cb_copy_name_array, 
 			  (MPI_Delete_function *) ADIOI_cb_delete_name_array,
-			  &cb_config_list_keyval, NULL);
+			  &ADIOI_cb_config_list_keyval, NULL);
     }
     else {
-	MPI_Attr_get(comm, cb_config_list_keyval, (void *) &array, &found);
+	MPI_Attr_get(comm, ADIOI_cb_config_list_keyval, (void *) &array, &found);
 	if (found) {
+            ADIOI_Assert(array != NULL);
 	    *arrayp = array;
 	    return 0;
 	}
@@ -231,8 +233,8 @@ int ADIOI_cb_gather_name_array(MPI_Comm comm,
      * it next time an open is performed on this same comm, and on the
      * dupcomm, so we can use it in I/O operations.
      */
-    MPI_Attr_put(comm, cb_config_list_keyval, array);
-    MPI_Attr_put(dupcomm, cb_config_list_keyval, array);
+    MPI_Attr_put(comm, ADIOI_cb_config_list_keyval, array);
+    MPI_Attr_put(dupcomm, ADIOI_cb_config_list_keyval, array);
     *arrayp = array;
     return 0;
 }
@@ -362,7 +364,7 @@ int ADIOI_cb_config_list_parse(char *config_list,
 /* ADIOI_cb_copy_name_array() - attribute copy routine
  */
 int ADIOI_cb_copy_name_array(MPI_Comm comm, 
-		       int *keyval, 
+		       int keyval, 
 		       void *extra, 
 		       void *attr_in,
 		       void **attr_out, 
@@ -371,11 +373,11 @@ int ADIOI_cb_copy_name_array(MPI_Comm comm,
     ADIO_cb_name_array array;
 
     ADIOI_UNREFERENCED_ARG(comm);
-    ADIOI_UNREFERENCED_ARG(keyval);
+    ADIOI_UNREFERENCED_ARG(keyval); 
     ADIOI_UNREFERENCED_ARG(extra);
 
     array = (ADIO_cb_name_array) attr_in;
-    array->refct++;
+    if (array != NULL) array->refct++;
 
     *attr_out = attr_in;
     *flag = 1; /* make a copy in the new communicator */
@@ -386,17 +388,17 @@ int ADIOI_cb_copy_name_array(MPI_Comm comm,
 /* ADIOI_cb_delete_name_array() - attribute destructor
  */
 int ADIOI_cb_delete_name_array(MPI_Comm comm, 
-			 int *keyval, 
+			 int keyval, 
 			 void *attr_val, 
 			 void *extra)
 {
     ADIO_cb_name_array array;
 
     ADIOI_UNREFERENCED_ARG(comm);
-    ADIOI_UNREFERENCED_ARG(keyval);
     ADIOI_UNREFERENCED_ARG(extra);
 
     array = (ADIO_cb_name_array) attr_val;
+    ADIOI_Assert(array != NULL);
     array->refct--;
 
     if (array->refct <= 0) {
@@ -411,7 +413,6 @@ int ADIOI_cb_delete_name_array(MPI_Comm comm,
 	if (array->names != NULL) ADIOI_Free(array->names);
 	ADIOI_Free(array);
     }
-
     return MPI_SUCCESS;
 }
 
@@ -679,19 +680,32 @@ static int get_max_procs(int cb_nodes)
  *
  * Returns a token of types defined at top of this file.
  */
+#ifdef ROMIO_BGL
+/* On BlueGene, the ',' character shows up in get_processor_name, so we have to
+ * use a different delimiter */
+#define COLON ':'
+#define COMMA ';'
+#define DELIMS ":;"
+#else 
+/* these tokens work for every other platform */
+#define COLON ':'
+#define COMMA ','
+#define DELIMS ":,"
+#endif
+
 static int cb_config_list_lex(void)
 {
     int slen;
 
     if (*token_ptr == '\0') return AGG_EOS;
 
-    slen = (int)strcspn(token_ptr, ":,");
+    slen = (int)strcspn(token_ptr, DELIMS);
 
-    if (*token_ptr == ':') {
+    if (*token_ptr == COLON) {
 	token_ptr++;
 	return AGG_COLON;
     }
-    if (*token_ptr == ',') {
+    if (*token_ptr == COMMA) {
 	token_ptr++;
 	return AGG_COMMA;
     }
