@@ -22,13 +22,12 @@
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #endif  /* HAVE_STRING_H */
 #include "ompi/mca/mpool/mpool.h"
 #include "base.h"
 #include "mpool_base_tree.h"
-#include "opal/threads/mutex.h" 
 #include "mpool_base_mem_cb.h"
 
 /**
