@@ -17,7 +17,7 @@
  * $HEADER$
  */
 
-#define OMPI_DISABLE_ENABLE_MEM_DEBUG 1
+#define OPAL_DISABLE_ENABLE_MEM_DEBUG 1
 #include "ompi_config.h"
 
 #include <stdio.h>
@@ -31,7 +31,6 @@
 #include "opal/mca/mca.h"
 #include "opal/mca/base/base.h"
 #include "opal/memoryhooks/memory.h"
-#include "ompi/mca/mpool/mpool.h"
 #include "ompi/mca/mpool/base/base.h"
 #include "ompi/constants.h"
 
