@@ -10,7 +10,7 @@
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2006      Voltaire. All rights reserved.
- * Copyright (c) 2007-2008 Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2007-2009 Cisco Systems, Inc.  All rights reserved.
  *
  * $COPYRIGHT$
  *
@@ -19,13 +19,11 @@
  * $HEADER$
  */
 
-#define OMPI_DISABLE_ENABLE_MEM_DEBUG 1
+#define OPAL_DISABLE_ENABLE_MEM_DEBUG 1
 #include "ompi_config.h"
-#include "orte/util/show_help.h"
 #include "opal/mca/base/base.h"
 #include "opal/mca/base/mca_base_param.h"
 #include "mpool_rdma.h"
-#include "orte/util/proc_info.h"
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -36,8 +34,10 @@
 /*
  * Local functions
  */
-static int mca_mpool_rdma_open(void);
-static mca_mpool_base_module_t* mca_mpool_rdma_init(
+static int rdma_open(void);
+static int rdma_close(void);
+static int rdma_register(void);
+static mca_mpool_base_module_t* rdma_init(
         struct mca_mpool_base_resources_t* resources);
 
 mca_mpool_rdma_component_t mca_mpool_rdma_component = {
@@ -52,22 +52,30 @@ mca_mpool_rdma_component_t mca_mpool_rdma_component = {
           OMPI_MAJOR_VERSION,  /* MCA component major version */
           OMPI_MINOR_VERSION,  /* MCA component minor version */
           OMPI_RELEASE_VERSION,  /* MCA component release version */
-          mca_mpool_rdma_open,  /* component open  */
-          NULL
+          rdma_open,  /* component open  */
+          rdma_close,
+          NULL,
+          rdma_register
       },
       {
           /* The component is checkpoint ready */
           MCA_BASE_METADATA_PARAM_CHECKPOINT
       },
 
-      mca_mpool_rdma_init
+      rdma_init
     }
 };
 
 /**
   * component open/close/init function
   */
-static int mca_mpool_rdma_open(void)
+static int rdma_open(void)
+{
+    return OMPI_SUCCESS;
+}
+
+
+static int rdma_register(void)
 {
     int val;
 
@@ -93,7 +101,18 @@ static int mca_mpool_rdma_open(void)
     return OMPI_SUCCESS;
 }
 
-static mca_mpool_base_module_t* mca_mpool_rdma_init(
+
+static int rdma_close(void)
+{
+    if (NULL != mca_mpool_rdma_component.rcache_name) {
+        free(mca_mpool_rdma_component.rcache_name);
+    }
+
+    return OMPI_SUCCESS;
+}
+
+
+static mca_mpool_base_module_t* rdma_init(
      struct mca_mpool_base_resources_t *resources)
 {
     mca_mpool_rdma_module_t* mpool_module;
