@@ -22,12 +22,12 @@
 #include "ompi/mca/mtl/mtl.h"
 #include "ompi/mca/mtl/base/base.h"
 #include "ompi/constants.h"
-#include "ompi/datatype/convertor.h"
-#include "ompi/datatype/datatype.h"
-#include "ompi/datatype/datatype_internal.h"
+#include "ompi/datatype/ompi_datatype.h"
+#include "opal/datatype/opal_convertor.h"
+#include "opal/datatype/opal_datatype_internal.h"
 
 static inline int
-ompi_mtl_datatype_pack(struct ompi_convertor_t *convertor,
+ompi_mtl_datatype_pack(struct opal_convertor_t *convertor,
                        void **buffer,
                        size_t *buffer_len,
                        bool *freeAfter)
@@ -35,7 +35,7 @@ ompi_mtl_datatype_pack(struct ompi_convertor_t *convertor,
     struct iovec iov;
     uint32_t iov_count = 1;
 
-    ompi_convertor_get_packed_size(convertor, buffer_len);
+    opal_convertor_get_packed_size(convertor, buffer_len);
     *freeAfter  = false;
     if( 0 == *buffer_len ) {
         *buffer     = NULL;
@@ -43,13 +43,13 @@ ompi_mtl_datatype_pack(struct ompi_convertor_t *convertor,
     }
     iov.iov_len = *buffer_len;
     iov.iov_base = NULL;
-    if (ompi_convertor_need_buffers(convertor)) {
+    if (opal_convertor_need_buffers(convertor)) {
         iov.iov_base = malloc(*buffer_len);
         if (NULL == iov.iov_base) return OMPI_ERR_OUT_OF_RESOURCE;
         *freeAfter = true;
     }
     
-    ompi_convertor_pack( convertor, &iov, &iov_count, buffer_len );
+    opal_convertor_pack( convertor, &iov, &iov_count, buffer_len );
     
     *buffer = iov.iov_base;
 
@@ -58,42 +58,42 @@ ompi_mtl_datatype_pack(struct ompi_convertor_t *convertor,
 
 
 static inline int
-ompi_mtl_datatype_recv_buf(struct ompi_convertor_t *convertor,
+ompi_mtl_datatype_recv_buf(struct opal_convertor_t *convertor,
                            void ** buffer,
                            size_t *buffer_len,
                            bool *free_on_error)
 {
-    ompi_convertor_get_packed_size(convertor, buffer_len);
+    opal_convertor_get_packed_size(convertor, buffer_len);
     *free_on_error = false;
     if( 0 == *buffer_len ) {
         *buffer = NULL;
         *buffer_len = 0;
         return OMPI_SUCCESS;
     }
-    if (ompi_convertor_need_buffers(convertor)) {
+    if (opal_convertor_need_buffers(convertor)) {
         *buffer = malloc(*buffer_len);
         *free_on_error = true;
     } else {
         *buffer = convertor->pBaseBuf + 
-            convertor->use_desc->desc[convertor->use_desc->used].end_loop.first_elem_disp;;
+            convertor->use_desc->desc[convertor->use_desc->used].end_loop.first_elem_disp;
     }
     return OMPI_SUCCESS;
 }
 
 
 static inline int
-ompi_mtl_datatype_unpack(struct ompi_convertor_t *convertor,
+ompi_mtl_datatype_unpack(struct opal_convertor_t *convertor,
                          void *buffer,
                          size_t buffer_len)
 {
     struct iovec iov;
     uint32_t iov_count = 1;
 
-    if (buffer_len > 0 && ompi_convertor_need_buffers(convertor)) {
+    if (buffer_len > 0 && opal_convertor_need_buffers(convertor)) {
         iov.iov_len = buffer_len;
         iov.iov_base = buffer;
 
-        ompi_convertor_unpack(convertor, &iov, &iov_count, &buffer_len );
+        opal_convertor_unpack(convertor, &iov, &iov_count, &buffer_len );
 
         free(buffer);
     }
