@@ -13,6 +13,8 @@
 #include "opal/util/output.h"
 #include "opal/mca/base/mca_base_param.h"
 #include "ompi/proc/proc.h"
+#include "opal/memoryhooks/memory.h"
+#include "ompi/runtime/mpiruntime.h"
 
 #include "mtl_mxm.h"
 #include "mtl_mxm_types.h"
@@ -82,24 +84,54 @@ static int ompi_mtl_mxm_component_register(void)
 static int ompi_mtl_mxm_component_open(void)
 {
     mxm_error_t err;
+    unsigned long cur_ver;
 
     mca_mtl_mxm_output = opal_output_open(NULL);
     opal_output_set_verbosity(mca_mtl_mxm_output, ompi_mtl_mxm.verbose);
-#if MXM_API < MXM_VERSION(1,5)
-        mxm_fill_context_opts(&ompi_mtl_mxm.mxm_opts);
-        err = mxm_init(&ompi_mtl_mxm.mxm_opts, &ompi_mtl_mxm.mxm_context);
-        MXM_VERBOSE(1, "mxm component open");
-#else
-        err = mxm_config_read_context_opts(&ompi_mtl_mxm.mxm_opts);
-        if (err != MXM_OK) {
-           MXM_ERROR("Failed to parse MXM configuration");
-            return OPAL_ERR_BAD_PARAM;
-        }
+    cur_ver = mxm_get_version();
+    if (cur_ver != MXM_API) {
+        char *str;
+        if (asprintf(&str, "OMPI was compiled with MXM version %d.%d but "
+                "version %ld.%ld detected.", MXM_VERNO_MAJOR,
+                MXM_VERNO_MINOR, (cur_ver >> MXM_MAJOR_BIT)& 0xff,
+                (cur_ver >> MXM_MINOR_BIT) & 0xff)>0) {
+                    orte_show_help("help-mtl-mxm.txt", "mxm init", true, str);
 
-        err = mxm_init(ompi_mtl_mxm.mxm_opts, &ompi_mtl_mxm.mxm_context);
-        MXM_VERBOSE(1, "mxm component open");
+                    free(str);
+                }
+        return OMPI_ERR_NOT_AVAILABLE;
+    }
+#if MXM_API < MXM_VERSION(1,5)
+    mxm_fill_context_opts(&ompi_mtl_mxm.mxm_opts);
+    err = mxm_init(&ompi_mtl_mxm.mxm_opts, &ompi_mtl_mxm.mxm_context);
+    MXM_VERBOSE(1, "mxm component open");
+#else
+
+#if MXM_API >= MXM_VERSION(2,0)
+    /* Register memory hooks */
+    if ((OPAL_MEMORY_FREE_SUPPORT | OPAL_MEMORY_MUNMAP_SUPPORT) ==
+        ((OPAL_MEMORY_FREE_SUPPORT | OPAL_MEMORY_MUNMAP_SUPPORT) &
+         opal_mem_hooks_support_level()))
+    {
+        setenv("MXM_MEM_ON_DEMAND_MAP", "y", 0);
+        MXM_VERBOSE(1, "Enabling on-demand memory mapping");
+        ompi_mtl_mxm.using_mem_hooks = 1;
+    } else {
+        MXM_VERBOSE(1, "Disabling on-demand memory mapping");
+        ompi_mtl_mxm.using_mem_hooks = 0;
+    }
+    setenv("MXM_SINGLE_THREAD", ompi_mpi_thread_multiple ? "n" : "y" , 0);
 #endif
 
+    err = mxm_config_read_context_opts(&ompi_mtl_mxm.mxm_opts);
+    if (err != MXM_OK) {
+        MXM_ERROR("Failed to parse MXM configuration");
+        return OPAL_ERR_BAD_PARAM;
+    }
+
+    err = mxm_init(ompi_mtl_mxm.mxm_opts, &ompi_mtl_mxm.mxm_context);
+    MXM_VERBOSE(1, "mxm component open");
+#endif
 
     if (MXM_OK != err) {
         if (MXM_ERR_NO_DEVICE == err) {
@@ -116,8 +148,13 @@ static int ompi_mtl_mxm_component_open(void)
 
 static int ompi_mtl_mxm_component_close(void)
 {
-    mxm_cleanup(ompi_mtl_mxm.mxm_context);
-    ompi_mtl_mxm.mxm_context = NULL;
+    unsigned long cur_ver;
+
+    cur_ver = mxm_get_version();
+    if ((cur_ver == MXM_API) && (ompi_mtl_mxm.mxm_context != NULL)) {
+        mxm_cleanup(ompi_mtl_mxm.mxm_context);
+        ompi_mtl_mxm.mxm_context = NULL;
+    }
     return OMPI_SUCCESS;
 }
 
@@ -139,4 +176,3 @@ ompi_mtl_mxm_component_init(bool enable_progress_threads,
             sizeof(mca_mtl_mxm_request_t) - sizeof(struct mca_mtl_request_t);
     return &ompi_mtl_mxm.super;
 }
-
