@@ -20,20 +20,17 @@ int ompi_mtl_mxm_iprobe(struct mca_mtl_base_module_t* mtl,
     mxm_error_t err;
     mxm_recv_req_t req;
 
-    req.base.state      = MXM_REQ_NEW;
-    req.base.mq         = (mxm_mq_h)comm->c_pml_comm;
-    req.tag        		= tag;
-    req.tag_mask   		= (tag == MPI_ANY_TAG) ? 0 : 0xffffffffU;
-    req.base.conn       = (src == MPI_ANY_SOURCE) ? NULL : ompi_mtl_mxm_conn_lookup(comm, src);
+    req.base.state = MXM_REQ_NEW;
+    ompi_mtl_mxm_set_recv_envelope(&req, comm, src, tag);
 
     err = mxm_req_probe(&req);
     if (MXM_OK == err) {
         *flag = 1;
         if (MPI_STATUS_IGNORE != status) {
-            status->MPI_SOURCE = *(int *)mxm_conn_get_context(req.base.conn);
+            ompi_mtl_mxm_to_mpi_status(err, status);
+            status->MPI_SOURCE = req.completion.sender_imm;
             status->MPI_TAG    = req.completion.sender_tag;
-            status->MPI_ERROR  = ompi_mtl_mxm_to_mpi_status(err);
-            status->_ucount    = req.completion.actual_len;
+            status->_ucount    = req.completion.sender_len;
         }
         return OMPI_SUCCESS;
     } else if (MXM_ERR_NO_MESSAGE == err) {
