@@ -29,23 +29,23 @@ typedef struct mca_mtl_mxm_module_t {
     int                   verbose;
     int                   mxm_np;
     mxm_h                 mxm_context;
+    mxm_ep_h              ep;
 #if MXM_API < MXM_VERSION(1,5)
     mxm_context_opts_t    mxm_opts;
 #else
     mxm_context_opts_t   *mxm_opts;
 #endif
-    mxm_ep_h              ep;
+#if MXM_API >= MXM_VERSION(2,0)
+    int                   using_mem_hooks;
+#endif
 } mca_mtl_mxm_module_t;
 
 
-typedef struct ompi_mtl_mxm_ep_conn_info_t {
 #if MXM_API < MXM_VERSION(2,0)
+typedef struct ompi_mtl_mxm_ep_conn_info_t {
     struct sockaddr_storage  ptl_addr[MXM_PTL_LAST];
-#else
-    unsigned                 domain_bitmap;
-    struct sockaddr_storage  dest_addr[MXM_DOMAIN_LAST];
-#endif
 } ompi_mtl_mxm_ep_conn_info_t;
+#endif
 
 extern mca_mtl_mxm_module_t ompi_mtl_mxm;
 
