@@ -2,7 +2,7 @@
  * Copyright (c) 2004-2006 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2005 The University of Tennessee and The University
+ * Copyright (c) 2004-2010 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
@@ -20,10 +20,9 @@
 #include "ompi_config.h"
 
 #include "opal/class/opal_list.h"
-#include "ompi/request/request.h"
-#include "ompi/datatype/datatype.h"
 #include "ompi/communicator/communicator.h"
-#include "ompi/datatype/convertor.h"
+#include "ompi/datatype/ompi_datatype.h"
+#include "opal/datatype/opal_convertor.h"
 #include "ompi/mca/mtl/base/base.h"
 #include "ompi/mca/mtl/base/mtl_base_datatype.h"
 
@@ -113,7 +112,7 @@ ompi_mtl_portals_recv_progress(ptl_event_t *ev,
         ptl_request->super.ompi_req->req_status.MPI_ERROR = 
             (ev->rlength > ev->mlength) ?
             MPI_ERR_TRUNCATE : MPI_SUCCESS;
-        ptl_request->super.ompi_req->req_status._count = 
+        ptl_request->super.ompi_req->req_status._ucount =
             ev->mlength;
 
         OPAL_OUTPUT_VERBOSE((50, ompi_mtl_base_output,
@@ -130,7 +129,7 @@ ompi_mtl_portals_recv_progress(ptl_event_t *ev,
 
         /* set the status - most of this filled in right after issuing
            the PtlGet*/
-        ptl_request->super.ompi_req->req_status._count = 
+        ptl_request->super.ompi_req->req_status._ucount = 
             ev->mlength;
 
         OPAL_OUTPUT_VERBOSE((50, ompi_mtl_base_output,
@@ -150,7 +149,7 @@ ompi_mtl_portals_recv_progress(ptl_event_t *ev,
 
 static int
 ompi_mtl_portals_get_data(ompi_mtl_portals_event_t *recv_event, 
-                          struct ompi_convertor_t *convertor,
+                          struct opal_convertor_t *convertor,
                           ompi_mtl_portals_request_t  *ptl_request)
 {
     int ret;
@@ -175,13 +174,13 @@ ompi_mtl_portals_get_data(ompi_mtl_portals_event_t *recv_event,
         /* see if this message filled the receive block */
         if (recv_event->ev.md.length - (recv_event->ev.offset + 
                                         recv_event->ev.mlength) <
-            recv_event->ev.md.max_size) {
+            (ptl_size_t) recv_event->ev.md.max_size) {
             block->full = true;
         }
 
         /* pull out the data */
         if (iov.iov_len > 0) {
-            ret = ompi_convertor_unpack(convertor, &iov, &iov_count,
+            ret = opal_convertor_unpack(convertor, &iov, &iov_count,
                                         &max_data );
             if (0 > ret) return ret;
         }
@@ -223,7 +222,7 @@ ompi_mtl_portals_get_data(ompi_mtl_portals_event_t *recv_event,
         /* finished with our buffer space */
         ompi_mtl_portals_return_block_part(&ompi_mtl_portals, block);
 
-        ompi_convertor_get_packed_size(convertor, &buflen);
+        opal_convertor_get_packed_size(convertor, &buflen);
 
         ptl_request->super.ompi_req->req_status.MPI_SOURCE =
             PTL_GET_SOURCE(recv_event->ev.match_bits);
@@ -232,7 +231,7 @@ ompi_mtl_portals_get_data(ompi_mtl_portals_event_t *recv_event,
         ptl_request->super.ompi_req->req_status.MPI_ERROR = 
             (recv_event->ev.rlength > buflen) ?
             MPI_ERR_TRUNCATE : MPI_SUCCESS;
-        ptl_request->super.ompi_req->req_status._count = 
+        ptl_request->super.ompi_req->req_status._ucount = 
             recv_event->ev.mlength;
 
         OPAL_OUTPUT_VERBOSE((50, ompi_mtl_base_output,
@@ -459,7 +458,7 @@ ompi_mtl_portals_irecv(struct mca_mtl_base_module_t* mtl,
                        struct ompi_communicator_t *comm,
                        int src,
                        int tag,
-                       struct ompi_convertor_t *convertor,
+                       struct opal_convertor_t *convertor,
                        mca_mtl_request_t *mtl_request)
 {
     ptl_match_bits_t match_bits, ignore_bits;
