@@ -18,9 +18,8 @@
 
 #include "ompi_config.h"
 
-#include "ompi/datatype/datatype.h"
 #include "ompi/communicator/communicator.h"
-#include "ompi/datatype/convertor.h"
+#include "opal/datatype/opal_convertor.h"
 #include "ompi/mca/mtl/base/base.h"
 #include "ompi/mca/mtl/base/mtl_base_datatype.h"
 
@@ -538,7 +537,7 @@ ompi_mtl_portals_send(struct mca_mtl_base_module_t* mtl,
                       struct ompi_communicator_t* comm,
                       int dest,
                       int tag,
-                      struct ompi_convertor_t *convertor,
+                      struct opal_convertor_t *convertor,
                       mca_pml_base_send_mode_t mode)
 {
     int ret;
@@ -574,7 +573,7 @@ ompi_mtl_portals_isend(struct mca_mtl_base_module_t* mtl,
                        struct ompi_communicator_t* comm,
                        int dest,
                        int tag,
-                       struct ompi_convertor_t *convertor,
+                       struct opal_convertor_t *convertor,
                        mca_pml_base_send_mode_t mode,
                        bool blocking,
                        mca_mtl_request_t *mtl_request)
