@@ -194,7 +194,7 @@ typedef int (*ompi_osc_base_module_put_fn_t)(void *origin_addr,
                                             int origin_count,
                                             struct ompi_datatype_t *origin_dt,
                                             int target,
-                                            OMPI_PTRDIFF_TYPE target_disp,
+                                            OPAL_PTRDIFF_TYPE target_disp,
                                             int target_count,
                                             struct ompi_datatype_t *target_dt,
                                             struct ompi_win_t *win);
@@ -204,7 +204,7 @@ typedef int (*ompi_osc_base_module_get_fn_t)(void *origin_addr,
                                             int origin_count,
                                             struct ompi_datatype_t *origin_dt,
                                             int target,
-                                            OMPI_PTRDIFF_TYPE target_disp,
+                                            OPAL_PTRDIFF_TYPE target_disp,
                                             int target_count,
                                             struct ompi_datatype_t *target_dt,
                                             struct ompi_win_t *win);
@@ -214,7 +214,7 @@ typedef int (*ompi_osc_base_module_accumulate_fn_t)(void *origin_addr,
                                                    int origin_count,
                                                    struct ompi_datatype_t *origin_dt,
                                                    int target,
-                                                   OMPI_PTRDIFF_TYPE target_disp,
+                                                   OPAL_PTRDIFF_TYPE target_disp,
                                                    int target_count,
                                                    struct ompi_datatype_t *target_dt,
                                                    struct ompi_op_t *op,
