@@ -20,10 +20,15 @@
 
 #include <stdio.h>
 
+#include "opal/class/opal_list.h"
+#include "opal/threads/mutex.h"
 #include "osc_pt2pt.h"
 #include "osc_pt2pt_sendreq.h"
 #include "osc_pt2pt_header.h"
 #include "osc_pt2pt_data_move.h"
+#include "ompi/datatype/ompi_datatype.h"
+#include "ompi/op/op.h"
+#include "ompi/win/win.h"
 #include "ompi/memchecker.h"
 
 static int
@@ -44,7 +49,7 @@ enqueue_sendreq(ompi_osc_pt2pt_module_t *module,
 int
 ompi_osc_pt2pt_module_accumulate(void *origin_addr, int origin_count,
                                  struct ompi_datatype_t *origin_dt,
-                                 int target, OMPI_PTRDIFF_TYPE target_disp, 
+                                 int target, OPAL_PTRDIFF_TYPE target_disp, 
                                  int target_count,
                                  struct ompi_datatype_t *target_dt,
                                  struct ompi_op_t *op, ompi_win_t *win)
@@ -99,7 +104,7 @@ ompi_osc_pt2pt_module_get(void *origin_addr,
                           int origin_count,
                           struct ompi_datatype_t *origin_dt,
                           int target,
-                          OMPI_PTRDIFF_TYPE target_disp,
+                          OPAL_PTRDIFF_TYPE target_disp,
                           int target_count,
                           struct ompi_datatype_t *target_dt,
                           ompi_win_t *win)
@@ -150,7 +155,7 @@ ompi_osc_pt2pt_module_get(void *origin_addr,
 int
 ompi_osc_pt2pt_module_put(void *origin_addr, int origin_count,
                           struct ompi_datatype_t *origin_dt,
-                          int target, OMPI_PTRDIFF_TYPE target_disp, 
+                          int target, OPAL_PTRDIFF_TYPE target_disp, 
                           int target_count,
                           struct ompi_datatype_t *target_dt, ompi_win_t *win)
 {
