@@ -9,7 +9,7 @@
  *                         All rights reserved.
  * Copyright (c) 2007      Los Alamos National Security, LLC.  All rights
  *                         reserved. 
- * Copyright (c) 2009      Sun Microsystems, Inc.  All rights reserved.
+ * Copyright (c) 2009-2011 Oracle and/or its affiliates.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -25,22 +25,24 @@
 #include "osc_rdma_data_move.h"
 #include "osc_rdma_obj_convert.h"
 
-#include "orte/util/show_help.h"
 #include "opal/util/arch.h"
+#include "opal/util/output.h"
 #include "opal/sys/atomic.h"
+#include "opal/align.h"
+#include "ompi/mca/pml/pml.h"
 #include "ompi/mca/bml/bml.h"
 #include "ompi/mca/bml/base/base.h"
 #include "ompi/mca/btl/btl.h"
 #include "ompi/mca/osc/base/base.h"
 #include "ompi/mca/osc/base/osc_base_obj_convert.h"
-#include "ompi/datatype/datatype.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "ompi/op/op.h"
 #include "ompi/memchecker.h"
 
 static inline int32_t
 create_send_tag(ompi_osc_rdma_module_t *module)
 {
-#if OMPI_HAVE_THREAD_SUPPORT && OPAL_HAVE_ATOMIC_CMPSET_32
+#if OPAL_HAVE_THREAD_SUPPORT && OPAL_HAVE_ATOMIC_CMPSET_32
     int32_t newval, oldval;
     do {
         oldval = module->m_tag_counter;
@@ -311,7 +313,7 @@ ompi_osc_rdma_sendreq_send_cb(struct mca_btl_base_module_t* btl,
            don't care when it completes - only when the data
            arrives. */
         if (OMPI_OSC_RDMA_HDR_GET != header->hdr_base.hdr_type) {
-#if !defined(WORDS_BIGENDIAN) && OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#if !defined(WORDS_BIGENDIAN) && OPAL_ENABLE_HETEROGENEOUS_SUPPORT
             if (header->hdr_base.hdr_flags & OMPI_OSC_RDMA_HDR_FLAG_NBO) {
                 OMPI_OSC_RDMA_SEND_HDR_NTOH(*header);
             }
@@ -360,11 +362,16 @@ ompi_osc_rdma_sendreq_send_cb(struct mca_btl_base_module_t* btl,
         if (0 == (header->hdr_base.hdr_flags & OMPI_OSC_RDMA_HDR_FLAG_MULTI)) {
             done = true;
         } else {
+            /* Find starting point for next header.  Note that the last part
+             * added in to compute the starting point for the next header is
+             * extra padding that may have been inserted. */
             header = (ompi_osc_rdma_send_header_t*)
                 (((char*) header) + 
                  sizeof(ompi_osc_rdma_send_header_t) + 
-                 ompi_ddt_pack_description_length(sendreq->req_target_datatype) +
-                 header->hdr_msg_length);
+                 ompi_datatype_pack_description_length(sendreq->req_target_datatype) +
+                 header->hdr_msg_length +
+                 (header->hdr_base.hdr_flags & OMPI_OSC_RDMA_HDR_FLAG_ALIGN_MASK));
+
             if (header->hdr_base.hdr_type == OMPI_OSC_RDMA_HDR_MULTI_END) {
                 done = true;
             }
@@ -374,22 +381,30 @@ ompi_osc_rdma_sendreq_send_cb(struct mca_btl_base_module_t* btl,
     /* release the descriptor and sendreq */
     btl->btl_free(btl, descriptor);
 
-    while (opal_list_get_size(&module->m_queued_sendreqs)) {
+    if (opal_list_get_size(&module->m_queued_sendreqs) > 0) {
         opal_list_item_t *item;
-        int ret;
+        int ret, i, len;
 
-        OPAL_THREAD_LOCK(&module->m_lock);
-        item = opal_list_remove_first(&module->m_queued_sendreqs);
-        OPAL_THREAD_UNLOCK(&module->m_lock);
-        if (NULL == item) break;
-
-        ret = ompi_osc_rdma_sendreq_send(module, (ompi_osc_rdma_sendreq_t*) item);
-        if (OMPI_SUCCESS != ret) {
+        len = opal_list_get_size(&module->m_queued_sendreqs);
+        OPAL_OUTPUT_VERBOSE((40, ompi_osc_base_output,
+                             "%d items in restart queue",
+                             len));
+        for (i = 0 ; i < len ; ++i) {
             OPAL_THREAD_LOCK(&module->m_lock);
-            opal_list_append(&(module->m_queued_sendreqs), item);
+            item = opal_list_remove_first(&module->m_queued_sendreqs);
             OPAL_THREAD_UNLOCK(&module->m_lock);
-            break;
+            if (NULL == item) break;
+
+            ret = ompi_osc_rdma_sendreq_send(module, (ompi_osc_rdma_sendreq_t*) item);
+            if (OMPI_SUCCESS != ret) {
+                OPAL_THREAD_LOCK(&module->m_lock);
+                opal_list_append(&(module->m_queued_sendreqs), item);
+                OPAL_THREAD_UNLOCK(&module->m_lock);
+            }
         }
+
+        /* flush so things actually get sent out and resources restored */
+        ompi_osc_rdma_flush(module);
     }
 }
 
@@ -407,32 +422,37 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
     mca_btl_base_descriptor_t *descriptor = NULL;
     ompi_osc_rdma_send_header_t *header = NULL;
     size_t written_data = 0;
+    size_t offset;
     size_t needed_len = sizeof(ompi_osc_rdma_send_header_t);
     const void *packed_ddt;
     size_t packed_ddt_len, remain;
 
     if ((module->m_eager_send_active) && 
         (module->m_use_rdma) &&
-        (ompi_ddt_is_contiguous_memory_layout(sendreq->req_target_datatype,
+        (ompi_datatype_is_contiguous_memory_layout(sendreq->req_target_datatype,
                                               sendreq->req_target_count)) &&
-        (!ompi_convertor_need_buffers(&sendreq->req_origin_convertor)) &&
+        (!opal_convertor_need_buffers(&sendreq->req_origin_convertor)) &&
         (sendreq->req_type != OMPI_OSC_RDMA_ACC)) {
         ret = ompi_osc_rdma_sendreq_rdma(module, sendreq);
         if (OPAL_LIKELY(OMPI_SUCCESS == ret)) return ret;
     }
 
     /* we always need to send the ddt */
-    packed_ddt_len = ompi_ddt_pack_description_length(sendreq->req_target_datatype);
+    packed_ddt_len = ompi_datatype_pack_description_length(sendreq->req_target_datatype);
     needed_len += packed_ddt_len;
     if (OMPI_OSC_RDMA_GET != sendreq->req_type) {
         needed_len += sendreq->req_origin_bytes_packed;
     }
 
-    /* see if we already have a buffer */
-    if ((module->m_pending_buffers[sendreq->req_target_rank].remain_len >=
-         sizeof(ompi_osc_rdma_send_header_t) + sendreq->req_origin_bytes_packed) ||
-        (0 < module->m_pending_buffers[sendreq->req_target_rank].remain_len && 
-         sendreq->req_origin_bytes_packed > 2048)) {
+    /* Reuse the buffer if:
+     *   - The whole message will fit
+     *   - The header and datatype will fit AND the payload would be long anyway
+     * Note that if the datatype is too big for an eager, we'll fall
+     * through and return an error out of the new buffer case */
+    if ((module->m_pending_buffers[sendreq->req_target_rank].remain_len >= needed_len) ||
+        ((sizeof(ompi_osc_rdma_send_header_t) + packed_ddt_len <
+          module->m_pending_buffers[sendreq->req_target_rank].remain_len) && 
+         (needed_len > module->m_pending_buffers[sendreq->req_target_rank].bml_btl->btl->btl_eager_limit))) {
         bml_btl = module->m_pending_buffers[sendreq->req_target_rank].bml_btl;
         descriptor = module->m_pending_buffers[sendreq->req_target_rank].descriptor;
         remain = module->m_pending_buffers[sendreq->req_target_rank].remain_len;
@@ -441,7 +461,6 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
         if (module->m_pending_buffers[sendreq->req_target_rank].descriptor) {
             send_multi_buffer(module, sendreq->req_target_rank);
         }
-        assert(OMPI_SUCCESS == ret);
 
         /* get a buffer... */
         endpoint = (mca_bml_base_endpoint_t*) sendreq->req_target_proc->proc_bml;
@@ -457,8 +476,8 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
         }
 
         /* verify at least enough space for header */
-        if (descriptor->des_src[0].seg_len < sizeof(ompi_osc_rdma_send_header_t)) {
-            ret = OMPI_ERR_OUT_OF_RESOURCE;
+        if (descriptor->des_src[0].seg_len < sizeof(ompi_osc_rdma_send_header_t) + packed_ddt_len) {
+            ret = MPI_ERR_TRUNCATE;
             goto cleanup;
         }
 
@@ -487,7 +506,7 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
     switch (sendreq->req_type) {
     case OMPI_OSC_RDMA_PUT:
         header->hdr_base.hdr_type = OMPI_OSC_RDMA_HDR_PUT;
-#if OMPI_ENABLE_MEM_DEBUG
+#if OPAL_ENABLE_MEM_DEBUG
         header->hdr_target_op = 0;
 #endif
         break;
@@ -499,7 +518,7 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
 
     case OMPI_OSC_RDMA_GET:
         header->hdr_base.hdr_type = OMPI_OSC_RDMA_HDR_GET;
-#if OMPI_ENABLE_MEM_DEBUG
+#if OPAL_ENABLE_MEM_DEBUG
         header->hdr_target_op = 0;
 #endif
         sendreq->req_refcount++;
@@ -507,7 +526,7 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
     }
 
     /* Set datatype id and / or pack datatype */
-    ret = ompi_ddt_get_pack_description(sendreq->req_target_datatype, &packed_ddt);
+    ret = ompi_datatype_get_pack_description(sendreq->req_target_datatype, &packed_ddt);
     if (OMPI_SUCCESS != ret) goto cleanup;
     memcpy((unsigned char*) descriptor->des_src[0].seg_addr.pval + descriptor->des_src[0].seg_len + written_data,
            packed_ddt, packed_ddt_len);
@@ -523,7 +542,7 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
             iov.iov_len = max_data;
             iov.iov_base = (IOVBASE_TYPE*)((unsigned char*) descriptor->des_src[0].seg_addr.pval + descriptor->des_src[0].seg_len + written_data);
 
-            ret = ompi_convertor_pack(&sendreq->req_origin_convertor, &iov, &iov_count,
+            ret = opal_convertor_pack(&sendreq->req_origin_convertor, &iov, &iov_count,
                                       &max_data );
             if (ret < 0) {
                 ret = OMPI_ERR_FATAL;
@@ -549,9 +568,30 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
     if (module->m_use_buffers) {
         header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_MULTI;
 
+        /* When putting multiple messages in a single buffer, the
+         * starting point for the next message needs to be aligned with
+         * pointer addresses.  Therefore, the pointer, amount written
+         * and space remaining are adjusted forward so that the
+         * starting position for the next message is aligned properly.
+         * The amount of this alignment is embedded in the hdr_flags
+         * field so the callback completion and receiving side can
+         * also know how much to move the pointer to find the starting
+         * point of the next header.  This strict alignment is
+         * required by certain platforms like SPARC.  Without it,
+         * bus errors can occur.  Keeping things aligned also may
+         * offer some performance improvements on other platforms.
+         */
+        offset = OPAL_ALIGN_PAD_AMOUNT(descriptor->des_src[0].seg_len, sizeof(uint64_t));
+        if (0 != offset) {
+            header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_ALIGN_MASK & offset;
+            descriptor->des_src[0].seg_len += offset;
+            written_data += offset;
+            module->m_pending_buffers[sendreq->req_target_rank].remain_len -= offset;
+        }
+
 #ifdef WORDS_BIGENDIAN
         header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
-#elif OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#elif OPAL_ENABLE_HETEROGENEOUS_SUPPORT
         if (sendreq->req_target_proc->proc_arch & OPAL_ARCH_ISBIGENDIAN) {
             header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
             OMPI_OSC_RDMA_SEND_HDR_HTON(*header);
@@ -570,7 +610,7 @@ ompi_osc_rdma_sendreq_send(ompi_osc_rdma_module_t *module,
     } else {
 #ifdef WORDS_BIGENDIAN
         header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
-#elif OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#elif OPAL_ENABLE_HETEROGENEOUS_SUPPORT
         if (sendreq->req_target_proc->proc_arch & OPAL_ARCH_ISBIGENDIAN) {
             header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
             OMPI_OSC_RDMA_SEND_HDR_HTON(*header);
@@ -638,7 +678,7 @@ ompi_osc_rdma_replyreq_send_cb(struct mca_btl_base_module_t* btl,
         return;
     }
 
-#if !defined(WORDS_BIGENDIAN) && OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#if !defined(WORDS_BIGENDIAN) && OPAL_ENABLE_HETEROGENEOUS_SUPPORT
         if (header->hdr_base.hdr_flags & OMPI_OSC_RDMA_HDR_FLAG_NBO) {
             OMPI_OSC_RDMA_REPLY_HDR_NTOH(*header);
         }
@@ -730,7 +770,7 @@ ompi_osc_rdma_replyreq_send(ompi_osc_rdma_module_t *module,
             memchecker_convertor_call(&opal_memchecker_base_mem_defined,
                                       &replyreq->rep_target_convertor);
         );
-        ret = ompi_convertor_pack(&replyreq->rep_target_convertor, &iov, &iov_count,
+        ret = opal_convertor_pack(&replyreq->rep_target_convertor, &iov, &iov_count,
                                   &max_data );
         MEMCHECKER(
             memchecker_convertor_call(&opal_memchecker_base_mem_noaccess,
@@ -754,7 +794,7 @@ ompi_osc_rdma_replyreq_send(ompi_osc_rdma_module_t *module,
 
 #ifdef WORDS_BIGENDIAN
     header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
-#elif OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#elif OPAL_ENABLE_HETEROGENEOUS_SUPPORT
     if (replyreq->rep_origin_proc->proc_arch & OPAL_ARCH_ISBIGENDIAN) {
         header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
         OMPI_OSC_RDMA_REPLY_HDR_HTON(*header);
@@ -814,19 +854,19 @@ ompi_osc_rdma_sendreq_recv_put(ompi_osc_rdma_module_t *module,
     }
 
     if (header->hdr_msg_length > 0) {
-        ompi_convertor_t convertor;
+        opal_convertor_t convertor;
         struct iovec iov;
         uint32_t iov_count = 1;
         size_t max_data;
         ompi_proc_t *proc;
 
         /* create convertor */
-        OBJ_CONSTRUCT(&convertor, ompi_convertor_t);
+        OBJ_CONSTRUCT(&convertor, opal_convertor_t);
 
         /* initialize convertor */
         proc         = ompi_comm_peer_lookup(module->m_comm, header->hdr_origin);
-        ompi_convertor_copy_and_prepare_for_recv(proc->proc_convertor,
-                                                 datatype,
+        opal_convertor_copy_and_prepare_for_recv(proc->proc_convertor,
+                                                 &(datatype->super),
                                                  header->hdr_target_count,
                                                  target,
                                                  0,
@@ -837,7 +877,7 @@ ompi_osc_rdma_sendreq_recv_put(ompi_osc_rdma_module_t *module,
         MEMCHECKER(
             memchecker_convertor_call(&opal_memchecker_base_mem_defined, &convertor);
         );
-        ompi_convertor_unpack(&convertor, 
+        opal_convertor_unpack(&convertor, 
                               &iov,
                               &iov_count,
                               &max_data );
@@ -913,17 +953,17 @@ ompi_osc_rdma_sendreq_recv_accum_long_cb(ompi_osc_rdma_longreq_t *longreq)
     OPAL_THREAD_LOCK(&longreq->req_module->m_acc_lock);
 
     if (longreq->req_op == &ompi_mpi_op_replace.op) {
-        ompi_convertor_t convertor;
+        opal_convertor_t convertor;
         struct iovec iov;
         uint32_t iov_count = 1;
         size_t max_data;
 
         /* create convertor */
-        OBJ_CONSTRUCT(&convertor, ompi_convertor_t);
+        OBJ_CONSTRUCT(&convertor, opal_convertor_t);
 
         /* initialize convertor */
-        ompi_convertor_copy_and_prepare_for_recv(ompi_proc_local()->proc_convertor,
-                                                 longreq->req_datatype,
+        opal_convertor_copy_and_prepare_for_recv(ompi_proc_local()->proc_convertor,
+                                                 &(longreq->req_datatype->super),
                                                  header->hdr_target_count,
                                                  target_buffer,
                                                  0,
@@ -936,7 +976,7 @@ ompi_osc_rdma_sendreq_recv_accum_long_cb(ompi_osc_rdma_longreq_t *longreq)
             memchecker_convertor_call(&opal_memchecker_base_mem_defined,
                                       &convertor);
         );
-        ompi_convertor_unpack(&convertor, 
+        opal_convertor_unpack(&convertor, 
                               &iov,
                               &iov_count,
                               &max_data);
@@ -1003,17 +1043,17 @@ ompi_osc_rdma_sendreq_recv_accum(ompi_osc_rdma_module_t *module,
         OPAL_THREAD_LOCK(&module->m_acc_lock);
 
         if (op == &ompi_mpi_op_replace.op) {
-            ompi_convertor_t convertor;
+            opal_convertor_t convertor;
             struct iovec iov;
             uint32_t iov_count = 1;
             size_t max_data;
 
             /* create convertor */
-            OBJ_CONSTRUCT(&convertor, ompi_convertor_t);
+            OBJ_CONSTRUCT(&convertor, opal_convertor_t);
 
             /* initialize convertor */
-            ompi_convertor_copy_and_prepare_for_recv(proc->proc_convertor,
-                                                     datatype,
+            opal_convertor_copy_and_prepare_for_recv(proc->proc_convertor,
+                                                     &(datatype->super),
                                                      header->hdr_target_count,
                                                      target_buffer,
                                                      0,
@@ -1025,7 +1065,7 @@ ompi_osc_rdma_sendreq_recv_accum(ompi_osc_rdma_module_t *module,
             MEMCHECKER(
                 memchecker_convertor_call(&opal_memchecker_base_mem_defined, &convertor);
             );
-            ompi_convertor_unpack(&convertor, 
+            opal_convertor_unpack(&convertor, 
                                   &iov,
                                   &iov_count,
                                   &max_data);
@@ -1036,13 +1076,13 @@ ompi_osc_rdma_sendreq_recv_accum(ompi_osc_rdma_module_t *module,
         } else {
             void *buffer = NULL;
 
-#if OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#if OPAL_ENABLE_HETEROGENEOUS_SUPPORT
             if (proc->proc_arch != ompi_proc_local()->proc_arch) {
-                ompi_convertor_t convertor;
+                opal_convertor_t convertor;
                 struct iovec iov;
                 uint32_t iov_count = 1;
                 size_t max_data;
-                struct ompi_datatype_t *primitive_datatype = NULL;
+                ompi_datatype_t *primitive_datatype = NULL;
                 uint32_t primitive_count;
                 size_t buflen;
 
@@ -1050,17 +1090,17 @@ ompi_osc_rdma_sendreq_recv_accum(ompi_osc_rdma_module_t *module,
                 primitive_count *= header->hdr_target_count;
 
                 /* figure out how big a buffer we need */
-                ompi_ddt_type_size(primitive_datatype, &buflen);
+                ompi_datatype_type_size(primitive_datatype, &buflen);
                 buflen *= primitive_count;
 
                 /* create convertor */
-                OBJ_CONSTRUCT(&convertor, ompi_convertor_t);
+                OBJ_CONSTRUCT(&convertor, opal_convertor_t);
 
                 payload = (void*) malloc(buflen);
 
                 /* initialize convertor */
-                ompi_convertor_copy_and_prepare_for_recv(proc->proc_convertor,
-                                                         primitive_datatype,
+                opal_convertor_copy_and_prepare_for_recv(proc->proc_convertor,
+                                                         &(primitive_datatype->super),
                                                          primitive_count,
                                                          buffer,
                                                          0,
@@ -1072,7 +1112,7 @@ ompi_osc_rdma_sendreq_recv_accum(ompi_osc_rdma_module_t *module,
                 MEMCHECKER(
                     memchecker_convertor_call(&opal_memchecker_base_mem_defined, &convertor);
                 );
-                ompi_convertor_unpack(&convertor, 
+                opal_convertor_unpack(&convertor, 
                                       &iov,
                                       &iov_count,
                                       &max_data);
@@ -1094,7 +1134,7 @@ ompi_osc_rdma_sendreq_recv_accum(ompi_osc_rdma_module_t *module,
                                            header->hdr_target_count,
                                            op);
 
-#if OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#if OPAL_ENABLE_HETEROGENEOUS_SUPPORT
             if (proc->proc_arch != ompi_proc_local()->proc_arch) {
                 if (NULL == buffer) free(buffer);
             }
@@ -1127,7 +1167,7 @@ ompi_osc_rdma_sendreq_recv_accum(ompi_osc_rdma_module_t *module,
         primitive_count *= header->hdr_target_count;
 
         /* figure out how big a buffer we need */
-        ompi_ddt_type_size(primitive_datatype, &buflen);
+        ompi_datatype_type_size(primitive_datatype, &buflen);
         buflen *= primitive_count;
 
         /* get a longreq and fill it in */
@@ -1219,7 +1259,7 @@ ompi_osc_rdma_replyreq_recv(ompi_osc_rdma_module_t *module,
             memchecker_convertor_call(&opal_memchecker_base_mem_defined,
                                       &sendreq->req_origin_convertor);
         );
-        ompi_convertor_unpack(&sendreq->req_origin_convertor,
+        opal_convertor_unpack(&sendreq->req_origin_convertor,
                               &iov,
                               &iov_count,
                               &max_data );
@@ -1324,7 +1364,7 @@ ompi_osc_rdma_control_send(ompi_osc_rdma_module_t *module,
 
 #ifdef WORDS_BIGENDIAN
     header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
-#elif OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#elif OPAL_ENABLE_HETEROGENEOUS_SUPPORT
     if (proc->proc_arch & OPAL_ARCH_ISBIGENDIAN) {
         header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
         OMPI_OSC_RDMA_CONTROL_HDR_HTON(*header);
@@ -1386,7 +1426,7 @@ ompi_osc_rdma_rdma_ack_send(ompi_osc_rdma_module_t *module,
 
 #ifdef WORDS_BIGENDIAN
     header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
-#elif OMPI_ENABLE_HETEROGENEOUS_SUPPORT
+#elif OPAL_ENABLE_HETEROGENEOUS_SUPPORT
     if (proc->proc_arch & OPAL_ARCH_ISBIGENDIAN) {
         header->hdr_base.hdr_flags |= OMPI_OSC_RDMA_HDR_FLAG_NBO;
         OMPI_OSC_RDMA_CONTROL_HDR_HTON(*header);
