@@ -20,6 +20,7 @@
 #include "ompi_config.h"
 #include "opal/threads/mutex.h"
 #include "opal/threads/condition.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "ompi/mca/allocator/base/base.h"
 #include "ompi/mca/allocator/allocator.h"
 #include "opal/mca/base/mca_base_param.h"
@@ -29,6 +30,9 @@
 #include "ompi/mca/pml/base/pml_base_bsend.h"
 #include "ompi/mca/mpool/mpool.h" 
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif  /* HAVE_UNISTD_H */
 
 static opal_mutex_t     mca_pml_bsend_mutex;      /* lock for thread safety */
 static opal_condition_t mca_pml_bsend_condition;  /* condition variable to block on detach */
@@ -107,7 +111,7 @@ int mca_pml_base_bsend_init(bool thread_safe)
 /*
  * One-time cleanup at shutdown - release any resources.
  */
-int mca_pml_base_bsend_fini()
+int mca_pml_base_bsend_fini(void)
 {
     if(OPAL_THREAD_ADD32(&mca_pml_bsend_init,-1) > 0) 
         return OMPI_SUCCESS;
@@ -152,7 +156,7 @@ int mca_pml_base_bsend_attach(void* addr, int size)
      * Save away what the user handed in.  This is done in case the
      * base and size are modified for alignment issues.
      */
-    mca_pml_bsend_userbase = addr;
+    mca_pml_bsend_userbase = (unsigned char*)addr;
     mca_pml_bsend_usersize = size;
     /* 
      * Align to pointer boundaries. The bsend overhead is large enough
@@ -249,7 +253,7 @@ int mca_pml_base_bsend_request_start(ompi_request_t* request)
         iov.iov_len = sendreq->req_bytes_packed;
         iov_count = 1;
         max_data = iov.iov_len;
-        if((rc = ompi_convertor_pack( &sendreq->req_base.req_convertor, 
+        if((rc = opal_convertor_pack( &sendreq->req_base.req_convertor, 
                                       &iov, 
                                       &iov_count, 
                                       &max_data )) < 0) {
@@ -257,7 +261,7 @@ int mca_pml_base_bsend_request_start(ompi_request_t* request)
         }
  
         /* setup convertor to point to packed buffer (at position zero) */
-        ompi_convertor_prepare_for_send( &sendreq->req_base.req_convertor, MPI_PACKED,
+        opal_convertor_prepare_for_send( &sendreq->req_base.req_convertor, &(ompi_mpi_packed.dt.super),
                                          max_data, sendreq->req_addr );
         /* increment count of pending requests */
         mca_pml_bsend_count++;
@@ -292,6 +296,9 @@ int mca_pml_base_bsend_request_alloc(ompi_request_t* request)
         /* release resources when request is freed */
         sendreq->req_base.req_pml_complete = true;
         OPAL_THREAD_UNLOCK(&mca_pml_bsend_mutex);
+        /* progress communications, with the hope that more resources
+         *   will be freed */
+        opal_progress();
         return OMPI_ERR_BUFFER;
     }
 
@@ -322,6 +329,9 @@ void*  mca_pml_base_bsend_request_alloc_buf( size_t length )
     if(NULL == buf) {
         /* release resources when request is freed */
         OPAL_THREAD_UNLOCK(&mca_pml_bsend_mutex);
+        /* progress communications, with the hope that more resources
+         *   will be freed */
+        opal_progress();
         return NULL;
     }
 
