@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-basic-offset:4 ; -*- */
 /*
- * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2010 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
  * Copyright (c) 2004-2007 The University of Tennessee and The University
@@ -10,6 +10,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -19,11 +20,17 @@
 
 #include "ompi_config.h"
 
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+
 #include "opal/class/opal_list.h"
+#include "opal/util/output.h"
 #include "orte/util/show_help.h"
 #include "opal/runtime/opal_progress.h"
 #include "opal/mca/mca.h"
 #include "opal/mca/base/base.h"
+#include "opal/runtime/opal.h"
 
 #include "orte/mca/errmgr/errmgr.h"
 #include "orte/util/name_fns.h"
@@ -63,7 +70,7 @@ int mca_pml_base_select(bool enable_progress_threads,
     opal_list_t opened;
     opened_component_t *om = NULL;
     bool found_pml;
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
     mca_pml_base_component_t *wrapper_component = NULL;
     mca_pml_base_module_t *wrapper_module = NULL;
     int wrapper_priority = -1;
@@ -134,7 +141,7 @@ int mca_pml_base_select(bool enable_progress_threads,
 
         opal_output_verbose( 10, mca_pml_base_output,
                              "select: init returned priority %d", priority );
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
         /* Determine if this is the wrapper component */
         if( priority <= PML_SELECT_WRAPPER_PRIORITY) {
             opal_output_verbose( 10, mca_pml_base_output,
@@ -199,7 +206,7 @@ int mca_pml_base_select(bool enable_progress_threads,
         om = (opened_component_t *) item;
 
         if (om->om_component != best_component
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
             && om->om_component != wrapper_component
 #endif
             ) {
@@ -222,7 +229,7 @@ int mca_pml_base_select(bool enable_progress_threads,
     }
     OBJ_DESTRUCT( &opened );
 
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
     /* Remove the wrapper component from the mca_pml_base_components_available list
      * so we don't unload it prematurely in the next call
      */
@@ -248,15 +255,19 @@ int mca_pml_base_select(bool enable_progress_threads,
                          "select: component %s selected",
                          mca_pml_base_selected_component.pmlm_version.mca_component_name );
 
+    if (opal_profile) {
+        opal_output(0, "pml:%s",  mca_pml_base_selected_component.pmlm_version.mca_component_name );
+    }
+    
     /* This base function closes, unloads, and removes from the
        available list all unselected components.  The available list will
        contain only the selected component. */
 
     mca_base_components_close(mca_pml_base_output, 
                               &mca_pml_base_components_available, 
-                              (mca_base_component_t *) best_component);
+                              (mca_base_component_t *) best_component, false);
     
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
     /* If we have a wrapper then initalize it */
     if( NULL != wrapper_component ) {
         priority = PML_SELECT_WRAPPER_PRIORITY;
