@@ -2,7 +2,7 @@
  * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2008 The University of Tennessee and The University
+ * Copyright (c) 2004-2010 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2007 High Performance Computing Center Stuttgart, 
@@ -29,7 +29,6 @@
 #include "ompi/mca/pml/csum/pml_csum_comm.h"
 #include "ompi/mca/mpool/base/base.h"
 #include "ompi/mca/pml/base/pml_base_recvreq.h"
-#include "ompi/datatype/datatype.h"
 
 BEGIN_C_DECLS
 
@@ -164,11 +163,11 @@ recv_request_pml_complete(mca_pml_csum_recv_request_t *recvreq)
     } else {
         /* initialize request status */
         recvreq->req_recv.req_base.req_pml_complete = true;
-        recvreq->req_recv.req_base.req_ompi.req_status._count =
-            (int)recvreq->req_bytes_received;
+        recvreq->req_recv.req_base.req_ompi.req_status._ucount =
+            recvreq->req_bytes_received;
         if (recvreq->req_recv.req_bytes_packed > recvreq->req_bytes_delivered) {
-            recvreq->req_recv.req_base.req_ompi.req_status._count =
-                (int)recvreq->req_recv.req_bytes_packed;
+            recvreq->req_recv.req_base.req_ompi.req_status._ucount =
+                recvreq->req_recv.req_bytes_packed;
             recvreq->req_recv.req_base.req_ompi.req_status.MPI_ERROR =
                 MPI_ERR_TRUNCATE;
         }
@@ -180,7 +179,7 @@ recv_request_pml_complete(mca_pml_csum_recv_request_t *recvreq)
 static inline bool
 recv_request_pml_complete_check(mca_pml_csum_recv_request_t *recvreq)
 {
-#if OMPI_HAVE_THREAD_SUPPORT
+#if OPAL_HAVE_THREAD_SUPPORT
     opal_atomic_rmb();
 #endif
     if(recvreq->req_match_received &&
@@ -196,17 +195,18 @@ recv_request_pml_complete_check(mca_pml_csum_recv_request_t *recvreq)
 extern void mca_pml_csum_recv_req_start(mca_pml_csum_recv_request_t *req);
 #define MCA_PML_CSUM_RECV_REQUEST_START(r) mca_pml_csum_recv_req_start(r)
 
+
 static inline void prepare_recv_req_converter(mca_pml_csum_recv_request_t *req)
 {
-    if( req->req_recv.req_base.req_datatype->size | req->req_recv.req_base.req_count ) {
-        ompi_convertor_copy_and_prepare_for_recv(
+    if( req->req_recv.req_base.req_datatype->super.size | req->req_recv.req_base.req_count ) {
+        opal_convertor_copy_and_prepare_for_recv(
                 req->req_recv.req_base.req_proc->proc_convertor,
-                req->req_recv.req_base.req_datatype,
+                &(req->req_recv.req_base.req_datatype->super),
                 req->req_recv.req_base.req_count,
                 req->req_recv.req_base.req_addr,
                 0,
                 &req->req_recv.req_base.req_convertor);
-        ompi_convertor_get_unpacked_size(&req->req_recv.req_base.req_convertor,
+        opal_convertor_get_unpacked_size(&req->req_recv.req_base.req_convertor,
                 &req->req_bytes_delivered);
     }
 }
@@ -220,7 +220,7 @@ static inline void recv_req_matched(mca_pml_csum_recv_request_t *req,
     req->req_recv.req_base.req_ompi.req_status.MPI_SOURCE = hdr->hdr_src;
     req->req_recv.req_base.req_ompi.req_status.MPI_TAG = hdr->hdr_tag;
     req->req_match_received = true;
-#if OMPI_HAVE_THREAD_SUPPORT
+#if OPAL_HAVE_THREAD_SUPPORT
     opal_atomic_wmb();
 #endif
     if(req->req_recv.req_bytes_packed > 0) {
@@ -269,9 +269,9 @@ do {
         PERUSE_TRACE_COMM_OMPI_EVENT (PERUSE_COMM_REQ_XFER_CONTINUE,              \
                                       &(recvreq->req_recv.req_base), max_data,    \
                                       PERUSE_RECV);                               \
-        ompi_convertor_set_position( &(request->req_recv.req_base.req_convertor), \
+        opal_convertor_set_position( &(request->req_recv.req_base.req_convertor), \
                                      &data_offset );                              \
-        ompi_convertor_unpack( &(request)->req_recv.req_base.req_convertor,       \
+        opal_convertor_unpack( &(request)->req_recv.req_base.req_convertor,       \
                                iov,                                               \
                                &iov_count,                                        \
                                &max_data );                                       \
