@@ -125,7 +125,7 @@ int mca_pml_csum_start(size_t count, ompi_request_t** requests)
                      * Reset the convertor in case we're dealing with the original
                      * request, which when completed do not reset the convertor.
                      */
-                    ompi_convertor_set_position( &sendreq->req_send.req_base.req_convertor,
+                    opal_convertor_set_position( &sendreq->req_send.req_base.req_convertor,
                                                  &offset );
                 }
                 MCA_PML_CSUM_SEND_REQUEST_START(sendreq, rc);
