@@ -1,8 +1,9 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /*
- * Copyright (c) 2004-2008 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2010 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2008 The University of Tennessee and The University
+ * Copyright (c) 2004-2009 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
@@ -11,6 +12,7 @@
  *                         All rights reserved.
  * Copyright (c) 2008      UT-Battelle, LLC. All rights reserved.
  * Copyright (c) 2006-2008 University of Houston.  All rights reserved.
+ * Copyright (c) 2009      Sun Microsystems, Inc.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -23,7 +25,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "ompi/class/ompi_bitmap.h"
+#include "opal/class/opal_bitmap.h"
 #include "ompi/mca/pml/pml.h"
 #include "ompi/mca/pml/base/base.h"
 #include "ompi/mca/btl/btl.h"
@@ -40,11 +42,9 @@
 #include "ompi/mca/bml/base/base.h"
 #include "orte/mca/errmgr/errmgr.h"
 #include "orte/mca/grpcomm/grpcomm.h"
-#include "orte/runtime/orte_globals.h"
+#include "orte/util/show_help.h"
 
 #include "ompi/runtime/ompi_cr.h"
-#include "ompi/runtime/ompi_module_exchange.h"
-#include "orte/mca/rml/rml.h"
 
 mca_pml_ob1_t mca_pml_ob1 = {
     {
@@ -72,11 +72,14 @@ mca_pml_ob1_t mca_pml_ob1 = {
 
 
 void mca_pml_ob1_error_handler( struct mca_btl_base_module_t* btl,
-                                int32_t flags );
+                                int32_t flags, ompi_proc_t* errproc,
+                                char* btlinfo );
 
 int mca_pml_ob1_enable(bool enable)
 {
-    if( false == enable ) return OMPI_SUCCESS;
+    if( false == enable ) {
+        return OMPI_SUCCESS;
+    }
 
     OBJ_CONSTRUCT(&mca_pml_ob1.lock, opal_mutex_t);
 
@@ -84,9 +87,9 @@ int mca_pml_ob1_enable(bool enable)
     OBJ_CONSTRUCT(&mca_pml_ob1.rdma_frags, ompi_free_list_t);
     ompi_free_list_init_new( &mca_pml_ob1.rdma_frags,
                          sizeof(mca_pml_ob1_rdma_frag_t),
-                         CACHE_LINE_SIZE,
+                         opal_cache_line_size,
                          OBJ_CLASS(mca_pml_ob1_rdma_frag_t),
-                         0,CACHE_LINE_SIZE,
+                         0,opal_cache_line_size,
                          mca_pml_ob1.free_list_num,
                          mca_pml_ob1.free_list_max,
                          mca_pml_ob1.free_list_inc,
@@ -96,9 +99,9 @@ int mca_pml_ob1_enable(bool enable)
 
     ompi_free_list_init_new( &mca_pml_ob1.recv_frags,
                          sizeof(mca_pml_ob1_recv_frag_t) + mca_pml_ob1.unexpected_limit,
-                         CACHE_LINE_SIZE,
+                         opal_cache_line_size,
                          OBJ_CLASS(mca_pml_ob1_recv_frag_t),
-                         0,CACHE_LINE_SIZE,
+                         0,opal_cache_line_size,
                          mca_pml_ob1.free_list_num,
                          mca_pml_ob1.free_list_max,
                          mca_pml_ob1.free_list_inc,
@@ -107,9 +110,9 @@ int mca_pml_ob1_enable(bool enable)
     OBJ_CONSTRUCT(&mca_pml_ob1.pending_pckts, ompi_free_list_t);
     ompi_free_list_init_new( &mca_pml_ob1.pending_pckts,
                          sizeof(mca_pml_ob1_pckt_pending_t),
-                         CACHE_LINE_SIZE,
+                         opal_cache_line_size,
                          OBJ_CLASS(mca_pml_ob1_pckt_pending_t),
-                         0,CACHE_LINE_SIZE,
+                         0,opal_cache_line_size,
                          mca_pml_ob1.free_list_num,
                          mca_pml_ob1.free_list_max,
                          mca_pml_ob1.free_list_inc,
@@ -121,9 +124,9 @@ int mca_pml_ob1_enable(bool enable)
     ompi_free_list_init_new( &mca_pml_ob1.send_ranges,
                          sizeof(mca_pml_ob1_send_range_t) +
                          (mca_pml_ob1.max_send_per_range - 1) * sizeof(mca_pml_ob1_com_btl_t),
-                         CACHE_LINE_SIZE,
+                         opal_cache_line_size,
                          OBJ_CLASS(mca_pml_ob1_send_range_t),
-                         0,CACHE_LINE_SIZE,
+                         0,opal_cache_line_size,
                          mca_pml_ob1.free_list_num,
                          mca_pml_ob1.free_list_max,
                          mca_pml_ob1.free_list_inc,
@@ -146,9 +149,9 @@ int mca_pml_ob1_enable(bool enable)
                          sizeof(mca_pml_ob1_send_request_t) +
                          (mca_pml_ob1.max_rdma_per_request - 1) *
                          sizeof(mca_pml_ob1_com_btl_t),
-                         CACHE_LINE_SIZE,
+                         opal_cache_line_size,
                          OBJ_CLASS(mca_pml_ob1_send_request_t),
-                         0,CACHE_LINE_SIZE,
+                         0,opal_cache_line_size,
                          mca_pml_ob1.free_list_num,
                          mca_pml_ob1.free_list_max,
                          mca_pml_ob1.free_list_inc,
@@ -158,9 +161,9 @@ int mca_pml_ob1_enable(bool enable)
                          sizeof(mca_pml_ob1_recv_request_t) +
                          (mca_pml_ob1.max_rdma_per_request - 1) *
                          sizeof(mca_pml_ob1_com_btl_t),
-                         CACHE_LINE_SIZE,
+                         opal_cache_line_size,
                          OBJ_CLASS(mca_pml_ob1_recv_request_t),
-                         0,CACHE_LINE_SIZE,
+                         0,opal_cache_line_size,
                          mca_pml_ob1.free_list_num,
                          mca_pml_ob1.free_list_max,
                          mca_pml_ob1.free_list_inc,
@@ -185,7 +188,7 @@ int mca_pml_ob1_add_comm(ompi_communicator_t* comm)
     }
 
     /* should never happen, but it was, so check */
-    if (comm->c_contextid > (uint32_t) mca_pml_ob1.super.pml_max_contextid) {
+    if (comm->c_contextid > mca_pml_ob1.super.pml_max_contextid) {
         OBJ_RELEASE(pml_comm);
         return OMPI_ERR_OUT_OF_RESOURCE;
     }
@@ -195,6 +198,7 @@ int mca_pml_ob1_add_comm(ompi_communicator_t* comm)
 
     for( i = 0; i < comm->c_remote_group->grp_proc_count; i++ ) {
         pml_comm->procs[i].ompi_proc = ompi_group_peer_lookup(comm->c_remote_group,i);
+        OBJ_RETAIN(pml_comm->procs[i].ompi_proc);
     }
     /* Grab all related messages from the non_existing_communicator pending queue */
     for( item = opal_list_get_first(&mca_pml_ob1.non_existing_communicator_pending);
@@ -208,11 +212,11 @@ int mca_pml_ob1_add_comm(ompi_communicator_t* comm)
         if( frag->hdr.hdr_match.hdr_ctx != comm->c_contextid )
             continue;
 
-        /* As we now know we work on a fragment for this communicator we should
-         * remove it from the non_existing_communicator_pending list. As a result
-         * after the call item will contain the previous item so the loop will
-         * continue to work as expected. */
-        item = opal_list_remove_item( &mca_pml_ob1.non_existing_communicator_pending, item );
+        /* As we now know we work on a fragment for this communicator
+         * we should remove it from the
+         * non_existing_communicator_pending list. */
+        opal_list_remove_item( &mca_pml_ob1.non_existing_communicator_pending, 
+                               item );
 
       add_fragment_to_unexpected:
 
@@ -265,6 +269,12 @@ int mca_pml_ob1_add_comm(ompi_communicator_t* comm)
 
 int mca_pml_ob1_del_comm(ompi_communicator_t* comm)
 {
+    mca_pml_ob1_comm_t* pml_comm = comm->c_pml_comm;
+    int i;
+
+    for( i = 0; i < comm->c_remote_group->grp_proc_count; i++ ) {
+        OBJ_RELEASE(pml_comm->procs[i].ompi_proc);
+    }
     OBJ_RELEASE(comm->c_pml_comm);
     comm->c_pml_comm = NULL;
     return OMPI_SUCCESS;
@@ -279,9 +289,10 @@ int mca_pml_ob1_del_comm(ompi_communicator_t* comm)
 
 int mca_pml_ob1_add_procs(ompi_proc_t** procs, size_t nprocs)
 {
-    ompi_bitmap_t reachable;
+    opal_bitmap_t reachable;
     int rc;
     size_t i;
+    opal_list_item_t *item;
 
     if(nprocs == 0)
         return OMPI_SUCCESS;
@@ -292,8 +303,8 @@ int mca_pml_ob1_add_procs(ompi_proc_t** procs, size_t nprocs)
         procs[i]->proc_pml = NULL;
     }
 
-    OBJ_CONSTRUCT(&reachable, ompi_bitmap_t);
-    rc = ompi_bitmap_init(&reachable, (int)nprocs);
+    OBJ_CONSTRUCT(&reachable, opal_bitmap_t);
+    rc = opal_bitmap_init(&reachable, (int)nprocs);
     if(OMPI_SUCCESS != rc)
         return rc;
 
@@ -303,7 +314,7 @@ int mca_pml_ob1_add_procs(ompi_proc_t** procs, size_t nprocs)
      * return failure as all processes will return the wrapper PML
      * component in use instead of the wrapped PML component underneath.
      */
-#if OPAL_ENABLE_FT == 0
+#if OPAL_ENABLE_FT_CR == 0
     /* make sure remote procs are using the same PML as us */
     if (OMPI_SUCCESS != (rc = mca_pml_base_pml_check_selected("ob1",
                                                               procs,
@@ -318,6 +329,39 @@ int mca_pml_ob1_add_procs(ompi_proc_t** procs, size_t nprocs)
     if(OMPI_SUCCESS != rc)
         goto cleanup_and_return;
 
+    /* Check that values supplied by all initialized btls will work
+       for us.  Note that this is the list of all initialized BTLs,
+       not the ones used for the just added procs.  This is a little
+       overkill and inaccurate, as we may end up not using the BTL in
+       question and all add_procs calls after the first one are
+       duplicating an already completed check.  But the final
+       initialization of the PML occurs before the final
+       initialization of the BTLs, and iterating through the in-use
+       BTLs requires iterating over the procs, as the BML does not
+       expose all currently in use btls. */
+
+    for (item = opal_list_get_first(&mca_btl_base_modules_initialized) ;
+         item != opal_list_get_end(&mca_btl_base_modules_initialized) ;
+         item = opal_list_get_next(item)) {
+        mca_btl_base_selected_module_t *sm = 
+            (mca_btl_base_selected_module_t*) item;
+        if (sm->btl_module->btl_eager_limit < sizeof(mca_pml_ob1_hdr_t)) {
+	    orte_show_help("help-mpi-pml-ob1.txt", "eager_limit_too_small",
+			   true, 
+			   sm->btl_component->btl_version.mca_component_name,
+			   orte_process_info.nodename,
+			   sm->btl_component->btl_version.mca_component_name,
+			   sm->btl_module->btl_eager_limit,
+			   sm->btl_component->btl_version.mca_component_name,
+			   sizeof(mca_pml_ob1_hdr_t),
+			   sm->btl_component->btl_version.mca_component_name);
+            rc = OMPI_ERR_BAD_PARAM;
+            goto cleanup_and_return;
+        }
+    }
+
+		    
+    /* TODO: Move these callback registration to another place */
     rc = mca_bml.bml_register( MCA_PML_OB1_HDR_TYPE_MATCH,
                                mca_pml_ob1_recv_frag_callback_match,
                                NULL );
@@ -428,7 +472,7 @@ static void mca_pml_ob1_fin_completion( mca_btl_base_module_t* btl,
  */
 int mca_pml_ob1_send_fin( ompi_proc_t* proc,
                           mca_bml_base_btl_t* bml_btl,
-                          void *hdr_des,
+                          ompi_ptr_t hdr_des,
                           uint8_t order,
                           uint32_t status )
 {
@@ -437,8 +481,7 @@ int mca_pml_ob1_send_fin( ompi_proc_t* proc,
     int rc;
 
     mca_bml_base_alloc(bml_btl, &fin, order, sizeof(mca_pml_ob1_fin_hdr_t),
-                       MCA_BTL_DES_FLAGS_PRIORITY | MCA_BTL_DES_FLAGS_BTL_OWNERSHIP |
-                       MCA_BTL_DES_SEND_ALWAYS_CALLBACK);
+                       MCA_BTL_DES_FLAGS_PRIORITY | MCA_BTL_DES_FLAGS_BTL_OWNERSHIP);
 
     if(NULL == fin) {
         MCA_PML_OB1_ADD_FIN_TO_PENDING(proc, hdr_des, bml_btl, order, status);
@@ -451,7 +494,7 @@ int mca_pml_ob1_send_fin( ompi_proc_t* proc,
     hdr = (mca_pml_ob1_fin_hdr_t*)fin->des_src->seg_addr.pval;
     hdr->hdr_common.hdr_flags = 0;
     hdr->hdr_common.hdr_type = MCA_PML_OB1_HDR_TYPE_FIN;
-    hdr->hdr_des.pval = hdr_des;
+    hdr->hdr_des = hdr_des;
     hdr->hdr_fail = status;
 
     ob1_hdr_hton(hdr, MCA_PML_OB1_HDR_TYPE_FIN, proc);
@@ -517,7 +560,7 @@ void mca_pml_ob1_process_pending_packets(mca_bml_base_btl_t* bml_btl)
                 break;
             case MCA_PML_OB1_HDR_TYPE_FIN:
                 rc = mca_pml_ob1_send_fin(pckt->proc, send_dst,
-                                          pckt->hdr.hdr_fin.hdr_des.pval,
+                                          pckt->hdr.hdr_fin.hdr_des,
                                           pckt->order,
                                           pckt->hdr.hdr_fin.hdr_fail);
                 if( OPAL_UNLIKELY(OMPI_ERR_OUT_OF_RESOURCE == rc) ) {
@@ -559,12 +602,12 @@ void mca_pml_ob1_process_pending_rdma(void)
 
 
 void mca_pml_ob1_error_handler(
-        struct mca_btl_base_module_t* btl,
-        int32_t flags) { 
+        struct mca_btl_base_module_t* btl, int32_t flags,
+        ompi_proc_t* errproc, char* btlinfo ) { 
     orte_errmgr.abort(-1, NULL);
 }
 
-#if OPAL_ENABLE_FT    == 0
+#if OPAL_ENABLE_FT_CR    == 0
 int mca_pml_ob1_ft_event( int state ) {
     return OMPI_SUCCESS;
 }
@@ -615,6 +658,9 @@ int mca_pml_ob1_ft_event( int state )
                 opal_output(0,
                             "pml:ob1: ft_event(Restart): proc_refresh Failed %d",
                             ret);
+                for(p = 0; p < (int)num_procs; ++p) {
+                    OBJ_RELEASE(procs[p]);
+                }
                 free (procs);
                 return ret;
             }
@@ -651,6 +697,9 @@ int mca_pml_ob1_ft_event( int state )
             opal_output(0,
                         "pml:ob1: ft_event(Restart): proc_refresh Failed %d",
                         ret);
+            for(p = 0; p < (int)num_procs; ++p) {
+                OBJ_RELEASE(procs[p]);
+            }
             free (procs);
             return ret;
         }
@@ -779,7 +828,7 @@ int mca_pml_ob1_ft_event( int state )
 
     return OMPI_SUCCESS;
 }
-#endif /* OPAL_ENABLE_FT */
+#endif /* OPAL_ENABLE_FT_CR */
 
 int mca_pml_ob1_com_btl_comp(const void *v1, const void *v2)
 {
@@ -793,3 +842,4 @@ int mca_pml_ob1_com_btl_comp(const void *v1, const void *v2)
 
     return 0;
 }
+
