@@ -62,13 +62,10 @@
 #define MCA_PML_H
 
 #include "ompi_config.h"
-#include "opal/class/opal_list.h"
 #include "opal/mca/mca.h"
 #include "mpi.h" /* needed for MPI_ANY_TAG */
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
 /*
  * PML component types
@@ -508,7 +505,7 @@ struct mca_pml_base_module_1_0_0_t {
     mca_pml_base_module_ft_event_fn_t     pml_ft_event;
 
     /* maximum constant sizes */
-    int                                   pml_max_contextid;
+    uint32_t                              pml_max_contextid;
     int                                   pml_max_tag;
 };
 typedef struct mca_pml_base_module_1_0_0_t mca_pml_base_module_1_0_0_t;
@@ -539,7 +536,5 @@ typedef mca_pml_base_module_1_0_0_t mca_pml_base_module_t;
 OMPI_DECLSPEC extern mca_pml_base_module_t mca_pml;
 
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 #endif /* MCA_PML_H */
