@@ -11,14 +11,12 @@
 #ifndef PML_V_OUTPUT_H_HAS_BEEN_INCLUDED
 #define PML_V_OUTPUT_H_HAS_BEEN_INCLUDED
 
-#include "orte/util/show_help.h"
+#include "opal/util/output.h"
 #include "opal_stdint.h"
 #include <stdio.h>
 #include "pml_v.h"
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
 int pml_v_output_open(char *output, int verbosity);
 void pml_v_output_close(void);
@@ -51,7 +49,7 @@ static inline void V_OUTPUT_ERR(const char *fmt, ... )
 #   define V_OUTPUT_VERBOSE(V, ARGS...)                                        \
         OPAL_OUTPUT_VERBOSE((V, mca_pml_v.output, ARGS))
             
-#elif OMPI_ENABLE_DEBUG
+#elif OPAL_ENABLE_DEBUG
     /* No variadic macros available... So sad */
 static inline void V_OUTPUT(const char* fmt, ... ) __opal_attribute_format__(__printf__, 1, 2);
 static inline void V_OUTPUT(const char* fmt, ... )
@@ -97,8 +95,6 @@ static inline void V_OUTPUT_VERBOSE(int V, const char* fmt, ... ) {
 }
 #endif /* DEBUG */
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 
 #endif /* PML_V_OUTPUT_H_HAS_BEEN_INCLUDED */
