@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -54,7 +55,7 @@ int mca_rcache_base_close(void)
      OMPI RTE program, or [possibly] multiple if this is the ompi_info-tool) */
 
   mca_base_components_close(mca_rcache_base_output, 
-                            &mca_rcache_base_components, NULL);
+                            &mca_rcache_base_components, NULL, true);
 
   /* All done */
 
