@@ -26,8 +26,8 @@
   */
 #ifndef MCA_RCACHE_VMA_H
 #define MCA_RCACHE_VMA_H
+#include "ompi_config.h"
 #include "opal/mca/mca.h"
-#include "ompi/info/info.h"
 #include "opal/class/opal_list.h" 
 #include "ompi/class/ompi_rb_tree.h"
 #include "ompi/mca/rcache/rcache.h"
@@ -44,7 +44,8 @@ typedef struct mca_rcache_vma_module_t mca_rcache_vma_module_t;
 
 struct mca_rcache_vma_component_t { 
     mca_rcache_base_component_t super; 
-}; typedef struct mca_rcache_vma_component_t mca_rcache_vma_component_t; 
+};
+typedef struct mca_rcache_vma_component_t mca_rcache_vma_component_t; 
 
 OMPI_DECLSPEC extern mca_rcache_vma_component_t mca_rcache_vma_component;
 
