@@ -25,7 +25,6 @@
 
 #include "ompi/mca/topo/base/base.h"
 #include "ompi/communicator/communicator.h"
-#include "ompi/mca/topo/topo.h"
 
 /*
  * function - retrieves Cartesian topology information associated with a
@@ -42,7 +41,7 @@
  *
  * @retval MPI_SUCCESS
  */
-int mca_topo_base_cart_get (MPI_Comm comm,
+int mca_topo_base_cart_get (ompi_communicator_t* comm,
                         int maxdims,
                         int *dims,
                         int *periods,
