@@ -23,11 +23,11 @@
 
 #include "opal/class/opal_list.h"
 #include "opal/util/argv.h"
+#include "opal/util/output.h"
 #include "opal/mca/mca.h"
 #include "opal/mca/base/base.h"
 #include "ompi/mca/topo/topo.h"
 #include "ompi/mca/topo/base/base.h"
-#include "orte/util/show_help.h"
 #include "ompi/communicator/communicator.h"
 
 
