@@ -21,9 +21,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "mpi.h"
 #include "opal/class/opal_list.h"
-#include "orte/util/show_help.h"
+#include "opal/util/output.h"
 #include "opal/mca/mca.h"
 #include "opal/mca/base/base.h"
 #include "opal/mca/base/mca_base_component_repository.h"
