@@ -10,6 +10,7 @@
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2006-2007 Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2009      Sun Microsystems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -19,13 +20,15 @@
 #include "ompi_config.h"
 #include <stdio.h>
 
-#include "orte/util/show_help.h"
 #include "ompi/info/info.h"
 #include "ompi/mpi/c/bindings.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
 #include "ompi/mca/dpm/dpm.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Comm_spawn = PMPI_Comm_spawn
 #endif
 
@@ -69,10 +72,6 @@ int MPI_Comm_spawn(char *command, char **argv, int maxprocs, MPI_Info info,
             return OMPI_ERRHANDLER_INVOKE(comm, MPI_ERR_ARG,
                                           FUNC_NAME);
         }
-        if (NULL == info || ompi_info_is_freed(info)) {
-          return OMPI_ERRHANDLER_INVOKE(MPI_COMM_WORLD, MPI_ERR_INFO,
-                                        FUNC_NAME);
-        }
     }
    
     rank = ompi_comm_rank ( comm );
@@ -86,6 +85,10 @@ int MPI_Comm_spawn(char *command, char **argv, int maxprocs, MPI_Info info,
                 return OMPI_ERRHANDLER_INVOKE(comm, MPI_ERR_ARG,
                                               FUNC_NAME);
             }
+            if (NULL == info || ompi_info_is_freed(info)) {
+                return OMPI_ERRHANDLER_INVOKE(MPI_COMM_WORLD, MPI_ERR_INFO,
+                                              FUNC_NAME);
+            }
         }
     }
 
@@ -93,7 +96,9 @@ int MPI_Comm_spawn(char *command, char **argv, int maxprocs, MPI_Info info,
     memset(port_name, 0, MPI_MAX_PORT_NAME);
     
     /* See if the info key "ompi_non_mpi" was set to true */
-    ompi_info_get_bool(info, "ompi_non_mpi", &non_mpi, &flag);
+    if (rank == root) {
+        ompi_info_get_bool(info, "ompi_non_mpi", &non_mpi, &flag);
+    }
 
     OPAL_CR_ENTER_LIBRARY();
 
@@ -104,6 +109,10 @@ int MPI_Comm_spawn(char *command, char **argv, int maxprocs, MPI_Info info,
             if (OMPI_SUCCESS != (rc = ompi_dpm.open_port (port_name, OMPI_RML_TAG_INVALID))) {
                 goto error;
             }
+        } else if (1 < ompi_comm_size(comm)) {
+            /* we do not support non_mpi spawns on comms this size */
+            rc = OMPI_ERR_NOT_SUPPORTED;
+            goto error;
         }
         if (OMPI_SUCCESS != (rc = ompi_dpm.spawn (1, &command, &argv, &maxprocs, 
                                                   &info, port_name))) {
