@@ -20,10 +20,12 @@
 #include "ompi_config.h"
 
 #include "ompi/mpi/c/bindings.h"
+#include "ompi/runtime/params.h"
+#include "ompi/errhandler/errhandler.h"
 #include "ompi/mpi/f77/fint_2_int.h"
 #include "ompi/file/file.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_File_c2f = PMPI_File_c2f
 #endif
 
@@ -41,7 +43,16 @@ MPI_Fint MPI_File_c2f(MPI_File file)
 
     if (MPI_PARAM_CHECK) {
         OMPI_ERR_INIT_FINALIZE(FUNC_NAME);
-        if (ompi_file_invalid(file)) {
+
+        /* Note that ompi_file_invalid() explicitly checks for
+           MPI_FILE_NULL, but MPI_FILE_C2F is supposed to treat
+           MPI_FILE_NULL as a valid file (and therefore return a valid
+           Fortran handle for it).  Hence, this function should not
+           return an error if MPI_FILE_NULL is passed in.
+
+           See a big comment in ompi/communicator/communicator.h about
+           this. */
+        if (ompi_file_invalid(file) && MPI_FILE_NULL != file) {
             return OMPI_INT_2_FINT(-1);
         }
     }
