@@ -19,13 +19,16 @@
 #include "ompi_config.h"
 
 #include "ompi/mpi/c/bindings.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
 #include "ompi/info/info.h"
 #include "ompi/file/file.h"
 #include "ompi/mca/io/io.h"
 #include "ompi/mca/io/base/base.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_File_open = PMPI_File_open
 #endif
 
@@ -79,8 +82,8 @@ int MPI_File_open(MPI_Comm comm, char *filename, int amode,
             return OMPI_ERRHANDLER_INVOKE(MPI_FILE_NULL, rc, FUNC_NAME);
         }
         if (OMPI_SUCCESS != 
-            (rc = mca_io_base_find_available(OMPI_ENABLE_PROGRESS_THREADS,
-                                             OMPI_ENABLE_MPI_THREADS))) {
+            (rc = mca_io_base_find_available(OPAL_ENABLE_PROGRESS_THREADS,
+                                             OMPI_ENABLE_THREAD_MULTIPLE))) {
             return OMPI_ERRHANDLER_INVOKE(MPI_FILE_NULL, rc, FUNC_NAME);
         }
     }
