@@ -1,8 +1,9 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2005 The University of Tennessee and The University
+ * Copyright (c) 2004-2007 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
@@ -20,10 +21,12 @@
 #include "ompi_config.h"
 
 #include "ompi/mpi/c/bindings.h"
+#include "ompi/runtime/params.h"
+#include "ompi/errhandler/errhandler.h"
 #include "ompi/mpi/f77/fint_2_int.h"
 #include "ompi/group/group.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Group_f2c = PMPI_Group_f2c
 #endif
 
@@ -38,6 +41,8 @@ MPI_Group MPI_Group_f2c(MPI_Fint group_f)
 {
     int group_index = OMPI_FINT_2_INT(group_f);
 
+    OPAL_CR_NOOP_PROGRESS();
+
     if (MPI_PARAM_CHECK) {
         OMPI_ERR_INIT_FINALIZE(FUNC_NAME);
     }
@@ -48,9 +53,9 @@ MPI_Group MPI_Group_f2c(MPI_Fint group_f)
 
     if (group_index < 0 ||
         group_index >=
-        ompi_pointer_array_get_size(ompi_group_f_to_c_table)) {
+        opal_pointer_array_get_size(&ompi_group_f_to_c_table)) {
         return NULL;
     }
 
-    return ompi_pointer_array_get_item(ompi_group_f_to_c_table, group_index);
+    return (MPI_Group)opal_pointer_array_get_item(&ompi_group_f_to_c_table, group_index);
 }
