@@ -20,11 +20,14 @@
 #include <stdio.h>
 
 #include "ompi/mpi/c/bindings.h"
-#include "ompi/datatype/datatype.h"
-#include "ompi/datatype/convertor.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
+#include "ompi/datatype/ompi_datatype.h"
+#include "opal/datatype/opal_convertor.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Pack_external_size = PMPI_Pack_external_size
 #endif
 
@@ -38,7 +41,7 @@ static const char FUNC_NAME[] = "MPI_Pack_external_size";
 int MPI_Pack_external_size(char *datarep, int incount,
                            MPI_Datatype datatype, MPI_Aint *size) 
 {
-    ompi_convertor_t local_convertor;
+    opal_convertor_t local_convertor;
     size_t length;
 
     MEMCHECKER(
@@ -56,15 +59,15 @@ int MPI_Pack_external_size(char *datarep, int incount,
 
     OPAL_CR_ENTER_LIBRARY();
 
-    OBJ_CONSTRUCT(&local_convertor, ompi_convertor_t);
+    OBJ_CONSTRUCT(&local_convertor, opal_convertor_t);
 
     /* the resulting convertor will be set to the position ZERO */
-    ompi_convertor_copy_and_prepare_for_send( ompi_mpi_external32_convertor,
-                                              datatype, incount, NULL,
+    opal_convertor_copy_and_prepare_for_send( ompi_mpi_external32_convertor,
+                                              &(datatype->super), incount, NULL,
                                               CONVERTOR_SEND_CONVERSION,
                                               &local_convertor );
 
-    ompi_convertor_get_packed_size( &local_convertor, &length );
+    opal_convertor_get_packed_size( &local_convertor, &length );
     *size = (MPI_Aint)length;
     OBJ_DESTRUCT( &local_convertor );
 
