@@ -22,11 +22,13 @@
 #include <stdio.h>
 
 #include "ompi/mpi/c/bindings.h"
-/*#include "ompi/mca/coll/coll.h"*/
-#include "ompi/datatype/datatype.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Scatter = PMPI_Scatter
 #endif
 
