@@ -19,10 +19,13 @@
 #include "ompi_config.h"
 
 #include "ompi/mpi/c/bindings.h"
-#include "ompi/datatype/datatype.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Type_create_indexed_block = PMPI_Type_create_indexed_block
 #endif
 
@@ -62,10 +65,10 @@ int MPI_Type_create_indexed_block(int count,
 
    OPAL_CR_ENTER_LIBRARY();
 
-   rc = ompi_ddt_create_indexed_block( count, blocklength, array_of_displacements,
+   rc = ompi_datatype_create_indexed_block( count, blocklength, array_of_displacements,
                                       oldtype, newtype );
    if( rc != MPI_SUCCESS ) {
-      ompi_ddt_destroy( newtype );
+      ompi_datatype_destroy( newtype );
       OMPI_ERRHANDLER_RETURN( rc, MPI_COMM_WORLD, rc, FUNC_NAME );
    }
    {
@@ -73,7 +76,7 @@ int MPI_Type_create_indexed_block(int count,
       a_i[0] = &count;
       a_i[1] = &blocklength;
       a_i[2] = array_of_displacements;
-      ompi_ddt_set_args( *newtype, 2 + count, a_i, 0, NULL, 1, &oldtype, MPI_COMBINER_INDEXED_BLOCK );
+      ompi_datatype_set_args( *newtype, 2 + count, a_i, 0, NULL, 1, &oldtype, MPI_COMBINER_INDEXED_BLOCK );
    }
 
    OPAL_CR_EXIT_LIBRARY();
