@@ -19,10 +19,13 @@
 #include "ompi_config.h"
 
 #include "ompi/mpi/c/bindings.h"
-#include "ompi/datatype/datatype.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
+#include "ompi/datatype/ompi_datatype.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Type_indexed = PMPI_Type_indexed
 #endif
 
@@ -68,11 +71,11 @@ int MPI_Type_indexed(int count,
 
    OPAL_CR_ENTER_LIBRARY();
 
-   rc = ompi_ddt_create_indexed ( count, array_of_blocklengths, 
+   rc = ompi_datatype_create_indexed ( count, array_of_blocklengths, 
                                  array_of_displacements,
                                  oldtype, newtype );
    if( rc != MPI_SUCCESS ) {
-      ompi_ddt_destroy( newtype );
+      ompi_datatype_destroy( newtype );
       OMPI_ERRHANDLER_RETURN( rc, MPI_COMM_WORLD,
                              rc, FUNC_NAME );
    }
@@ -84,7 +87,7 @@ int MPI_Type_indexed(int count,
       a_i[1] = array_of_blocklengths;
       a_i[2] = array_of_displacements;
 
-      ompi_ddt_set_args( *newtype, 2 * count + 1, a_i, 0, NULL, 1, &oldtype,
+      ompi_datatype_set_args( *newtype, 2 * count + 1, a_i, 0, NULL, 1, &oldtype,
                          MPI_COMBINER_INDEXED );
    }
 
