@@ -1,14 +1,15 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
  * Copyright (c) 2004-2005 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2008 High Performance Computing Center Stuttgart, 
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2006      Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -19,10 +20,14 @@
 #include <stdio.h>
 
 #include "ompi/mpi/c/bindings.h"
-#include "ompi/datatype/datatype.h"
-#include "ompi/datatype/convertor.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
+#include "ompi/datatype/ompi_datatype.h"
+#include "opal/datatype/opal_convertor.h"
+#include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Unpack = PMPI_Unpack
 #endif
 
@@ -37,12 +42,18 @@ int MPI_Unpack(void *inbuf, int insize, int *position,
                void *outbuf, int outcount, MPI_Datatype datatype,
                MPI_Comm comm) 
 {
-    int rc = 1, freeAfter;
-    ompi_convertor_t local_convertor;
+    int rc = 1;
+    opal_convertor_t local_convertor;
     struct iovec outvec;
     unsigned int iov_count;
     size_t size;
 
+    MEMCHECKER(
+        memchecker_datatype(datatype);
+        memchecker_call(&opal_memchecker_base_isdefined, outbuf, outcount, datatype);
+        memchecker_comm(comm);
+    );
+
     if (MPI_PARAM_CHECK) {
         OMPI_ERR_INIT_FINALIZE(FUNC_NAME);
         if (ompi_comm_invalid(comm)) {
@@ -58,31 +69,34 @@ int MPI_Unpack(void *inbuf, int insize, int *position,
             return OMPI_ERRHANDLER_INVOKE(comm, MPI_ERR_COUNT, FUNC_NAME);
         }
 
-        if (MPI_DATATYPE_NULL == datatype) {
+        if (MPI_DATATYPE_NULL == datatype || NULL == datatype) {
             return OMPI_ERRHANDLER_INVOKE(comm, MPI_ERR_TYPE, FUNC_NAME);
         }
     }
+
+    OPAL_CR_ENTER_LIBRARY();
+
     if( insize > 0 ) { 
-        OBJ_CONSTRUCT( &local_convertor, ompi_convertor_t );
+        OBJ_CONSTRUCT( &local_convertor, opal_convertor_t );
         /* the resulting convertor will be set the the position ZERO */
-        ompi_convertor_copy_and_prepare_for_recv( ompi_mpi_local_convertor, datatype,
+        opal_convertor_copy_and_prepare_for_recv( ompi_mpi_local_convertor, &(datatype->super),
                                                   outcount, outbuf, 0, &local_convertor );
         
         /* Check for truncation */
-        ompi_convertor_get_packed_size( &local_convertor, &size );
+        opal_convertor_get_packed_size( &local_convertor, &size );
         if( (*position + size) > (unsigned int)insize ) {
             OBJ_DESTRUCT( &local_convertor );
+            OPAL_CR_EXIT_LIBRARY();
             return OMPI_ERRHANDLER_INVOKE(comm, MPI_ERR_TRUNCATE, FUNC_NAME);
         }
         
         /* Prepare the iovec with all informations */
         outvec.iov_base = (char*) inbuf + (*position);
-        outvec.iov_len = insize - (*position);
+        outvec.iov_len = size;
         
         /* Do the actual unpacking */
         iov_count = 1;
-        rc = ompi_convertor_unpack( &local_convertor, &outvec, &iov_count,
-                                    &size, &freeAfter );
+        rc = opal_convertor_unpack( &local_convertor, &outvec, &iov_count, &size );
         *position += size;
         OBJ_DESTRUCT( &local_convertor );
         
@@ -90,6 +104,7 @@ int MPI_Unpack(void *inbuf, int insize, int *position,
            OMPI_SUCCESS. */
  
     }
+
     OMPI_ERRHANDLER_RETURN((rc == 1) ? OMPI_SUCCESS : OMPI_ERROR,
                            comm, MPI_ERR_UNKNOWN, FUNC_NAME);
     
