@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
  * Copyright (c) 2004-2005 The University of Tennessee and The University
@@ -19,10 +19,13 @@
 #include <stdio.h>
 
 #include "ompi/mpi/c/bindings.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
 #include "ompi/win/win.h"
 #include "ompi/mca/osc/osc.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Win_test = PMPI_Win_test
 #endif
 
@@ -47,6 +50,8 @@ int MPI_Win_test(MPI_Win win, int *flag)
         }
     }
 
+    OPAL_CR_ENTER_LIBRARY();
+
     rc = win->w_osc_module->osc_test(win, flag);
     OMPI_ERRHANDLER_RETURN(rc, win, rc, FUNC_NAME);
 }
