@@ -22,7 +22,7 @@
 #include "ompi/mpi/f77/constants.h"
 
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_ACCUMULATE = mpi_accumulate_f
 #pragma weak pmpi_accumulate = mpi_accumulate_f
 #pragma weak pmpi_accumulate_ = mpi_accumulate_f
@@ -37,14 +37,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_ACCUMULATE,
                            (origin_addr, origin_count, origin_datatype, target_rank, target_disp, target_count, target_datatype, op, win, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_ACCUMULATE = mpi_accumulate_f
 #pragma weak mpi_accumulate = mpi_accumulate_f
 #pragma weak mpi_accumulate_ = mpi_accumulate_f
 #pragma weak mpi_accumulate__ = mpi_accumulate_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_ACCUMULATE,
                            mpi_accumulate,
                            mpi_accumulate_,
@@ -55,7 +55,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_ACCUMULATE,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
