@@ -22,7 +22,7 @@
 #include "ompi/attribute/attribute.h"
 #include "ompi/communicator/communicator.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_ATTR_PUT = mpi_attr_put_f
 #pragma weak pmpi_attr_put = mpi_attr_put_f
 #pragma weak pmpi_attr_put_ = mpi_attr_put_f
@@ -37,14 +37,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_ATTR_PUT,
                            (comm, keyval, attribute_val, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_ATTR_PUT = mpi_attr_put_f
 #pragma weak mpi_attr_put = mpi_attr_put_f
 #pragma weak mpi_attr_put_ = mpi_attr_put_f
 #pragma weak mpi_attr_put__ = mpi_attr_put_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_ATTR_PUT,
                            mpi_attr_put,
                            mpi_attr_put_,
@@ -55,7 +55,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_ATTR_PUT,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
