@@ -21,7 +21,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/mpi/f77/constants.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_BCAST = mpi_bcast_f
 #pragma weak pmpi_bcast = mpi_bcast_f
 #pragma weak pmpi_bcast_ = mpi_bcast_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_BCAST,
                            (buffer, count, datatype, root, comm, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_BCAST = mpi_bcast_f
 #pragma weak mpi_bcast = mpi_bcast_f
 #pragma weak mpi_bcast_ = mpi_bcast_f
 #pragma weak mpi_bcast__ = mpi_bcast_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_BCAST,
                            mpi_bcast,
                            mpi_bcast_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_BCAST,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
