@@ -21,7 +21,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/mpi/f77/constants.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_BSEND = mpi_bsend_f
 #pragma weak pmpi_bsend = mpi_bsend_f
 #pragma weak pmpi_bsend_ = mpi_bsend_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_BSEND,
                            (buf, count, datatype, dest, tag, comm, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_BSEND = mpi_bsend_f
 #pragma weak mpi_bsend = mpi_bsend_f
 #pragma weak mpi_bsend_ = mpi_bsend_f
 #pragma weak mpi_bsend__ = mpi_bsend_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_BSEND,
                            mpi_bsend,
                            mpi_bsend_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_BSEND,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
