@@ -21,7 +21,7 @@
 
 #include "ompi/mpi/f77/bindings.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_BUFFER_DETACH = mpi_buffer_detach_f
 #pragma weak pmpi_buffer_detach = mpi_buffer_detach_f
 #pragma weak pmpi_buffer_detach_ = mpi_buffer_detach_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_BUFFER_DETACH,
                            (buffer, size, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_BUFFER_DETACH = mpi_buffer_detach_f
 #pragma weak mpi_buffer_detach = mpi_buffer_detach_f
 #pragma weak mpi_buffer_detach_ = mpi_buffer_detach_f
 #pragma weak mpi_buffer_detach__ = mpi_buffer_detach_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_BUFFER_DETACH,
                            mpi_buffer_detach,
                            mpi_buffer_detach_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_BUFFER_DETACH,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
