@@ -5,7 +5,7 @@
  * Copyright (c) 2004-2005 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2007 High Performance Computing Center Stuttgart, 
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
@@ -20,7 +20,7 @@
 
 #include "ompi/mpi/f77/bindings.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_CART_CREATE = mpi_cart_create_f
 #pragma weak pmpi_cart_create = mpi_cart_create_f
 #pragma weak pmpi_cart_create_ = mpi_cart_create_f
@@ -31,34 +31,34 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_CART_CREATE,
                            pmpi_cart_create_,
                            pmpi_cart_create__,
                            pmpi_cart_create_f,
-                           (MPI_Fint *old_comm, MPI_Fint *ndims, MPI_Fint *dims, MPI_Flogical *periods, MPI_Flogical *reorder, MPI_Fint *comm_cart, MPI_Fint *ierr),
+                           (MPI_Fint *old_comm, MPI_Fint *ndims, MPI_Fint *dims, ompi_fortran_logical_t *periods, ompi_fortran_logical_t *reorder, MPI_Fint *comm_cart, MPI_Fint *ierr),
                            (old_comm, ndims, dims, periods, reorder, comm_cart, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_CART_CREATE = mpi_cart_create_f
 #pragma weak mpi_cart_create = mpi_cart_create_f
 #pragma weak mpi_cart_create_ = mpi_cart_create_f
 #pragma weak mpi_cart_create__ = mpi_cart_create_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_CART_CREATE,
                            mpi_cart_create,
                            mpi_cart_create_,
                            mpi_cart_create__,
                            mpi_cart_create_f,
-                           (MPI_Fint *old_comm, MPI_Fint *ndims, MPI_Fint *dims, MPI_Flogical *periods, MPI_Flogical *reorder, MPI_Fint *comm_cart, MPI_Fint *ierr),
+                           (MPI_Fint *old_comm, MPI_Fint *ndims, MPI_Fint *dims, ompi_fortran_logical_t *periods, ompi_fortran_logical_t *reorder, MPI_Fint *comm_cart, MPI_Fint *ierr),
                            (old_comm, ndims, dims, periods, reorder, comm_cart, ierr) )
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
 void mpi_cart_create_f(MPI_Fint *old_comm, MPI_Fint *ndims, MPI_Fint *dims,
-                       MPI_Flogical *periods, MPI_Flogical *reorder,
+                       ompi_fortran_logical_t *periods, ompi_fortran_logical_t *reorder,
                        MPI_Fint *comm_cart, MPI_Fint *ierr)
 {
     MPI_Comm c_comm1, c_comm2;
@@ -67,7 +67,6 @@ void mpi_cart_create_f(MPI_Fint *old_comm, MPI_Fint *ndims, MPI_Fint *dims,
     OMPI_LOGICAL_ARRAY_NAME_DECL(periods);
 
     c_comm1 = MPI_Comm_f2c(*old_comm);
-    c_comm2 = MPI_Comm_f2c(*comm_cart);
 
     size = OMPI_FINT_2_INT(*ndims);
     OMPI_ARRAY_FINT_2_INT(dims, size);
