@@ -22,7 +22,7 @@
 #include "ompi/attribute/attribute.h"
 #include "ompi/communicator/communicator.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_COMM_SET_ATTR = mpi_comm_set_attr_f
 #pragma weak pmpi_comm_set_attr = mpi_comm_set_attr_f
 #pragma weak pmpi_comm_set_attr_ = mpi_comm_set_attr_f
@@ -37,14 +37,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_COMM_SET_ATTR,
                            (comm, comm_keyval, attribute_val, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_COMM_SET_ATTR = mpi_comm_set_attr_f
 #pragma weak mpi_comm_set_attr = mpi_comm_set_attr_f
 #pragma weak mpi_comm_set_attr_ = mpi_comm_set_attr_f
 #pragma weak mpi_comm_set_attr__ = mpi_comm_set_attr_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_COMM_SET_ATTR,
                            mpi_comm_set_attr,
                            mpi_comm_set_attr_,
@@ -55,7 +55,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_COMM_SET_ATTR,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
