@@ -24,7 +24,7 @@
 #include "ompi/mpi/f77/f77_strings.h"
 #include "opal/util/argv.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_COMM_SPAWN = mpi_comm_spawn_f
 #pragma weak pmpi_comm_spawn = mpi_comm_spawn_f
 #pragma weak pmpi_comm_spawn_ = mpi_comm_spawn_f
@@ -39,14 +39,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_COMM_SPAWN,
                             (command, argv, maxprocs, info, root, comm, intercomm, array_of_errcodes, ierr, cmd_len, string_len) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_COMM_SPAWN = mpi_comm_spawn_f
 #pragma weak mpi_comm_spawn = mpi_comm_spawn_f
 #pragma weak mpi_comm_spawn_ = mpi_comm_spawn_f
 #pragma weak mpi_comm_spawn__ = mpi_comm_spawn_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_COMM_SPAWN,
                             mpi_comm_spawn,
                             mpi_comm_spawn_,
@@ -57,7 +57,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_COMM_SPAWN,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
