@@ -21,7 +21,7 @@
 
 #include "ompi/mpi/f77/bindings.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_FILE_GET_TYPE_EXTENT = mpi_file_get_type_extent_f
 #pragma weak pmpi_file_get_type_extent = mpi_file_get_type_extent_f
 #pragma weak pmpi_file_get_type_extent_ = mpi_file_get_type_extent_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_FILE_GET_TYPE_EXTENT,
                            (fh, datatype, extent, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_FILE_GET_TYPE_EXTENT = mpi_file_get_type_extent_f
 #pragma weak mpi_file_get_type_extent = mpi_file_get_type_extent_f
 #pragma weak mpi_file_get_type_extent_ = mpi_file_get_type_extent_f
 #pragma weak mpi_file_get_type_extent__ = mpi_file_get_type_extent_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_FILE_GET_TYPE_EXTENT,
                            mpi_file_get_type_extent,
                            mpi_file_get_type_extent_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_FILE_GET_TYPE_EXTENT,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
