@@ -21,10 +21,8 @@
 
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/mpi/f77/constants.h"
-#include "ompi/errhandler/errhandler.h"
-#include "ompi/communicator/communicator.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_FILE_READ_AT_ALL = mpi_file_read_at_all_f
 #pragma weak pmpi_file_read_at_all = mpi_file_read_at_all_f
 #pragma weak pmpi_file_read_at_all_ = mpi_file_read_at_all_f
@@ -39,14 +37,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_FILE_READ_AT_ALL,
                            (fh, offset, buf, count, datatype, status, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_FILE_READ_AT_ALL = mpi_file_read_at_all_f
 #pragma weak mpi_file_read_at_all = mpi_file_read_at_all_f
 #pragma weak mpi_file_read_at_all_ = mpi_file_read_at_all_f
 #pragma weak mpi_file_read_at_all__ = mpi_file_read_at_all_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_FILE_READ_AT_ALL,
                            mpi_file_read_at_all,
                            mpi_file_read_at_all_,
@@ -57,7 +55,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_FILE_READ_AT_ALL,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
