@@ -21,7 +21,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/mpi/f77/constants.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_FILE_READ_ORDERED_BEGIN = mpi_file_read_ordered_begin_f
 #pragma weak pmpi_file_read_ordered_begin = mpi_file_read_ordered_begin_f
 #pragma weak pmpi_file_read_ordered_begin_ = mpi_file_read_ordered_begin_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_FILE_READ_ORDERED_BEGIN,
                            (fh, buf, count, datatype, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_FILE_READ_ORDERED_BEGIN = mpi_file_read_ordered_begin_f
 #pragma weak mpi_file_read_ordered_begin = mpi_file_read_ordered_begin_f
 #pragma weak mpi_file_read_ordered_begin_ = mpi_file_read_ordered_begin_f
 #pragma weak mpi_file_read_ordered_begin__ = mpi_file_read_ordered_begin_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_FILE_READ_ORDERED_BEGIN,
                            mpi_file_read_ordered_begin,
                            mpi_file_read_ordered_begin_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_FILE_READ_ORDERED_BEGIN,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
@@ -64,7 +64,7 @@ void mpi_file_read_ordered_begin_f(MPI_Fint *fh, char *buf, MPI_Fint *count,
    MPI_File c_fh = MPI_File_f2c(*fh);
    MPI_Datatype c_type = MPI_Type_f2c(*datatype);
 
-   *ierr = OMPI_INT_2_FINT(MPI_File_read_ordered_begin(c_fh, OMPI_ADDR(buf), 
+   *ierr = OMPI_INT_2_FINT(MPI_File_read_ordered_begin(c_fh, OMPI_F2C_BOTTOM(buf), 
                                                        OMPI_FINT_2_INT(*count),
                                                        c_type));
 }
