@@ -22,7 +22,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/errhandler/errhandler.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_FILE_SET_ERRHANDLER = mpi_file_set_errhandler_f
 #pragma weak pmpi_file_set_errhandler = mpi_file_set_errhandler_f
 #pragma weak pmpi_file_set_errhandler_ = mpi_file_set_errhandler_f
@@ -37,14 +37,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_FILE_SET_ERRHANDLER,
                            (file, errhandler, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_FILE_SET_ERRHANDLER = mpi_file_set_errhandler_f
 #pragma weak mpi_file_set_errhandler = mpi_file_set_errhandler_f
 #pragma weak mpi_file_set_errhandler_ = mpi_file_set_errhandler_f
 #pragma weak mpi_file_set_errhandler__ = mpi_file_set_errhandler_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_FILE_SET_ERRHANDLER,
                            mpi_file_set_errhandler,
                            mpi_file_set_errhandler_,
@@ -55,7 +55,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_FILE_SET_ERRHANDLER,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
