@@ -21,7 +21,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/mpi/f77/constants.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_IBSEND = mpi_ibsend_f
 #pragma weak pmpi_ibsend = mpi_ibsend_f
 #pragma weak pmpi_ibsend_ = mpi_ibsend_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_IBSEND,
                            (buf, count, datatype, dest, tag, comm, request, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_IBSEND = mpi_ibsend_f
 #pragma weak mpi_ibsend = mpi_ibsend_f
 #pragma weak mpi_ibsend_ = mpi_ibsend_f
 #pragma weak mpi_ibsend__ = mpi_ibsend_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_IBSEND,
                            mpi_ibsend,
                            mpi_ibsend_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_IBSEND,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
