@@ -22,7 +22,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/communicator/communicator.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_KEYVAL_CREATE = mpi_keyval_create_f
 #pragma weak pmpi_keyval_create = mpi_keyval_create_f
 #pragma weak pmpi_keyval_create_ = mpi_keyval_create_f
@@ -37,14 +37,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_KEYVAL_CREATE,
                            (copy_fn, delete_fn, keyval, extra_state, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_KEYVAL_CREATE = mpi_keyval_create_f
 #pragma weak mpi_keyval_create = mpi_keyval_create_f
 #pragma weak mpi_keyval_create_ = mpi_keyval_create_f
 #pragma weak mpi_keyval_create__ = mpi_keyval_create_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_KEYVAL_CREATE,
                            mpi_keyval_create,
                            mpi_keyval_create_,
@@ -55,7 +55,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_KEYVAL_CREATE,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
