@@ -21,7 +21,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/mpi/f77/constants.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_PACK = mpi_pack_f
 #pragma weak pmpi_pack = mpi_pack_f
 #pragma weak pmpi_pack_ = mpi_pack_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_PACK,
                            (inbuf, incount, datatype, outbuf, outsize, position, comm, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_PACK = mpi_pack_f
 #pragma weak mpi_pack = mpi_pack_f
 #pragma weak mpi_pack_ = mpi_pack_f
 #pragma weak mpi_pack__ = mpi_pack_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_PACK,
                            mpi_pack,
                            mpi_pack_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_PACK,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
