@@ -21,9 +21,9 @@
 
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/attribute/attribute.h"
-#include "ompi/datatype/datatype.h"
+#include "ompi/datatype/ompi_datatype.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_TYPE_GET_ATTR = mpi_type_get_attr_f
 #pragma weak pmpi_type_get_attr = mpi_type_get_attr_f
 #pragma weak pmpi_type_get_attr_ = mpi_type_get_attr_f
@@ -34,34 +34,34 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_TYPE_GET_ATTR,
                            pmpi_type_get_attr_,
                            pmpi_type_get_attr__,
                            pmpi_type_get_attr_f,
-                           (MPI_Fint *type, MPI_Fint *type_keyval, MPI_Aint *attribute_val, MPI_Flogical *flag, MPI_Fint *ierr),
+                           (MPI_Fint *type, MPI_Fint *type_keyval, MPI_Aint *attribute_val, ompi_fortran_logical_t *flag, MPI_Fint *ierr),
                            (type, type_keyval, attribute_val, flag, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_TYPE_GET_ATTR = mpi_type_get_attr_f
 #pragma weak mpi_type_get_attr = mpi_type_get_attr_f
 #pragma weak mpi_type_get_attr_ = mpi_type_get_attr_f
 #pragma weak mpi_type_get_attr__ = mpi_type_get_attr_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_TYPE_GET_ATTR,
                            mpi_type_get_attr,
                            mpi_type_get_attr_,
                            mpi_type_get_attr__,
                            mpi_type_get_attr_f,
-                           (MPI_Fint *type, MPI_Fint *type_keyval, MPI_Aint *attribute_val, MPI_Flogical *flag, MPI_Fint *ierr),
+                           (MPI_Fint *type, MPI_Fint *type_keyval, MPI_Aint *attribute_val, ompi_fortran_logical_t *flag, MPI_Fint *ierr),
                            (type, type_keyval, attribute_val, flag, ierr) )
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
 void mpi_type_get_attr_f(MPI_Fint *type, MPI_Fint *type_keyval,
-                         MPI_Aint *attribute_val, MPI_Flogical *flag,
+                         MPI_Aint *attribute_val, ompi_fortran_logical_t *flag,
                          MPI_Fint *ierr)
 {
     int c_err;
