@@ -21,7 +21,7 @@
 #include "ompi/mpi/f77/bindings.h"
 #include "ompi/mpi/f77/constants.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_UNPACK = mpi_unpack_f
 #pragma weak pmpi_unpack = mpi_unpack_f
 #pragma weak pmpi_unpack_ = mpi_unpack_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_UNPACK,
                            (inbuf, insize, position, outbuf, outcount, datatype, comm, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_UNPACK = mpi_unpack_f
 #pragma weak mpi_unpack = mpi_unpack_f
 #pragma weak mpi_unpack_ = mpi_unpack_f
 #pragma weak mpi_unpack__ = mpi_unpack_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_UNPACK,
                            mpi_unpack,
                            mpi_unpack_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_UNPACK,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
