@@ -21,7 +21,7 @@
 
 #include "ompi/mpi/f77/bindings.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_WIN_CREATE = mpi_win_create_f
 #pragma weak pmpi_win_create = mpi_win_create_f
 #pragma weak pmpi_win_create_ = mpi_win_create_f
@@ -36,14 +36,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_WIN_CREATE,
                            (base, size, disp_unit, info, comm, win, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_WIN_CREATE = mpi_win_create_f
 #pragma weak mpi_win_create = mpi_win_create_f
 #pragma weak mpi_win_create_ = mpi_win_create_f
 #pragma weak mpi_win_create__ = mpi_win_create_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_WIN_CREATE,
                            mpi_win_create,
                            mpi_win_create_,
@@ -54,7 +54,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_WIN_CREATE,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
