@@ -23,7 +23,7 @@
 #include "ompi/win/win.h"
 
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILE_LAYER
 #pragma weak PMPI_WIN_SET_ATTR = mpi_win_set_attr_f
 #pragma weak pmpi_win_set_attr = mpi_win_set_attr_f
 #pragma weak pmpi_win_set_attr_ = mpi_win_set_attr_f
@@ -38,14 +38,14 @@ OMPI_GENERATE_F77_BINDINGS (PMPI_WIN_SET_ATTR,
                            (win, win_keyval, attribute_val, ierr) )
 #endif
 
-#if OMPI_HAVE_WEAK_SYMBOLS
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_WIN_SET_ATTR = mpi_win_set_attr_f
 #pragma weak mpi_win_set_attr = mpi_win_set_attr_f
 #pragma weak mpi_win_set_attr_ = mpi_win_set_attr_f
 #pragma weak mpi_win_set_attr__ = mpi_win_set_attr_f
 #endif
 
-#if ! OMPI_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
+#if ! OPAL_HAVE_WEAK_SYMBOLS && ! OMPI_PROFILE_LAYER
 OMPI_GENERATE_F77_BINDINGS (MPI_WIN_SET_ATTR,
                            mpi_win_set_attr,
                            mpi_win_set_attr_,
@@ -56,7 +56,7 @@ OMPI_GENERATE_F77_BINDINGS (MPI_WIN_SET_ATTR,
 #endif
 
 
-#if OMPI_PROFILE_LAYER && ! OMPI_HAVE_WEAK_SYMBOLS
+#if OMPI_PROFILE_LAYER && ! OPAL_HAVE_WEAK_SYMBOLS
 #include "ompi/mpi/f77/profile/defines.h"
 #endif
 
