@@ -9,7 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2006-2008 Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2006-2011 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -37,9 +37,9 @@
 #include "orte/runtime/runtime.h"
 #include "orte/runtime/orte_globals.h"
 #include "orte/util/name_fns.h"
+#include "orte/util/show_help.h"
 #include "orte/mca/errmgr/errmgr.h"
 #include "ompi/communicator/communicator.h"
-#include "ompi/proc/proc.h"
 #include "ompi/runtime/mpiruntime.h"
 #include "ompi/runtime/params.h"
 #include "ompi/debuggers/debuggers.h"
@@ -75,8 +75,8 @@ ompi_mpi_abort(struct ompi_communicator_t* comm,
     }
     pid = getpid();
 
-    /* Should we print a stack trace? */
-
+    /* Should we print a stack trace?  Not aggregated because they
+       might be different on all processes. */
     if (ompi_mpi_abort_print_stack) {
         char **messages;
         int len, i;
@@ -135,9 +135,21 @@ ompi_mpi_abort(struct ompi_communicator_t* comm,
        communicators are not setup yet). Sorry, Charlie... */
 
     if (!orte_initialized || !ompi_mpi_initialized || ompi_mpi_finalized) {
-        fprintf(stderr, "[%s:%d] Abort %s completed successfully; not able to guarantee that all other processes were killed!\n",
-                host, (int) pid, ompi_mpi_finalized ? 
-                "after MPI_FINALIZE" : "before MPI_INIT");
+        if (orte_show_help_is_available()) {
+            orte_show_help("help-mpi-runtime.txt", 
+                           "ompi mpi abort:cannot guarantee all killed",
+                           true,
+                           (ompi_mpi_finalized ? 
+                            "After MPI_FINALIZE was invoked" :
+                            (ompi_mpi_init_started ?
+                             "Before MPI_INIT completed" : 
+                             "Before MPI_INIT was invoked")),
+                           host, (int) pid);
+        } else {
+            fprintf(stderr, "[%s:%d] Local abort %s completed successfully; not able to aggregate error messages, and not able to guarantee that all other processes were killed!\n",
+                    host, (int) pid, ompi_mpi_finalized ? 
+                    "after MPI_FINALIZE" : "before MPI_INIT");
+        }
         exit(errcode);
     }
 
