@@ -47,6 +47,7 @@
 #include "opal/util/show_help.h"
 #include "opal/runtime/opal.h"
 #include "opal/event/event.h"
+#include "opal/mca/hwloc/hwloc.h"
 
 #include "orte/util/proc_info.h"
 #include "orte/runtime/runtime.h"
@@ -405,6 +406,17 @@ int ompi_mpi_init(int argc, char **argv, int requested, int *provided)
 	goto error;
     }
 
+#if OPAL_HAVE_HWLOC
+    /* If orte_init() didn't fill in opal_hwloc_topology, then we need
+       to go fill it in ourselves. */
+    if (NULL == opal_hwloc_topology) {
+        if (0 != hwloc_topology_init(&opal_hwloc_topology) ||
+            0 != hwloc_topology_load(opal_hwloc_topology)) {
+            return OPAL_ERR_NOT_SUPPORTED;
+        }
+    }
+#endif
+
     /* Once we've joined the RTE, see if any MCA parameters were
        passed to the MPI level */
 
@@ -422,73 +434,6 @@ int ompi_mpi_init(int argc, char **argv, int requested, int *provided)
                           orte_process_info.pid);
     }
 
-    /* if it hasn't already been done, setup process affinity. 
-     * First check to see if a slot list was
-     * specified.  If so, use it.  If no slot list was specified,
-     * that's not an error -- just fall through and try the next
-     * paffinity scheme.
-     */
-    ret = opal_paffinity_base_get(&mask);
-    if (OPAL_SUCCESS == ret) {
-        /* paffinity is supported - check for binding */
-        OPAL_PAFFINITY_PROCESS_IS_BOUND(mask, &proc_bound);
-        if (proc_bound || opal_paffinity_base_bound) {
-            /* someone external set it - indicate it is set
-             * so that we know
-             */
-            paffinity_enabled = true;
-        } else {
-            /* the system is capable of doing processor affinity, but it
-             * has not yet been set - see if a slot_list was given
-             */
-            if (NULL != opal_paffinity_base_slot_list) {
-                /* It's an error if multiple paffinity schemes were specified */
-                if (opal_paffinity_alone) {
-                    ret = OMPI_ERR_BAD_PARAM;
-                    error = "Multiple processor affinity schemes specified (can only specify one)";
-                    goto error;
-                }
-                ret = opal_paffinity_base_slot_list_set((long)ORTE_PROC_MY_NAME->vpid, opal_paffinity_base_slot_list);
-                if (OPAL_ERR_NOT_FOUND != ret) {
-                    error = "opal_paffinity_base_slot_list_set() returned an error";
-                    goto error;
-                }
-                paffinity_enabled = true;
-            } else if (opal_paffinity_alone) {
-                /* no slot_list, but they asked for paffinity */
-                int phys_cpu;
-                orte_node_rank_t nrank;
-                if (ORTE_NODE_RANK_INVALID == (nrank = orte_ess.get_node_rank(ORTE_PROC_MY_NAME))) {
-                    error = "Could not get node rank - cannot set processor affinity";
-                    goto error;
-                }
-                OPAL_PAFFINITY_CPU_ZERO(mask);
-                phys_cpu = opal_paffinity_base_get_physical_processor_id(nrank);
-                if (0 > phys_cpu) {
-                    ret = phys_cpu;
-                    error = "Could not get physical processor id - cannot set processor affinity";
-                    goto error;
-                }
-                OPAL_PAFFINITY_CPU_SET(phys_cpu, mask);
-                ret = opal_paffinity_base_set(mask);
-                if (OPAL_SUCCESS != ret) {
-                    error = "Setting processor affinity failed";
-                    goto error;
-                }
-                paffinity_enabled = true;
-            }
-        }
-    }
-    
-    /* If we were able to set processor affinity, try setting up
-       memory affinity */
-    if (!opal_maffinity_setup && paffinity_enabled) {
-        if (OPAL_SUCCESS == opal_maffinity_base_open() &&
-            OPAL_SUCCESS == opal_maffinity_base_select()) {
-            opal_maffinity_setup = true;
-        }
-    }
-    
     /* initialize datatypes. This step should be done early as it will
      * create the local convertor and local arch used in the proc
      * init.
@@ -580,6 +525,108 @@ int ompi_mpi_init(int argc, char **argv, int requested, int *provided)
         goto error;
     }
 
+    /* check for timing request - get stop time and report elapsed time if so */
+    if (timing && 0 == ORTE_PROC_MY_NAME->vpid) {
+        gettimeofday(&ompistop, NULL);
+        opal_output(0, "ompi_mpi_init[%ld]: time from completion of orte_init to modex %ld usec",
+                    (long)ORTE_PROC_MY_NAME->vpid,
+                    (long int)((ompistop.tv_sec - ompistart.tv_sec)*1000000 +
+                               (ompistop.tv_usec - ompistart.tv_usec)));
+        gettimeofday(&ompistart, NULL);
+    }
+    
+    /* exchange connection info - this function also acts as a barrier
+     * as it will not return until the exchange is complete
+     */
+    if (OMPI_SUCCESS != (ret = orte_grpcomm.modex(NULL))) {
+        error = "orte_grpcomm_modex failed";
+        goto error;
+    }
+
+    if (timing && 0 == ORTE_PROC_MY_NAME->vpid) {
+        gettimeofday(&ompistop, NULL);
+        opal_output(0, "ompi_mpi_init[%ld]: time to execute modex %ld usec",
+                    (long)ORTE_PROC_MY_NAME->vpid,
+                    (long int)((ompistop.tv_sec - ompistart.tv_sec)*1000000 +
+                               (ompistop.tv_usec - ompistart.tv_usec)));
+        gettimeofday(&ompistart, NULL);
+    }
+    
+    /* identify the architectures of remote procs and setup
+     * their datatype convertors, if required
+     */
+    if (OMPI_SUCCESS != (ret = ompi_proc_set_arch())) {
+        error = "ompi_proc_set_arch failed";
+        goto error;
+    }
+
+    /* if it hasn't already been done, setup process affinity. 
+     * First check to see if a slot list was
+     * specified.  If so, use it.  If no slot list was specified,
+     * that's not an error -- just fall through and try the next
+     * paffinity scheme.
+     */
+    ret = opal_paffinity_base_get(&mask);
+    if (OPAL_SUCCESS == ret) {
+        /* paffinity is supported - check for binding */
+        OPAL_PAFFINITY_PROCESS_IS_BOUND(mask, &proc_bound);
+        if (proc_bound || opal_paffinity_base_bound) {
+            /* someone external set it - indicate it is set
+             * so that we know
+             */
+            paffinity_enabled = true;
+        } else {
+            /* the system is capable of doing processor affinity, but it
+             * has not yet been set - see if a slot_list was given
+             */
+            if (NULL != opal_paffinity_base_slot_list) {
+                /* It's an error if multiple paffinity schemes were specified */
+                if (opal_paffinity_alone) {
+                    ret = OMPI_ERR_BAD_PARAM;
+                    error = "Multiple processor affinity schemes specified (can only specify one)";
+                    goto error;
+                }
+                ret = opal_paffinity_base_slot_list_set((long)ORTE_PROC_MY_NAME->vpid, opal_paffinity_base_slot_list);
+                if (OPAL_ERR_NOT_FOUND != ret) {
+                    error = "opal_paffinity_base_slot_list_set() returned an error";
+                    goto error;
+                }
+                paffinity_enabled = true;
+            } else if (opal_paffinity_alone) {
+                /* no slot_list, but they asked for paffinity */
+                int phys_cpu;
+                orte_node_rank_t nrank;
+                if (ORTE_NODE_RANK_INVALID == (nrank = orte_ess.get_node_rank(ORTE_PROC_MY_NAME))) {
+                    error = "Could not get node rank - cannot set processor affinity";
+                    goto error;
+                }
+                OPAL_PAFFINITY_CPU_ZERO(mask);
+                phys_cpu = opal_paffinity_base_get_physical_processor_id(nrank);
+                if (0 > phys_cpu) {
+                    ret = phys_cpu;
+                    error = "Could not get physical processor id - cannot set processor affinity";
+                    goto error;
+                }
+                OPAL_PAFFINITY_CPU_SET(phys_cpu, mask);
+                ret = opal_paffinity_base_set(mask);
+                if (OPAL_SUCCESS != ret) {
+                    error = "Setting processor affinity failed";
+                    goto error;
+                }
+                paffinity_enabled = true;
+            }
+        }
+    }
+    
+    /* If we were able to set processor affinity, try setting up
+       memory affinity */
+    if (!opal_maffinity_setup && paffinity_enabled) {
+        if (OPAL_SUCCESS == opal_maffinity_base_open() &&
+            OPAL_SUCCESS == opal_maffinity_base_select()) {
+            opal_maffinity_setup = true;
+        }
+    }
+    
     /* select buffered send allocator component to be used */
     ret=mca_pml_base_bsend_init(OMPI_ENABLE_THREAD_MULTIPLE);
     if( OMPI_SUCCESS != ret ) {
@@ -672,41 +719,6 @@ int ompi_mpi_init(int argc, char **argv, int requested, int *provided)
         goto error;
     }
 
-    /* check for timing request - get stop time and report elapsed time if so */
-    if (timing && 0 == ORTE_PROC_MY_NAME->vpid) {
-        gettimeofday(&ompistop, NULL);
-        opal_output(0, "ompi_mpi_init[%ld]: time from completion of orte_init to modex %ld usec",
-                    (long)ORTE_PROC_MY_NAME->vpid,
-                    (long int)((ompistop.tv_sec - ompistart.tv_sec)*1000000 +
-                               (ompistop.tv_usec - ompistart.tv_usec)));
-        gettimeofday(&ompistart, NULL);
-    }
-    
-    /* exchange connection info - this function also acts as a barrier
-     * as it will not return until the exchange is complete
-     */
-    if (OMPI_SUCCESS != (ret = orte_grpcomm.modex(NULL))) {
-        error = "orte_grpcomm_modex failed";
-        goto error;
-    }
-
-    if (timing && 0 == ORTE_PROC_MY_NAME->vpid) {
-        gettimeofday(&ompistop, NULL);
-        opal_output(0, "ompi_mpi_init[%ld]: time to execute modex %ld usec",
-                    (long)ORTE_PROC_MY_NAME->vpid,
-                    (long int)((ompistop.tv_sec - ompistart.tv_sec)*1000000 +
-                               (ompistop.tv_usec - ompistart.tv_usec)));
-        gettimeofday(&ompistart, NULL);
-    }
-    
-    /* identify the architectures of remote procs and setup
-     * their datatype convertors, if required
-     */
-    if (OMPI_SUCCESS != (ret = ompi_proc_set_arch())) {
-        error = "ompi_proc_set_arch failed";
-        goto error;
-    }
-
     /* If thread support was enabled, then setup OPAL to allow for
        them. */
     if ((OPAL_ENABLE_PROGRESS_THREADS == 1) ||
