@@ -11,6 +11,8 @@
  *                         All rights reserved.
  * Copyright (c) 2006-2009 Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2011      Oracle and/or its affiliates.  All rights reserved.
+ * Copyright (c) 2011      Los Alamos National Security, LLC.
+ *                         All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -37,6 +39,8 @@
 #include "opal/mca/paffinity/base/base.h"
 #include "opal/mca/carto/carto.h"
 #include "opal/mca/carto/base/base.h"
+#include "opal/mca/shmem/shmem.h"
+#include "opal/mca/shmem/base/base.h"
 #include "opal/mca/maffinity/maffinity.h"
 #include "opal/mca/maffinity/base/base.h"
 #include "opal/mca/memory/memory.h"
@@ -49,6 +53,7 @@
 #include "opal/mca/installdirs/base/base.h"
 #include "opal/mca/sysinfo/sysinfo.h"
 #include "opal/mca/sysinfo/base/base.h"
+#include "opal/mca/hwloc/base/base.h"
 #if OPAL_ENABLE_FT_CR == 1
 #include "opal/mca/crs/crs.h"
 #include "opal/mca/crs/base/base.h"
@@ -102,10 +107,6 @@
 #include "orte/mca/ras/base/ras_private.h"
 #include "orte/mca/rmaps/rmaps.h"
 #include "orte/mca/rmaps/base/base.h"
-#if ORTE_ENABLE_MULTICAST
-#include "orte/mca/rmcast/rmcast.h"
-#include "orte/mca/rmcast/base/base.h"
-#endif
 #include "orte/mca/rml/rml.h"
 #include "orte/mca/rml/base/base.h"
 #include "orte/mca/routed/routed.h"
@@ -294,6 +295,14 @@ void ompi_info_open_components(void)
     map->type = strdup("carto");
     map->components = &opal_carto_base_components_opened;
     opal_pointer_array_add(&component_map, map);
+
+    if (OPAL_SUCCESS != opal_shmem_base_open()) {
+        goto error;
+    }
+    map = OBJ_NEW(ompi_info_component_map_t);
+    map->type = strdup("shmem");
+    map->components = &opal_shmem_base_components_opened;
+    opal_pointer_array_add(&component_map, map);
     
     if (OPAL_SUCCESS != opal_maffinity_base_open()) {
         goto error;
@@ -311,6 +320,16 @@ void ompi_info_open_components(void)
     map->components = &opal_sysinfo_base_components_opened;
     opal_pointer_array_add(&component_map, map);
 
+#if OPAL_HAVE_HWLOC
+    if (OPAL_SUCCESS != opal_hwloc_base_open()) {
+        goto error;
+    }
+    map = OBJ_NEW(ompi_info_component_map_t);
+    map->type = strdup("hwloc");
+    map->components = &opal_hwloc_base_components;
+    opal_pointer_array_add(&component_map, map);
+#endif
+
     if (OPAL_SUCCESS != opal_timer_base_open()) {
         goto error;
     }
@@ -416,16 +435,6 @@ void ompi_info_open_components(void)
     map->components = &orte_rmaps_base.available_components;
     opal_pointer_array_add(&component_map, map);
     
-#if ORTE_ENABLE_MULTICAST
-    if (ORTE_SUCCESS != orte_rmcast_base_open()) {
-        goto error;
-    }
-    map = OBJ_NEW(ompi_info_component_map_t);
-    map->type = strdup("rmcast");
-    map->components = &orte_rmcast_base.rmcast_opened;
-    opal_pointer_array_add(&component_map, map);
-#endif
-
     if (ORTE_SUCCESS != orte_rml_base_open()) {
         goto error;
     }
@@ -670,10 +679,6 @@ void ompi_info_close_components()
         (void) orte_rml_base_close();
         (void) orte_routed_base_close();
         (void) mca_oob_base_close();
-#if ORTE_ENABLE_MULTICAST
-
-        (void) orte_rmcast_base_close();
-#endif
 #endif
         (void) orte_errmgr_base_close();
         
@@ -684,6 +689,10 @@ void ompi_info_close_components()
         (void) opal_carto_base_close();
         (void) opal_maffinity_base_close();
         (void) opal_timer_base_close();
+        (void) opal_sysinfo_base_close();
+#if OPAL_HAVE_HWLOC
+        (void) opal_hwloc_base_close();
+#endif
 #if OPAL_ENABLE_FT_CR == 1
         (void) opal_crs_base_close();
 #endif
