@@ -515,6 +515,8 @@ void ompi_info_do_config(bool want_all)
     char *wtime_support;
     char *symbol_visibility;
     char *ft_support;
+    char *topology_support;
+    char *vt_support;
     /* Do a little preprocessor trickery here to figure ompi_info_out the
      * tri-state of MPI_PARAM_CHECK (which will be either 0, 1, or
      * ompi_mpi_param_check).  The preprocessor will only allow
@@ -558,6 +560,8 @@ void ompi_info_do_config(bool want_all)
     have_mpi_io = OMPI_PROVIDE_MPI_FILE_INTERFACE ? "yes" : "no";
     wtime_support = OPAL_TIMER_USEC_NATIVE ? "native" : "gettimeofday";
     symbol_visibility = OPAL_C_HAVE_VISIBILITY ? "yes" : "no";
+    topology_support = OPAL_HAVE_HWLOC ? "yes" : "no";
+    vt_support = OMPI_ENABLE_CONTRIB_vt ? "yes" : "no";
     
     /* setup strings that require allocation */
     if (OMPI_WANT_F77_BINDINGS) {
@@ -826,12 +830,16 @@ void ompi_info_do_config(bool want_all)
     ompi_info_out("MPI I/O support", "options:mpi-io", have_mpi_io);
     ompi_info_out("MPI_WTIME support", "options:mpi-wtime", wtime_support);
     ompi_info_out("Symbol vis. support", "options:visibility", symbol_visibility);
+    ompi_info_out("Host topology support", "options:host-topology", 
+                  topology_support);
     
     ompi_info_out("MPI extensions", "options:mpi_ext", OMPI_EXT_COMPONENTS);
     
     ompi_info_out("FT Checkpoint support", "options:ft_support", ft_support);
     free(ft_support);
     
+    ompi_info_out("VampirTrace support", "options:vt", vt_support);
+
     ompi_info_out_int("MPI_MAX_PROCESSOR_NAME", "options:mpi-max-processor-name", 
                   MPI_MAX_PROCESSOR_NAME);
     ompi_info_out_int("MPI_MAX_ERROR_STRING",   "options:mpi-max-error-string",   
