@@ -24,15 +24,13 @@
 #include "opal_config.h"
 #include "opal/class/opal_list.h"
 
-#if OMPI_HAVE_THREAD_SUPPORT
+#if OPAL_HAVE_THREAD_SUPPORT
 #include "opal/sys/atomic.h"
-#endif  /* OMPI_HAVE_THREAD_SUPPORT */
+#endif  /* OPAL_HAVE_THREAD_SUPPORT */
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
-    /* Atomic Last In First Out lists. If we are in a multi-threaded environment then the
+/* Atomic Last In First Out lists. If we are in a multi-threaded environment then the
  * atomicity is insured via the compare-and-swap operation, if not we simply do a read
  * and/or a write.
  *
@@ -52,6 +50,7 @@ typedef struct opal_atomic_lifo_t opal_atomic_lifo_t;
 
 OPAL_DECLSPEC OBJ_CLASS_DECLARATION(opal_atomic_lifo_t);
 
+
 /* The ghost pointer will never change. The head will change via an atomic
  * compare-and-swap. On most architectures the reading of a pointer is an
  * atomic operation so we don't have to protect it.
@@ -61,6 +60,7 @@ static inline bool opal_atomic_lifo_is_empty( opal_atomic_lifo_t* lifo )
     return (lifo->opal_lifo_head == &(lifo->opal_lifo_ghost) ? true : false);
 }
 
+
 /* Add one element to the LIFO. We will return the last head of the list
  * to allow the upper level to detect if this element is the first one in the
  * list (if the list was empty before this operation).
@@ -68,7 +68,7 @@ static inline bool opal_atomic_lifo_is_empty( opal_atomic_lifo_t* lifo )
 static inline opal_list_item_t* opal_atomic_lifo_push( opal_atomic_lifo_t* lifo,
                                                        opal_list_item_t* item )
 {
-#if OMPI_HAVE_THREAD_SUPPORT
+#if OPAL_HAVE_THREAD_SUPPORT
     do {
         item->opal_list_next = lifo->opal_lifo_head;
 	opal_atomic_wmb();
@@ -84,7 +84,7 @@ static inline opal_list_item_t* opal_atomic_lifo_push( opal_atomic_lifo_t* lifo,
     item->opal_list_next = lifo->opal_lifo_head;
     lifo->opal_lifo_head = item;
     return (opal_list_item_t*)item->opal_list_next;
-#endif  /* OMPI_HAVE_THREAD_SUPPORT */
+#endif  /* OPAL_HAVE_THREAD_SUPPORT */
 }
 
 /* Retrieve one element from the LIFO. If we reach the ghost element then the LIFO
@@ -93,7 +93,7 @@ static inline opal_list_item_t* opal_atomic_lifo_push( opal_atomic_lifo_t* lifo,
 static inline opal_list_item_t* opal_atomic_lifo_pop( opal_atomic_lifo_t* lifo )
 {
     opal_list_item_t* item;
-#if OMPI_HAVE_THREAD_SUPPORT
+#if OPAL_HAVE_THREAD_SUPPORT
     while((item = lifo->opal_lifo_head) != &(lifo->opal_lifo_ghost))
     {
 	opal_atomic_rmb();
@@ -109,15 +109,13 @@ static inline opal_list_item_t* opal_atomic_lifo_pop( opal_atomic_lifo_t* lifo )
 #else
     item = lifo->opal_lifo_head;
     lifo->opal_lifo_head = (opal_list_item_t*)item->opal_list_next;
-#endif  /* OMPI_HAVE_THREAD_SUPPORT */
+#endif  /* OPAL_HAVE_THREAD_SUPPORT */
     if( item == &(lifo->opal_lifo_ghost) ) return NULL;
     item->opal_list_next = NULL;
     return item;
 }
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 
 #endif  /* OPAL_ATOMIC_LIFO_H_HAS_BEEN_INCLUDED */
 
