@@ -2,13 +2,14 @@
  * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2006 The University of Tennessee and The University
+ * Copyright (c) 2004-2007 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2006 High Performance Computing Center Stuttgart, 
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2007      Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -34,13 +35,13 @@
  * In a interface (.h) file, define the class.  The first element
  * should always be the parent class, for example
  * @code
- *   typedef struct sally_t sally_t;
  *   struct sally_t
  *   {
  *     parent_t parent;
  *     void *first_member;
  *     ...
  *   };
+ *   typedef struct sally_t sally_t;
  *
  *   OBJ_CLASS_DECLARATION(sally_t);
  * @endcode
@@ -58,7 +59,8 @@
  *     OBJ_CLASS(parent_t),  // pointer to parent_t_class
  *     sally_construct,
  *     sally_destruct,
- *     0, 0, NULL, NULL
+ *     0, 0, NULL, NULL,
+ *     sizeof ("sally_t")
  *   };
  * @endcode
  * This variable should be declared in the interface (.h) file using
@@ -114,28 +116,21 @@
 #ifndef OPAL_OBJECT_H
 #define OPAL_OBJECT_H
 
+#include "opal_config.h"
 #include <assert.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif  /* HAVE_STDLIB_H */
 
-#if OMPI_HAVE_THREAD_SUPPORT
+#if OPAL_HAVE_THREAD_SUPPORT
 #include "opal/sys/atomic.h"
-#endif  /* OMPI_HAVE_THREAD_SUPPORT */
+#endif  /* OPAL_HAVE_THREAD_SUPPORT */
 
-/*
- * BEGIN_C_DECLS should be used at the beginning of your declarations,
- * so that C++ compilers don't mangle their names.  Use END_C_DECLS at
- * the end of C declarations.
- */
-#undef BEGIN_C_DECLS
-#undef END_C_DECLS
-#if defined(c_plusplus) || defined(__cplusplus)
-# define BEGIN_C_DECLS extern "C" {
-# define END_C_DECLS }
-#else
-#define BEGIN_C_DECLS          /* empty */
-#define END_C_DECLS            /* empty */
+BEGIN_C_DECLS
+
+#if OPAL_ENABLE_DEBUG
+/* Any kind of unique ID should do the job */
+#define OPAL_OBJ_MAGIC_ID ((0xdeafbeedULL << 32) + 0xdeafbeedULL)
 #endif
 
 /* typedefs ***********************************************************/
@@ -168,18 +163,34 @@ struct opal_class_t {
     size_t cls_sizeof;              /**< size of an object instance */
 };
 
+/**
+ * For static initializations of OBJects.
+ *
+ * @param NAME   Name of the class to initialize
+ */
+#if OPAL_ENABLE_DEBUG
+#define OPAL_OBJ_STATIC_INIT(BASE_CLASS) { OPAL_OBJ_MAGIC_ID, OBJ_CLASS(BASE_CLASS), 1, __FILE__, __LINE__ }
+#else
+#define OPAL_OBJ_STATIC_INIT(BASE_CLASS) { OBJ_CLASS(BASE_CLASS), 1 }
+#endif
+
 /**
  * Base object.
  *
  * This is special and does not follow the pattern for other classes.
  */
 struct opal_object_t {
+#if OPAL_ENABLE_DEBUG
+    /** Magic ID -- want this to be the very first item in the
+        struct's memory */
+    uint64_t obj_magic_id;
+#endif
     opal_class_t *obj_class;            /**< class descriptor */
     volatile int32_t obj_reference_count;   /**< reference count */
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
    const char* cls_init_file_name;        /**< In debug mode store the file where the object get contructed */
    int   cls_init_lineno;           /**< In debug mode store the line number where the object get contructed */
-#endif  /* OMPI_ENABLE_DEBUG */
+#endif  /* OPAL_ENABLE_DEBUG */
 };
 
 /* macros ************************************************************/
@@ -234,10 +245,11 @@ struct opal_object_t {
  * @return              Pointer to the object 
  */
 static inline opal_object_t *opal_obj_new(opal_class_t * cls);
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
 static inline opal_object_t *opal_obj_new_debug(opal_class_t* type, const char* file, int line)
 {
     opal_object_t* object = opal_obj_new(type);
+    object->obj_magic_id = OPAL_OBJ_MAGIC_ID;
     object->cls_init_file_name = file;
     object->cls_init_lineno = line;
     return object;
@@ -247,34 +259,43 @@ static inline opal_object_t *opal_obj_new_debug(opal_class_t* type, const char*
 #else
 #define OBJ_NEW(type)                                   \
     ((type *) opal_obj_new(OBJ_CLASS(type)))
-#endif  /* OMPI_ENABLE_DEBUG */
+#endif  /* OPAL_ENABLE_DEBUG */
 
 /**
  * Retain an object (by incrementing its reference count)
  *
  * @param object        Pointer to the object
  */
+#if OPAL_ENABLE_DEBUG
 #define OBJ_RETAIN(object)                                              \
     do {                                                                \
-        assert(NULL != object);                                         \
         assert(NULL != ((opal_object_t *) (object))->obj_class);        \
+        assert(OPAL_OBJ_MAGIC_ID == ((opal_object_t *) (object))->obj_magic_id); \
         opal_obj_update((opal_object_t *) (object), 1);                 \
         assert(((opal_object_t *) (object))->obj_reference_count >= 0); \
     } while (0)
+#else
+#define OBJ_RETAIN(object)  opal_obj_update((opal_object_t *) (object), 1);
+#endif
 
 /**
  * Helper macro for the debug mode to store the locations where the status of
  * an object change.
  */
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
 #define OBJ_REMEMBER_FILE_AND_LINENO( OBJECT, FILE, LINENO )    \
     do {                                                        \
         ((opal_object_t*)(OBJECT))->cls_init_file_name = FILE;  \
         ((opal_object_t*)(OBJECT))->cls_init_lineno = LINENO;   \
     } while(0)
+#define OBJ_SET_MAGIC_ID( OBJECT, VALUE )                       \
+    do {                                                        \
+        ((opal_object_t*)(OBJECT))->obj_magic_id = (VALUE);     \
+    } while(0)
 #else
 #define OBJ_REMEMBER_FILE_AND_LINENO( OBJECT, FILE, LINENO )
-#endif  /* OMPI_ENABLE_DEBUG */
+#define OBJ_SET_MAGIC_ID( OBJECT, VALUE )
+#endif  /* OPAL_ENABLE_DEBUG */
 
 /**
  * Release an object (by decrementing its reference count).  If the
@@ -286,17 +307,29 @@ static inline opal_object_t *opal_obj_new_debug(opal_class_t* type, const char*
  *
  * @param object        Pointer to the object
  */
+#if OPAL_ENABLE_DEBUG
 #define OBJ_RELEASE(object)                                             \
     do {                                                                \
-        assert(NULL != object);                                         \
         assert(NULL != ((opal_object_t *) (object))->obj_class);        \
+        assert(OPAL_OBJ_MAGIC_ID == ((opal_object_t *) (object))->obj_magic_id); \
         if (0 == opal_obj_update((opal_object_t *) (object), -1)) {     \
+            OBJ_SET_MAGIC_ID((object), 0);                              \
             opal_obj_run_destructors((opal_object_t *) (object));       \
             OBJ_REMEMBER_FILE_AND_LINENO( object, __FILE__, __LINE__ ); \
             free(object);                                               \
             object = NULL;                                              \
         }                                                               \
     } while (0)
+#else
+#define OBJ_RELEASE(object)                                             \
+    do {                                                                \
+        if (0 == opal_obj_update((opal_object_t *) (object), -1)) {     \
+            opal_obj_run_destructors((opal_object_t *) (object));       \
+            free(object);                                               \
+            object = NULL;                                              \
+        }                                                               \
+    } while (0)
+#endif
 
 
 /**
@@ -309,17 +342,18 @@ static inline opal_object_t *opal_obj_new_debug(opal_class_t* type, const char*
 #define OBJ_CONSTRUCT(object, type)                             \
 do {                                                            \
     OBJ_CONSTRUCT_INTERNAL((object), OBJ_CLASS(type));          \
-    OBJ_REMEMBER_FILE_AND_LINENO( object, __FILE__, __LINE__ ); \
 } while (0)
 
 #define OBJ_CONSTRUCT_INTERNAL(object, type)                        \
 do {                                                                \
+    OBJ_SET_MAGIC_ID((object), OPAL_OBJ_MAGIC_ID);              \
     if (0 == (type)->cls_initialized) {                             \
         opal_class_initialize((type));                              \
     }                                                               \
     ((opal_object_t *) (object))->obj_class = (type);               \
     ((opal_object_t *) (object))->obj_reference_count = 1;          \
     opal_obj_run_constructors((opal_object_t *) (object));          \
+    OBJ_REMEMBER_FILE_AND_LINENO( object, __FILE__, __LINE__ ); \
 } while (0)
 
 
@@ -328,13 +362,21 @@ do {                                                                \
  *
  * @param object        Pointer to the object
  */
+#if OPAL_ENABLE_DEBUG
+#define OBJ_DESTRUCT(object)                                    \
+do {                                                            \
+    assert(OPAL_OBJ_MAGIC_ID == ((opal_object_t *) (object))->obj_magic_id); \
+    OBJ_SET_MAGIC_ID((object), 0);                              \
+    opal_obj_run_destructors((opal_object_t *) (object));       \
+    OBJ_REMEMBER_FILE_AND_LINENO( object, __FILE__, __LINE__ ); \
+} while (0)
+#else
 #define OBJ_DESTRUCT(object)                                    \
 do {                                                            \
     opal_obj_run_destructors((opal_object_t *) (object));       \
     OBJ_REMEMBER_FILE_AND_LINENO( object, __FILE__, __LINE__ ); \
 } while (0)
-
-BEGIN_C_DECLS
+#endif
 
 OPAL_DECLSPEC OBJ_CLASS_DECLARATION(opal_object_t);
 
@@ -361,7 +403,6 @@ OPAL_DECLSPEC void opal_class_initialize(opal_class_t *);
  */
 OPAL_DECLSPEC int opal_class_finalize(void);
 
-END_C_DECLS
 /**
  * Run the hierarchy of class constructors for this object, in a
  * parent-first order.
@@ -448,9 +489,10 @@ static inline opal_object_t *opal_obj_new(opal_class_t * cls)
  * @param inc           Increment by which to update reference count
  * @return              New value of the reference count
  */
+static inline int opal_obj_update(opal_object_t *object, int inc) __opal_attribute_always_inline__;
 static inline int opal_obj_update(opal_object_t *object, int inc)
 {
-#if OMPI_HAVE_THREAD_SUPPORT
+#if OPAL_HAVE_THREAD_SUPPORT
     return opal_atomic_add_32(&(object->obj_reference_count), inc );
 #else
     object->obj_reference_count += inc;
@@ -458,7 +500,7 @@ static inline int opal_obj_update(opal_object_t *object, int inc)
 #endif
 }
 
+END_C_DECLS
 
-/**********************************************************************/
+#endif
 
-#endif                          /* OPAL_OBJECT_H */
