@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
  * Copyright (c) 2004-2006 The University of Tennessee and The University
@@ -24,20 +24,16 @@
 #include <string.h>
 
 #include "opal/class/opal_object.h"
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
 #include "opal/util/output.h"
 #endif
 #include "opal/constants.h"
 
+BEGIN_C_DECLS
+
 /*
  *  @file  Array of elements maintained by value.
- *
- * See ompi_bitmap.h for an explanation of why there is a split
- * between OMPI and ORTE for this generic class.
  */
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
 
 struct opal_value_array_t
 {
@@ -57,7 +53,7 @@ OPAL_DECLSPEC OBJ_CLASS_DECLARATION(opal_value_array_t);
  *
  *  @param   array       The array to initialize (IN).
  *  @param   item_size   The sizeof each array element (IN).
- *  @return  OMPI error code
+ *  @return  OPAL error code
  *
  * Note that there is no corresponding "finalize" function -- use
  * OBJ_DESTRUCT (for stack arrays) or OBJ_RELEASE (for heap arrays) to
@@ -79,7 +75,7 @@ static inline int opal_value_array_init(opal_value_array_t *array, size_t item_s
  *
  *  @param   array   The input array (IN).
  *  @param   size    The anticipated size of the array (IN).
- *  @return  OMPI error code.
+ *  @return  OPAL error code.
  */
 
 static inline int opal_value_array_reserve(opal_value_array_t* array, size_t size)
@@ -91,7 +87,7 @@ static inline int opal_value_array_reserve(opal_value_array_t* array, size_t siz
              array->array_alloc_size = 0;
              return OPAL_ERR_OUT_OF_RESOURCE;
          }
-         array->array_alloc_size = 1;
+         array->array_alloc_size = size;
      }
      return OPAL_SUCCESS;
 }
@@ -117,7 +113,7 @@ static inline size_t opal_value_array_get_size(opal_value_array_t* array)
  *  @param  array   The input array (IN).
  *  @param  size    The new array size.
  *
- *  @return  OMPI error code.
+ *  @return  OPAL error code.
  *
  *  Note that resizing the array to a smaller size may not change
  *  the underlying memory allocated by the array. However, setting
@@ -149,20 +145,20 @@ OPAL_DECLSPEC int opal_value_array_set_size(opal_value_array_t* array, size_t si
 /**
  *  Retrieve an item from the array by reference.
  *
- *  @param  array     The input array (IN).
- *  @param  index     The array index (IN).
+ *  @param  array          The input array (IN).
+ *  @param  item_index     The array index (IN).
  *
  *  @return ptr Pointer to the requested item.
  *
- *  Note that if the specified index is larger than the current
+ *  Note that if the specified item_index is larger than the current
  *  array size, the array is grown to satisfy the request.
  */
 
-static inline void* opal_value_array_get_item(opal_value_array_t *array, size_t index)
+static inline void* opal_value_array_get_item(opal_value_array_t *array, size_t item_index)
 {
-    if(index >= array->array_size && opal_value_array_set_size(array, index+1) != OPAL_SUCCESS)
+    if(item_index >= array->array_size && opal_value_array_set_size(array, item_index+1) != OPAL_SUCCESS)
         return NULL;
-    return array->array_items + (index * array->array_item_sizeof);
+    return array->array_items + (item_index * array->array_item_sizeof);
 }
 
 /** 
@@ -192,19 +188,19 @@ static inline void* opal_value_array_get_item(opal_value_array_t *array, size_t
  *  @param   item_value  A pointer to the item, which is copied into 
  *                       the array.
  *
- *  @return  OMPI error code.
+ *  @return  OPAL error code.
  *
  * It is safe to free the item after returning from this call; it is
  * copied into the array by value.
  */
 
-static inline int opal_value_array_set_item(opal_value_array_t *array, size_t index, const void* item)
+static inline int opal_value_array_set_item(opal_value_array_t *array, size_t item_index, const void* item)
 {
     int rc;
-    if(index >= array->array_size && 
-       (rc = opal_value_array_set_size(array, index+1)) != OPAL_SUCCESS)
+    if(item_index >= array->array_size && 
+       (rc = opal_value_array_set_size(array, item_index+1)) != OPAL_SUCCESS)
         return rc;
-    memcpy(array->array_items + (index * array->array_item_sizeof), item, array->array_item_sizeof);
+    memcpy(array->array_items + (item_index * array->array_item_sizeof), item, array->array_item_sizeof);
     return OPAL_SUCCESS;
 }
 
@@ -216,7 +212,7 @@ static inline int opal_value_array_set_item(opal_value_array_t *array, size_t in
  *  @param   item     A pointer to the item to append, which is copied 
  *                    into the array.
  *
- *  @return  OMPI error code 
+ *  @return  OPAL error code 
  *
  * This will grow the array if it is not large enough to contain the
  * item.  It is safe to free the item after returning from this call;
@@ -232,26 +228,26 @@ static inline int opal_value_array_append_item(opal_value_array_t *array, const
 /**
  *  Remove a specific item from the array. 
  *
- *  @param   array  The input array (IN).
- *  @param   index  The index to remove, which must be less than
- *                  the current array size (IN).
+ *  @param   array       The input array (IN).
+ *  @param   item_index  The index to remove, which must be less than
+ *                       the current array size (IN).
  *
- *  @return  OMPI error code.
+ *  @return  OPAL error code.
  *
  * All elements following this index are shifted down.
  */
 
-static inline int opal_value_array_remove_item(opal_value_array_t *array, size_t index)
+static inline int opal_value_array_remove_item(opal_value_array_t *array, size_t item_index)
 {
-#if OMPI_ENABLE_DEBUG
-    if (index >= array->array_size) {
-        opal_output(0, "opal_value_array_remove_item: invalid index %d\n", index);
+#if OPAL_ENABLE_DEBUG
+    if (item_index >= array->array_size) {
+        opal_output(0, "opal_value_array_remove_item: invalid index %lu\n", (unsigned long)item_index);
         return OPAL_ERR_BAD_PARAM;
     }
 #endif   
-    memmove(array->array_items+(array->array_item_sizeof * index), 
-            array->array_items+(array->array_item_sizeof * (index+1)),
-            array->array_item_sizeof * (array->array_size - index - 1));
+    memmove(array->array_items+(array->array_item_sizeof * item_index), 
+            array->array_items+(array->array_item_sizeof * (item_index+1)),
+            array->array_item_sizeof * (array->array_size - item_index - 1));
     array->array_size--;
     return OPAL_SUCCESS;
 }
@@ -275,9 +271,7 @@ static inline int opal_value_array_remove_item(opal_value_array_t *array, size_t
 #define OPAL_VALUE_ARRAY_GET_BASE(array, item_type) \
   ((item_type*) ((array)->array_items))
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
+END_C_DECLS
+
 #endif
-#endif  
-
 
