@@ -1,8 +1,9 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /*
  * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2006 The University of Tennessee and The University
+ * Copyright (c) 2004-2009 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
@@ -95,10 +96,8 @@ static void opal_buffer_construct (opal_buffer_t* buffer)
 
 static void opal_buffer_destruct (opal_buffer_t* buffer)
 {
-    if (NULL != buffer) {
-        if (NULL != buffer->base_ptr) {
-            free (buffer->base_ptr);
-        }
+    if (NULL != buffer->base_ptr) {
+        free (buffer->base_ptr);
     }
 }
 
@@ -133,6 +132,26 @@ OBJ_CLASS_INSTANCE(opal_dss_type_info_t, opal_object_t,
                    opal_dss_type_info_destruct);
 
 
+static void opal_pstat_construct(opal_pstats_t *obj)
+{
+    memset(obj->node, 0, sizeof(obj->node));
+    memset(obj->cmd, 0, sizeof(obj->cmd));
+    obj->state = 'U';
+    obj->time = 0;
+    obj->priority = -1;
+    obj->num_threads = -1;
+    obj->vsize = 0;
+    obj->rss = 0;
+    obj->peak_vsize = 0;
+    obj->shared_size = 0;
+    obj->processor = -1;
+}
+
+OBJ_CLASS_INSTANCE(opal_pstats_t, opal_list_item_t,
+                   opal_pstat_construct,
+                   NULL);
+
+
 int opal_dss_open(void)
 {
     char *enviro_val;
@@ -153,7 +172,7 @@ int opal_dss_open(void)
      * to fully described buffers. Otherwise, we default to non-described for brevity
      * and performance
      */
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
     def_type = OPAL_DSS_BUFFER_FULLY_DESC;
 #else
     def_type = OPAL_DSS_BUFFER_NON_DESC;
@@ -418,6 +437,18 @@ int opal_dss_open(void)
         return rc;
     }
 
+    tmp = OPAL_PSTAT;
+    if (OPAL_SUCCESS != (rc = opal_dss.register_type(opal_dss_pack_pstat,
+                                                     opal_dss_unpack_pstat,
+                                                     (opal_dss_copy_fn_t)opal_dss_copy_pstat,
+                                                     (opal_dss_compare_fn_t)opal_dss_compare_pstat,
+                                                     (opal_dss_size_fn_t)opal_dss_size_pstat,
+                                                     (opal_dss_print_fn_t)opal_dss_print_pstat,
+                                                     (opal_dss_release_fn_t)opal_dss_std_obj_release,
+                                                     OPAL_DSS_STRUCTURED,
+                                                     "OPAL_PSTAT", &tmp))) {
+        return rc;
+    }
     /* All done */
 
     return OPAL_SUCCESS;
@@ -433,6 +464,7 @@ int opal_dss_close(void)
     for (i = 0 ; i < opal_pointer_array_get_size(&opal_dss_types) ; ++i) {
         opal_dss_type_info_t *info = (opal_dss_type_info_t*)opal_pointer_array_get_item(&opal_dss_types, i);
         if (NULL != info) {
+            opal_pointer_array_set_item(&opal_dss_types, i, NULL);
             OBJ_RELEASE(info);
         }
     }
