@@ -66,6 +66,8 @@ struct event_base {
 	struct timeval event_tv;
 
 	struct min_heap timeheap;
+
+	struct timeval tv_cache;
 };
 
 /* Internal use only: Functions that might be missing from <sys/queue.h> */
@@ -89,6 +91,9 @@ int _evsignal_set_handler(struct event_base *base, int evsignal,
 			  void (*fn)(int));
 int _evsignal_restore_handler(struct event_base *base, int evsignal);
 
+/* defined in evutil.c */
+const char *evutil_getenv(const char *varname);
+
 #ifdef __cplusplus
 }
 #endif
