@@ -1,5 +1,8 @@
 /*
  * Copyright (c) 2008      Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2008-2009 The University of Tennessee and The University
+ *                         of Tennessee Research Foundation.  All rights
+ *                         reserved.
  * Copyright (c) 2000-2004 Niels Provos <provos@citi.umich.edu>
  * All rights reserved.
  *
@@ -35,13 +38,12 @@
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #undef WIN32_LEAN_AND_MEAN
-#include "misc.h"
 #endif
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #else
 #  ifndef HAVE_WINSOCK2_H
-#include <sys/_time.h>
+#include <sys/_libevent_time.h>
 #  endif
 #endif
 #ifndef HAVE_TIMERADD
@@ -97,7 +99,7 @@ extern const struct eventop win32ops;
 #endif
 
 /* In order of preference */
-const struct eventop *eventops[] = {
+static const struct eventop *eventops[] = {
 #if defined(HAVE_EVENT_PORTS) && HAVE_EVENT_PORTS
 	&evportops,
 #endif
@@ -129,10 +131,6 @@ extern struct event_base *evsignal_base;
 static int use_monotonic;
 #endif  /* defined(HAVE_CLOCK_GETTIME) && defined(CLOCK_MONOTONIC) */
 
-/* Handle signals - This is a deprecated interface */
-int (*event_sigcb)(void);		/* Signal callback when gotsig is set */
-volatile sig_atomic_t event_gotsig;	/* Set in signal handler */
-
 /* Prototypes */
 static void	event_queue_insert(struct event_base *, struct event *, int);
 static void	event_queue_remove(struct event_base *, struct event *, int);
@@ -159,12 +157,17 @@ detect_monotonic(void)
 }
 
 static int
-gettime(struct timeval *tp)
+gettime(struct event_base *base, struct timeval *tp)
 {
-#if defined(HAVE_CLOCK_GETTIME) && defined(CLOCK_MONOTONIC)
-	struct timespec	ts;
+	if (base->tv_cache.tv_sec) {
+		*tp = base->tv_cache;
+		return (0);
+	}
 
+#if defined(HAVE_CLOCK_GETTIME) && defined(CLOCK_MONOTONIC)
 	if (use_monotonic) {
+		struct timespec	ts;
+
 		if (clock_gettime(CLOCK_MONOTONIC, &ts) == -1)
 			return (-1);
 
@@ -174,14 +177,14 @@ gettime(struct timeval *tp)
 	}
 #endif
 
-	return (gettimeofday(tp, NULL));
+	return (evutil_gettimeofday(tp, NULL));
 }
 
 
 OPAL_DECLSPEC opal_mutex_t opal_event_lock;
 static int  opal_event_inited = 0;
 static bool opal_event_enabled = false;
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 static opal_thread_t opal_event_thread;
 static opal_event_t opal_event_pipe_event;
 static int opal_event_pipe[2];
@@ -190,13 +193,13 @@ static int opal_event_pipe_signalled;
 
 bool opal_event_progress_thread(void)
 {
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 	return opal_using_threads() ? opal_thread_self_compare(&opal_event_thread) : true;
 #else
 	return true;
 #endif
 }
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 /* run loop for dispatch thread */
 static void* opal_event_run(opal_object_t* arg)
 {
@@ -218,10 +221,10 @@ static void* opal_event_run(opal_object_t* arg)
 
 	return NULL;
 }
-#endif /* OMPI_ENABLE_PROGRESS_THREADS */
+#endif /* OPAL_ENABLE_PROGRESS_THREADS */
 
 
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 static void opal_event_pipe_handler(int sd, short flags, void* user)
 {
 	unsigned char byte;
@@ -230,7 +233,7 @@ static void opal_event_pipe_handler(int sd, short flags, void* user)
 		opal_event_del(&opal_event_pipe_event);
 	}
 }
-#endif /* OMPI_ENABLE_PROGRESS_THREADS */
+#endif /* OPAL_ENABLE_PROGRESS_THREADS */
 
 static char** opal_event_module_include = NULL;
 
@@ -310,7 +313,11 @@ opal_event_init(void)
 #ifdef __APPLE__
                                        "select",
 #else
+#  ifdef __WINDOWS__
+                                       "win32",
+#  else
                                        "poll",
+#  endif
 #endif
                                        &event_module_include);
         free(help_msg);  /* release the help message */
@@ -341,15 +348,11 @@ event_base_new(void)
 	if ((base = calloc(1, sizeof(struct event_base))) == NULL)
 		event_err(1, "%s: calloc", __func__);
 
-	event_sigcb = NULL;
-	event_gotsig = 0;
-
 	detect_monotonic();
-	gettime(&base->event_tv);
+	gettime(base, &base->event_tv);
 	
 	min_heap_ctor(&base->timeheap);
 	TAILQ_INIT(&base->eventqueue);
-	TAILQ_INIT(&base->sig.signalqueue);
 	base->sig.ev_signal_pair[0] = -1;
 	base->sig.ev_signal_pair[1] = -1;
 	
@@ -365,7 +368,7 @@ event_base_new(void)
 	if (base->evbase == NULL)
 		event_errx(1, "%s: no event mechanism available", __func__);
 
-	if (getenv("EVENT_SHOW_METHOD")) 
+	if (evutil_getenv("EVENT_SHOW_METHOD")) 
 		event_msgx("libevent using: %s\n",
 			   base->evsel->name);
 
@@ -382,12 +385,17 @@ int opal_event_fini(void)
     if (NULL != opal_event_module_include) {
         opal_argv_free(opal_event_module_include);
     }
+    if( NULL != opal_current_base ) {
+        event_base_free(opal_current_base);
+        opal_current_base = NULL;
+    }
+
     return OPAL_SUCCESS;
 }
 
 int opal_event_enable(void)
 {
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 	if(opal_using_threads()) {
 		int rc;
 
@@ -437,7 +445,7 @@ int opal_event_enable(void)
 
 int opal_event_disable(void)
 {
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 	if(opal_using_threads()) {
 		opal_mutex_lock(&opal_event_lock);
 		if(opal_event_inited > 0 && opal_event_enabled == false) {
@@ -466,7 +474,7 @@ int opal_event_disable(void)
 int opal_event_restart(void)
 {
 #if OPAL_HAVE_WORKING_EVENTOPS && !defined(__WINDOWS__)
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 	opal_mutex_lock(&opal_event_lock);
 	if(opal_event_pipe[0] >= 0) {
 		event_del(&opal_event_pipe_event); 
@@ -514,17 +522,36 @@ event_base_free(struct event_base *base)
 		++n_deleted;
 	}
 
+	for (i = 0; i < base->nactivequeues; ++i) {
+		for (ev = TAILQ_FIRST(base->activequeues[i]); ev; ) {
+			struct event *next = TAILQ_NEXT(ev, ev_active_next);
+			if (!(ev->ev_flags & EVLIST_INTERNAL)) {
+				event_del(ev);
+				++n_deleted;
+			}
+			ev = next;
+		}
+	}
+
 	if (n_deleted)
 		event_debug(("%s: %d events were still set in base",
-					 __func__, n_deleted));
+			__func__, n_deleted));
 
 	if (base->evsel->dealloc != NULL)
 		base->evsel->dealloc(base, base->evbase);
 
+#if 0
+        /* Per ticket #1805
+           (https://svn.open-mpi.org/trac/ompi/ticket/1805), these
+           asserts are temporarily removed until we can have the rest
+           of the code base absolutely clean up all pending libevents,
+           we're #if 0'ing out these asserts so that we stop dumping
+           core. :-\ */
 	for (i = 0; i < base->nactivequeues; ++i)
 		assert(TAILQ_EMPTY(base->activequeues[i]));
 
 	assert(min_heap_empty(&base->timeheap));
+#endif
 	min_heap_dtor(&base->timeheap);
 
 	for (i = 0; i < base->nactivequeues; ++i)
@@ -549,9 +576,21 @@ event_reinit(struct event_base *base)
 	if (!evsel->need_reinit)
 		return (0);
 
+	/* prevent internal delete */
+	if (base->sig.ev_signal_added) {
+		/* we cannot call event_del here because the base has
+		 * not been reinitialized yet. */
+		event_queue_remove(base, &base->sig.ev_signal,
+		    EVLIST_INSERTED);
+		if (base->sig.ev_signal.ev_flags & EVLIST_ACTIVE)
+			event_queue_remove(base, &base->sig.ev_signal,
+			    EVLIST_ACTIVE);
+		base->sig.ev_signal_added = 0;
+	}
+	
 	if (base->evsel->dealloc != NULL)
 		base->evsel->dealloc(base, base->evbase);
-	base->evbase = evsel->init(base);
+	evbase = base->evbase = evsel->init(base);
 	if (base->evbase == NULL)
 		event_errx(1, "%s: could not reinitialize event mechanism",
 		    __func__);
@@ -587,8 +626,8 @@ event_base_priority_init(struct event_base *base, int npriorities)
 
 	/* Allocate our priority queues */
 	base->nactivequeues = npriorities;
-	base->activequeues = (struct event_list **)calloc(base->nactivequeues,
-	    npriorities * sizeof(struct event_list *));
+	base->activequeues = (struct event_list **)
+	    calloc(base->nactivequeues, sizeof(struct event_list *));
 	if (base->activequeues == NULL)
 		event_err(1, "%s: calloc", __func__);
 
@@ -644,9 +683,10 @@ event_process_active(struct event_base *base)
 			ncalls--;
 			ev->ev_ncalls = ncalls;
                         OPAL_THREAD_UNLOCK(&opal_event_lock);
-                        (*ev->ev_callback)((int)ev->ev_fd, ev->ev_res, ev->ev_arg);
+			(*ev->ev_callback)((int)ev->ev_fd, ev->ev_res, ev->ev_arg);
 			OPAL_THREAD_LOCK(&opal_event_lock);
-                        if (event_gotsig || base->event_break)
+
+			if (base->event_break)
 				return;
 		}
 	}
@@ -686,14 +726,14 @@ event_loopexit_cb(int fd, short what, void *arg)
 
 /* not thread safe */
 int
-event_loopexit(struct timeval *tv)
+event_loopexit(const struct timeval *tv)
 {
 	return (event_once(-1, EV_TIMEOUT, event_loopexit_cb,
 		    current_base, tv));
 }
 
 int
-event_base_loopexit(struct event_base *event_base, struct timeval *tv)
+event_base_loopexit(struct event_base *event_base, const struct timeval *tv)
 {
 	return (event_base_once(event_base, -1, EV_TIMEOUT, event_loopexit_cb,
 		    event_base, tv));
@@ -741,10 +781,13 @@ event_base_loop(struct event_base *base, int flags)
 		return(0);
 
 #if OPAL_HAVE_WORKING_EVENTOPS
+	/* clear time cache */
+	base->tv_cache.tv_sec = 0;
+
 	res = OPAL_THREAD_TRYLOCK(&opal_event_lock);
         if (0 != res) return 0;
         
-	if(!TAILQ_EMPTY(&base->sig.signalqueue))
+	if (base->sig.ev_signal_added)
 		evsignal_base = base;
 	done = 0;
 	while (!done && opal_event_enabled) {
@@ -758,20 +801,6 @@ event_base_loop(struct event_base *base, int flags)
 			base->event_break = 0;
 			break;
 		}
-
-		/* You cannot use this interface for multi-threaded apps */
-		while (event_gotsig) {
-			event_gotsig = 0;
-			if (event_sigcb) {
-				res = (*event_sigcb)();
-				if (res == -1) {
-					errno = EINTR;
-                                        OPAL_THREAD_UNLOCK(&opal_event_lock);
-                                        return (-1);
-				}
-			}
-		}
-
 #if 0
                 /* OMPI: George wants to comment this out for now */
 		OPAL_THREAD_UNLOCK(&opal_event_lock);
@@ -796,13 +825,19 @@ event_base_loop(struct event_base *base, int flags)
                     return (1);
 		}
 
-#if OMPI_ENABLE_PROGRESS_THREADS
+		/* update last old time */
+		gettime(base, &base->event_tv);
+
+		/* clear time cache */
+		base->tv_cache.tv_sec = 0;
+
+#if OPAL_ENABLE_PROGRESS_THREADS
 		opal_event_pipe_signalled = 0;
 #endif
 
 		res = evsel->dispatch(base, evbase, tv_p);
 
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 		opal_event_pipe_signalled = 1;
 #endif
 
@@ -812,6 +847,7 @@ event_base_loop(struct event_base *base, int flags)
 			OPAL_THREAD_UNLOCK(&opal_event_lock);
                         return (-1);
                     }
+		gettime(base, &base->tv_cache);
 
 		timeout_process(base);
 
@@ -823,6 +859,9 @@ event_base_loop(struct event_base *base, int flags)
 			done = 1;
 	}
 
+	/* clear time cache */
+	base->tv_cache.tv_sec = 0;
+
 	event_debug(("%s: asked to terminate loop.", __func__));
         
 	OPAL_THREAD_UNLOCK(&opal_event_lock);
@@ -855,7 +894,7 @@ event_once_cb(int fd, short events, void *arg)
 /* not threadsafe, event scheduled once. */
 int
 event_once(int fd, short events,
-    void (*callback)(int, short, void *), void *arg, struct timeval *tv)
+    void (*callback)(int, short, void *), void *arg, const struct timeval *tv)
 {
 	return event_base_once(current_base, fd, events, callback, arg, tv);
 }
@@ -863,7 +902,7 @@ event_once(int fd, short events,
 /* Schedules an event once */
 int
 event_base_once(struct event_base *base, int fd, short events,
-    void (*callback)(int, short, void *), void *arg, struct timeval *tv)
+    void (*callback)(int, short, void *), void *arg, const struct timeval *tv)
 {
 	struct event_once *eonce;
 	struct timeval etv;
@@ -972,22 +1011,20 @@ event_pending(struct event *ev, short event, struct timeval *tv)
 	int flags = 0;
 
 	if (ev->ev_flags & EVLIST_INSERTED)
-		flags |= (ev->ev_events & (EV_READ|EV_WRITE));
+		flags |= (ev->ev_events & (EV_READ|EV_WRITE|EV_SIGNAL));
 	if (ev->ev_flags & EVLIST_ACTIVE)
 		flags |= ev->ev_res;
 	if (ev->ev_flags & EVLIST_TIMEOUT)
 		flags |= EV_TIMEOUT;
-	if (ev->ev_flags & EVLIST_SIGNAL)
-		flags |= EV_SIGNAL;
 
 	event &= (EV_TIMEOUT|EV_READ|EV_WRITE|EV_SIGNAL);
 
 	/* See if there is a timeout that we should report */
 	if (tv != NULL && (flags & event & EV_TIMEOUT)) {
-		gettime(&now);
+		gettime(ev->ev_base, &now);
 		evutil_timersub(&ev->ev_timeout, &now, &res);
 		/* correctly remap to real time */
-		gettimeofday(&now, NULL);
+		evutil_gettimeofday(&now, NULL);
 		evutil_timeradd(&now, &res, tv);
 	}
 
@@ -995,12 +1032,13 @@ event_pending(struct event *ev, short event, struct timeval *tv)
 }
 
 int
-event_add(struct event *ev, struct timeval *tv)
+event_add(struct event *ev, const struct timeval *tv)
 {
 	struct event_base *base = ev->ev_base;
 	const struct eventop *evsel = base->evsel;
 	void *evbase = base->evbase;
-        int res = 0;
+	int res = 0;
+
 	event_debug((
 		 "event_add: event: %p, %s%s%scall %p",
 		 ev,
@@ -1011,14 +1049,36 @@ event_add(struct event *ev, struct timeval *tv)
 
 	assert(!(ev->ev_flags & ~EVLIST_ALL));
 
-	if (tv != NULL) {
+	/*
+	 * prepare for timeout insertion further below, if we get a
+	 * failure on any step, we should not change any state.
+	 */
+	if (tv != NULL && !(ev->ev_flags & EVLIST_TIMEOUT)) {
+		if (min_heap_reserve(&base->timeheap,
+			1 + min_heap_size(&base->timeheap)) == -1)
+			return (-1);  /* ENOMEM == errno */
+	}
+
+	if ((ev->ev_events & (EV_READ|EV_WRITE|EV_SIGNAL)) &&
+	    !(ev->ev_flags & (EVLIST_INSERTED|EVLIST_ACTIVE))) {
+		res = evsel->add(evbase, ev);
+		if (res != -1)
+			event_queue_insert(base, ev, EVLIST_INSERTED);
+	}
+
+	/* 
+	 * we should change the timout state only if the previous event
+	 * addition succeeded.
+	 */
+	if (res != -1 && tv != NULL) {
 		struct timeval now;
 
+		/* 
+		 * we already reserved memory above for the case where we
+		 * are not replacing an exisiting timeout.
+		 */
 		if (ev->ev_flags & EVLIST_TIMEOUT)
 			event_queue_remove(base, ev, EVLIST_TIMEOUT);
-		else if (min_heap_reserve(&base->timeheap,
-			1 + min_heap_size(&base->timeheap)) == -1)
-		    return (-1);  /* ENOMEM == errno */
 
 		/* Check if it is active due to a timeout.  Rescheduling
 		 * this timeout before the callback can be executed
@@ -1036,32 +1096,17 @@ event_add(struct event *ev, struct timeval *tv)
 			event_queue_remove(base, ev, EVLIST_ACTIVE);
 		}
 
-		gettime(&now);
+		gettime(base, &now);
 		evutil_timeradd(&now, tv, &ev->ev_timeout);
 
 		event_debug((
-			 "event_add: timeout in %d seconds, call %p",
+			 "event_add: timeout in %ld seconds, call %p",
 			 tv->tv_sec, ev->ev_callback));
 
 		event_queue_insert(base, ev, EVLIST_TIMEOUT);
 	}
 
-	if ((ev->ev_events & (EV_READ|EV_WRITE)) &&
-	    !(ev->ev_flags & (EVLIST_INSERTED|EVLIST_ACTIVE))) {
-                res = evsel->add(evbase, ev);
-		if (res != -1)
-			event_queue_insert(base, ev, EVLIST_INSERTED);
-
-		return (res);
-	} else if ((ev->ev_events & EV_SIGNAL) &&
-	    !(ev->ev_flags & EVLIST_SIGNAL)) {
-		res = evsel->add(evbase, ev);
-		if (res != -1)
-			event_queue_insert(base, ev, EVLIST_SIGNAL);
-
-        }
-
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
 	if(opal_using_threads() && opal_event_pipe_signalled == 0) {
             unsigned char byte = 0;
             if(write(opal_event_pipe[1], &byte, 1) != 1)
@@ -1069,7 +1114,7 @@ event_add(struct event *ev, struct timeval *tv)
             opal_event_pipe_signalled++;
 	}
 #endif
-	return res;
+	return (res);
 }
 
 int
@@ -1108,11 +1153,8 @@ event_del(struct event *ev)
 	if (ev->ev_flags & EVLIST_INSERTED) {
 		event_queue_remove(base, ev, EVLIST_INSERTED);
 		rc = (evsel->del(evbase, ev));
-	} else if (ev->ev_flags & EVLIST_SIGNAL) {
-		event_queue_remove(base, ev, EVLIST_SIGNAL);
-		rc = (evsel->del(evbase, ev));
 	}
-#if OMPI_ENABLE_PROGRESS_THREADS
+#if OPAL_ENABLE_PROGRESS_THREADS
         if(opal_using_threads() && opal_event_pipe_signalled == 0) {
             unsigned char byte = 0;
             if(write(opal_event_pipe[1], &byte, 1) != 1)
@@ -1152,7 +1194,7 @@ timeout_next(struct event_base *base, struct timeval **tv_p)
 		return (0);
 	}
 
-	if (gettime(&now) == -1)
+	if (gettime(base, &now) == -1)
 		return (-1);
 
 	if (evutil_timercmp(&ev->ev_timeout, &now, <=)) {
@@ -1165,7 +1207,7 @@ timeout_next(struct event_base *base, struct timeval **tv_p)
 	assert(tv->tv_sec >= 0);
 	assert(tv->tv_usec >= 0);
 
-	event_debug(("timeout_next: in %d seconds", tv->tv_sec));
+	event_debug(("timeout_next: in %ld seconds", tv->tv_sec));
 	return (0);
 }
 
@@ -1188,7 +1230,7 @@ timeout_correct(struct event_base *base, struct timeval *tv)
 		return;
 
 	/* Check if time is running backwards */
-	gettime(tv);
+	gettime(base, tv);
 	if (evutil_timercmp(tv, &base->event_tv, >=)) {
 		base->event_tv = *tv;
 		return;
@@ -1208,6 +1250,8 @@ timeout_correct(struct event_base *base, struct timeval *tv)
 		struct timeval *ev_tv = &(**pev).ev_timeout;
 		evutil_timersub(ev_tv, &off, ev_tv);
 	}
+	/* Now remember what the new time turned out to be. */
+	base->event_tv = *tv;
 }
 #endif
 
@@ -1220,7 +1264,7 @@ timeout_process(struct event_base *base)
 	if (min_heap_empty(&base->timeheap))
 		return;
 
-	gettime(&now);
+	gettime(base, &now);
 
 	while ((ev = min_heap_top(&base->timeheap))) {
 		if (evutil_timercmp(&ev->ev_timeout, &now, >))
@@ -1247,20 +1291,17 @@ event_queue_remove(struct event_base *base, struct event *ev, int queue)
 
 	ev->ev_flags &= ~queue;
 	switch (queue) {
+	case EVLIST_INSERTED:
+		TAILQ_REMOVE(&base->eventqueue, ev, ev_next);
+		break;
 	case EVLIST_ACTIVE:
 		base->event_count_active--;
 		TAILQ_REMOVE(base->activequeues[ev->ev_pri],
 		    ev, ev_active_next);
 		break;
-	case EVLIST_SIGNAL:
-		TAILQ_REMOVE(&base->sig.signalqueue, ev, ev_signal_next);
-		break;
 	case EVLIST_TIMEOUT:
 		min_heap_erase(&base->timeheap, ev);
 		break;
-	case EVLIST_INSERTED:
-		TAILQ_REMOVE(&base->eventqueue, ev, ev_next);
-		break;
 	default:
 		event_errx(1, "%s: unknown queue %x", __func__, queue);
 	}
@@ -1283,21 +1324,18 @@ event_queue_insert(struct event_base *base, struct event *ev, int queue)
 
 	ev->ev_flags |= queue;
 	switch (queue) {
+	case EVLIST_INSERTED:
+		TAILQ_INSERT_TAIL(&base->eventqueue, ev, ev_next);
+		break;
 	case EVLIST_ACTIVE:
 		base->event_count_active++;
 		TAILQ_INSERT_TAIL(base->activequeues[ev->ev_pri],
 		    ev,ev_active_next);
 		break;
-	case EVLIST_SIGNAL:
-		TAILQ_INSERT_TAIL(&base->sig.signalqueue, ev, ev_signal_next);
-		break;
 	case EVLIST_TIMEOUT: {
 		min_heap_push(&base->timeheap, ev);
 		break;
 	}
-	case EVLIST_INSERTED:
-		TAILQ_INSERT_TAIL(&base->eventqueue, ev, ev_next);
-		break;
 	default:
 		event_errx(1, "%s: unknown queue %x", __func__, queue);
 	}
