@@ -39,7 +39,7 @@
 #else
 /* C code */
 
-#if OMPI_C_HAVE_BUILTIN_EXPECT
+#if OPAL_C_HAVE_BUILTIN_EXPECT
 #define OPAL_LIKELY(expression) __builtin_expect(!!(expression), 1)
 #define OPAL_UNLIKELY(expression) __builtin_expect(!!(expression), 0)
 #else
@@ -47,7 +47,7 @@
 #define OPAL_UNLIKELY(expression) (expression)
 #endif
 
-#if OMPI_C_HAVE_BUILTIN_PREFETCH
+#if OPAL_C_HAVE_BUILTIN_PREFETCH
 #define OPAL_PREFETCH(address,rw,locality) __builtin_prefetch(address,rw,locality)
 #else
 #define OPAL_PREFETCH(address,rw,locality)
