@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2007      Sun Microsystems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -55,16 +56,16 @@
 /* do some quick #define cleanup in cases where we are doing
    testing... */
 #ifdef OMPI_DISABLE_INLINE_ASM
-#undef OMPI_C_GCC_INLINE_ASSEMBLY
-#define OMPI_C_GCC_INLINE_ASSEMBLY 0
+#undef OPAL_C_GCC_INLINE_ASSEMBLY
+#define OPAL_C_GCC_INLINE_ASSEMBLY 0
 #undef OMPI_CXX_GCC_INLINE_ASSEMBLY
 #define OMPI_CXX_GCC_INLINE_ASSEMBLY 0
-#undef OMPI_C_DEC_INLINE_ASSEMBLY
-#define OMPI_C_DEC_INLINE_ASSEMBLY 0
+#undef OPAL_C_DEC_INLINE_ASSEMBLY
+#define OPAL_C_DEC_INLINE_ASSEMBLY 0
 #undef OMPI_CXX_DEC_INLINE_ASSEMBLY
 #define OMPI_CXX_DEC_INLINE_ASSEMBLY 0
-#undef OMPI_C_XLC_INLINE_ASSEMBLY
-#define OMPI_C_XLC_INLINE_ASSEMBLY 0
+#undef OPAL_C_XLC_INLINE_ASSEMBLY
+#define OPAL_C_XLC_INLINE_ASSEMBLY 0
 #undef OMPI_CXX_XLC_INLINE_ASSEMBLY
 #define OMPI_CXX_XLC_INLINE_ASSEMBLY 0
 #endif
@@ -77,15 +78,13 @@
 #define OMPI_DEC_INLINE_ASSEMBLY OMPI_CXX_DEC_INLINE_ASSEMBLY
 #define OMPI_XLC_INLINE_ASSEMBLY OMPI_CXX_XLC_INLINE_ASSEMBLY
 #else
-#define OMPI_GCC_INLINE_ASSEMBLY OMPI_C_GCC_INLINE_ASSEMBLY
-#define OMPI_DEC_INLINE_ASSEMBLY OMPI_C_DEC_INLINE_ASSEMBLY
-#define OMPI_XLC_INLINE_ASSEMBLY OMPI_C_XLC_INLINE_ASSEMBLY
+#define OMPI_GCC_INLINE_ASSEMBLY OPAL_C_GCC_INLINE_ASSEMBLY
+#define OMPI_DEC_INLINE_ASSEMBLY OPAL_C_DEC_INLINE_ASSEMBLY
+#define OMPI_XLC_INLINE_ASSEMBLY OPAL_C_XLC_INLINE_ASSEMBLY
 #endif
 
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 /**********************************************************************
  *
  * Data structures for atomic ops
@@ -108,6 +107,29 @@ struct opal_atomic_lock_t {
 };
 typedef struct opal_atomic_lock_t opal_atomic_lock_t;
 
+/**********************************************************************
+ *
+ * Set or unset these macros in the architecture-specific atomic.h
+ * files if we need to specify them as inline or non-inline 
+ * 
+ *********************************************************************/
+#if !OMPI_GCC_INLINE_ASSEMBLY
+#define OPAL_HAVE_INLINE_ATOMIC_MEM_BARRIER 0
+#define OPAL_HAVE_INLINE_ATOMIC_CMPSET_32 0
+#define OPAL_HAVE_INLINE_ATOMIC_CMPSET_64 0
+#define OPAL_HAVE_INLINE_ATOMIC_ADD_32 0
+#define OPAL_HAVE_INLINE_ATOMIC_SUB_32 0
+#define OPAL_HAVE_INLINE_ATOMIC_ADD_64 0
+#define OPAL_HAVE_INLINE_ATOMIC_SUB_64 0
+#else
+#define OPAL_HAVE_INLINE_ATOMIC_MEM_BARRIER 1
+#define OPAL_HAVE_INLINE_ATOMIC_CMPSET_32 1
+#define OPAL_HAVE_INLINE_ATOMIC_CMPSET_64 1
+#define OPAL_HAVE_INLINE_ATOMIC_ADD_32 1
+#define OPAL_HAVE_INLINE_ATOMIC_SUB_32 1
+#define OPAL_HAVE_INLINE_ATOMIC_ADD_64 1
+#define OPAL_HAVE_INLINE_ATOMIC_SUB_64 1
+#endif
 
 /**********************************************************************
  *
@@ -117,28 +139,30 @@ typedef struct opal_atomic_lock_t opal_atomic_lock_t;
  *********************************************************************/
 #if defined(DOXYGEN)
 /* don't include system-level gorp when generating doxygen files */ 
-#elif OMPI_ASSEMBLY_ARCH == OMPI_WINDOWS
+#elif OPAL_ASSEMBLY_ARCH == OMPI_WINDOWS
 /* windows first, as they have API-level primitives for this stuff */
 #include "opal/sys/win32/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_ALPHA
+#elif OPAL_ASSEMBLY_ARCH == OMPI_ALPHA
 #include "opal/sys/alpha/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_AMD64
+#elif OPAL_ASSEMBLY_ARCH == OMPI_AMD64
 #include "opal/sys/amd64/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_IA32
+#elif OPAL_ASSEMBLY_ARCH == OMPI_ARM
+#include "opal/sys/arm/atomic.h"
+#elif OPAL_ASSEMBLY_ARCH == OMPI_IA32
 #include "opal/sys/ia32/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_IA64
+#elif OPAL_ASSEMBLY_ARCH == OMPI_IA64
 #include "opal/sys/ia64/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_MIPS
+#elif OPAL_ASSEMBLY_ARCH == OMPI_MIPS
 #include "opal/sys/mips/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_POWERPC32
+#elif OPAL_ASSEMBLY_ARCH == OMPI_POWERPC32
 #include "opal/sys/powerpc/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_POWERPC64
+#elif OPAL_ASSEMBLY_ARCH == OMPI_POWERPC64
 #include "opal/sys/powerpc/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_SPARC
+#elif OPAL_ASSEMBLY_ARCH == OMPI_SPARC
 #include "opal/sys/sparc/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_SPARCV9_32
+#elif OPAL_ASSEMBLY_ARCH == OMPI_SPARCV9_32
 #include "opal/sys/sparcv9/atomic.h"
-#elif OMPI_ASSEMBLY_ARCH == OMPI_SPARCV9_64
+#elif OPAL_ASSEMBLY_ARCH == OMPI_SPARCV9_64
 #include "opal/sys/sparcv9/atomic.h"
 #endif
 
@@ -179,6 +203,10 @@ typedef struct opal_atomic_lock_t opal_atomic_lock_t;
  * generally grinding the memory controller's performance.  Use only
  * if you need *both* read and write barriers.
  */
+
+#if OPAL_HAVE_INLINE_ATOMIC_MEM_BARRIER
+static inline 
+#endif
 void opal_atomic_mb(void);
 
 /**
@@ -190,6 +218,10 @@ void opal_atomic_mb(void);
  * next read.  Nothing is said about the ordering of writes when using
  * \c opal_atomic_rmb().
  */
+
+#if OPAL_HAVE_INLINE_ATOMIC_MEM_BARRIER
+static inline 
+#endif
 void opal_atomic_rmb(void);
 
 /**
@@ -201,6 +233,10 @@ void opal_atomic_rmb(void);
  * next write.  Nothing is said about the ordering of reads when using
  * \c opal_atomic_wmb().
  */
+
+#if OPAL_HAVE_INLINE_ATOMIC_MEM_BARRIER
+static inline 
+#endif
 void opal_atomic_wmb(void);
 
 #endif /* defined(DOXYGEN) || OPAL_HAVE_ATOMIC_MEM_BARRIER */
@@ -293,11 +329,23 @@ void opal_atomic_unlock(opal_atomic_lock_t *lock);
 #define OPAL_HAVE_ATOMIC_CMPSET_32 0
 #endif
 #if defined(DOXYGEN) || OPAL_HAVE_ATOMIC_CMPSET_32
-int opal_atomic_cmpset_32(volatile int32_t *addr, int32_t oldval, 
+
+#if OPAL_HAVE_INLINE_ATOMIC_CMPSET_32
+static inline 
+#endif
+int opal_atomic_cmpset_32(volatile int32_t *addr, int32_t oldval,
                           int32_t newval);
-int opal_atomic_cmpset_acq_32(volatile int32_t *addr, int32_t oldval, 
+
+#if OPAL_HAVE_INLINE_ATOMIC_CMPSET_32
+static inline 
+#endif
+int opal_atomic_cmpset_acq_32(volatile int32_t *addr, int32_t oldval,
                               int32_t newval);
-int opal_atomic_cmpset_rel_32(volatile int32_t *addr, int32_t oldval, 
+
+#if OPAL_HAVE_INLINE_ATOMIC_CMPSET_32
+static inline 
+#endif
+int opal_atomic_cmpset_rel_32(volatile int32_t *addr, int32_t oldval,
                               int32_t newval);
 #endif
 
@@ -306,28 +354,56 @@ int opal_atomic_cmpset_rel_32(volatile int32_t *addr, int32_t oldval,
 #define OPAL_HAVE_ATOMIC_CMPSET_64 0
 #endif
 #if defined(DOXYGEN) || OPAL_HAVE_ATOMIC_CMPSET_64
-int opal_atomic_cmpset_64(volatile int64_t *addr, int64_t oldval, 
+
+#if OPAL_HAVE_INLINE_ATOMIC_CMPSET_64
+static inline 
+#endif
+int opal_atomic_cmpset_64(volatile int64_t *addr, int64_t oldval,
                           int64_t newval);
-int opal_atomic_cmpset_acq_64(volatile int64_t *addr, int64_t oldval, 
+
+#if OPAL_HAVE_INLINE_ATOMIC_CMPSET_64
+static inline 
+#endif
+int opal_atomic_cmpset_acq_64(volatile int64_t *addr, int64_t oldval,
                               int64_t newval);
-int opal_atomic_cmpset_rel_64(volatile int64_t *addr, int64_t oldval, 
+
+#if OPAL_HAVE_INLINE_ATOMIC_CMPSET_64
+static inline 
+#endif
+int opal_atomic_cmpset_rel_64(volatile int64_t *addr, int64_t oldval,
                               int64_t newval);
+
 #endif
 
 #if !defined(OPAL_HAVE_ATOMIC_MATH_32) && !defined(DOXYGEN)
   /* define to 0 for these tests.  WIll fix up later. */
   #define OPAL_HAVE_ATOMIC_MATH_32 0
 #endif
+
 #if defined(DOXYGEN) ||  OPAL_HAVE_ATOMIC_MATH_32 || OPAL_HAVE_ATOMIC_CMPSET_32
-#if ! OPAL_HAVE_ATOMIC_MATH_32
+
+/* OPAL_HAVE_INLINE_ATOMIC_*_32 will be 1 if <arch>/atomic.h provides
+   a static inline version of it (in assembly).  If it's 0 but
+   OPAL_HAVE_ATOMIC_CMPSET_32 is 1, then atomic_impl.h (below) will
+   define a static inline version of it (in C, using
+   atomic_cmpset_32()).  */
+#if OPAL_HAVE_INLINE_ATOMIC_ADD_32 || OPAL_HAVE_ATOMIC_CMPSET_32
 static inline
 #endif
 int32_t opal_atomic_add_32(volatile int32_t *addr, int delta);
-#if ! OPAL_HAVE_ATOMIC_MATH_32
+
+/* OPAL_HAVE_INLINE_ATOMIC_*_32 will be 1 if <arch>/atomic.h provides
+   a static inline version of it (in assembly).  If it's 0 but
+   OPAL_HAVE_ATOMIC_CMPSET_32 is 1, then atomic_impl.h (below) will
+   define a static inline version of it (in C, using
+   atomic_cmpset_32()).  */
+#if OPAL_HAVE_INLINE_ATOMIC_SUB_32 || OPAL_HAVE_ATOMIC_CMPSET_32
 static inline
 #endif
 int32_t opal_atomic_sub_32(volatile int32_t *addr, int delta);
+
 #endif /* OPAL_HAVE_ATOMIC_MATH_32 */
+
 #if ! OPAL_HAVE_ATOMIC_MATH_32
 /* fix up the value of ompi_have_atomic_math_32 to allow for C versions */
 #undef OPAL_HAVE_ATOMIC_MATH_32
@@ -338,16 +414,31 @@ int32_t opal_atomic_sub_32(volatile int32_t *addr, int delta);
 /* define to 0 for these tests.  WIll fix up later. */
 #define OPAL_HAVE_ATOMIC_MATH_64 0
 #endif
+
 #if defined(DOXYGEN) || OPAL_HAVE_ATOMIC_MATH_64 || OPAL_HAVE_ATOMIC_CMPSET_64
-#if OPAL_HAVE_ATOMIC_CMPSET_64
+
+/* OPAL_HAVE_INLINE_ATOMIC_*_64 will be 1 if <arch>/atomic.h provides
+   a static inline version of it (in assembly).  If it's 0 but
+   OPAL_HAVE_ATOMIC_CMPSET_64 is 1, then atomic_impl.h (below) will
+   define a static inline version of it (in C, using
+   atomic_cmpset_64()).  */
+#if OPAL_HAVE_INLINE_ATOMIC_ADD_64 || OPAL_HAVE_ATOMIC_CMPSET_64
 static inline
 #endif
 int64_t opal_atomic_add_64(volatile int64_t *addr, int64_t delta);
-#if OPAL_HAVE_ATOMIC_CMPSET_64
-static inline 
+
+/* OPAL_HAVE_INLINE_ATOMIC_*_64 will be 1 if <arch>/atomic.h provides
+   a static inline version of it (in assembly).  If it's 0 but
+   OPAL_HAVE_ATOMIC_CMPSET_64 is 1, then atomic_impl.h (below) will
+   define a static inline version of it (in C, using
+   atomic_cmpset_64()).  */
+#if OPAL_HAVE_INLINE_ATOMIC_SUB_64 || OPAL_HAVE_ATOMIC_CMPSET_64
+static inline
 #endif
 int64_t opal_atomic_sub_64(volatile int64_t *addr, int64_t delta);
+
 #endif /* OPAL_HAVE_ATOMIC_MATH_32 */
+
 #if ! OPAL_HAVE_ATOMIC_MATH_64
 /* fix up the value of ompi_have_atomic_math_64 to allow for C versions */
 #undef OPAL_HAVE_ATOMIC_MATH_64
@@ -359,7 +450,7 @@ int64_t opal_atomic_sub_64(volatile int64_t *addr, int64_t delta);
  *  interface and can catch type errors.  When not in debug mode,
  * just make it a macro, so that there's no performance penalty
  */
-#if defined(DOXYGEN) || OMPI_ENABLE_DEBUG
+#if defined(DOXYGEN) || OPAL_ENABLE_DEBUG
 static inline size_t
 opal_atomic_add_size_t(volatile size_t *addr, int delta)
 {
@@ -430,8 +521,8 @@ static inline int opal_atomic_cmpset_rel_ptr(volatile void* addr,
  * See opal_atomic_cmpset_* for pseudo-code.
  */
 #define opal_atomic_cmpset( ADDR, OLDVAL, NEWVAL )                  \
-   opal_atomic_cmpset_xx( (volatile void*)(ADDR), (int64_t)(OLDVAL), \
-                          (int64_t)(NEWVAL), sizeof(*(ADDR)) )
+   opal_atomic_cmpset_xx( (volatile void*)(ADDR), (intptr_t)(OLDVAL), \
+                          (intptr_t)(NEWVAL), sizeof(*(ADDR)) )
 
 /**
  * Atomic compare and set of pointer with acquire semantics. This
@@ -525,12 +616,6 @@ static inline int64_t opal_atomic_sub_ptr( volatile void* addr, void* delta );
  *********************************************************************/
 #include "opal/sys/atomic_impl.h"
 
-
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
-
-
-
+END_C_DECLS
 
 #endif /* OPAL_SYS_ATOMIC_H */
