@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2010      Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -18,6 +19,9 @@
 
 /* Inline C implementation of the functions defined in atomic.h */
 
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 
 /**********************************************************************
  *
@@ -97,6 +101,16 @@ opal_atomic_sub_64(volatile int64_t *addr, int64_t delta)
 }
 #endif  /* OPAL_HAVE_ATOMIC_SUB_64 */
 
+#else
+
+#if !defined(OPAL_HAVE_ATOMIC_ADD_64)
+#define OPAL_HAVE_ATOMIC_ADD_64 0
+#endif
+
+#if !defined(OPAL_HAVE_ATOMIC_SUB_64)
+#define OPAL_HAVE_ATOMIC_SUB_64 0
+#endif
+
 #endif  /* OPAL_HAVE_ATOMIC_CMPSET_64 */
 
 
@@ -119,9 +133,9 @@ opal_atomic_cmpset_xx(volatile void* addr, int64_t oldval,
                                     (int64_t)oldval, (int64_t)newval );
 #endif  /* OPAL_HAVE_ATOMIC_CMPSET_64 */
    default:
-      /* This should never happen, so deliberately cause a seg fault
-         for corefile analysis */
-      *(int*)(0) = 0;
+       /* This should never happen, so deliberately abort (hopefully
+          leaving a coreful for analysis) */
+       abort();
    }
    return 0;  /* always fail */
 }
@@ -144,9 +158,9 @@ opal_atomic_cmpset_acq_xx(volatile void* addr, int64_t oldval,
                                         (int64_t)oldval, (int64_t)newval );
 #endif  /* OPAL_HAVE_ATOMIC_CMPSET_64 */
    default:
-      /* This should never happen, so deliberately cause a seg fault
-         for corefile analysis */
-      *(int*)(0) = 0;
+       /* This should never happen, so deliberately abort (hopefully
+          leaving a coreful for analysis) */
+       abort();
    }
    return 0;  /* always fail */
 }
@@ -169,9 +183,9 @@ opal_atomic_cmpset_rel_xx(volatile void* addr, int64_t oldval,
                                         (int64_t)oldval, (int64_t)newval );
 #endif  /* OPAL_HAVE_ATOMIC_CMPSET_64 */
    default:
-      /* This should never happen, so deliberately cause a seg fault
-         for corefile analysis */
-      *(int*)(0) = 0;
+       /* This should never happen, so deliberately abort (hopefully
+          leaving a coreful for analysis) */
+       abort();
    }
    return 0;  /* always fail */
 }
@@ -250,9 +264,9 @@ opal_atomic_add_xx(volatile void* addr, int32_t value, size_t length)
       break;
 #endif  /* OPAL_HAVE_ATOMIC_CMPSET_64 */
    default:
-      /* This should never happen, so deliberately cause a seg fault
-         for corefile analysis */
-      *(int*)(0) = 0;
+       /* This should never happen, so deliberately abort (hopefully
+          leaving a coreful for analysis) */
+       abort();
    }
 }
 
@@ -273,9 +287,9 @@ opal_atomic_sub_xx(volatile void* addr, int32_t value, size_t length)
       break;
 #endif  /* OPAL_HAVE_ATOMIC_CMPSET_64 */
    default:
-      /* This should never happen, so deliberately cause a seg fault
-         for corefile analysis */
-      *(int*)(0) = 0;
+       /* This should never happen, so deliberately abort (hopefully
+          leaving a coreful for analysis) */
+       abort();
    }
 }
 
