@@ -1433,6 +1433,12 @@ static int param_register(const char *type_name,
               NULL != param.mbp_default_value.stringval) {
               array[i].mbp_default_value.stringval =
                   strdup(param.mbp_default_value.stringval);
+          } else {
+              /* If the new STRING doesn't have a default value, we
+                 must set the default value to "NULL" because it still
+                 contains the old INT default value (which may not
+                 compare equally to NULL) */
+              array[i].mbp_default_value.stringval = NULL;
           }
 
           if (NULL != file_value &&
@@ -1440,6 +1446,12 @@ static int param_register(const char *type_name,
               array[i].mbp_file_value.stringval =
                   strdup(param.mbp_file_value.stringval);
               array[i].mbp_file_value_set = true;
+          } else {
+              /* Similar to above, be sure to set the file default
+                 value to NULL to ensure that it's not still set to a
+                 non-NULL value from the prior INT default value */
+              array[i].mbp_file_value.stringval = NULL;
+              array[i].mbp_file_value_set = false;
           }
 
           if (NULL != override_value &&
@@ -1447,6 +1459,12 @@ static int param_register(const char *type_name,
               array[i].mbp_override_value.stringval =
                   strdup(param.mbp_override_value.stringval);
               array[i].mbp_override_value_set = true;
+          } else {
+              /* Similar to above, be sure to set the file default
+                 value to NULL to ensure that it's not still set to a
+                 non-NULL value from the prior INT default value */
+              array[i].mbp_file_value.stringval = NULL;
+              array[i].mbp_file_value_set = false;
           }
 
           array[i].mbp_type = param.mbp_type;
@@ -1456,13 +1474,19 @@ static int param_register(const char *type_name,
 
       else if (MCA_BASE_PARAM_TYPE_STRING == array[i].mbp_type &&
                  MCA_BASE_PARAM_TYPE_INT == param.mbp_type) {
+          /* Free the old STRING default value, if it exists */
+          if (NULL != array[i].mbp_default_value.stringval) {
+              free(array[i].mbp_default_value.stringval);
+          }
+
+          /* Set the new default value, or 0 if one wasn't provided */
           if (NULL != default_value) {
-              if (NULL != array[i].mbp_default_value.stringval) {
-                  free(array[i].mbp_default_value.stringval);
-              }
               array[i].mbp_default_value.intval =
                   param.mbp_default_value.intval;
+          } else {
+              array[i].mbp_default_value.intval = 0;
           }
+
           if (NULL != file_value) {
               if (NULL != array[i].mbp_file_value.stringval) {
                   free(array[i].mbp_file_value.stringval);
@@ -1470,7 +1494,11 @@ static int param_register(const char *type_name,
               array[i].mbp_file_value.intval =
                   param.mbp_file_value.intval;
               array[i].mbp_file_value_set = true;
+          } else {
+              array[i].mbp_file_value.intval = 0;
+              array[i].mbp_file_value_set = false;
           }
+
           if (NULL != override_value) {
               if (NULL != array[i].mbp_override_value.stringval) {
                   free(array[i].mbp_override_value.stringval);
@@ -1478,6 +1506,9 @@ static int param_register(const char *type_name,
               array[i].mbp_override_value.intval =
                   param.mbp_override_value.intval;
               array[i].mbp_override_value_set = true;
+          } else {
+              array[i].mbp_file_value.intval = 0;
+              array[i].mbp_file_value_set = false;
           }
 
           array[i].mbp_type = param.mbp_type;
@@ -2191,3 +2222,232 @@ static void syn_info_destructor(syn_info_t *si)
 
     syn_info_constructor(si);
 }
+
+int mca_base_param_find_int(const mca_base_component_t *component,
+                            const char *param_name,
+                            char **env,
+                            int *current_value)
+{
+    char *tmp, *ptr;
+    int len, i;
+    int rc=OPAL_ERR_NOT_FOUND;
+    
+    if (NULL == env) {
+        return OPAL_ERR_NOT_FOUND;
+    }
+    
+    asprintf(&tmp, "%s%s_%s_%s", mca_prefix, component->mca_type_name,
+             component->mca_component_name, param_name);
+    len = strlen(tmp);
+    for (i=0; NULL != env[i]; i++) {
+        if (0 == strncmp(tmp, env[i], len)) {
+            ptr = strchr(env[i], '=');
+            ptr++;
+            *current_value = strtol(ptr, NULL, 10);
+            rc = OPAL_SUCCESS;
+            break;
+        }
+    }
+    free(tmp);
+    return rc;
+}
+
+int mca_base_param_find_int_name(const char *type,
+                                 const char *param_name,
+                                 char **env,
+                                 int *current_value)
+{
+    char *tmp, *ptr;
+    int len, i;
+    int rc=OPAL_ERR_NOT_FOUND;
+    
+    if (NULL == env) {
+        return OPAL_ERR_NOT_FOUND;
+    }
+    
+    asprintf(&tmp, "%s%s_%s", mca_prefix, type, param_name);
+    len = strlen(tmp);
+    for (i=0; NULL != env[i]; i++) {
+        if (0 == strncmp(tmp, env[i], len)) {
+            ptr = strchr(env[i], '=');
+            ptr++;
+            *current_value = strtol(ptr, NULL, 10);
+            rc = OPAL_SUCCESS;
+            break;
+        }
+    }
+    free(tmp);
+    return rc;
+}
+
+int mca_base_param_find_string(const mca_base_component_t *component,
+                               const char *param_name,
+                               char **env,
+                               char **current_value)
+{
+    char *tmp, *ptr;
+    int len, i;
+    int rc=OPAL_ERR_NOT_FOUND;
+    
+    if (NULL == env) {
+        return OPAL_ERR_NOT_FOUND;
+    }
+    
+    asprintf(&tmp, "%s%s_%s_%s", mca_prefix, component->mca_type_name,
+             component->mca_component_name, param_name);
+    len = strlen(tmp);
+    for (i=0; NULL != env[i]; i++) {
+        if (0 == strncmp(tmp, env[i], len)) {
+            ptr = strchr(env[i], '=');
+            ptr++;
+            *current_value = ptr;
+            rc = OPAL_SUCCESS;
+            break;
+        }
+    }
+    free(tmp);
+    return rc;
+}
+
+int mca_base_param_find_string_name(const char *type,
+                                    const char *param_name,
+                                    char **env,
+                                    char **current_value)
+{
+    char *tmp, *ptr;
+    int len, i;
+    int rc=OPAL_ERR_NOT_FOUND;
+    
+    if (NULL == env) {
+        return OPAL_ERR_NOT_FOUND;
+    }
+    
+    asprintf(&tmp, "%s%s_%s", mca_prefix, type, param_name);
+    len = strlen(tmp);
+    for (i=0; NULL != env[i]; i++) {
+        if (0 == strncmp(tmp, env[i], len)) {
+            ptr = strchr(env[i], '=');
+            ptr++;
+            *current_value = ptr;
+            rc = OPAL_SUCCESS;
+            break;
+        }
+    }
+    free(tmp);
+    return rc;
+}
+
+static char *source_name(mca_base_param_source_t source, 
+                               const char *filename)
+{
+    char *ret;
+
+    switch (source) {
+    case MCA_BASE_PARAM_SOURCE_DEFAULT:
+        return strdup("default value");
+        break;
+
+    case MCA_BASE_PARAM_SOURCE_ENV:
+        return strdup("command line or environment variable");
+        break;
+
+    case MCA_BASE_PARAM_SOURCE_FILE:
+        asprintf(&ret, "file (%s)", filename);
+        return ret;
+        break;
+
+    case MCA_BASE_PARAM_SOURCE_OVERRIDE:
+        return strdup("internal override");
+        break;
+
+    default:
+        return strdup("unknown (!)");
+        break;
+    }
+}
+
+int mca_base_param_check_exclusive_string(const char *type_a,
+                                          const char *component_a,
+                                          const char *param_a,
+                                          const char *type_b,
+                                          const char *component_b,
+                                          const char *param_b)
+{
+    int i, ret;
+    mca_base_param_source_t source_a, source_b;
+    char *filename_a, *filename_b;
+
+    i = mca_base_param_find(type_a, component_a, param_a);
+    if (i < 0) {
+        return OPAL_ERR_NOT_FOUND;
+    }
+    ret = mca_base_param_lookup_source(i, &source_a, &filename_a);
+    if (OPAL_SUCCESS != ret) {
+        return ret;
+    }
+
+    i = mca_base_param_find(type_b, component_b, param_b);
+    if (i < 0) {
+        return OPAL_ERR_NOT_FOUND;
+    }
+    ret = mca_base_param_lookup_source(i, &source_b, &filename_b);
+    if (OPAL_SUCCESS != ret) {
+        return ret;
+    }
+
+    if (MCA_BASE_PARAM_SOURCE_DEFAULT != source_a &&
+        MCA_BASE_PARAM_SOURCE_DEFAULT != source_b) {
+        size_t len;
+        char *str_a, *str_b, *name_a, *name_b;
+
+        /* Form cosmetic string names for A */
+        str_a = source_name(source_a, filename_a);
+        len = 5;
+        if (NULL != type_a) len += strlen(type_a);
+        if (NULL != component_a) len += strlen(component_a);
+        if (NULL != param_a) len += strlen(param_a);
+        name_a = calloc(1, len);
+        if (NULL == name_a) {
+            return OPAL_ERR_OUT_OF_RESOURCE;
+        }
+        if (NULL != type_a) {
+            strncat(name_a, type_a, len);
+            strncat(name_a, "_", len);
+        }
+        if (NULL != component_a) strncat(name_a, component_a, len);
+        strncat(name_a, "_", len);
+        strncat(name_a, param_a, len);
+
+        /* Form cosmetic string names for B */
+        str_b = source_name(source_b, filename_b);
+        len = 5;
+        if (NULL != type_b) len += strlen(type_b);
+        if (NULL != component_b) len += strlen(component_b);
+        if (NULL != param_b) len += strlen(param_b);
+        name_b = calloc(1, len);
+        if (NULL == name_b) {
+            return OPAL_ERR_OUT_OF_RESOURCE;
+        }
+        if (NULL != type_b) {
+            strncat(name_b, type_b, len);
+            strncat(name_b, "_", len);
+        }
+        if (NULL != component_b) strncat(name_b, component_b, len);
+        strncat(name_b, "_", len);
+        strncat(name_b, param_b, len);
+
+        /* Print it all out */
+        opal_show_help("help-mca-param.txt", 
+                       "mutually exclusive params",
+                       true, name_a, str_a, name_b, str_b);
+
+        /* Free the temp strings */
+        free(str_a);
+        free(name_a);
+        free(str_b);
+        free(name_b);
+        return OPAL_ERR_BAD_PARAM;
+    }
+
+    return OPAL_SUCCESS;
+}
