@@ -9,7 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2008      Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2008-2011 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -636,6 +636,120 @@ BEGIN_C_DECLS
                                           const char *component, 
                                           const char *param);
 
+/**
+ * Find an MCA parameter in an env array based on its names.
+ *
+ * @param component [in] Pointer to the component for which the
+ * parameter was registered.
+ * @param param_name [in] The name of the parameter being
+ * registered (string).
+ * @param env [in] NULL-terminated list of strings (e.g., from an environment).
+ * @param current_value [out] Return the current value (if found).
+ *
+ * @retval OPAL_ERROR If the parameter was not found.
+ *
+ * Look for a specific MCA parameter in an environment and return its value
+ */
+OPAL_DECLSPEC int mca_base_param_find_int(const mca_base_component_t *component,
+                                          const char *param_name,
+                                          char **env,
+                                          int *current_value);
+
+/**
+ * Find an MCA parameter (in an env array) that is not associated with a
+ * component.
+ *
+ * @param type [in] Although this parameter is not associated with
+ * a component, it still must have a string type name that will
+ * act as a prefix (string).
+ * @param param_name [in] The name of the parameter being
+ * registered (string).
+ * @param env [in] NULL-terminated list of strings (e.g., from an environment).
+ * @param current_value [out] Return the current value (if found).
+ *
+ * @retval OPAL_ERROR If the parameter was not found.
+ *
+ * Look for a specific MCA parameter in an environment and return its value
+ */
+OPAL_DECLSPEC int mca_base_param_find_int_name(const char *type,
+                                               const char *param_name,
+                                               char **env,
+                                               int *current_value);
+/**
+ * Find a string MCA parameter in an env array based on its names.
+ *
+ * @param component [in] Pointer to the component for which the
+ * parameter was registered.
+ * @param param_name [in] The name of the parameter being
+ * registered (string).
+ * @param env [in] NULL-terminated list of strings (e.g., from an environment).
+ * @param current_value [out] Return the current value (if found).
+ *
+ * @retval OPAL_ERROR If the parameter was not found.
+ *
+ * Look for a specific MCA parameter in an environment and return its value
+ */
+OPAL_DECLSPEC int mca_base_param_find_string(const mca_base_component_t *component,
+                                             const char *param_name,
+                                             char **env,
+                                             char **current_value);
+
+/**
+ * Find a string MCA parameter (in an env array) that is not associated with a
+ * component.
+ *
+ * @param type [in] Although this parameter is not associated with
+ * a component, it still must have a string type name that will
+ * act as a prefix (string).
+ * @param param_name [in] The name of the parameter being
+ * registered (string).
+ * @param env [in] NULL-terminated list of strings (e.g., from an environment).
+ * @param current_value [out] Return the current value (if found).
+ *
+ * @retval OPAL_ERROR If the parameter was not found.
+ *
+ * Look for a specific MCA parameter in an environment and return its value
+ */
+OPAL_DECLSPEC int mca_base_param_find_string_name(const char *type,
+                                                  const char *param_name,
+                                                  char **env,
+                                                  char **current_value);
+
+/**
+ * Check that two MCA parameters were not both set to non-default
+ * values.
+ *
+ * @param type_a [in] Framework name of parameter A (string).
+ * @param component_a [in] Component name of parameter A (string).
+ * @param param_a [in] Parameter name of parameter A (string.
+ * @param type_b [in] Framework name of parameter A (string).
+ * @param component_b [in] Component name of parameter A (string).
+ * @param param_b [in] Parameter name of parameter A (string.
+ *
+ * This function is useful for checking that the user did not set both
+ * of 2 mutually-exclusive MCA parameters.
+ *
+ * This function will print an opal_show_help() message and return
+ * OPAL_ERR_BAD_PARAM if it finds that the two parameters both have
+ * value sources that are not MCA_BASE_PARAM_SOURCE_DEFAULT.  This
+ * means that both parameters have been set by the user (i.e., they're
+ * not default values).
+ *
+ * Note that opal_show_help() allows itself to be hooked, so if this
+ * happens after the aggregated orte_show_help() system is
+ * initialized, the messages will be aggregated (w00t).
+ *
+ * @returns OPAL_ERR_BAD_PARAM if the two parameters have sources that
+ * are not MCA_BASE_PARAM_SOURCE_DEFAULT.
+ * @returns OPAL_SUCCESS otherwise.
+ */
+OPAL_DECLSPEC int mca_base_param_check_exclusive_string(const char *type_a,
+                                          const char *component_a,
+                                          const char *param_a,
+                                          const char *type_b,
+                                          const char *component_b,
+                                          const char *param_b);
+
     /**
      * Set the "internal" flag on an MCA parameter to true or false.
      *
