@@ -19,13 +19,14 @@
 #include "opal/constants.h"
 #include "opal/mca/crs/crs.h"
 #include "opal/mca/crs/base/base.h"
+#include "opal/util/output.h"
 #include "crs_self.h"
 
 /*
  * Public string for version number
  */
 const char *opal_crs_self_component_version_string = 
-"OPAL CRS self MCA component version " OMPI_VERSION;
+"OPAL CRS self MCA component version " OPAL_VERSION;
 
 /*
  * Local functionality
@@ -48,9 +49,9 @@ opal_crs_self_component_t mca_crs_self_component = {
 
             /* Component name and version */
             "self",
-            OMPI_MAJOR_VERSION,
-            OMPI_MINOR_VERSION,
-            OMPI_RELEASE_VERSION,
+            OPAL_MAJOR_VERSION,
+            OPAL_MINOR_VERSION,
+            OPAL_RELEASE_VERSION,
             
             /* Component open and close functions */
             crs_self_open,
