@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2009 The Trustees of Indiana University.
+ * Copyright (c) 2004-2010 The Trustees of Indiana University.
  *                         All rights reserved.
  * Copyright (c) 2004-2005 The Trustees of the University of Tennessee.
  *                         All rights reserved.
@@ -261,7 +261,10 @@ int opal_crs_self_module_finalize(void)
 }
 
 
-int opal_crs_self_checkpoint(pid_t pid, opal_crs_base_snapshot_t *base_snapshot, opal_crs_state_type_t *state)
+int opal_crs_self_checkpoint(pid_t pid,
+                             opal_crs_base_snapshot_t *base_snapshot,
+                             opal_crs_base_ckpt_options_t *options,
+                             opal_crs_state_type_t *state)
 {
     opal_crs_self_snapshot_t *snapshot = OBJ_NEW(opal_crs_self_snapshot_t);
     int ret, exit_status = OPAL_SUCCESS;
@@ -274,6 +277,11 @@ int opal_crs_self_checkpoint(pid_t pid, opal_crs_base_snapshot_t *base_snapshot,
         return OPAL_ERR_NOT_SUPPORTED;
     }
 
+    if( options->stop ) {
+        opal_output(0,
+                    "crs:self: checkpoint(): Error: SIGSTOP Not currently supported!");
+    }
+
     /*
      * Setup for snapshot directory creation
      */
@@ -674,6 +682,9 @@ static int self_cold_start(opal_crs_self_snapshot_t *snapshot) {
      */
     if( OPAL_SUCCESS != (ret = opal_crs_base_extract_expected_component(snapshot->super.local_location, 
                                                                         &component_name, &prev_pid) ) ) {
+        opal_output(mca_crs_self_component.super.output_handle,
+                    "crs:self: self_cold_start: Error: Failed to extract the metadata from the local snapshot (%s). Returned %d.",
+                    snapshot->super.local_location, ret);
         exit_status = ret;
         goto cleanup;
     }
