@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2011 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -162,4 +163,4 @@ OPAL_DECLSPEC extern bool opal_maffinity_setup;
 
 END_C_DECLS
     
-#endif /* OPAL_BASE_MAFFINITY_H */
+#endif /* OPAL_MAFFINITY_BASE_H */
