@@ -2,6 +2,7 @@
  * Copyright (c) 2004-2005 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -22,7 +23,8 @@ int opal_memcpy_base_close(void)
 {
     /* Close all components that are still open (this should only
        happen during laminfo). */
-    mca_base_components_close(0, &opal_memcpy_base_components_opened, NULL);
+    mca_base_components_close(0, &opal_memcpy_base_components_opened, 
+                              NULL, true);
     OBJ_DESTRUCT(&opal_memcpy_base_components_opened);
 
     /* All done */
