@@ -2,7 +2,7 @@
  * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2005 The University of Tennessee and The University
+ * Copyright (c) 2004-2007 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
@@ -10,6 +10,7 @@
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2008	   Sun Microsystems, Inc.  All rights reserved.
+ * Copyright (c) 2010	   Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -29,7 +30,16 @@ BEGIN_C_DECLS
 /** version string of opal */
 OPAL_DECLSPEC extern const char opal_version_string[];
 
-OPAL_DECLSPEC extern bool opal_mmap_on_nfs_warning;
+/* profile flag */
+OPAL_DECLSPEC extern bool opal_profile;
+OPAL_DECLSPEC extern char *opal_profile_file;
+
+/* Size of a cache line.  To be replaced with real hwloc info (in
+   trunk/v1.5 and beyond, only), but for the moment, just move it here
+   so that we can remove opal/include/sys/cache.h whose only purpose
+   is life is to #define CACHE_LINE_SIZE (and has a conflict on
+   NetBSD). */
+OPAL_DECLSPEC extern int opal_cache_line_size;
 
 /**
  * Initialize the OPAL layer, including the MCA system.
@@ -40,7 +50,7 @@ OPAL_DECLSPEC extern bool opal_mmap_on_nfs_warning;
  * \note If this function is called, opal_init_util() should *not* be
  * called.
  */
-OPAL_DECLSPEC int opal_init(void);
+OPAL_DECLSPEC int opal_init(int* pargc, char*** pargv);
 
 /**
  * Finalize the OPAL layer, including the MCA system. 
@@ -62,7 +72,7 @@ OPAL_DECLSPEC int opal_finalize(void);
  * \note If this function is called, opal_init() should *not*
  * be called.
  */
-OPAL_DECLSPEC int opal_init_util(void);
+OPAL_DECLSPEC int opal_init_util(int* pargc, char*** pargv);
 
 /**
  * Finalize the OPAL layer, excluding the MCA system. 
