@@ -13,6 +13,8 @@
  *                         reserved. 
  * Copyright (c) 2008-2010 Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2009      Oak Ridge National Labs.  All rights reserved.
+ * Copyright (c) 2011      Los Alamos National Security, LLC.
+ *                         All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -33,6 +35,7 @@
 #include "opal/mca/base/mca_base_param.h"
 #include "opal/threads/mutex.h"
 #include "opal/mca/paffinity/base/base.h"
+#include "opal/mca/shmem/base/base.h"
 
 int opal_register_params(void)
 {
@@ -112,6 +115,12 @@ int opal_register_params(void)
         return ret;
     }
 
+    /* shmem base also has a few parameters */
+    ret = opal_shmem_base_register_params();
+    if (OPAL_SUCCESS != ret) {
+        return ret;
+    }
+
     /* Paffinity base also has some parameters */
     return opal_paffinity_base_register_params();
 }
