@@ -9,6 +9,8 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2007      Los Alamos National Security, LLC.  All rights
+ *                         reserved. 
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -30,15 +32,15 @@
  * available.
  */
 
+#include "opal_config.h"
 
-#if OMPI_HAVE_POSIX_THREADS
+#if OPAL_HAVE_POSIX_THREADS
 #ifdef HAVE_PTHREAD_H
 #include <pthread.h>
 #endif
 #include <errno.h>
 #include <stdio.h>
-#endif
-#if OMPI_HAVE_SOLARIS_THREADS
+#elif OPAL_HAVE_SOLARIS_THREADS
 #include <thread.h>
 #include <synch.h>
 #endif
@@ -46,20 +48,25 @@
 #include "opal/class/opal_object.h"
 #include "opal/sys/atomic.h"
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
+
 struct opal_mutex_t {
     opal_object_t super;
-#if OMPI_HAVE_POSIX_THREADS
+
+#if OPAL_HAVE_POSIX_THREADS
     pthread_mutex_t m_lock_pthread;
-#endif
-#if OMPI_HAVE_SOLARIS_THREADS
+#elif OPAL_HAVE_SOLARIS_THREADS
     mutex_t m_lock_solaris;
 #endif
+
+#if !OPAL_HAVE_THREAD_SUPPORT && OPAL_ENABLE_DEBUG
+    int m_lock_debug;
+    const char *m_lock_file;
+    int m_lock_line;
+#endif
+
     opal_atomic_lock_t m_lock_atomic;
 };
-
 OPAL_DECLSPEC OBJ_CLASS_DECLARATION(opal_mutex_t);
 
 /************************************************************************
@@ -68,7 +75,7 @@ OPAL_DECLSPEC OBJ_CLASS_DECLARATION(opal_mutex_t);
  *
  ************************************************************************/
 
-#if OMPI_HAVE_POSIX_THREADS
+#if OPAL_HAVE_POSIX_THREADS
 
 /************************************************************************
  * POSIX threads
@@ -76,7 +83,7 @@ OPAL_DECLSPEC OBJ_CLASS_DECLARATION(opal_mutex_t);
 
 static inline int opal_mutex_trylock(opal_mutex_t *m)
 {
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
     int ret = pthread_mutex_trylock(&m->m_lock_pthread);
     if (ret == EDEADLK) {
         errno = ret;
@@ -91,7 +98,7 @@ static inline int opal_mutex_trylock(opal_mutex_t *m)
 
 static inline void opal_mutex_lock(opal_mutex_t *m)
 {
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
     int ret = pthread_mutex_lock(&m->m_lock_pthread);
     if (ret == EDEADLK) {
         errno = ret;
@@ -105,7 +112,7 @@ static inline void opal_mutex_lock(opal_mutex_t *m)
 
 static inline void opal_mutex_unlock(opal_mutex_t *m)
 {
-#if OMPI_ENABLE_DEBUG
+#if OPAL_ENABLE_DEBUG
     int ret = pthread_mutex_unlock(&m->m_lock_pthread);
     if (ret == EPERM) {
         errno = ret;
@@ -117,7 +124,7 @@ static inline void opal_mutex_unlock(opal_mutex_t *m)
 #endif
 }
 
-#elif OMPI_HAVE_SOLARIS_THREADS
+#elif OPAL_HAVE_SOLARIS_THREADS
 
 /************************************************************************
  * Solaris threads
@@ -217,7 +224,6 @@ static inline void opal_mutex_atomic_unlock(opal_mutex_t *m)
 
 #endif
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
+
 #endif                          /* OPAL_MUTEX_UNIX_H */
