@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
  * Copyright (c) 2004-2006 The University of Tennessee and The University
@@ -52,9 +52,7 @@
 
 #include "opal_config.h"
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
 /**
  * Convert a size_t to an int.
@@ -63,21 +61,19 @@ extern "C" {
  * @param out The output int value.
  * @param want_check Whether to check for truncation or not
  *
- * @returns OMPI_SUCESS If all went well
- * @returns OMPI_NOT_SUPPORTED if the size_t value was truncated
+ * @returns OPAL_SUCESS If all went well
+ * @returns OPAL_NOT_SUPPORTED if the size_t value was truncated
  *
  * The conversion will always occur.  However, if the size_t value was
  * truncated (i.e., sizeof(size_t) > sizeof(int), and the cast down to
- * the int actually changed the value), OMPI_NOT_SUPPORTED will be
+ * the int actually changed the value), OPAL_NOT_SUPPORTED will be
  * returned.
  *
  * On platforms where sizeof(size_t) <= sizeof(int), this function
  * will aways return OPAL_SUCCESS.
  */
-OPAL_DECLSPEC int opal_size2int(size_t in, int *out, bool want_check);
+OPAL_DECLSPEC int opal_size2int(size_t in, int *out, bool want_check) __opal_attribute_nonnull__(2);
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 
 #endif
