@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
  * Copyright (c) 2004-2005 The University of Tennessee and The University
@@ -19,9 +19,9 @@
 #ifndef OPAL_FEW_H
 #define OPAL_FEW_H
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+#include "opal_config.h"
+
+BEGIN_C_DECLS
 	
 /**
  *  Forks, execs, and waits for a subordinate program
@@ -55,7 +55,5 @@ extern "C" {
  */
 OPAL_DECLSPEC int opal_few(char *argv[], int *status);
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
-#endif /* OMPI_FEW_H */
+END_C_DECLS
+#endif /* OPAL_FEW_H */
