@@ -70,10 +70,8 @@
 #include <ifaddrs.h>
 #endif
 
-#include "opal/class/opal_list.h"
 #include "opal/util/net.h"
 #include "opal/util/output.h"
-#include "opal/util/strncpy.h"
 #include "opal/util/argv.h"
 #include "opal/util/show_help.h"
 #include "opal/constants.h"
@@ -343,7 +341,7 @@ opal_net_get_hostname(const struct sockaddr *addr)
         opal_output(0, "opal_sockaddr2str: malloc() failed\n");
         return NULL;
     }
-    OMPI_DEBUG_ZERO(*name);
+    OPAL_DEBUG_ZERO(*name);
 
     switch (addr->sa_family) {
     case AF_INET:
