@@ -1,14 +1,15 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2005 The University of Tennessee and The University
+ * Copyright (c) 2004-2008 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2008      Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -18,14 +19,16 @@
  * @file
  */
 
-#ifndef OMPI_STACKTRACE_H
-#define OMPI_STACKTRACE_H
+#ifndef OPAL_STACKTRACE_H
+#define OPAL_STACKTRACE_H
 
 #include "opal_config.h"
 
-#ifdef HAVE_SIGNAL_H
-#include <signal.h>
-#endif
+/**
+ * Output the current stack trace (not including the call to this
+ * function) to the stream indicated.
+ */
+OPAL_DECLSPEC void opal_stackframe_output(int stream);
 
 /**
  * Here we register the opal_show_stackframe function for signals
@@ -37,6 +40,6 @@
  *    is not a valid signal-number
  *               
  */
-OMPI_DECLSPEC int opal_util_register_stackhandlers (void);
+OPAL_DECLSPEC int opal_util_register_stackhandlers (void);
 
-#endif /* OMPI_STACKTRACE_H */
+#endif /* OPAL_STACKTRACE_H */
