@@ -19,37 +19,48 @@
 #ifndef OMPI_MISC_H
 #define OMPI_MISC_H
 
+#include <stdio.h>
 #include <stdlib.h>
 
 #define _SC_PAGESIZE 0
 #define _SC_OPEN_MAX 1
 
+#if 0
 /* currently, this is a memory leak */
 static __inline char* getenv (const char *name)
 {
     int ret;
     char *buffer;
-    DWORD length = GetEnvironmentVariable( name, NULL, 0 );
+    DWORD length = GetEnvironmentVariable( (LPCSTR)name, NULL, 0 );
 
     if( 0 == length ) return NULL;
     buffer = (char *)malloc(sizeof(char) * length);
-    ret = GetEnvironmentVariable(name, buffer, length);
+    ret = GetEnvironmentVariable((LPCSTR)name, (LPSTR)buffer, length);
     return (ret > 0) ? buffer: NULL;
 }
 
 
-static __inline int setenv (const char *name, const char *value, int rewrite) {
-
+static __inline int setenv (const char *name, const char *value, int rewrite)
+{
+    int ret;
+    if( 0 == rewrite  ) {
+        DWORD length = 0;
+        if( 0 == (length = GetEnvironmentVariable( (LPCSTR)name, NULL, length )) ) {
+            if( ERROR_ENVVAR_NOT_FOUND == GetLastError() ) {  /* do not exist */
+                return 0;
+            }
+        }
+    }
     /* just push it back to the windows thingy */
-    int ret = SetEnvironmentVariable (name, value);
+    ret = SetEnvironmentVariable ((LPCSTR)name, (LPCSTR)value);
     return (0 != ret)? 1: 0;
 }
+#endif
 
 static __inline unsigned int sleep(unsigned int seconds) {
 
-    /* microsoft sleep is in milliseconds. Note: interrupt beaviour has
-      not yet been handled */
-    Sleep(seconds * 100);
+    /* Allow interruptions */
+    SleepEx(seconds * 1000, TRUE);
     return 0;
 }
 
@@ -59,18 +70,16 @@ static __inline size_t sysconf(int option) {
     
     SYSTEM_INFO sys_info;
 
-    /* hardcoded on windows ... The maximum limit seems to be 2048 but
-     * it requires a call to _setmaxstdio.
-     */
-    if( _SC_OPEN_MAX == option )
-        return 512;
+    if( _SC_OPEN_MAX == option ) {
+        return _getmaxstdio();
+    }
 
     GetSystemInfo(&sys_info);
     if (_SC_PAGESIZE == option){
         return (size_t)sys_info.dwPageSize;
     }
     printf( "This functionality is not supported: line: %d\tfile: %s\n",
-            __LINE__, __FILE__);
+            __LINE__, __FILE__ );
     abort();
     return 0;
 }
