@@ -19,21 +19,18 @@
 #ifndef OMPI_PROCESS_H
 #define OMPI_PROCESS_H
 
+#include "opal_config.h"
+
 #ifndef OMPI_WIN_COMPAT_H
 #error This file is supposed to be included only from win_compat.h
 #endif  /* OMPI_WIN_COMPAT_H */
 
-#if defined(c_plusplus) || defined (__cplusplus)
-extern "C"
-{
-#endif
+BEGIN_C_DECLS
 
-OMPI_DECLSPEC pid_t waitpid (pid_t pid, int *status, int options) ;
+OPAL_DECLSPEC pid_t waitpid (pid_t pid, int *status, int options) ;
 
-OMPI_DECLSPEC int kill(pid_t pid, int sig) ;
+OPAL_DECLSPEC int kill(pid_t pid, int sig) ;
 
-#if defined(c_plusplus) || defined (__cplusplus)
-}
-#endif
+END_C_DECLS
 
 #endif				/* OMPI_PROCESS_H */
