@@ -98,7 +98,10 @@ enum {
     ORTE_ERR_FAILED_TO_START                = (ORTE_ERR_BASE - 26),
     ORTE_ERR_FILE_NOT_EXECUTABLE            = (ORTE_ERR_BASE - 27),
     ORTE_ERR_HNP_COULD_NOT_START            = (ORTE_ERR_BASE - 28),
-    ORTE_ERR_SYS_LIMITS_SOCKETS             = (ORTE_ERR_BASE - 29)
+    ORTE_ERR_SYS_LIMITS_SOCKETS             = (ORTE_ERR_BASE - 29),
+    ORTE_ERR_SOCKET_NOT_AVAILABLE           = (ORTE_ERR_BASE - 30),
+    ORTE_ERR_SYSTEM_WILL_BOOTSTRAP          = (ORTE_ERR_BASE - 31),
+    ORTE_ERR_COMM_DISABLED                  = (ORTE_ERR_BASE - 32)
 };
 
 #define ORTE_ERR_MAX                      (ORTE_ERR_BASE - 100)
