@@ -25,6 +25,10 @@
 #endif
 #include <stdlib.h>
 
+#if WANT_PMI_SUPPORT
+#include <pmi.h>
+#endif
+
 #include "opal/util/trace.h"
 #include "opal/util/output.h"
 
@@ -51,6 +55,38 @@ void orte_errmgr_base_log(int error_code, char *filename, int line)
                 ORTE_ERROR_NAME(error_code), filename, line);
 }
 
+#if WANT_PMI_SUPPORT
+/* useful util */
+char* orte_errmgr_base_pmi_error(int pmi_err)
+{
+    char * err_msg;
+
+    switch(pmi_err) {
+        case PMI_FAIL: err_msg = "Operation failed"; break;
+        case PMI_ERR_INIT: err_msg = "PMI is not initialized"; break;
+        case PMI_ERR_NOMEM: err_msg = "Input buffer not large enough"; break;
+        case PMI_ERR_INVALID_ARG: err_msg = "Invalid argument"; break;
+        case PMI_ERR_INVALID_KEY: err_msg = "Invalid key argument"; break;
+        case PMI_ERR_INVALID_KEY_LENGTH: err_msg = "Invalid key length argument"; break;
+        case PMI_ERR_INVALID_VAL: err_msg = "Invalid value argument"; break;
+        case PMI_ERR_INVALID_VAL_LENGTH: err_msg = "Invalid value length argument"; break;
+        case PMI_ERR_INVALID_LENGTH: err_msg = "Invalid length argument"; break;
+        case PMI_ERR_INVALID_NUM_ARGS: err_msg = "Invalid number of arguments"; break;
+        case PMI_ERR_INVALID_ARGS: err_msg = "Invalid args argument"; break;
+        case PMI_ERR_INVALID_NUM_PARSED: err_msg = "Invalid num_parsed length argument"; break;
+        case PMI_ERR_INVALID_KEYVALP: err_msg = "Invalid keyvalp argument"; break;
+        case PMI_ERR_INVALID_SIZE: err_msg = "Invalid size argument"; break;
+#if defined(PMI_ERR_INVALID_KVS)
+	/* pmi.h calls this a valid return code but mpich doesn't define it (slurm does). wtf */
+        case PMI_ERR_INVALID_KVS: err_msg = "Invalid kvsname argument"; break;
+#endif
+        case PMI_SUCCESS: err_msg = "Success"; break;
+        default: err_msg = "Unkown error";
+    }
+    return err_msg;
+}
+#endif
+
 void orte_errmgr_base_proc_aborted_not_avail(orte_process_name_t *name, int exit_code)
 {
     return;
