@@ -39,9 +39,6 @@
 #include "orte/mca/routed/base/base.h"
 #include "orte/mca/errmgr/errmgr.h"
 #include "orte/mca/grpcomm/base/base.h"
-#if ORTE_ENABLE_MULTICAST
-#include "orte/mca/rmcast/base/base.h"
-#endif
 #include "orte/mca/plm/plm.h"
 #include "orte/mca/filem/base/base.h"
 #if OPAL_ENABLE_FT_CR == 1
@@ -103,20 +100,6 @@ int orte_ess_base_app_setup(void)
         goto error;
     }
     
-    /* multicast */
-#if ORTE_ENABLE_MULTICAST
-    if (ORTE_SUCCESS != (ret = orte_rmcast_base_open())) {
-        ORTE_ERROR_LOG(ret);
-        error = "orte_rmcast_base_open";
-        goto error;
-    }
-    if (ORTE_SUCCESS != (ret = orte_rmcast_base_select())) {
-        ORTE_ERROR_LOG(ret);
-        error = "orte_rmcast_base_select";
-        goto error;
-    }
-#endif
-    
     /* non-daemon/HNP apps can only have the default proxy PLM
      * module open - provide a chance for it to initialize
      */
@@ -255,11 +238,6 @@ int orte_ess_base_app_finalize(void)
     
     orte_wait_finalize();
     
-    /* close the multicast */
-#if ORTE_ENABLE_MULTICAST
-    orte_rmcast_base_close();
-#endif
-    
     /* now can close the rml and its friendly group comm */
     orte_grpcomm_base_close();
     orte_routed_base_close();
