@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
+ * Copyright (c) 2004-2010 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2005 The University of Tennessee and The University
+ * Copyright (c) 2004-2009 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
@@ -28,24 +28,22 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#include <stdlib.h>
 
 #include "opal/event/event.h"
-#include "opal/threads/mutex.h"
 #include "opal/runtime/opal.h"
-#include "opal/runtime/opal_cr.h"
-#include "opal/class/opal_pointer_array.h"
+#include "opal/mca/paffinity/paffinity.h"
 
 #include "orte/util/show_help.h"
 #include "opal/mca/mca.h"
 #include "opal/mca/base/base.h"
 #include "opal/mca/base/mca_base_param.h"
-#include "opal/util/os_path.h"
-#include "opal/util/cmd_line.h"
+#include "opal/util/output.h"
 #include "opal/util/malloc.h"
 #include "opal/util/argv.h"
 
 #include "orte/mca/rml/base/base.h"
-#include "orte/mca/rml/base/rml_contact.h"
+#include "orte/mca/rml/rml_types.h"
 #include "orte/mca/routed/base/base.h"
 #include "orte/mca/routed/routed.h"
 #include "orte/mca/errmgr/base/base.h"
@@ -55,17 +53,16 @@
 #include "orte/mca/ess/ess.h"
 #include "orte/mca/ras/base/base.h"
 #include "orte/mca/plm/base/base.h"
-#include "orte/mca/odls/base/base.h"
 
 #include "orte/mca/rmaps/base/base.h"
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
 #include "orte/mca/snapc/base/base.h"
 #endif
 #include "orte/mca/filem/base/base.h"
 #include "orte/util/proc_info.h"
 #include "orte/util/session_dir.h"
-#include "orte/util/hnp_contact.h"
 #include "orte/util/name_fns.h"
+#include "orte/util/nidmap.h"
 
 #include "orte/runtime/runtime.h"
 #include "orte/runtime/orte_wait.h"
@@ -78,46 +75,49 @@
 
 static int env_set_name(void);
 
-static int rte_init(char flags);
+static int rte_init(void);
 static int rte_finalize(void);
-static bool proc_is_local(orte_process_name_t *proc);
+static uint8_t proc_get_locality(orte_process_name_t *proc);
+static orte_vpid_t proc_get_daemon(orte_process_name_t *proc);
 static char* proc_get_hostname(orte_process_name_t *proc);
-static uint32_t proc_get_arch(orte_process_name_t *proc);
 static orte_local_rank_t proc_get_local_rank(orte_process_name_t *proc);
 static orte_node_rank_t proc_get_node_rank(orte_process_name_t *proc);
-static int update_arch(orte_process_name_t *proc, uint32_t arch);
+static int update_pidmap(opal_byte_object_t *bo);
+static int update_nidmap(opal_byte_object_t *bo);
 
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
 static int rte_ft_event(int state);
-static int ess_env_ft_event_update_process_info(orte_process_name_t proc, pid_t pid);
 #endif
 
 orte_ess_base_module_t orte_ess_env_module = {
     rte_init,
     rte_finalize,
     orte_ess_base_app_abort,
-    proc_is_local,
+    proc_get_locality,
+    proc_get_daemon,
     proc_get_hostname,
-    proc_get_arch,
     proc_get_local_rank,
     proc_get_node_rank,
-    update_arch,
-#if OPAL_ENABLE_FT == 1
+    update_pidmap,
+    update_nidmap,
+#if OPAL_ENABLE_FT_CR == 1
     rte_ft_event
 #else
     NULL
 #endif
 };
 
-static opal_pointer_array_t nidmap;
-static opal_pointer_array_t jobmap;
-static orte_vpid_t nprocs;
+/*
+ * Local variables
+ */
+static orte_node_rank_t my_node_rank=ORTE_NODE_RANK_INVALID;
 
-static int rte_init(char flags)
+static int rte_init(void)
 {
     int ret;
     char *error = NULL;
-    orte_jmap_t *jmap;
+    char **hosts = NULL;
+    char *nodelist;
 
     /* run the prolog */
     if (ORTE_SUCCESS != (ret = orte_ess_base_std_prolog())) {
@@ -131,51 +131,51 @@ static int rte_init(char flags)
     /* if I am a daemon, complete my setup using the
      * default procedure
      */
-    if (orte_process_info.daemon) {
-        if (ORTE_SUCCESS != (ret = orte_ess_base_orted_setup())) {
+    if (ORTE_PROC_IS_DAEMON) {
+        /* get the list of nodes used for this job */
+        nodelist = getenv("OMPI_MCA_orte_nodelist");
+        
+        if (NULL != nodelist) {
+            /* split the node list into an argv array */
+            hosts = opal_argv_split(nodelist, ',');
+        }
+        if (ORTE_SUCCESS != (ret = orte_ess_base_orted_setup(hosts))) {
             ORTE_ERROR_LOG(ret);
             error = "orte_ess_base_orted_setup";
             goto error;
         }
-        
-    } else if (orte_process_info.tool) {
+        opal_argv_free(hosts);
+        return ORTE_SUCCESS;
+    }
+    
+    if (ORTE_PROC_IS_TOOL) {
         /* otherwise, if I am a tool proc, use that procedure */
         if (ORTE_SUCCESS != (ret = orte_ess_base_tool_setup())) {
             ORTE_ERROR_LOG(ret);
             error = "orte_ess_base_tool_setup";
             goto error;
         }
+        /* as a tool, I don't need a nidmap - so just return now */
+        return ORTE_SUCCESS;
         
-    } else {
-        /* otherwise, I must be an application process - use
-         * the default procedure to finish my setup
-         */
-        if (ORTE_SUCCESS != (ret = orte_ess_base_app_setup())) {
-            ORTE_ERROR_LOG(ret);
-            error = "orte_ess_base_app_setup";
-            goto error;
-        }
-        
-        /* setup the nidmap arrays */
-        OBJ_CONSTRUCT(&nidmap, opal_pointer_array_t);
-        opal_pointer_array_init(&nidmap, 8, INT32_MAX, 8);
-        
-        /* setup array of jmaps */
-        OBJ_CONSTRUCT(&jobmap, opal_pointer_array_t);
-        opal_pointer_array_init(&jobmap, 1, INT32_MAX, 1);
-        jmap = OBJ_NEW(orte_jmap_t);
-        jmap->job = ORTE_PROC_MY_NAME->jobid;
-        opal_pointer_array_add(&jobmap, jmap);
-        
-        /* if one was provided, build my nidmap */
-        if (ORTE_SUCCESS != (ret = orte_ess_base_build_nidmap(orte_process_info.sync_buf,
-                                                              &nidmap, &jmap->pmap, &nprocs))) {
-            ORTE_ERROR_LOG(ret);
-            error = "orte_ess_base_build_nidmap";
-            goto error;
-        }
     }
-
+    
+    /* otherwise, I must be an application process - use
+     * the default procedure to finish my setup
+     */
+    if (ORTE_SUCCESS != (ret = orte_ess_base_app_setup())) {
+        ORTE_ERROR_LOG(ret);
+        error = "orte_ess_base_app_setup";
+        goto error;
+    }
+    
+    /* if one was provided, build my nidmap */
+    if (ORTE_SUCCESS != (ret = orte_util_nidmap_init(orte_process_info.sync_buf))) {
+        ORTE_ERROR_LOG(ret);
+        error = "orte_util_nidmap_init";
+        goto error;
+    }
+    
     return ORTE_SUCCESS;
 
 error:
@@ -189,59 +189,49 @@ error:
 static int rte_finalize(void)
 {
     int ret;
-    orte_nid_t **nids;
-    orte_jmap_t **jmaps;
-    int32_t i;
     
     /* if I am a daemon, finalize using the default procedure */
-    if (orte_process_info.daemon) {
+    if (ORTE_PROC_IS_DAEMON) {
         if (ORTE_SUCCESS != (ret = orte_ess_base_orted_finalize())) {
             ORTE_ERROR_LOG(ret);
         }
-    } else if (orte_process_info.tool) {
+    } else if (ORTE_PROC_IS_TOOL) {
         /* otherwise, if I am a tool proc, use that procedure */
         if (ORTE_SUCCESS != (ret = orte_ess_base_tool_finalize())) {
             ORTE_ERROR_LOG(ret);
         }
+        /* as a tool, I didn't create a nidmap - so just return now */
+        return ret;
     } else {
-        /* otherwise, I must be an application process - deconstruct
-         * my nidmap and jobmap arrays
+        /* otherwise, I must be an application process
+         * use the default procedure to finish
          */
-        nids = (orte_nid_t**)nidmap.addr;
-        for (i=0; i < nidmap.size && NULL != nids[i]; i++) {
-            OBJ_RELEASE(nids[i]);
-        }
-        OBJ_DESTRUCT(&nidmap);
-        jmaps = (orte_jmap_t**)jobmap.addr;
-        for (i=0; i < jobmap.size && NULL != jmaps[i]; i++) {
-            OBJ_RELEASE(jmaps[i]);
-        }
-        OBJ_DESTRUCT(&jobmap);
-        
-        /* use the default procedure to finish */
         if (ORTE_SUCCESS != (ret = orte_ess_base_app_finalize())) {
             ORTE_ERROR_LOG(ret);
         }
     }
     
+    /* deconstruct the nidmap and jobmap arrays */
+    orte_util_nidmap_finalize();
+    
     return ret;    
 }
 
-static bool proc_is_local(orte_process_name_t *proc)
+static uint8_t proc_get_locality(orte_process_name_t *proc)
 {
     orte_nid_t *nid;
     
-    if (NULL == (nid = orte_ess_base_lookup_nid(&nidmap, &jobmap, proc))) {
+    if (NULL == (nid = orte_util_lookup_nid(proc))) {
         ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
-        return false;
+        return OPAL_PROC_NON_LOCAL;
     }
     
     if (nid->daemon == ORTE_PROC_MY_DAEMON->vpid) {
         OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
-                             "%s ess:env: proc %s is LOCAL",
+                             "%s ess:env: proc %s on LOCAL NODE",
                              ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
                              ORTE_NAME_PRINT(proc)));
-        return true;
+        return (OPAL_PROC_ON_NODE | OPAL_PROC_ON_CU | OPAL_PROC_ON_CLUSTER);
     }
 
     OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
@@ -249,15 +239,36 @@ static bool proc_is_local(orte_process_name_t *proc)
                          ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
                          ORTE_NAME_PRINT(proc)));
     
-    return false;
+    return OPAL_PROC_NON_LOCAL;
     
 }
 
+static orte_vpid_t proc_get_daemon(orte_process_name_t *proc)
+{
+    orte_nid_t *nid;
+
+    if( ORTE_JOBID_IS_DAEMON(proc->jobid) ) {
+        return proc->vpid;
+    }
+
+    if (NULL == (nid = orte_util_lookup_nid(proc))) {
+        return ORTE_VPID_INVALID;
+    }
+    
+    OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
+                         "%s ess:env: proc %s is hosted by daemon %s",
+                         ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
+                         ORTE_NAME_PRINT(proc),
+                         ORTE_VPID_PRINT(nid->daemon)));
+    
+    return nid->daemon;
+}
+
 static char* proc_get_hostname(orte_process_name_t *proc)
 {
     orte_nid_t *nid;
         
-    if (NULL == (nid = orte_ess_base_lookup_nid(&nidmap, &jobmap, proc))) {
+    if (NULL == (nid = orte_util_lookup_nid(proc))) {
         ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
         return NULL;
     }
@@ -271,51 +282,13 @@ static char* proc_get_hostname(orte_process_name_t *proc)
     return nid->name;
 }
 
-static uint32_t proc_get_arch(orte_process_name_t *proc)
-{
-    orte_nid_t *nid;
-    
-    if (NULL == (nid = orte_ess_base_lookup_nid(&nidmap, &jobmap, proc))) {
-        ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
-        return 0;
-    }
-    
-    OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
-                         "%s ess:env: proc %s has arch %0x",
-                         ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
-                         ORTE_NAME_PRINT(proc),
-                         nid->arch));
-    
-    return nid->arch;
-}
-
-static int update_arch(orte_process_name_t *proc, uint32_t arch)
-{
-    orte_nid_t *nid;
-    
-    if (NULL == (nid = orte_ess_base_lookup_nid(&nidmap, &jobmap, proc))) {
-        ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
-        return ORTE_ERR_NOT_FOUND;
-    }
-    
-    OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
-                         "%s ess:env: updating proc %s to arch %0x",
-                         ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
-                         ORTE_NAME_PRINT(proc),
-                         arch));
-    
-    nid->arch = arch;
-    
-    return ORTE_SUCCESS;
-}
-
 static orte_local_rank_t proc_get_local_rank(orte_process_name_t *proc)
 {
     orte_pmap_t *pmap;
     
-    if (NULL == (pmap = orte_ess_base_lookup_pmap(&jobmap, proc))) {
+    if (NULL == (pmap = orte_util_lookup_pmap(proc))) {
         ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
-        return UINT8_MAX;
+        return ORTE_LOCAL_RANK_INVALID;
     }    
     
     OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
@@ -331,9 +304,19 @@ static orte_node_rank_t proc_get_node_rank(orte_process_name_t *proc)
 {
     orte_pmap_t *pmap;
     
-    if (NULL == (pmap = orte_ess_base_lookup_pmap(&jobmap, proc))) {
-        ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
-        return UINT8_MAX;
+    /* is this me? */
+    if (proc->jobid == ORTE_PROC_MY_NAME->jobid &&
+        proc->vpid == ORTE_PROC_MY_NAME->vpid) {
+        /* yes it is - reply with my rank. This is necessary
+         * because the pidmap will not have arrived when I
+         * am starting up, and if we use static ports, then
+         * I need to know my node rank during init
+         */
+        return my_node_rank;
+    }
+    
+    if (NULL == (pmap = orte_util_lookup_pmap(proc))) {
+        return ORTE_NODE_RANK_INVALID;
     }    
     
     OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
@@ -345,36 +328,62 @@ static orte_node_rank_t proc_get_node_rank(orte_process_name_t *proc)
     return pmap->node_rank;
 }
 
+static int update_pidmap(opal_byte_object_t *bo)
+{
+    int ret;
+    
+    OPAL_OUTPUT_VERBOSE((2, orte_ess_base_output,
+                         "%s ess:env: updating pidmap",
+                         ORTE_NAME_PRINT(ORTE_PROC_MY_NAME)));
+    
+    /* build the pmap */
+    if (ORTE_SUCCESS != (ret = orte_util_decode_pidmap(bo))) {
+        ORTE_ERROR_LOG(ret);
+    }
+    
+    return ret;
+}
+
+static int update_nidmap(opal_byte_object_t *bo)
+{
+    int rc;
+    /* decode the nidmap - the util will know what to do */
+    if (ORTE_SUCCESS != (rc = orte_util_decode_nodemap(bo))) {
+        ORTE_ERROR_LOG(rc);
+    }    
+    return rc;
+}
+
 static int env_set_name(void)
 {
-    char *jobid_str, *procid_str;
-    int id, rc;
+    char *tmp;
+    int rc;
     orte_jobid_t jobid;
     orte_vpid_t vpid;
     
-    id = mca_base_param_register_string("orte", "ess", "jobid", NULL, NULL);
-    mca_base_param_lookup_string(id, &jobid_str);
-    if (NULL == jobid_str) {
+    mca_base_param_reg_string_name("orte", "ess_jobid", "Process jobid",
+                                   true, false, NULL, &tmp);
+    if (NULL == tmp) {
         ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
         return ORTE_ERR_NOT_FOUND;
     }
-    if (ORTE_SUCCESS != (rc = orte_util_convert_string_to_jobid(&jobid, jobid_str))) {
+    if (ORTE_SUCCESS != (rc = orte_util_convert_string_to_jobid(&jobid, tmp))) {
         ORTE_ERROR_LOG(rc);
         return(rc);
     }
-    free(jobid_str);
+    free(tmp);
     
-    id = mca_base_param_register_string("orte", "ess", "vpid", NULL, NULL);
-    mca_base_param_lookup_string(id, &procid_str);
-    if (NULL == procid_str) {
+    mca_base_param_reg_string_name("orte", "ess_vpid", "Process vpid",
+                                   true, false, NULL, &tmp);
+    if (NULL == tmp) {
         ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
         return ORTE_ERR_NOT_FOUND;
     }
-    if (ORTE_SUCCESS != (rc = orte_util_convert_string_to_vpid(&vpid, procid_str))) {
+    if (ORTE_SUCCESS != (rc = orte_util_convert_string_to_vpid(&vpid, tmp))) {
         ORTE_ERROR_LOG(rc);
         return(rc);
     }
-    free(procid_str);
+    free(tmp);
     
     ORTE_PROC_MY_NAME->jobid = jobid;
     ORTE_PROC_MY_NAME->vpid = vpid;
@@ -382,6 +391,15 @@ static int env_set_name(void)
     OPAL_OUTPUT_VERBOSE((1, orte_ess_base_output,
                          "ess:env set name to %s", ORTE_NAME_PRINT(ORTE_PROC_MY_NAME)));
     
+    /* get my node rank in case we are using static ports - this won't
+     * be present for daemons, so don't error out if we don't have it
+     */
+    mca_base_param_reg_string_name("orte", "ess_node_rank", "Process node rank",
+                                   true, false, NULL, &tmp);
+    if (NULL != tmp) {
+        my_node_rank = strtol(tmp, NULL, 10);
+    }
+    
     /* get the non-name common environmental variables */
     if (ORTE_SUCCESS != (rc = orte_ess_env_get())) {
         ORTE_ERROR_LOG(rc);
@@ -391,14 +409,11 @@ static int env_set_name(void)
     return ORTE_SUCCESS;
 }
 
-#if OPAL_ENABLE_FT == 1
+#if OPAL_ENABLE_FT_CR == 1
 static int rte_ft_event(int state)
 {
     int ret, exit_status = ORTE_SUCCESS;
-    orte_nid_t **nids = NULL;
-    orte_jmap_t *jmap = NULL;
-    orte_jmap_t **jmaps = NULL;
-    int32_t i;
+    orte_proc_type_t svtype;
 
     /******** Checkpoint Prep ********/
     if(OPAL_CRS_CHECKPOINT == state) {
@@ -406,6 +421,7 @@ static int rte_ft_event(int state)
          * Notify SnapC
          */
         if( ORTE_SUCCESS != (ret = orte_snapc.ft_event(OPAL_CRS_CHECKPOINT))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -414,6 +430,7 @@ static int rte_ft_event(int state)
          * Notify Routed
          */
         if( ORTE_SUCCESS != (ret = orte_routed.ft_event(OPAL_CRS_CHECKPOINT))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -422,6 +439,7 @@ static int rte_ft_event(int state)
          * Notify RML -> OOB
          */
         if( ORTE_SUCCESS != (ret = orte_rml.ft_event(OPAL_CRS_CHECKPOINT))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -432,6 +450,7 @@ static int rte_ft_event(int state)
          * Notify RML -> OOB
          */
         if( ORTE_SUCCESS != (ret = orte_rml.ft_event(OPAL_CRS_CONTINUE))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -440,6 +459,7 @@ static int rte_ft_event(int state)
          * Notify Routed
          */
         if( ORTE_SUCCESS != (ret = orte_routed.ft_event(OPAL_CRS_CONTINUE))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -448,6 +468,7 @@ static int rte_ft_event(int state)
          * Notify SnapC
          */
         if( ORTE_SUCCESS != (ret = orte_snapc.ft_event(OPAL_CRS_CONTINUE))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -461,23 +482,7 @@ static int rte_ft_event(int state)
         /*
          * Clear nidmap and jmap
          */
-        nids = (orte_nid_t**)nidmap.addr;
-        for (i=0; i < nidmap.size; i++) {
-            if (NULL == nids[i]) {
-                break;
-            }
-            if (NULL != nids[i]->name) {
-                free(nids[i]->name);
-                nids[i]->name = NULL;
-            }
-        }
-        OBJ_DESTRUCT(&nidmap);
-
-        jmaps = (orte_jmap_t**)jobmap.addr;
-        for (i=0; i < jobmap.size && NULL != jmaps[i]; i++) {
-            OBJ_RELEASE(jmaps[i]);
-        }
-        OBJ_DESTRUCT(&jobmap);
+        orte_util_nidmap_finalize();
 
         /*
          * - Reset Contact information
@@ -490,6 +495,7 @@ static int rte_ft_event(int state)
          * Notify RML -> OOB
          */
         if( ORTE_SUCCESS != (ret = orte_rml.ft_event(OPAL_CRS_RESTART))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -498,13 +504,16 @@ static int rte_ft_event(int state)
          * Restart the routed framework
          * JJH: Lie to the finalize function so it does not try to contact the daemon.
          */
-        orte_process_info.tool = true;
+        svtype = orte_process_info.proc_type;
+        orte_process_info.proc_type = ORTE_PROC_TOOL;
         if (ORTE_SUCCESS != (ret = orte_routed.finalize()) ) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
-        orte_process_info.tool = false;
+        orte_process_info.proc_type = svtype;
         if (ORTE_SUCCESS != (ret = orte_routed.initialize()) ) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -514,10 +523,12 @@ static int rte_ft_event(int state)
          */
         orte_grpcomm.finalize();
         if (ORTE_SUCCESS != (ret = orte_grpcomm.init())) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
         if (ORTE_SUCCESS != (ret = orte_grpcomm.purge_proc_attrs())) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -541,6 +552,7 @@ static int rte_ft_event(int state)
          * RML - Enable communications
          */
         if (ORTE_SUCCESS != (ret = orte_rml.enable_comm())) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -563,6 +575,7 @@ static int rte_ft_event(int state)
          * Notify Routed
          */
         if( ORTE_SUCCESS != (ret = orte_routed.ft_event(OPAL_CRS_RESTART))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -571,38 +584,13 @@ static int rte_ft_event(int state)
          * Notify SnapC
          */
         if( ORTE_SUCCESS != (ret = orte_snapc.ft_event(OPAL_CRS_RESTART))) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
 
-        /*
-         * Send new PID to HNP/daemon
-         * The checkpointer could have used a proxy program to boot us
-         * so the pid that the orted got from fork() may not be the
-         * PID of this application.
-         * - Note: BLCR does this because it tries to preseve the PID
-         *         of the program across checkpointes
-         */
-        if( ORTE_SUCCESS != (ret = ess_env_ft_event_update_process_info(orte_process_info.my_name, getpid())) ) {
-            exit_status = ret;
-            goto cleanup;
-        }
-
-        /*
-         * Refresh nidmap and jmaps structures
-         */
-        OBJ_CONSTRUCT(&nidmap, opal_pointer_array_t);
-        opal_pointer_array_init(&nidmap, 8, INT32_MAX, 8);
-
-        OBJ_CONSTRUCT(&jobmap, opal_pointer_array_t);
-        opal_pointer_array_init(&jobmap, 1, INT32_MAX, 1);
-        jmap = OBJ_NEW(orte_jmap_t);
-        jmap->job = ORTE_PROC_MY_NAME->jobid;
-        opal_pointer_array_add(&jobmap, jmap);
-
         /* if one was provided, build my nidmap */
-        if (ORTE_SUCCESS != (ret = orte_ess_base_build_nidmap(orte_process_info.sync_buf,
-                                                              &nidmap, &jmap->pmap, &nprocs))) {
+        if (ORTE_SUCCESS != (ret = orte_util_nidmap_init(orte_process_info.sync_buf))) {
             ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
@@ -619,43 +607,4 @@ static int rte_ft_event(int state)
 
     return exit_status;
 }
-
-static int ess_env_ft_event_update_process_info(orte_process_name_t proc, pid_t proc_pid)
-{
-    int ret, exit_status = ORTE_SUCCESS;
-    opal_buffer_t buffer;
-    orte_snapc_cmd_flag_t command = ORTE_SNAPC_LOCAL_UPDATE_CMD;
-
-    OBJ_CONSTRUCT(&buffer, opal_buffer_t);
-
-    if (ORTE_SUCCESS != (ret = opal_dss.pack(&buffer, &command, 1, ORTE_SNAPC_CMD )) ) {
-        ORTE_ERROR_LOG(ret);
-        exit_status = ret;
-        goto cleanup;
-    }
-
-    if (ORTE_SUCCESS != (ret = opal_dss.pack(&buffer, &proc, 1, ORTE_NAME))) {
-        ORTE_ERROR_LOG(ret);
-        exit_status = ret;
-        goto cleanup;
-    }
-
-    if (ORTE_SUCCESS != (ret = opal_dss.pack(&buffer, &proc_pid, 1, OPAL_PID))) {
-        ORTE_ERROR_LOG(ret);
-        exit_status = ret;
-        goto cleanup;
-    }
-
-    if (0 > (ret = orte_rml.send_buffer(ORTE_PROC_MY_DAEMON, &buffer, ORTE_RML_TAG_SNAPC, 0))) {
-        ORTE_ERROR_LOG(ret);
-        exit_status = ret;
-        goto cleanup;
-    }
-
- cleanup:
-    OBJ_DESTRUCT(&buffer);
-
-    return exit_status;
-}
 #endif
-
