@@ -7,6 +7,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -101,9 +102,9 @@ int orte_filem_base_select(void)
 
         /* JJH: Todo: Check if none is in the list */
         /* Close all components since none will be used */
-        mca_base_components_close(0, /* Pass 0 to keep this from closing the output handle */
+        mca_base_components_close(orte_filem_base_output,
                                   &orte_filem_base_components_available,
-                                  NULL);
+                                  NULL, false);
         goto skip_select;
     }
 
