@@ -21,11 +21,7 @@
 #define GRPCOMM_BASIC_H
 
 #include "orte_config.h"
-#include "orte/types.h"
 
-#include "opal/threads/mutex.h"
-#include "opal/threads/condition.h"
-#include "opal/class/opal_object.h"
 
 #include "orte/mca/grpcomm/grpcomm.h"
 
