@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -37,7 +38,8 @@ int orte_notifier_base_close(void)
      OpenRTE program, or [possibly] multiple if this is ompi_info) */
     
     mca_base_components_close(orte_notifier_base_output, 
-                              &mca_notifier_base_components_available, NULL);
+                              &mca_notifier_base_components_available, 
+                              NULL, true);
     
     /* All done */
     
