@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -54,7 +55,8 @@ int orte_odls_base_close(void)
     /* Close all available components (only one in this case)  */
 
     mca_base_components_close(orte_odls_globals.output, 
-                              &orte_odls_base.available_components, NULL);
+                              &orte_odls_base.available_components, 
+                              NULL, true);
 
     /* All done */
 
