@@ -21,6 +21,9 @@
 #include "orte_config.h"
 #include "orte/constants.h"
 
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -30,10 +33,11 @@
 
 #include "opal/util/argv.h"
 #include "orte/util/show_help.h"
-#include "opal/util/trace.h"
+#include "orte/runtime/orte_globals.h"
 #include "opal/util/basename.h"
 
 #include "orte/util/name_fns.h"
+#include "orte/util/proc_info.h"
 #include "orte/mca/errmgr/errmgr.h"
 
 #include "orte/mca/filem/filem.h"
@@ -69,7 +73,7 @@ int orte_odls_base_preload_files_app_context(orte_app_context_t* app_context)
 
     /* Define the process set */
     p_set = OBJ_NEW(orte_filem_base_process_set_t);
-    if( orte_process_info.hnp ) {
+    if( ORTE_PROC_IS_HNP ) {
         /* if I am the HNP, then use me as the source */
         p_set->source.jobid = ORTE_PROC_MY_NAME->jobid;
         p_set->source.vpid  = ORTE_PROC_MY_NAME->vpid;
@@ -221,7 +225,7 @@ static int orte_odls_base_preload_append_files(orte_app_context_t* context,
             }
 
             /* If this is the HNP, then source = sink, so use the same path for each local and remote */
-            if( orte_process_info.hnp ) {
+            if( ORTE_PROC_IS_HNP ) {
                 free(remote_targets[i]);
                 remote_targets[i] = strdup(local_ref);
             }
