@@ -19,8 +19,8 @@
  * @file:
  */
 
-#ifndef ORTE_ODLS_H
-#define ORTE_ODLS_H
+#ifndef ORTE_ODLS_DEFAULT_H
+#define ORTE_ODLS_DEFAULT_H
 
 #include "orte_config.h"
 
@@ -43,6 +43,9 @@ int orte_odls_default_component_query(mca_base_module_t **module, int *priority)
 extern orte_odls_base_module_t orte_odls_default_module;
 ORTE_MODULE_DECLSPEC extern orte_odls_base_component_t mca_odls_default_component;
 
+/* dedicated debug output flag */
+ORTE_MODULE_DECLSPEC extern bool orte_odls_default_report_bindings;
+
 END_C_DECLS
 
 #endif /* ORTE_ODLS_H */
