@@ -35,6 +35,9 @@
 #include "orte/mca/odls/base/odls_private.h"
 #include "orte/mca/odls/default/odls_default.h"
 
+/* instantiate a module-global variable */
+bool orte_odls_default_report_bindings;
+
 /*
  * Instantiate the public struct with all of our public information
  * and pointers to our public functions in it
@@ -66,7 +69,6 @@ orte_odls_base_component_t mca_odls_default_component = {
 
 int orte_odls_default_component_open(void)
 {
-    /* nothing to do */
     return ORTE_SUCCESS;
 }
 
@@ -90,12 +92,5 @@ int orte_odls_default_component_query(mca_base_module_t **module, int *priority)
 
 int orte_odls_default_component_close(void)
 {
-    opal_list_item_t *item;
-    
-    /* cleanup state */
-    while (NULL != (item = opal_list_remove_first(&orte_odls_globals.children))) {
-        OBJ_RELEASE(item);
-    }
-
     return ORTE_SUCCESS;
 }
