@@ -30,13 +30,10 @@
 #include "orte/types.h"
 
 #include "opal/mca/mca.h"
-#include "opal/class/opal_list.h"
+#include "opal/class/opal_pointer_array.h"
 
 #include "opal/dss/dss_types.h"
-#include "orte/mca/rmaps/rmaps_types.h"
 #include "orte/mca/rml/rml_types.h"
-#include "orte/runtime/orte_globals.h"
-
 #include "orte/mca/odls/odls_types.h"
 
 BEGIN_C_DECLS
@@ -65,7 +62,7 @@ typedef int (*orte_odls_base_module_launch_local_processes_fn_t)(opal_buffer_t *
 /**
  * Kill the local processes on this node
  */
-typedef int (*orte_odls_base_module_kill_local_processes_fn_t)(orte_jobid_t job, bool set_state);
+typedef int (*orte_odls_base_module_kill_local_processes_fn_t)(opal_pointer_array_t *procs, bool set_state);
 
 /**
  * Signal local processes
@@ -74,7 +71,7 @@ typedef int (*orte_odls_base_module_signal_local_process_fn_t)(const orte_proces
                                                               int32_t signal);
 
 /**
-    * Deliver a message to local processes
+ * Deliver a message to local processes
  */
 typedef int (*orte_odls_base_module_deliver_message_fn_t)(orte_jobid_t job, opal_buffer_t *buffer,
                                                           orte_rml_tag_t tag);
@@ -86,12 +83,6 @@ typedef int (*orte_odls_base_module_require_sync_fn_t)(orte_process_name_t *proc
                                                        opal_buffer_t *buffer,
                                                        bool drop_nidmap);
 
-/**
- * Collect data as part of a collective operation by the procs
- */
-typedef int (*orte_odls_base_module_collect_data_fn_t)(orte_process_name_t *proc, opal_buffer_t *buffer);
-
-
 /**
  * pls module version
  */
@@ -102,7 +93,6 @@ struct orte_odls_base_module_1_3_0_t {
     orte_odls_base_module_signal_local_process_fn_t   		signal_local_procs;
     orte_odls_base_module_deliver_message_fn_t              deliver_message;
     orte_odls_base_module_require_sync_fn_t                 require_sync;
-    orte_odls_base_module_collect_data_fn_t                 collect_data;
 };
 
 /** shorten orte_odls_base_module_1_3_0_t declaration */
