@@ -22,10 +22,10 @@
 #include "orte/constants.h"
 
 #include "opal/mca/mca.h"
+#include "opal/util/output.h"
 #include "opal/mca/base/base.h"
 #include "opal/mca/base/mca_base_param.h"
 
-#include "orte/util/show_help.h"
 
 #include "orte/mca/oob/base/base.h"
 
