@@ -24,6 +24,8 @@
 #define _MCA_OOB_TCP_PEER_H_
 
 #include "orte_config.h"
+#include "orte/types.h"
+
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
@@ -31,10 +33,12 @@
 
 #include "opal/class/opal_list.h"
 #include "opal/threads/mutex.h"
-#include "orte/mca/ns/ns_types.h"
+#include "opal/event/event.h"
+
 #include "oob_tcp_msg.h"
 #include "oob_tcp_addr.h"
-#include "opal/event/event.h"
+
+BEGIN_C_DECLS
 
 /**
  * the state of the connection
@@ -59,6 +63,7 @@ struct mca_oob_tcp_peer_t {
     int peer_retries;                 /**< number of times connection attempt has failed */
     mca_oob_tcp_addr_t* peer_addr;    /**< the addresses of the peer process */
     int peer_sd;                      /**< socket descriptor of the connection */
+    uint16_t peer_current_af;         /**< currently connecting af */
     opal_event_t peer_send_event;     /**< registration with event thread for send events */
     opal_event_t peer_recv_event;     /**< registration with event thread for recv events */
     opal_event_t peer_timer_event;    /**< timer for retrying connection failures */
@@ -88,15 +93,11 @@ typedef struct mca_oob_tcp_peer_t mca_oob_tcp_peer_t;
 #define MCA_OOB_TCP_PEER_RETURN(peer)                                   \
 {                                                                       \
     mca_oob_tcp_peer_shutdown(peer);                                    \
-    orte_hash_table_remove_proc(&mca_oob_tcp_component.tcp_peers, &peer->peer_name); \
+    opal_hash_table_remove_value_uint64(&mca_oob_tcp_component.tcp_peers, orte_util_hash_name(&peer->peer_name)); \
     OPAL_FREE_LIST_RETURN(&mca_oob_tcp_component.tcp_peer_free,         \
                           &peer->super);                                \
 }
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
-
 /*
  * Class declaration.
  */
@@ -156,9 +157,9 @@ int mca_oob_tcp_peer_send_ident(mca_oob_tcp_peer_t* peer);
  */
 void mca_oob_tcp_peer_dequeue_msg(mca_oob_tcp_peer_t* peer, mca_oob_tcp_msg_t* msg);
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+void mca_oob_tcp_peer_dump(mca_oob_tcp_peer_t* peer, const char* msg);
+
+END_C_DECLS
 
 #endif /* _MCA_OOB_TCP_PEER_H */
 
