@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -82,7 +83,8 @@ int orte_plm_base_close(void)
     
     /* Close all open components */
     mca_base_components_close(orte_plm_globals.output, 
-                              &orte_plm_base.available_components, NULL);
+                              &orte_plm_base.available_components, 
+                              NULL, true);
     OBJ_DESTRUCT(&orte_plm_base.available_components);
     
     return ORTE_SUCCESS;
