@@ -2,7 +2,7 @@
  * Copyright (c) 2004-2006 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2009 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2008 High Performance Computing Center Stuttgart, 
  *                         University of Stuttgart.  All rights reserved.
  * $COPYRIGHT$
  * 
@@ -19,9 +19,7 @@
 #include "opal/mca/mca.h"
 #include "orte/mca/plm/plm.h"
 
-#if defined(c_plusplus) || defined(__cplusplus)
-extern "C" {
-#endif
+BEGIN_C_DECLS
 
 struct orte_plm_ccp_component_t {
     orte_plm_base_component_t super;
@@ -32,6 +30,7 @@ struct orte_plm_ccp_component_t {
     char **checked_paths;
     char *stdout_file;
     char *stderr_file;
+    char *job_name;
     bool timing;
 };
 typedef struct orte_plm_ccp_component_t orte_plm_ccp_component_t;
@@ -39,8 +38,6 @@ typedef struct orte_plm_ccp_component_t orte_plm_ccp_component_t;
 ORTE_DECLSPEC extern orte_plm_ccp_component_t mca_plm_ccp_component;
 extern orte_plm_base_module_t orte_plm_ccp_module;
 
-#if defined(c_plusplus) || defined(__cplusplus)
-}
-#endif
+END_C_DECLS
 
 #endif /* ORTE_plm_CCP_EXPORT_H */
