@@ -2,14 +2,15 @@
  * Copyright (c) 2004-2008 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2006 The University of Tennessee and The University
+ * Copyright (c) 2004-2009 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2008-2009 Sun Microsystems, Inc.  All rights reserved.
+ * Copyright (c) 2008      Sun Microsystems, Inc.  All rights reserved.
+ * Copyright (c) 2011      IBM Corporation.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -53,9 +54,7 @@ int orte_plm_rsh_finalize(void);
  * Interface
  */
 int orte_plm_rsh_init(void);
-int orte_plm_rsh_set_hnp_name(void);
 int orte_plm_rsh_launch(orte_job_t *jdata);
-int orte_plm_rsh_terminate_job(orte_jobid_t);
 int orte_plm_rsh_terminate_orteds(void);
 int orte_plm_rsh_signal_job(orte_jobid_t, int32_t);
 
@@ -64,16 +63,15 @@ int orte_plm_rsh_signal_job(orte_jobid_t, int32_t);
  */
 struct orte_plm_rsh_component_t {
     orte_plm_base_component_t super;
-    bool assume_same_shell;
     bool force_rsh;
     bool disable_qrsh;
+    bool using_qrsh;
     bool daemonize_qrsh;
+    bool disable_llspawn;
+    bool using_llspawn;
+    bool daemonize_llspawn;
     int delay;
     int priority;
-    char *agent_param;
-    char** agent_argv;
-    int agent_argc;
-    char* agent_path;
     bool tree_spawn;
     opal_list_t children;
     orte_std_cntr_t num_children;
