@@ -29,6 +29,7 @@
 #include "opal/mca/base/base.h"
 #include "opal/class/opal_list.h"
 #include "opal/util/output.h"
+#include "opal/util/argv.h"
 
 #include "orte/util/show_help.h"
 #include "opal/dss/dss.h"
@@ -91,6 +92,7 @@ int orte_ras_base_allocate(orte_job_t *jdata)
     orte_std_cntr_t i;
     bool override_oversubscribed;
     orte_app_context_t *app;
+    bool default_hostfile_used;
 
     OPAL_OUTPUT_VERBOSE((5, orte_ras_base.ras_output,
                          "%s ras:base:allocate",
@@ -160,6 +162,8 @@ int orte_ras_base_allocate(orte_job_t *jdata)
             return rc;
         }
         OBJ_DESTRUCT(&nodes);
+        /* flag that the allocation is managed */
+        orte_managed_allocation = true;
         goto DISPLAY;
     } else if (orte_allocation_required) {
         /* if nothing was found, and an allocation is
@@ -180,46 +184,9 @@ int orte_ras_base_allocate(orte_job_t *jdata)
     
     /* nothing was found, or no active module was alive. Our next
      * option is to look for a hostfile and assign our global
-     * pool from there. First, we check for a default hostfile
-     * as set by an mca param.
+     * pool from there.
      *
-     * Note that any relative node syntax found in the hostfile will
-     * generate an error in this scenario, so only non-relative syntax
-     * can be present
-     */
-    if (NULL != orte_default_hostfile) {
-        OPAL_OUTPUT_VERBOSE((5, orte_ras_base.ras_output,
-                             "%s ras:base:allocate parsing default hostfile %s",
-                             ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
-                             orte_default_hostfile));
-        
-        /* a default hostfile was provided - parse it */
-        if (ORTE_SUCCESS != (rc = orte_util_add_hostfile_nodes(&nodes,
-                                                               &override_oversubscribed,
-                                                               orte_default_hostfile))) {
-            ORTE_ERROR_LOG(rc);
-            OBJ_DESTRUCT(&nodes);
-            return rc;
-        }
-    }
-    /* if something was found in the default hostfile, we use that as our global
-     * pool - set it and we are done
-     */
-    if (!opal_list_is_empty(&nodes)) {
-        /* store the results in the global resource pool - this removes the
-         * list items
-         */
-        if (ORTE_SUCCESS != (rc = orte_ras_base_node_insert(&nodes, jdata))) {
-            ORTE_ERROR_LOG(rc);
-        }
-        /* update the jdata object with override_oversubscribed flag */
-        jdata->oversubscribe_override = override_oversubscribed;
-        /* cleanup */
-        OBJ_DESTRUCT(&nodes);
-        goto DISPLAY;
-    }
-    
-    /* Individual hostfile names, if given, are included
+     * Individual hostfile names, if given, are included
      * in the app_contexts for this job. We therefore need to
      * retrieve the app_contexts for the job, and then cycle
      * through them to see if anything is there. The parser will
@@ -227,32 +194,72 @@ int orte_ras_base_allocate(orte_job_t *jdata)
      * the resulting list contains the UNION of all nodes specified
      * in hostfiles from across all app_contexts
      *
+     * Any app that has no hostfile but has a dash-host, will have
+     * those nodes added to the list
+     *
+     * Any app that fails to have a hostfile or a dash-host will be given the
+     * default hostfile, if we have it
+     *
      * Note that any relative node syntax found in the hostfiles will
      * generate an error in this scenario, so only non-relative syntax
      * can be present
      */
-    
+    default_hostfile_used = false;
     for (i=0; i < jdata->apps->size; i++) {
         if (NULL == (app = (orte_app_context_t*)opal_pointer_array_get_item(jdata->apps, i))) {
             continue;
         }
         if (NULL != app->hostfile) {
             OPAL_OUTPUT_VERBOSE((5, orte_ras_base.ras_output,
-                                 "%s ras:base:allocate checking hostfile %s",
+                                 "%s ras:base:allocate adding hostfile %s",
                                  ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
                                  app->hostfile));
             
             /* hostfile was specified - parse it and add it to the list */
             if (ORTE_SUCCESS != (rc = orte_util_add_hostfile_nodes(&nodes,
-                                                &override_oversubscribed,
-                                                app->hostfile))) {
+                                                                   &override_oversubscribed,
+                                                                   app->hostfile))) {
                 ORTE_ERROR_LOG(rc);
                 OBJ_DESTRUCT(&nodes);
                 return rc;
             }
+        } else if (NULL != app->dash_host) {
+            OPAL_OUTPUT_VERBOSE((5, orte_ras_base.ras_output,
+                                 "%s ras:base:allocate adding dash_hosts",
+                                 ORTE_NAME_PRINT(ORTE_PROC_MY_NAME)));
+            if (ORTE_SUCCESS != (rc = orte_util_add_dash_host_nodes(&nodes,
+                                                                    &override_oversubscribed,
+                                                                    app->dash_host))) {
+                ORTE_ERROR_LOG(rc);
+                OBJ_DESTRUCT(&nodes);
+                return rc;
+            }
+        } else if (!default_hostfile_used) {
+            if (NULL != orte_default_hostfile) {
+                OPAL_OUTPUT_VERBOSE((5, orte_ras_base.ras_output,
+                                     "%s ras:base:allocate parsing default hostfile %s",
+                                     ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
+                                     orte_default_hostfile));
+        
+                /* a default hostfile was provided - parse it */
+                if (ORTE_SUCCESS != (rc = orte_util_add_hostfile_nodes(&nodes,
+                                                                       &override_oversubscribed,
+                                                                       orte_default_hostfile))) {
+                    ORTE_ERROR_LOG(rc);
+                    OBJ_DESTRUCT(&nodes);
+                    return rc;
+                }
+            }
+            /* only look at it once */
+            default_hostfile_used = true;
+        }
+        /* update the jdata object with override_oversubscribed flag, but don't
+         * overwrite a prior setting to true
+         */
+        if (!jdata->oversubscribe_override) {
+            jdata->oversubscribe_override = override_oversubscribed;
         }
     }
-
     /* if something was found in the hostfile(s), we use that as our global
      * pool - set it and we are done
      */
@@ -262,70 +269,16 @@ int orte_ras_base_allocate(orte_job_t *jdata)
          */
         if (ORTE_SUCCESS != (rc = orte_ras_base_node_insert(&nodes, jdata))) {
             ORTE_ERROR_LOG(rc);
+            OBJ_DESTRUCT(&nodes);
+            return rc;
         }
-        /* update the jdata object with override_oversubscribed flag */
-        jdata->oversubscribe_override = override_oversubscribed;
         /* cleanup */
         OBJ_DESTRUCT(&nodes);
         goto DISPLAY;
     }
-    
-    
-    
-    OPAL_OUTPUT_VERBOSE((5, orte_ras_base.ras_output,
-                         "%s ras:base:allocate nothing found in hostfiles - checking dash-host options",
-                         ORTE_NAME_PRINT(ORTE_PROC_MY_NAME)));
-    
-    /* Our next option is to look for hosts provided via the -host
-     * command line option. If they are present, we declare this
-     * to represent not just a mapping, but to define the global
-     * resource pool in the absence of any other info.
-     *
-     * -host lists are provided as part of the app_contexts for
-     * this job. We therefore need to retrieve the app_contexts
-     * for the job, and then cycle through them to see if anything
-     * is there. The parser will add the -host nodes to our list - i.e.,
-     * the resulting list contains the UNION of all nodes specified
-     * by -host across all app_contexts
-     *
-     * Note that any relative node syntax found in the -host lists will
-     * generate an error in this scenario, so only non-relative syntax
-     * can be present
-     */
-    for (i=0; i < jdata->apps->size; i++) {
-        if (NULL == (app = (orte_app_context_t*)opal_pointer_array_get_item(jdata->apps, i))) {
-            continue;
-        }
-        if (NULL != app->dash_host) {
-            if (ORTE_SUCCESS != (rc = orte_util_add_dash_host_nodes(&nodes,
-                                                    &override_oversubscribed,
-                                                    app->dash_host))) {
-                ORTE_ERROR_LOG(rc);
-                OBJ_DESTRUCT(&nodes);
-                return rc;
-            }
-        }
-    }
 
-    /* if something was found in -host, we use that as our global
-     * pool - set it and we are done
-     */
-    if (!opal_list_is_empty(&nodes)) {
-        /* store the results in the global resource pool - this removes the
-         * list items
-         */
-        if (ORTE_SUCCESS != (rc = orte_ras_base_node_insert(&nodes, jdata))) {
-            ORTE_ERROR_LOG(rc);
-        }
-        /* update the jdata object with override_oversubscribed flag */
-        jdata->oversubscribe_override = override_oversubscribed;
-        /* cleanup */
-        OBJ_DESTRUCT(&nodes);
-        goto DISPLAY;
-    }
-    
     OPAL_OUTPUT_VERBOSE((5, orte_ras_base.ras_output,
-                         "%s ras:base:allocate nothing found in dash-host - checking for rankfile",
+                         "%s ras:base:allocate nothing found in hostfiles or dash-host - checking for rankfile",
                          ORTE_NAME_PRINT(ORTE_PROC_MY_NAME)));
     
     /* Our next option is to look for a rankfile - if one was provided, we
@@ -452,6 +405,9 @@ int orte_ras_base_add_hosts(orte_job_t *jdata)
                 OBJ_DESTRUCT(&nodes);
                 return rc;
             }
+            /* now indicate that this app is to run across it */
+            app->hostfile = app->add_hostfile;
+            app->add_hostfile = NULL;
         }
     }
 
@@ -469,6 +425,12 @@ int orte_ras_base_add_hosts(orte_job_t *jdata)
             continue;
         }
         if (NULL != app->add_host) {
+            if (4 < opal_output_get_verbosity(orte_ras_base.ras_output)) {
+                char *fff = opal_argv_join(app->add_host, ',');
+                opal_output(0, "%s ras:base:add_hosts checking add-host %s",
+                            ORTE_NAME_PRINT(ORTE_PROC_MY_NAME), fff);
+                free(fff);
+            }
             if (ORTE_SUCCESS != (rc = orte_util_add_dash_host_nodes(&nodes,
                                                                     &override_oversubscribed,
                                                                     app->add_host))) {
@@ -476,6 +438,9 @@ int orte_ras_base_add_hosts(orte_job_t *jdata)
                 OBJ_DESTRUCT(&nodes);
                 return rc;
             }
+            /* now indicate that this app is to run across them */
+            app->dash_host = app->add_host;
+            app->add_host = NULL;
         }
     }
     
