@@ -9,6 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -44,7 +45,7 @@ int orte_ras_base_close(void)
         Open RTE program, or [possibly] multiple if this is ompi_info) */
 
         mca_base_components_close(orte_ras_base.ras_output, 
-                                  &orte_ras_base.ras_opened, NULL);
+                                  &orte_ras_base.ras_opened, NULL, true);
   
     return ORTE_SUCCESS;
 }
