@@ -20,8 +20,7 @@
 
 #include "opal/mca/base/base.h"
 #include "opal/mca/base/mca_base_param.h"
-#include "orte/util/show_help.h"
-#include "orte/util/proc_info.h"
+#include "orte/runtime/orte_globals.h"
 #include "orte/util/name_fns.h"
 
 #include "orte/mca/ras/base/ras_private.h"
