@@ -21,15 +21,13 @@
 
 #include <string.h>
 
-#include "orte/util/show_help.h"
 #include "opal/mca/mca.h"
+#include "opal/util/output.h"
 #include "opal/mca/base/base.h"
 
 #include "opal/dss/dss.h"
 #include "orte/mca/errmgr/errmgr.h"
 #include "orte/runtime/orte_globals.h"
-#include "orte/util/name_fns.h"
-#include "orte/util/show_help.h"
 
 #include "orte/mca/rmaps/base/base.h"
 #include "orte/mca/rmaps/base/rmaps_private.h"
@@ -69,9 +67,12 @@ int orte_rmaps_base_map_job(orte_job_t *jdata)
             return ORTE_ERR_OUT_OF_RESOURCE;
         }
         /* load it with the system defaults */
-        map->policy = orte_rmaps_base.policy;
-        map->pernode = orte_rmaps_base.pernode;
+        map->policy = orte_default_mapping_policy;
         map->npernode = orte_rmaps_base.npernode;
+        map->nperboard = orte_rmaps_base.nperboard;
+        map->npersocket = orte_rmaps_base.npersocket;
+        map->cpus_per_rank = orte_rmaps_base.cpus_per_rank;
+        map->stride = orte_rmaps_base.stride;
         map->oversubscribe = orte_rmaps_base.oversubscribe;
         map->display_map = orte_rmaps_base.display_map;
         /* assign the map object to this job */
@@ -92,7 +93,12 @@ int orte_rmaps_base_map_job(orte_job_t *jdata)
     if (jdata->map->display_map) {
         char *output;
         opal_dss.print(&output, NULL, jdata->map, ORTE_JOB_MAP);
-        opal_output(orte_clean_output, "%s", output);
+        if (orte_xml_output) {
+            fprintf(orte_xml_fp, "%s\n", output);
+            fflush(orte_xml_fp);
+        } else {
+            opal_output(orte_clean_output, "%s", output);
+        }
         free(output);
     }
     
