@@ -97,12 +97,11 @@ static int npernode(orte_job_t *jdata)
     opal_list_item_t *item;
     orte_std_cntr_t num_slots;
     orte_node_t *node;
-    int total_procs=0, np, nprocs;
+    int np, nprocs;
     int num_nodes;
     
     /* setup the node list */
     OBJ_CONSTRUCT(&node_list, opal_list_t);
-    total_procs = 0;
    
     /* loop through the app_contexts */
     for(i=0; i < jdata->apps->size; i++) {
@@ -145,11 +144,12 @@ static int npernode(orte_job_t *jdata)
                         goto error;
                     }
                 }
-                total_procs++;
                 nprocs++;
             }
             OBJ_RELEASE(node);
         }
+        /* update the number of procs in the job */
+        jdata->num_procs += nprocs;
         /* if the user requested a specific number of procs and
          * the total number of procs we were able to assign
          * doesn't equal the number requested, then we have a
@@ -171,7 +171,6 @@ static int npernode(orte_job_t *jdata)
             return rc;
         }
     }
-    jdata->num_procs = total_procs;
 
 error:
     while (NULL != (item = opal_list_remove_first(&node_list))) {
@@ -189,12 +188,11 @@ static int nperboard(orte_job_t *jdata)
     opal_list_item_t *item;
     orte_std_cntr_t num_slots;
     orte_node_t *node;
-    int total_procs=0, np, nprocs;
-    int num_boards;
+    int np, nprocs;
+    int num_boards=0;
 
     /* setup the node list */
     OBJ_CONSTRUCT(&node_list, opal_list_t);
-    total_procs = 0;
     
     /* loop through the app_contexts */
     for(i=0; i < jdata->apps->size; i++) {
@@ -239,12 +237,13 @@ static int nperboard(orte_job_t *jdata)
                             goto error;
                         }
                     }
-                    total_procs++;
                     nprocs++;
                 }
             }
             OBJ_RELEASE(node);
         }
+        /* update the number of procs in the job */
+        jdata->num_procs += nprocs;
         /* if the user requested a specific number of procs and
          * the total number of procs we were able to assign
          * doesn't equal the number requested, then we have a
@@ -266,7 +265,6 @@ static int nperboard(orte_job_t *jdata)
             return rc;
         }
     }
-    jdata->num_procs = total_procs;
 
 error:
     while (NULL != (item = opal_list_remove_first(&node_list))) {
@@ -285,12 +283,11 @@ static int npersocket(orte_job_t *jdata)
     opal_list_item_t *item;
     orte_std_cntr_t num_slots;
     orte_node_t *node;
-    int total_procs=0, np, nprocs;
-    int num_sockets;
+    int np, nprocs;
+    int num_sockets=0;
 
     /* setup the node list */
     OBJ_CONSTRUCT(&node_list, opal_list_t);
-    total_procs = 0;
    
     /* loop through the app_contexts */
     for(i=0; i < jdata->apps->size; i++) {
@@ -322,7 +319,7 @@ static int npersocket(orte_job_t *jdata)
                 /* loop through the number of sockets/board */
                 for (n=0; n < node->sockets_per_board && nprocs < np; n++) {
                     /* put the specified number of procs on each socket */
-                    for (j=0; j < jdata->map->npersocket && total_procs < np; j++) {
+                    for (j=0; j < jdata->map->npersocket && nprocs < np; j++) {
                         if (ORTE_SUCCESS != (rc = orte_rmaps_base_claim_slot(jdata, node,
                                                                              jdata->map->cpus_per_rank, app->idx,
                                                                              &node_list, jdata->map->oversubscribe,
@@ -338,13 +335,14 @@ static int npersocket(orte_job_t *jdata)
                             }
                         }
                         /* track the number of procs */
-                        total_procs++;
                         nprocs++;
                     }
                 }
             }
             OBJ_RELEASE(node);
         }
+        /* update the number of procs in the job */
+        jdata->num_procs += nprocs;
         /* if the user requested a specific number of procs and
          * the total number of procs we were able to assign
          * doesn't equal the number requested, then we have a
@@ -366,7 +364,6 @@ static int npersocket(orte_job_t *jdata)
             return rc;
         }
     }
-    jdata->num_procs = total_procs;
     
 error:
     while (NULL != (item = opal_list_remove_first(&node_list))) {
@@ -387,14 +384,13 @@ static int loadbalance(orte_job_t *jdata)
     int i, j;
     opal_list_t node_list;
     orte_std_cntr_t num_nodes, num_slots;
-    int rc=ORTE_SUCCESS, total_procs, np, nprocs;
+    int rc=ORTE_SUCCESS, np, nprocs;
     int ppn = 0;
     opal_list_item_t *item, *start;
     orte_node_t *node;
 
     /* setup */
     OBJ_CONSTRUCT(&node_list, opal_list_t);
-    total_procs = 0;
 
     /* compute total #procs we are going to add and the total number of nodes available */
     for(i=0; i < jdata->apps->size; i++) {
@@ -440,7 +436,6 @@ static int loadbalance(orte_job_t *jdata)
                         goto error;
                     }
                 }
-                total_procs++;
                 nprocs++;
             }
             /* move to next node */
@@ -471,7 +466,6 @@ static int loadbalance(orte_job_t *jdata)
                     goto error;
                 }
             }
-            total_procs++;
             nprocs++;
             /* move to next node */
             if (opal_list_get_end(&node_list) == opal_list_get_next(item)) {
@@ -483,6 +477,8 @@ static int loadbalance(orte_job_t *jdata)
         }
         /* save the bookmark */
         jdata->bookmark = node;
+        /* update the number of procs in the job */
+        jdata->num_procs += nprocs;
         
         /* cleanup */
         while (NULL != (item = opal_list_remove_first(&node_list))) {
@@ -509,8 +505,6 @@ static int loadbalance(orte_job_t *jdata)
             return rc;
         }
     }
-    /* record the number of procs */
-    jdata->num_procs = total_procs;
     
 error:
     while(NULL != (item = opal_list_remove_first(&node_list))) {
