@@ -20,6 +20,9 @@
 #include "orte_config.h"
 #include "orte/constants.h"
 
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
 #ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
