@@ -18,29 +18,44 @@
 
 #include "orte_config.h"
 
-#if HAVE_SYS_TYPES_H
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif  /* HAVE_SYS_TYPES_H */
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif  /* HAVE_UNISTD_H */
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif /* HAVE_SYS_TYPES_H */
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif /* HAVE_SYS_STAT_H */
+#ifdef HAVE_DIRENT_H
+#include <dirent.h>
+#endif /* HAVE_DIRENT_H */
 #include <time.h>
 
 #include "opal/mca/mca.h"
 #include "opal/mca/base/base.h"
 
-#include "orte/util/show_help.h"
 #include "opal/mca/base/mca_base_param.h"
 #include "opal/util/os_dirpath.h"
 #include "opal/util/output.h"
 #include "opal/util/show_help.h"
 #include "opal/util/basename.h"
+#include "opal/util/argv.h"
 #include "opal/mca/crs/crs.h"
 #include "opal/mca/crs/base/base.h"
 
 #include "orte/mca/rml/rml.h"
+#include "orte/mca/rml/rml_types.h"
+#include "orte/mca/errmgr/errmgr.h"
 #include "orte/runtime/orte_globals.h"
 #include "orte/util/name_fns.h"
+#include "orte/mca/notifier/notifier.h"
 
 #include "orte/mca/snapc/snapc.h"
 #include "orte/mca/snapc/base/base.h"
@@ -66,27 +81,51 @@ size_t orte_snapc_base_snapshot_seq_number = 0;
 /******************
  * Object stuff
  ******************/
-OBJ_CLASS_INSTANCE(orte_snapc_base_snapshot_t,
-                   opal_crs_base_snapshot_t,
-                   orte_snapc_base_snapshot_construct,
-                   orte_snapc_base_snapshot_destruct);
+OBJ_CLASS_INSTANCE(orte_snapc_base_local_snapshot_t,
+                   opal_list_item_t,
+                   orte_snapc_base_local_snapshot_construct,
+                   orte_snapc_base_local_snapshot_destruct);
 
-void orte_snapc_base_snapshot_construct(orte_snapc_base_snapshot_t *snapshot)
+void orte_snapc_base_local_snapshot_construct(orte_snapc_base_local_snapshot_t *snapshot)
 {
     snapshot->process_name.jobid  = 0;
     snapshot->process_name.vpid   = 0;
-    snapshot->process_pid  = 0;
+
     snapshot->state = ORTE_SNAPC_CKPT_STATE_NONE;
-    snapshot->term  = false;
+
+    snapshot->reference_name  = NULL;
+    snapshot->local_location  = NULL;
+    snapshot->remote_location = NULL;
+
+    snapshot->opal_crs      = NULL;
 }
 
-void orte_snapc_base_snapshot_destruct( orte_snapc_base_snapshot_t *snapshot)
+void orte_snapc_base_local_snapshot_destruct( orte_snapc_base_local_snapshot_t *snapshot)
 {
     snapshot->process_name.jobid  = 0;
     snapshot->process_name.vpid   = 0;
-    snapshot->process_pid  = 0;
+
     snapshot->state = ORTE_SNAPC_CKPT_STATE_NONE;
-    snapshot->term  = false;
+
+    if( NULL != snapshot->reference_name ) {
+        free(snapshot->reference_name);
+        snapshot->reference_name = NULL;
+    }
+
+    if( NULL != snapshot->local_location ) {
+        free(snapshot->local_location);
+        snapshot->local_location = NULL;
+    }
+
+    if( NULL != snapshot->remote_location ) {
+        free(snapshot->remote_location);
+        snapshot->remote_location = NULL;
+    }
+
+    if( NULL != snapshot->opal_crs ) {
+        free(snapshot->opal_crs);
+        snapshot->opal_crs = NULL;
+    }
 }
 
 /****/
@@ -97,13 +136,18 @@ OBJ_CLASS_INSTANCE(orte_snapc_base_global_snapshot_t,
 
 void orte_snapc_base_global_snapshot_construct(orte_snapc_base_global_snapshot_t *snapshot)
 {
-    OBJ_CONSTRUCT(&(snapshot->snapshots), opal_list_t);
+    char *tmp_dir = NULL;
 
-    snapshot->component_name = NULL;
-    snapshot->reference_name = orte_snapc_base_unique_global_snapshot_name(getpid());
-    snapshot->local_location = opal_dirname(orte_snapc_base_get_global_snapshot_directory(snapshot->reference_name));
+    OBJ_CONSTRUCT(&(snapshot->local_snapshots), opal_list_t);
+
+    orte_snapc_base_unique_global_snapshot_name(&(snapshot->reference_name), getpid());
+
+    orte_snapc_base_get_global_snapshot_directory(&tmp_dir, snapshot->reference_name);
+    snapshot->local_location = opal_dirname(tmp_dir);
+    free(tmp_dir);
     
     snapshot->seq_num    = 0;
+
     snapshot->start_time = NULL;
     snapshot->end_time   = NULL;
 }
@@ -112,21 +156,16 @@ void orte_snapc_base_global_snapshot_destruct( orte_snapc_base_global_snapshot_t
 {
     opal_list_item_t* item = NULL;
 
-    while (NULL != (item = opal_list_remove_first(&snapshot->snapshots))) {
+    while (NULL != (item = opal_list_remove_first(&snapshot->local_snapshots))) {
         OBJ_RELEASE(item);
     }
-    OBJ_DESTRUCT(&(snapshot->snapshots));
+    OBJ_DESTRUCT(&(snapshot->local_snapshots));
 
     if(NULL != snapshot->reference_name) {
         free(snapshot->reference_name);
         snapshot->reference_name = NULL;
     }
 
-    if(NULL != snapshot->component_name) {
-        free(snapshot->component_name);
-        snapshot->component_name = NULL;
-    }
-
     if(NULL != snapshot->local_location) {
         free(snapshot->local_location);
         snapshot->local_location = NULL;
@@ -145,6 +184,58 @@ void orte_snapc_base_global_snapshot_destruct( orte_snapc_base_global_snapshot_t
     snapshot->seq_num = 0;
 }
 
+OBJ_CLASS_INSTANCE(orte_snapc_base_quiesce_t,
+                   opal_object_t,
+                   orte_snapc_base_quiesce_construct,
+                   orte_snapc_base_quiesce_destruct);
+
+void orte_snapc_base_quiesce_construct(orte_snapc_base_quiesce_t *quiesce)
+{
+    quiesce->epoch         = -1;
+    quiesce->snapshot      = NULL;
+    quiesce->handle        = NULL;
+    quiesce->target_dir    = NULL;
+    quiesce->crs_name      = NULL;
+    quiesce->cmdline       = NULL;
+    quiesce->cr_state      = OPAL_CRS_NONE;
+    quiesce->checkpointing = false;
+    quiesce->restarting    = false;
+
+}
+
+void orte_snapc_base_quiesce_destruct( orte_snapc_base_quiesce_t *quiesce)
+{
+    quiesce->epoch = -1;
+
+    if( NULL != quiesce->snapshot ) {
+        OBJ_RELEASE(quiesce->snapshot);
+        quiesce->snapshot      = NULL;
+    }
+
+    if( NULL != quiesce->handle ) {
+        free(quiesce->handle);
+        quiesce->handle = NULL;
+    }
+    if( NULL != quiesce->target_dir ) {
+        free(quiesce->target_dir);
+        quiesce->target_dir = NULL;
+    }
+    if( NULL != quiesce->crs_name ) {
+        free(quiesce->crs_name);
+        quiesce->crs_name = NULL;
+    }
+    if( NULL != quiesce->cmdline ) {
+        free(quiesce->cmdline);
+        quiesce->cmdline = NULL;
+    }
+
+    quiesce->cr_state      = OPAL_CRS_NONE;
+    quiesce->checkpointing = false;
+    quiesce->restarting    = false;
+
+}
+
+
 /***********************
  * None component stuff
  ************************/
@@ -196,6 +287,7 @@ int orte_snapc_base_none_setup_job(orte_jobid_t jobid)
                                                       ORTE_RML_PERSISTENT,
                                                       snapc_none_global_cmdline_request,
                                                       NULL))) {
+        ORTE_ERROR_LOG(rc);
         exit_status = rc;
         goto cleanup;
     }
@@ -218,6 +310,17 @@ int orte_snapc_base_none_ft_event(int state)
     return ORTE_SUCCESS;
 }
 
+int orte_snapc_base_none_start_ckpt(orte_snapc_base_quiesce_t *datum)
+{
+    return ORTE_SUCCESS;
+}
+
+int orte_snapc_base_none_end_ckpt(orte_snapc_base_quiesce_t *datum)
+{
+    return ORTE_SUCCESS;
+}
+
+
 /********************
  * Local Functions
  ********************/
@@ -231,11 +334,14 @@ static void snapc_none_global_cmdline_request(int status,
     int ret, exit_status = ORTE_SUCCESS;
     orte_snapc_cmd_flag_t command;
     orte_std_cntr_t n = 1;
-    bool term = false;
+    opal_crs_base_ckpt_options_t *options = NULL;
     orte_jobid_t jobid;
 
+    options = OBJ_NEW(opal_crs_base_ckpt_options_t);
+
     n = 1;
     if (ORTE_SUCCESS != (ret = opal_dss.unpack(buffer, &command, &n, ORTE_SNAPC_CMD))) {
+        ORTE_ERROR_LOG(ret);
         exit_status = ret;
         goto cleanup;
     }
@@ -248,7 +354,8 @@ static void snapc_none_global_cmdline_request(int status,
         /*
          * Do the basic handshake with the orte_checkpoint command
          */
-        if( ORTE_SUCCESS != (ret = orte_snapc_base_global_coord_ckpt_init_cmd(sender, buffer, &term, &jobid)) ) {
+        if( ORTE_SUCCESS != (ret = orte_snapc_base_global_coord_ckpt_init_cmd(sender, buffer, options, &jobid)) ) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -257,6 +364,7 @@ static void snapc_none_global_cmdline_request(int status,
          * Respond with an invalid response
          */
         if( ORTE_SUCCESS != (ret = orte_snapc_base_global_coord_ckpt_update_cmd(sender, NULL, -1, ORTE_SNAPC_CKPT_STATE_NO_CKPT)) ) {
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -269,15 +377,53 @@ static void snapc_none_global_cmdline_request(int status,
     }
     
  cleanup:
+    if( NULL != options ) {
+        OBJ_RELEASE(options);
+        options = NULL;
+    }
+
     return;
 }
 
 /********************
  * Utility functions
  ********************/
+
+/* Report the checkpoint status over the notifier interface */
+void orte_snapc_ckpt_state_notify(int state)
+{
+    switch(state) {
+    case ORTE_SNAPC_CKPT_STATE_FINISHED:
+	    orte_notifier.log(ORTE_NOTIFIER_INFO, ORTE_SNAPC_CKPT_NOTIFY(state),
+                          "%d: Checkpoint established for process %s.",
+			  orte_process_info.pid, ORTE_JOBID_PRINT(ORTE_PROC_MY_NAME->jobid));
+        break;
+    case ORTE_SNAPC_CKPT_STATE_NO_CKPT:
+        orte_notifier.log(ORTE_NOTIFIER_WARN, ORTE_SNAPC_CKPT_NOTIFY(state),
+                          "%d: Process %s is not checkpointable.",
+                          orte_process_info.pid, ORTE_JOBID_PRINT(ORTE_PROC_MY_NAME->jobid));
+        break;
+    case ORTE_SNAPC_CKPT_STATE_ERROR:
+        orte_notifier.log(ORTE_NOTIFIER_WARN, ORTE_SNAPC_CKPT_NOTIFY(state),
+                          "%d: Failed to checkpoint process %s.",
+                          orte_process_info.pid, ORTE_JOBID_PRINT(ORTE_PROC_MY_NAME->jobid));
+        break;
+    /* ADK: We currently do not notify for these states, but good to
+     * have them around anyways. */
+    case ORTE_SNAPC_CKPT_STATE_NONE:
+    case ORTE_SNAPC_CKPT_STATE_REQUEST:
+    case ORTE_SNAPC_CKPT_STATE_PENDING:
+    case ORTE_SNAPC_CKPT_STATE_RUNNING:
+    case ORTE_SNAPC_CKPT_STATE_STOPPED:
+    case ORTE_SNAPC_CKPT_STATE_FINISHED_LOCAL:
+    default:
+        break;
+    }
+}
+
 int orte_snapc_base_global_coord_ckpt_init_cmd(orte_process_name_t* peer,
                                                opal_buffer_t* buffer,
-                                               bool *term,
+                                               opal_crs_base_ckpt_options_t *options,
                                                orte_jobid_t *jobid)
 {
     int ret, exit_status = ORTE_SUCCESS;
@@ -301,39 +447,91 @@ int orte_snapc_base_global_coord_ckpt_init_cmd(orte_process_name_t* peer,
     /********************
      * Receive command line checkpoint request:
      * - Command (already received)
-     * - term flag
+     * - options
      * - jobid
      ********************/
-    count = 1;
-    if ( ORTE_SUCCESS != (ret = opal_dss.unpack(buffer, term, &count, OPAL_BOOL)) ) {
+    if( ORTE_SUCCESS != (ret = orte_snapc_base_unpack_options(buffer, options)) ) {
         opal_output(orte_snapc_base_output,
-                    "%s) base:ckpt_init_cmd: Error: DSS Unpack (term) Failure (ret = %d) (LINE = %d)\n",
-                    ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
-                    ret, __LINE__);
+                    "%s) base:ckpt_init_cmd: Error: Unpack (options) Failure (ret = %d)\n",
+                    ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type), ret );
+        ORTE_ERROR_LOG(ret);
         exit_status = ret;
         goto cleanup;
     }
-    
+
     count = 1;
     if ( ORTE_SUCCESS != (ret = opal_dss.unpack(buffer, jobid, &count, ORTE_JOBID)) ) {
         opal_output(orte_snapc_base_output,
                     "%s) base:ckpt_init_cmd: Error: DSS Unpack (jobid) Failure (ret = %d) (LINE = %d)\n",
                     ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                     ret, __LINE__);
+        ORTE_ERROR_LOG(ret);
         exit_status = ret;
         goto cleanup;
     }
 
     OPAL_OUTPUT_VERBOSE((10, orte_snapc_base_output,
-                         "%s) base:ckpt_init_cmd: Received [%d, %s]\n",
+                         "%s) base:ckpt_init_cmd: Received [%d, %d, %s]\n",
                          ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
-                         (int)*term,
+                         (int)(options->term),
+                         (int)(options->stop),
                          ORTE_JOBID_PRINT(*jobid)));
 
  cleanup:
     return exit_status;
 }
 
+int orte_snapc_base_unpack_options(opal_buffer_t* buffer,
+                                   opal_crs_base_ckpt_options_t *options)
+{
+    int ret, exit_status = ORTE_SUCCESS;
+    orte_std_cntr_t count = 1;
+
+    count = 1;
+    if ( ORTE_SUCCESS != (ret = opal_dss.unpack(buffer, &(options->term), &count, OPAL_BOOL)) ) {
+        opal_output(orte_snapc_base_output,
+                    "snapc:base:unpack_options: Error: Unpack (term) Failure (ret = %d)\n",
+                    ret);
+        ORTE_ERROR_LOG(ret);
+        exit_status = ret;
+        goto cleanup;
+    }
+
+    count = 1;
+    if ( ORTE_SUCCESS != (ret = opal_dss.unpack(buffer, &(options->stop), &count, OPAL_BOOL)) ) {
+        opal_output(orte_snapc_base_output,
+                    "snapc:base:unpack_options: Error: Unpack (stop) Failure (ret = %d)\n",
+                    ret);
+        ORTE_ERROR_LOG(ret);
+        exit_status = ret;
+        goto cleanup;
+    }
+    
+ cleanup:
+    return exit_status;
+}
+
+int orte_snapc_base_pack_options(opal_buffer_t* buffer,
+                                 opal_crs_base_ckpt_options_t *options)
+{
+    int ret, exit_status = ORTE_SUCCESS;
+
+    if (ORTE_SUCCESS != (ret = opal_dss.pack(buffer, &(options->term), 1, OPAL_BOOL))) {
+        ORTE_ERROR_LOG(ret);
+        exit_status = ret;
+        goto cleanup;
+    }
+
+    if (ORTE_SUCCESS != (ret = opal_dss.pack(buffer, &(options->stop), 1, OPAL_BOOL))) {
+        ORTE_ERROR_LOG(ret);
+        exit_status = ret;
+        goto cleanup;
+    }
+
+ cleanup:
+    return exit_status;
+}
+
 int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
                                                  char *global_snapshot_handle,
                                                  int seq_num,
@@ -343,6 +541,15 @@ int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
     opal_buffer_t *loc_buffer = NULL;
     orte_snapc_cmd_flag_t command = ORTE_SNAPC_GLOBAL_UPDATE_CMD;
 
+    /*
+     * Noop if invalid peer, or peer not specified (JJH Double check this)
+     */
+    if( NULL == peer ||
+        OPAL_EQUAL == orte_util_compare_name_fields(ORTE_NS_CMP_ALL, ORTE_NAME_INVALID, peer) ) {
+        /*return ORTE_ERR_BAD_PARAM;*/
+        return ORTE_SUCCESS;
+    }
+
     /*
      * Do not send to self, as that is silly.
      */
@@ -354,6 +561,11 @@ int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
         return ORTE_SUCCESS;
     }
 
+    /*
+     * Pass on the checkpoint state over the notifier interface.
+     */
+    orte_snapc_ckpt_state_notify(ckpt_status);
+
     OPAL_OUTPUT_VERBOSE((10, orte_snapc_base_output,
                          "%s) base:ckpt_update_cmd: Sending update command <%s> <seq %d> <status %d>\n",
                          ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
@@ -371,6 +583,7 @@ int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
     }
 
     if (ORTE_SUCCESS != (ret = opal_dss.pack(loc_buffer, &command, 1, ORTE_SNAPC_CMD)) ) {
+        ORTE_ERROR_LOG(ret);
         exit_status = ret;
         goto cleanup;
     }
@@ -380,17 +593,20 @@ int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
                     "%s) base:ckpt_update_cmd: Error: DSS Pack (ckpt_status) Failure (ret = %d) (LINE = %d)\n",
                     ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                     ret, __LINE__);
+        ORTE_ERROR_LOG(ret);
         exit_status = ret;
         goto cleanup;
     }
 
     if( ORTE_SNAPC_CKPT_STATE_FINISHED == ckpt_status ||
+        ORTE_SNAPC_CKPT_STATE_STOPPED  == ckpt_status ||
         ORTE_SNAPC_CKPT_STATE_ERROR    == ckpt_status ) {
         if (ORTE_SUCCESS != (ret = opal_dss.pack(loc_buffer, &global_snapshot_handle, 1, OPAL_STRING))) {
             opal_output(orte_snapc_base_output,
                         "%s) base:ckpt_update_cmd: Error: DSS Pack (snapshot handle) Failure (ret = %d) (LINE = %d)\n",
                         ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                         ret, __LINE__);
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -399,6 +615,7 @@ int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
                         "%s) base:ckpt_update_cmd: Error: DSS Pack (seq number) Failure (ret = %d) (LINE = %d)\n",
                         ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                         ret, __LINE__);
+            ORTE_ERROR_LOG(ret);
             exit_status = ret;
             goto cleanup;
         }
@@ -409,6 +626,7 @@ int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
                     "%s) base:ckpt_update_cmd: Error: Send (ckpt_status) Failure (ret = %d) (LINE = %d)\n",
                     ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                     ret, __LINE__);
+        ORTE_ERROR_LOG(ret);
         exit_status = ret;
         goto cleanup;
     }
@@ -431,42 +649,172 @@ int orte_snapc_base_global_coord_ckpt_update_cmd(orte_process_name_t* peer,
 /*****************************
  * Snapshot metadata functions
  *****************************/
-char * orte_snapc_base_unique_global_snapshot_name(pid_t pid)
+int orte_snapc_base_get_all_snapshot_refs(char *base_dir, int *num_refs, char ***snapshot_refs)
 {
-    char * uniq_name;
+#ifndef HAVE_DIRENT_H
+    return ORTE_ERR_NOT_SUPPORTED;
+#else
+    int ret, exit_status = ORTE_SUCCESS;
+    char * tmp_str = NULL, * metadata_file = NULL;
+    DIR *dirp = NULL;
+    struct dirent *dir_entp = NULL;
+    struct stat file_status;
 
-    if( NULL == orte_snapc_base_global_snapshot_ref ) {
-        asprintf(&uniq_name, "ompi_global_snapshot_%d.ckpt", pid);
+    if( NULL == base_dir ) {
+        if( NULL == orte_snapc_base_global_snapshot_dir ) {
+            exit_status = ORTE_ERROR;
+            goto cleanup;
+        }
+        base_dir = strdup(orte_snapc_base_global_snapshot_dir);
     }
-    else {
-        uniq_name = strdup(orte_snapc_base_global_snapshot_ref);
+
+    /*
+     * Get all subdirectories under the base directory
+     */
+    dirp = opendir(base_dir);
+    while( NULL != (dir_entp = readdir(dirp))) {
+        /* Skip "." and ".." if they are in the list */
+        if( 0 == strncmp("..", dir_entp->d_name, strlen("..") ) ||
+            0 == strncmp(".",  dir_entp->d_name, strlen(".")  ) ) {
+            continue;
+        }
+
+        /* Add the full path */
+        asprintf(&tmp_str, "%s/%s", base_dir, dir_entp->d_name);
+        if(0 != (ret = stat(tmp_str, &file_status) ) ){
+            free( tmp_str);
+            tmp_str = NULL;
+            continue;
+        } else {
+            /* Is it a directory? */
+            if(S_ISDIR(file_status.st_mode) ) {
+                asprintf(&metadata_file, "%s/%s",
+                         tmp_str,
+                         orte_snapc_base_metadata_filename);
+                if(0 != (ret = stat(metadata_file, &file_status) ) ){
+                    free( tmp_str);
+                    tmp_str = NULL;
+                    free( metadata_file);
+                    metadata_file = NULL;
+                    continue;
+                } else {
+                    if(S_ISREG(file_status.st_mode) ) {
+                        opal_argv_append(num_refs, snapshot_refs, dir_entp->d_name);
+                    }
+                }
+                free( metadata_file);
+                metadata_file = NULL;
+            }
+        }
+
+        free( tmp_str);
+        tmp_str = NULL;
     }
     
-    return uniq_name;
+    closedir(dirp);
+
+ cleanup:
+    if( NULL != tmp_str) {
+        free( tmp_str);
+        tmp_str = NULL;
+    }
+
+    return exit_status;
+#endif /* HAVE_DIRENT_H */
 }
 
-char * orte_snapc_base_get_global_snapshot_metadata_file(char *uniq_snapshot_name)
+int orte_snapc_base_get_all_snapshot_ref_seqs(char *base_dir, char *snapshot_name, int *num_seqs, int **snapshot_ref_seqs)
 {
-    char * path = NULL;
+    int exit_status = ORTE_SUCCESS;
+    char * metadata_file = NULL;
+    FILE * meta_data = NULL;
+    int s, next_seq_int;
+
+    if( NULL == base_dir ) {
+        if( NULL == orte_snapc_base_global_snapshot_dir ) {
+            exit_status = ORTE_ERROR;
+            goto cleanup;
+        }
+        base_dir = strdup(orte_snapc_base_global_snapshot_dir);
+    }
+
+    asprintf(&metadata_file, "%s/%s/%s",
+             base_dir,
+             snapshot_name,
+             orte_snapc_base_metadata_filename);
+
+
+    if (NULL == (meta_data = fopen(metadata_file, "r")) ) {
+        opal_output(0, "Error: Unable to open the file <%s>\n", metadata_file);
+        exit_status = ORTE_ERROR;
+        goto cleanup;
+    }
+
+    /* First pass to count the number of sequence numbers */
+    *num_seqs = 0;
+    while(0 <= (next_seq_int = get_next_valid_seq_number(meta_data)) ){
+        *num_seqs += 1;
+    }
+
+    /* If there are no valid seq numbers then just return here */
+    if( 0 == *num_seqs ) {
+        exit_status = ORTE_SUCCESS;
+        goto cleanup;
+    }
+
+    rewind(meta_data);
+
+    /* Second pass to add them to the list */
+    (*snapshot_ref_seqs) = (int *) malloc(sizeof(int) * (*num_seqs));
+    s = 0;
+    while(0 <= (next_seq_int = get_next_valid_seq_number(meta_data)) ){
+        (*snapshot_ref_seqs)[s] = next_seq_int;
+        ++s;
+    }
+
+ cleanup:
+    if(NULL != meta_data) {
+        fclose(meta_data);
+        meta_data = NULL;
+    }
+    if(NULL != metadata_file) {
+        free(metadata_file);
+        metadata_file = NULL;
+    }
+
+    return exit_status;
+}
+
+int orte_snapc_base_unique_global_snapshot_name(char **name_str, pid_t pid)
+{
+    if( NULL == orte_snapc_base_global_snapshot_ref ) {
+        asprintf(name_str, "ompi_global_snapshot_%d.ckpt", pid);
+    }
+    else {
+        *name_str = strdup(orte_snapc_base_global_snapshot_ref);
+    }
     
-    asprintf(&path, "%s/%s/%s",
+    return ORTE_SUCCESS;
+}
+
+int orte_snapc_base_get_global_snapshot_metadata_file(char **file_name, char *uniq_snapshot_name)
+{
+    asprintf(file_name, "%s/%s/%s",
              orte_snapc_base_global_snapshot_dir,
              uniq_snapshot_name,
              orte_snapc_base_metadata_filename);
     
-    return path;
+    return ORTE_SUCCESS;
 }
 
-char * orte_snapc_base_get_global_snapshot_directory(char *uniq_snapshot_name)
+int orte_snapc_base_get_global_snapshot_directory(char **dir_name, char *uniq_snapshot_name)
 {
-    char * dir_name = NULL;
-    
-    asprintf(&dir_name, "%s/%s/%d", 
+    asprintf(dir_name, "%s/%s/%d", 
              orte_snapc_base_global_snapshot_dir, 
              uniq_snapshot_name,
              (int)orte_snapc_base_snapshot_seq_number);
 
-    return dir_name;
+    return ORTE_SUCCESS;
 }
 
 int orte_snapc_base_init_global_snapshot_directory(char *uniq_global_snapshot_name, bool empty_metadata)
@@ -480,8 +828,9 @@ int orte_snapc_base_init_global_snapshot_directory(char *uniq_global_snapshot_na
     /*
      * Make the snapshot directory from the uniq_global_snapshot_name
      */
-    dir_name = orte_snapc_base_get_global_snapshot_directory(uniq_global_snapshot_name);
+    orte_snapc_base_get_global_snapshot_directory(&dir_name, uniq_global_snapshot_name);
     if(OPAL_SUCCESS != (ret = opal_os_dirpath_create(dir_name, my_mode)) ) {
+        ORTE_ERROR_LOG(ret);
         exit_status = ret;
         goto cleanup;
     }
@@ -489,13 +838,14 @@ int orte_snapc_base_init_global_snapshot_directory(char *uniq_global_snapshot_na
     /*
      * Initialize the metadata file at the top of that directory.
      */
-    meta_data_fname = orte_snapc_base_get_global_snapshot_metadata_file(uniq_global_snapshot_name);
+    orte_snapc_base_get_global_snapshot_metadata_file(&meta_data_fname, uniq_global_snapshot_name);
 
     if (NULL == (meta_data = fopen(meta_data_fname, "a")) ) {
         opal_output(orte_snapc_base_output,
                     "%s) base:init_global_snapshot_directory: Error: Unable to open the file (%s)\n",
                     ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                     meta_data_fname);
+        ORTE_ERROR_LOG(ORTE_ERROR);
         exit_status = ORTE_ERROR;
         goto cleanup;
     }
@@ -527,7 +877,7 @@ int orte_snapc_base_init_global_snapshot_directory(char *uniq_global_snapshot_na
     if(NULL != meta_data_fname)
         free(meta_data_fname);
 
-    return OPAL_SUCCESS;
+    return ORTE_SUCCESS;
 }
 
 /*
@@ -573,13 +923,14 @@ int orte_snapc_base_add_timestamp(char * global_snapshot_ref)
     char * meta_data_fname = NULL;
     time_t timestamp;
 
-    meta_data_fname = orte_snapc_base_get_global_snapshot_metadata_file(global_snapshot_ref);
+    orte_snapc_base_get_global_snapshot_metadata_file(&meta_data_fname, global_snapshot_ref);
 
     if (NULL == (meta_data = fopen(meta_data_fname, "a")) ) {
         opal_output(orte_snapc_base_output,
                     "%s) base:add_timestamp: Error: Unable to open the file (%s)\n",
                     ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                     meta_data_fname);
+        ORTE_ERROR_LOG(ORTE_ERROR);
         exit_status = ORTE_ERROR;
         goto cleanup;
     }
@@ -605,13 +956,14 @@ int orte_snapc_base_finalize_metadata(char * global_snapshot_ref)
     /* Add the final timestamp */
     orte_snapc_base_add_timestamp(global_snapshot_ref);
 
-    meta_data_fname = orte_snapc_base_get_global_snapshot_metadata_file(global_snapshot_ref);
+    orte_snapc_base_get_global_snapshot_metadata_file(&meta_data_fname, global_snapshot_ref);
 
     if (NULL == (meta_data = fopen(meta_data_fname, "a")) ) {
         opal_output(orte_snapc_base_output,
                     "%s) base:add_timestamp: Error: Unable to open the file (%s)\n",
                     ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                     meta_data_fname);
+        ORTE_ERROR_LOG(ORTE_ERROR);
         exit_status = ORTE_ERROR;
         goto cleanup;
     }
@@ -631,23 +983,29 @@ int orte_snapc_base_finalize_metadata(char * global_snapshot_ref)
 int orte_snapc_base_add_vpid_metadata( orte_process_name_t *proc,
                                        char * global_snapshot_ref,
                                        char *snapshot_ref,
-                                       char *snapshot_location)
+                                       char *snapshot_location,
+                                       char *crs_agent)
 {
     int ret, exit_status = ORTE_SUCCESS;
     FILE * meta_data = NULL;
     char * meta_data_fname = NULL;
     char * crs_comp = NULL;
-    char * local_dir = NULL;
     char * proc_name = NULL;
+    char * local_snapshot = NULL;
     int prev_pid = 0;
 
-    meta_data_fname = orte_snapc_base_get_global_snapshot_metadata_file(global_snapshot_ref);
+    if( NULL == snapshot_location ) {
+        return ORTE_ERROR;
+    }
+
+    orte_snapc_base_get_global_snapshot_metadata_file(&meta_data_fname, global_snapshot_ref);
 
     if (NULL == (meta_data = fopen(meta_data_fname, "a")) ) {
         opal_output(orte_snapc_base_output,
                     "%s) base:add_metadata: Error: Unable to open the file (%s)\n",
                     ORTE_SNAPC_COORD_NAME_PRINT(orte_snapc_coord_type),
                     meta_data_fname);
+        ORTE_ERROR_LOG(ORTE_ERROR);
         exit_status = ORTE_ERROR;
         goto cleanup;
     }
@@ -661,22 +1019,23 @@ int orte_snapc_base_add_vpid_metadata( orte_process_name_t *proc,
     orte_util_convert_process_name_to_string(&proc_name, proc);
 
     /* Extract the checkpointer */
-    if( OPAL_SUCCESS != (ret = opal_crs_base_extract_expected_component(snapshot_location, &crs_comp, &prev_pid)) ) {
-        opal_show_help("help-orte-snapc-base.txt", "invalid_metadata", true,
-                       proc_name, opal_crs_base_metadata_filename, snapshot_location);
-        exit_status = ret;
-        goto cleanup;
+    if( NULL == crs_agent ) {
+        asprintf(&local_snapshot, "%s/%s", snapshot_location, snapshot_ref);
+        if( OPAL_SUCCESS != (ret = opal_crs_base_extract_expected_component(local_snapshot, &crs_comp, &prev_pid)) ) {
+            opal_show_help("help-orte-snapc-base.txt", "invalid_metadata", true,
+                           proc_name, opal_crs_base_metadata_filename, local_snapshot);
+            exit_status = ret;
+            goto cleanup;
+        }
+    } else {
+        crs_comp = strdup(crs_agent);
     }
 
-    /* get the base of the location */
-    local_dir = strdup(snapshot_location);
-    local_dir = opal_dirname(local_dir);
-
     /* Write the string */
     fprintf(meta_data, "%s%s\n", SNAPC_METADATA_PROCESS,   proc_name);
     fprintf(meta_data, "%s%s\n", SNAPC_METADATA_CRS_COMP,  crs_comp);
     fprintf(meta_data, "%s%s\n", SNAPC_METADATA_SNAP_REF,  snapshot_ref);
-    fprintf(meta_data, "%s%s\n", SNAPC_METADATA_SNAP_LOC,  local_dir);
+    fprintf(meta_data, "%s%s\n", SNAPC_METADATA_SNAP_LOC,  snapshot_location);
 
  cleanup:
     if( NULL != meta_data ) {
@@ -687,11 +1046,11 @@ int orte_snapc_base_add_vpid_metadata( orte_process_name_t *proc,
         free(meta_data_fname);
         meta_data_fname = NULL;
     }
-    if( NULL != local_dir) {
-        free(local_dir);
-        local_dir = NULL;
+    if( NULL != local_snapshot ) {
+        free( local_snapshot );
+        local_snapshot = NULL;
     }
-
+    
     return exit_status;
 }
 
@@ -703,13 +1062,14 @@ int orte_snapc_base_extract_metadata(orte_snapc_base_global_snapshot_t *global_s
     int    next_seq_int;
     char * token = NULL;
     char * value = NULL;
-    orte_snapc_base_snapshot_t *vpid_snapshot = NULL;
+    orte_snapc_base_local_snapshot_t *vpid_snapshot = NULL;
 
     /*
      * Open the metadata file
      */
-    meta_data_fname = orte_snapc_base_get_global_snapshot_metadata_file(global_snapshot->reference_name);
+    orte_snapc_base_get_global_snapshot_metadata_file(&meta_data_fname, global_snapshot->reference_name);
     if (NULL == (meta_data = fopen(meta_data_fname, "r")) ) {
+        ORTE_ERROR_LOG(ORTE_ERROR);
         exit_status = ORTE_ERROR;
         goto cleanup;
     }
@@ -761,29 +1121,29 @@ int orte_snapc_base_extract_metadata(orte_snapc_base_global_snapshot_t *global_s
 
             /* Not the first process, so append it to the list */
             if( NULL != vpid_snapshot) {
-                opal_list_append(&global_snapshot->snapshots, &(vpid_snapshot->crs_snapshot_super.super));
+                opal_list_append(&global_snapshot->local_snapshots, &(vpid_snapshot->super));
             }
 
-            vpid_snapshot = OBJ_NEW(orte_snapc_base_snapshot_t);
+            vpid_snapshot = OBJ_NEW(orte_snapc_base_local_snapshot_t);
 
             vpid_snapshot->process_name.jobid  = proc.jobid;
             vpid_snapshot->process_name.vpid   = proc.vpid;
         }
         else if(0 == strncmp(SNAPC_METADATA_CRS_COMP, token, strlen(SNAPC_METADATA_CRS_COMP)) ) {
-            vpid_snapshot->crs_snapshot_super.component_name = strdup(value);
+            vpid_snapshot->opal_crs = strdup(value);
         }
         else if(0 == strncmp(SNAPC_METADATA_SNAP_REF, token, strlen(SNAPC_METADATA_SNAP_REF)) ) {
-            vpid_snapshot->crs_snapshot_super.reference_name = strdup(value);
+            vpid_snapshot->reference_name = strdup(value);
         }
         else if(0 == strncmp(SNAPC_METADATA_SNAP_LOC, token, strlen(SNAPC_METADATA_SNAP_LOC)) ) {
-            vpid_snapshot->crs_snapshot_super.local_location  = strdup(value);
-            vpid_snapshot->crs_snapshot_super.remote_location = strdup(value);
+            vpid_snapshot->local_location  = strdup(value);
+            vpid_snapshot->remote_location = strdup(value);
         }
     } while(0 == feof(meta_data) );
     
     /* Append the last item */
     if( NULL != vpid_snapshot) {
-        opal_list_append(&global_snapshot->snapshots, &(vpid_snapshot->crs_snapshot_super.super));
+        opal_list_append(&global_snapshot->local_snapshots, &(vpid_snapshot->super));
     }
     
  cleanup:
@@ -965,34 +1325,40 @@ static int metadata_extract_next_token(FILE *file, char **token, char **value)
     return exit_status;
 }
 
-char * orte_snapc_ckpt_state_str(size_t state)
+int orte_snapc_ckpt_state_str(char ** state_str, int state)
 {
     switch(state) {
     case ORTE_SNAPC_CKPT_STATE_NONE:
-        return strdup(" -- ");
+        *state_str = strdup(" -- ");
         break;
     case ORTE_SNAPC_CKPT_STATE_REQUEST:
-        return strdup("Requested");
-        break;
-    case ORTE_SNAPC_CKPT_STATE_PENDING_TERM:
-        return strdup("Pending (Termination)");
+        *state_str = strdup("Requested");
         break;
     case ORTE_SNAPC_CKPT_STATE_PENDING:
-        return strdup("Pending");
+        *state_str = strdup("Pending");
         break;
     case ORTE_SNAPC_CKPT_STATE_RUNNING:
-        return strdup("Running");
+        *state_str = strdup("Running");
+        break;
+    case ORTE_SNAPC_CKPT_STATE_STOPPED:
+        *state_str = strdup("Stopped");
         break;
     case ORTE_SNAPC_CKPT_STATE_FILE_XFER:
-        return strdup("File Transfer");
+        *state_str = strdup("File Transfer");
         break;
     case ORTE_SNAPC_CKPT_STATE_FINISHED:
-        return strdup("Finished");
+        *state_str = strdup("Finished");
+        break;
+    case ORTE_SNAPC_CKPT_STATE_FINISHED_LOCAL:
+        *state_str = strdup("Locally Finished");
         break;
     case ORTE_SNAPC_CKPT_STATE_ERROR:
-        return strdup("Error");
+        *state_str = strdup("Error");
         break;
     default:
-        return strdup("Unknown");
+        asprintf(state_str, "Unknown %d", state);
+        break;
     }
+
+    return ORTE_SUCCESS;
 }
