@@ -11,6 +11,8 @@
  *                         All rights reserved.
  * Copyright (c) 2007-2009 Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2009-2011 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c)      2011 Los Alamos National Security, LLC.  All rights
+ *                         reserved. 
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -77,12 +79,18 @@ char **orte_launch_environ;
 
 bool orte_hnp_is_allocated = false;
 bool orte_allocation_required;
+bool orte_managed_allocation = false;
 
 char *orte_launch_agent = NULL;
 char **orted_cmd_line=NULL;
 
 /* debugger job */
 orte_job_t *orte_debugger_daemon=NULL;
+bool orte_debugger_dump_proctable;
+char *orte_debugger_test_daemon;
+bool orte_debugger_test_attach;
+bool orte_debugger_enable_fifo_attach;
+int orte_debugger_check_rate;
 
 /* exit triggers and flags */ 
 orte_trigger_event_t orte_exit, orteds_exit;
@@ -146,7 +154,6 @@ uint8_t orte_default_num_sockets_per_board;
 uint8_t orte_default_num_cores_per_socket;
 
 /* allocation specification */
-char *orte_default_cpu_set;
 char *orte_default_hostfile = NULL;
 char *orte_rankfile;
 #ifdef __WINDOWS__
@@ -174,7 +181,7 @@ bool orte_xml_output = false;
 FILE *orte_xml_fp = NULL;
 char *orte_job_ident = NULL;
 
-/* See comment in orte/mca/debugger/mpir/mpir.c about this MCA
+/* See comment in orte/tools/orterun/orterun.c about this MCA
    param */
 bool orte_in_parallel_debugger = false;
 
@@ -710,11 +717,6 @@ static void orte_node_construct(orte_node_t* node)
     node->boards = orte_default_num_boards;
     node->sockets_per_board = orte_default_num_sockets_per_board;
     node->cores_per_socket = orte_default_num_cores_per_socket;
-    if (NULL != orte_default_cpu_set) {
-        node->cpu_set = strdup(orte_default_cpu_set);
-    } else {
-        node->cpu_set = NULL;
-    }
     
     node->username = NULL;
     
@@ -751,10 +753,6 @@ static void orte_node_destruct(orte_node_t* node)
     }
     OBJ_RELEASE(node->procs);
     
-    if (NULL != node->cpu_set) {
-        free(node->cpu_set);
-        node->cpu_set = NULL;
-    }
     if (NULL != node->username) {
         free(node->username);
         node->username = NULL;
