@@ -11,6 +11,8 @@
  *                         All rights reserved.
  * Copyright (c) 2007      Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2009-2011 Oracle and/or its affiliates.  All rights reserved.
+ * Copyright (c)      2011 Los Alamos National Security, LLC.  All rights
+ *                         reserved. 
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -29,6 +31,7 @@
 
 #include "opal/mca/base/mca_base_param.h"
 #include "opal/mca/paffinity/base/base.h"
+#include "opal/mca/installdirs/installdirs.h"
 #include "opal/util/output.h"
 #include "opal/util/argv.h"
 
@@ -113,7 +116,7 @@ int orte_register_params(void)
                                 false, false, (int)false, &value);
     orte_leave_session_attached = OPAL_INT_TO_BOOL(value);
     
-    /* See comment in mca/debugger/mpir/mpir.c about this MCA
+    /* See comment in orte/tools/orterun/orterun.c about this MCA
        param (this param is internal) */
     mca_base_param_reg_int_name("orte",
                                 "in_parallel_debugger",
@@ -122,6 +125,27 @@ int orte_register_params(void)
                                 true, false, 0, &value);
     orte_in_parallel_debugger = OPAL_INT_TO_BOOL(value);
     
+    mca_base_param_reg_int_name("orte",
+                                "output_debugger_proctable",
+                                "Whether or not to output the debugger proctable after launch (default: false)",
+                                false, false, 0, &value);
+    orte_debugger_dump_proctable = OPAL_INT_TO_BOOL(value);
+
+    mca_base_param_reg_string_name("orte", "debugger_test_daemon",
+                                   "Name of the executable to be used to simulate a debugger colaunch (relative or absolute path)",
+                                   false, false, NULL, &orte_debugger_test_daemon);
+
+    mca_base_param_reg_int_name("orte",
+                                "debugger_test_attach",
+                                "Test debugger colaunch after debugger attachment",
+                                false, false, 0, &value);
+    orte_debugger_test_attach = OPAL_INT_TO_BOOL(value);
+
+    mca_base_param_reg_int_name("orte",
+                                "debugger_check_rate",
+                                "Set rate (in secs) for auto-detect of debugger attachment (0 => do not check)",
+                                false, false, 0, &orte_debugger_check_rate);
+
     mca_base_param_reg_int_name("orte", "do_not_launch",
                                 "Perform all necessary operations to prepare to launch the application, but do not actually launch it",
                                 false, false, (int)false, &value);
@@ -201,9 +225,15 @@ int orte_register_params(void)
                                 false, false, 1000, &orte_timeout_usec_per_proc);
     
     /* default hostfile */
+    asprintf(&orte_default_hostfile, "%s/openmpi-default-hostfile", opal_install_dirs.sysconfdir);
     mca_base_param_reg_string_name("orte", "default_hostfile",
-                                   "Name of the default hostfile (relative or absolute path)",
-                                   false, false, NULL, &orte_default_hostfile);
+                                   "Name of the default hostfile (relative or absolute path, \"none\" to ignore environmental or default MCA param setting)",
+                                   false, false, orte_default_hostfile, &orte_default_hostfile);
+    if (0 == strcmp(orte_default_hostfile, "none")) {
+        free(orte_default_hostfile);
+        orte_default_hostfile = NULL;
+    }
+
     /* rankfile */
     tmp = mca_base_param_reg_string_name("orte", "rankfile",
                                          "Name of the rankfile to be used for mapping processes (relative or absolute path)",
@@ -369,11 +399,6 @@ int orte_register_params(void)
                                 false, false, 0, &value);
     orte_default_num_cores_per_socket = (uint8_t)value;
     
-    /* cpu allocation specification */
-    mca_base_param_reg_string_name("orte", "cpu_set",
-                                   "Comma-separated list of ranges specifying logical cpus allocated to this job [default: none]",
-                                   false, false, NULL, &orte_default_cpu_set);
-    
     /* binding specification - this will be overridden by any cmd line directive, and
      * ignored unless opal_paffinity_alone is set
      */
