@@ -9,7 +9,7 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2007      Los Alamos National Security, LLC.  All rights
+ * Copyright (c) 2007-2012 Los Alamos National Security, LLC.  All rights
  *                         reserved. 
  * $COPYRIGHT$
  *
@@ -365,13 +365,6 @@ static int hostfile_parse_line(int token, opal_list_t* updates, opal_list_t* exc
             node->cores_per_socket = rc;
             break;
 
-        case ORTE_HOSTFILE_CPU_SET:
-            if (NULL != node->cpu_set) {
-                free(node->cpu_set);
-            }
-            node->cpu_set = hostfile_parse_string();
-            break;
-                
         case ORTE_HOSTFILE_COUNT:
         case ORTE_HOSTFILE_CPU:
         case ORTE_HOSTFILE_SLOTS:
@@ -594,7 +587,8 @@ int orte_util_filter_hostfile_nodes(opal_list_t *nodes,
     int num_empty, nodeidx;
     bool want_all_empty = false;
     opal_list_t keep;
-    
+    bool found;
+
     OPAL_OUTPUT_VERBOSE((1, orte_debug_output,
                         "%s hostfile: filtering nodes through hostfile %s",
                         ORTE_NAME_PRINT(ORTE_PROC_MY_NAME), hostfile));
@@ -604,9 +598,17 @@ int orte_util_filter_hostfile_nodes(opal_list_t *nodes,
     OBJ_CONSTRUCT(&exclude, opal_list_t);
     if (ORTE_SUCCESS != (rc = hostfile_parse(hostfile, &newnodes, &exclude, false))) {
         OBJ_DESTRUCT(&newnodes);
+        OBJ_DESTRUCT(&exclude);
         return rc;
     }
     
+    /* if the hostfile was empty, then treat it as a no-op filter */
+    if (0 == opal_list_get_size(&newnodes)) {
+        OBJ_DESTRUCT(&newnodes);
+        OBJ_DESTRUCT(&exclude);
+        return ORTE_SUCCESS;
+    }
+
     /* remove from the list of newnodes those that are in the exclude list
      * since we could have added duplicate names above due to the */
     while (NULL != (item1 = opal_list_remove_first(&exclude))) {
@@ -726,6 +728,7 @@ int orte_util_filter_hostfile_nodes(opal_list_t *nodes,
              * search the provided list of nodes to see if this
              * one is found
              */
+            found = false;
             for (item1 = opal_list_get_first(nodes);
                  item1 != opal_list_get_end(nodes);
                  item1 = opal_list_get_next(item1)) {
@@ -749,9 +752,21 @@ int orte_util_filter_hostfile_nodes(opal_list_t *nodes,
                     opal_list_remove_item(nodes, item1);
                     /* xfer it to keep list */
                     opal_list_append(&keep, item1);
+                    /* mark as found */
+                    found = true;
                     break;
                 }
             }
+            /* if the host in the newnode list wasn't found,
+             * then that is an error we need to report to the
+             * user and abort
+             */
+            if (!found) {
+                orte_show_help("help-hostfile.txt", "hostfile:extra-node-not-found",
+                               true, hostfile, node_from_file->name);
+                rc = ORTE_ERR_SILENT;
+                goto cleanup;
+            }
         }
         /* cleanup the newnode list */
         OBJ_RELEASE(item2);
