@@ -76,5 +76,7 @@ extern orte_hostfile_value_t  orte_util_hostfile_value;
 #define ORTE_HOSTFILE_SOCKETS_PER_BOARD     18
 #define ORTE_HOSTFILE_CORES_PER_SOCKET      19
 #define ORTE_HOSTFILE_CPU_SET               20
+/* ensure we can handle a rank_file input */
+#define ORTE_HOSTFILE_RANK                  21
 
 #endif
